-- Pays (codePays, nomP)
-- Sport (sid, nomS)
-- Epreuve (epid, sid*, nomEp, categorie, dateDebut, dateFin)    
-- Athlete (aid, nomAth, prenomAth, dateNaissance, codePays*)
-- Equipe (eqid*, codePays*)
-- AthletesEquipe(eqid*, aid*)
-- RangIndividuel (epid*, aid*, rang)
-- RangEquipe (epid*, eqid*, rang)

DROP TABLE RangEquipe PURGE IF EXISTS;
DROP TABLE RangIndividuel PURGE IF EXISTS;
DROP TABLE AthletesEquipe PURGE IF EXISTS;
DROP TABLE Equipe PURGE IF EXISTS;
DROP TABLE Epreuve PURGE IF EXISTS;
DROP TABLE Athlete PURGE IF EXISTS;
DROP TABLE Sport PURGE IF EXISTS;
DROP TABLE Pays PURGE IF EXISTS;

CREATE TABLE Pays (
    codePays VARCHAR2(4) PRIMARY KEY,
    nomP VARCHAR2(100)
);

CREATE TABLE Sport  (
    sid INT PRIMARY KEY,
    nomSp VARCHAR2(50)
);

CREATE TABLE Athlete (
    aid INT PRIMARY KEY,
    nomAth VARCHAR2(50),
    prenomAth VARCHAR2(50),
    dateNaissance DATE,
    codePays VARCHAR2(4),

    FOREIGN KEY (codePays) REFERENCES Pays(codePays)
);

CREATE TABLE Epreuve (
    epid INT PRIMARY KEY,
    sid INT,
    nomEp VARCHAR2(50),
    categorie VARCHAR2(6),
    dateDebut DATE,
    dateFin DATE,

    CHECK (categorie IN ('Hommes', 'Femmes', 'Mixte')),
    FOREIGN KEY (sid) REFERENCES Sport(sid)
);

CREATE TABLE Equipe (
    eqid INT,
    codePays VARCHAR2(4),

    PRIMARY KEY (eqid),
    FOREIGN KEY (codePays) REFERENCES Pays(codePays)
);

CREATE TABLE AthletesEquipe (
    eqid INT,
    aid INT,

    PRIMARY KEY (eqid, aid),
    FOREIGN KEY (eqid) REFERENCES Equipe(eqid),
    FOREIGN KEY (aid) REFERENCES Athlete(aid)
);

CREATE TABLE RangIndividuel (
    epid INT,
    aid INT,
    rang INT,

    PRIMARY KEY(epid, aid),
    FOREIGN KEY (epid) REFERENCES Epreuve(epid),
    FOREIGN KEY (aid) REFERENCES Athlete(aid)
);

CREATE TABLE RangEquipe (
    epid INT,
    eqid INT,
    rang INT,

    PRIMARY KEY(epid, eqid),
    FOREIGN KEY (epid) REFERENCES Epreuve(epid),
    FOREIGN KEY (eqid) REFERENCES Equipe(eqid)
);



INSERT INTO Pays VALUES ('AFG','Afghanistan');
INSERT INTO Pays VALUES ('ALB','Albanie');
INSERT INTO Pays VALUES ('ALG','Algérie');
INSERT INTO Pays VALUES ('AND','Andorre');
INSERT INTO Pays VALUES ('ANG','Angola');
INSERT INTO Pays VALUES ('ANT','Antigua-et-Barbuda');
INSERT INTO Pays VALUES ('ARG','Argentine');
INSERT INTO Pays VALUES ('ARM','Arménie');
INSERT INTO Pays VALUES ('ARU','Aruba');
INSERT INTO Pays VALUES ('ASA','Samoa américaines');
INSERT INTO Pays VALUES ('AUS','Australie');
INSERT INTO Pays VALUES ('AUT','Autriche');
INSERT INTO Pays VALUES ('AZE','Azerbaïdjan');
INSERT INTO Pays VALUES ('BAH','Bahamas');
INSERT INTO Pays VALUES ('BAN','Bangladesh');
INSERT INTO Pays VALUES ('BAR','Barbade');
INSERT INTO Pays VALUES ('BDI','Burundi');
INSERT INTO Pays VALUES ('BEL','Belgique');
INSERT INTO Pays VALUES ('BEN','Bénin Bénin');
INSERT INTO Pays VALUES ('BER','Bermudes');
INSERT INTO Pays VALUES ('BHU','Bhoutan');
INSERT INTO Pays VALUES ('BIH','Bosnie-Herzégovine');
INSERT INTO Pays VALUES ('BIZ','Belize');
INSERT INTO Pays VALUES ('BLR','Biélorussie');
INSERT INTO Pays VALUES ('BOL','Bolivie');
INSERT INTO Pays VALUES ('BOT','Botswana');
INSERT INTO Pays VALUES ('BRA','Brésil');
INSERT INTO Pays VALUES ('BRN','Bahreïn');
INSERT INTO Pays VALUES ('BRU','Brunei');
INSERT INTO Pays VALUES ('BUL','Bulgarie');
INSERT INTO Pays VALUES ('BUR','Burkina Faso');
INSERT INTO Pays VALUES ('CAF','République centrafricaine');
INSERT INTO Pays VALUES ('CAM','Cambodge');
INSERT INTO Pays VALUES ('CAN','Canada');
INSERT INTO Pays VALUES ('CAY','Îles Caïmans');
INSERT INTO Pays VALUES ('CGO','République du Congo');
INSERT INTO Pays VALUES ('CHA','Tchad');
INSERT INTO Pays VALUES ('CHI','Chili');
INSERT INTO Pays VALUES ('CHN','République populaire de Chine');
INSERT INTO Pays VALUES ('CIV','Côte d''Ivoire');
INSERT INTO Pays VALUES ('CMR','Cameroun');
INSERT INTO Pays VALUES ('COD','République démocratique du Congo');
INSERT INTO Pays VALUES ('COK','Îles Cook');
INSERT INTO Pays VALUES ('COL','Colombie');
INSERT INTO Pays VALUES ('COM','Comores');
INSERT INTO Pays VALUES ('CPV','Cap-Vert');
INSERT INTO Pays VALUES ('CRC','Costa Rica');
INSERT INTO Pays VALUES ('CRO','Croatie');
INSERT INTO Pays VALUES ('CUB','Cuba');
INSERT INTO Pays VALUES ('CYP','Chypre');
INSERT INTO Pays VALUES ('CZE','République tchèque');
INSERT INTO Pays VALUES ('DEN','Danemark');
INSERT INTO Pays VALUES ('DJI','Djibouti');
INSERT INTO Pays VALUES ('DMA','Dominique');
INSERT INTO Pays VALUES ('DOM','République dominicaine');
INSERT INTO Pays VALUES ('ECU','Équateur');
INSERT INTO Pays VALUES ('EGY','Égypte');
INSERT INTO Pays VALUES ('ERI','Érythrée');
INSERT INTO Pays VALUES ('ESA','Salvador');
INSERT INTO Pays VALUES ('ESP','Espagne');
INSERT INTO Pays VALUES ('EST','Estonie');
INSERT INTO Pays VALUES ('ETH','Éthiopie');
INSERT INTO Pays VALUES ('FIJ','Fidji');
INSERT INTO Pays VALUES ('FIN','Finlande');
INSERT INTO Pays VALUES ('FRA','France');
INSERT INTO Pays VALUES ('FSM','Micronésie');
INSERT INTO Pays VALUES ('GAB','Gabon');
INSERT INTO Pays VALUES ('GAM','Gambie');
INSERT INTO Pays VALUES ('GBR','Royaume-Uni');
INSERT INTO Pays VALUES ('GBS','Guinée-Bissau');
INSERT INTO Pays VALUES ('GEO','Géorgie');
INSERT INTO Pays VALUES ('GEQ','Guinée équatoriale');
INSERT INTO Pays VALUES ('GER','Allemagne');
INSERT INTO Pays VALUES ('GHA','Ghana');
INSERT INTO Pays VALUES ('GRE','Grèce');
INSERT INTO Pays VALUES ('GRN','Grenade');
INSERT INTO Pays VALUES ('GUA','Guatemala');
INSERT INTO Pays VALUES ('GUI','Guinée');
INSERT INTO Pays VALUES ('GUM','Guam');
INSERT INTO Pays VALUES ('GUY','Guyana');
INSERT INTO Pays VALUES ('HAI','Haïti');
INSERT INTO Pays VALUES ('HKG','Hong Kong');
INSERT INTO Pays VALUES ('HON','Honduras');
INSERT INTO Pays VALUES ('HUN','Hongrie');
INSERT INTO Pays VALUES ('INA','Indonésie');
INSERT INTO Pays VALUES ('IND','Inde');
INSERT INTO Pays VALUES ('IOA','Athlètes olympiques indépendants');
INSERT INTO Pays VALUES ('IRI','Iran');
INSERT INTO Pays VALUES ('IRL','Irlande');
INSERT INTO Pays VALUES ('IRQ','Irak');
INSERT INTO Pays VALUES ('ISL','Islande');
INSERT INTO Pays VALUES ('ISR','Israël');
INSERT INTO Pays VALUES ('ISV','Îles Vierges des États-Unis');
INSERT INTO Pays VALUES ('ITA','Italie');
INSERT INTO Pays VALUES ('IVB','Îles Vierges britanniques');
INSERT INTO Pays VALUES ('JAM','Jamaïque');
INSERT INTO Pays VALUES ('JOR','Jordanie');
INSERT INTO Pays VALUES ('JPN','Japon');
INSERT INTO Pays VALUES ('KAZ','Kazakhstan');
INSERT INTO Pays VALUES ('KEN','Kenya');
INSERT INTO Pays VALUES ('KGZ','Kirghizistan');
INSERT INTO Pays VALUES ('KIR','Kiribati');
INSERT INTO Pays VALUES ('KOS','Kosovo');
INSERT INTO Pays VALUES ('KOR','Corée du Sud');
INSERT INTO Pays VALUES ('KSA','Arabie saoudite');
INSERT INTO Pays VALUES ('KUW','Koweït');
INSERT INTO Pays VALUES ('LAO','Laos');
INSERT INTO Pays VALUES ('LAT','Lettonie');
INSERT INTO Pays VALUES ('LBA','Libye');
INSERT INTO Pays VALUES ('LBR','Libéria');
INSERT INTO Pays VALUES ('LCA','Sainte-Lucie');
INSERT INTO Pays VALUES ('LES','Lesotho');
INSERT INTO Pays VALUES ('LIB','Liban');
INSERT INTO Pays VALUES ('LIE','Liechtenstein');
INSERT INTO Pays VALUES ('LTU','Lituanie');
INSERT INTO Pays VALUES ('LUX','Luxembourg');
INSERT INTO Pays VALUES ('MAD','Madagascar');
INSERT INTO Pays VALUES ('MAR','Maroc');
INSERT INTO Pays VALUES ('MAS','Malaisie');
INSERT INTO Pays VALUES ('MAW','Malawi');
INSERT INTO Pays VALUES ('MDA','Moldavie');
INSERT INTO Pays VALUES ('MDV','Maldives');
INSERT INTO Pays VALUES ('MEX','Mexique');
INSERT INTO Pays VALUES ('MGL','Mongolie');
INSERT INTO Pays VALUES ('MHL','Îles Marshall');
INSERT INTO Pays VALUES ('MKD','Ex-république yougoslave de Macédoine');
INSERT INTO Pays VALUES ('MLI','Mali');
INSERT INTO Pays VALUES ('MLT','Malte');
INSERT INTO Pays VALUES ('MNE','Monténégro');
INSERT INTO Pays VALUES ('MON','Monaco');
INSERT INTO Pays VALUES ('MOZ','Mozambique');
INSERT INTO Pays VALUES ('MRI','Maurice');
INSERT INTO Pays VALUES ('MTN','Mauritanie');
INSERT INTO Pays VALUES ('MYA','Birmanie');
INSERT INTO Pays VALUES ('NAM','Namibie');
INSERT INTO Pays VALUES ('NCA','Nicaragua');
INSERT INTO Pays VALUES ('NED','Pays-Bas');
INSERT INTO Pays VALUES ('NEP','Népal');
INSERT INTO Pays VALUES ('NGR','Nigeria');
INSERT INTO Pays VALUES ('NIG','Niger');
INSERT INTO Pays VALUES ('NOR','Norvège');
INSERT INTO Pays VALUES ('NRU','Nauru');
INSERT INTO Pays VALUES ('NZL','Nouvelle-Zélande');
INSERT INTO Pays VALUES ('OMA','Oman');
INSERT INTO Pays VALUES ('PAK','Pakistan');
INSERT INTO Pays VALUES ('PAN','Panama');
INSERT INTO Pays VALUES ('PAR','Paraguay');
INSERT INTO Pays VALUES ('PER','Pérou');
INSERT INTO Pays VALUES ('PHI','Philippines');
INSERT INTO Pays VALUES ('PLE','Palestine');
INSERT INTO Pays VALUES ('PLW','Palaos');
INSERT INTO Pays VALUES ('PNG','Papouasie-Nouvelle-Guinée');
INSERT INTO Pays VALUES ('POL','Pologne');
INSERT INTO Pays VALUES ('POR','Portugal');
INSERT INTO Pays VALUES ('PRK','Corée du Nord');
INSERT INTO Pays VALUES ('PUR','Porto Rico');
INSERT INTO Pays VALUES ('QAT','Qatar');
INSERT INTO Pays VALUES ('ROU','Roumanie');
INSERT INTO Pays VALUES ('RSA','Afrique du Sud');
INSERT INTO Pays VALUES ('RUS','Russie');
INSERT INTO Pays VALUES ('RWA','Rwanda');
INSERT INTO Pays VALUES ('SAM','Samoa');
INSERT INTO Pays VALUES ('SEN','Sénégal');
INSERT INTO Pays VALUES ('SEY','Seychelles');
INSERT INTO Pays VALUES ('SIN','Singapour');
INSERT INTO Pays VALUES ('SKN','Saint-Christophe-et-Niévès');
INSERT INTO Pays VALUES ('SLE','Sierra Leone');
INSERT INTO Pays VALUES ('SLO','Slovénie');
INSERT INTO Pays VALUES ('SMR','Saint-Marin');
INSERT INTO Pays VALUES ('SOL','Îles Salomon');
INSERT INTO Pays VALUES ('SOM','Somalie');
INSERT INTO Pays VALUES ('SRB','Serbie');
INSERT INTO Pays VALUES ('SRI','Sri Lanka');
INSERT INTO Pays VALUES ('STP','Sao Tomé-et-Principe');
INSERT INTO Pays VALUES ('SUD','Soudan');
INSERT INTO Pays VALUES ('SUI','Suisse');
INSERT INTO Pays VALUES ('SUR','Suriname');
INSERT INTO Pays VALUES ('SVK','Slovaquie');
INSERT INTO Pays VALUES ('SWE','Suède');
INSERT INTO Pays VALUES ('SWZ','Swaziland');
INSERT INTO Pays VALUES ('SYR','Syrie');
INSERT INTO Pays VALUES ('TAN','République unie de Tanzanie');
INSERT INTO Pays VALUES ('TGA','Tonga');
INSERT INTO Pays VALUES ('THA','Thaïlande');
INSERT INTO Pays VALUES ('TJK','Tadjikistan');
INSERT INTO Pays VALUES ('TKM','Turkménistan');
INSERT INTO Pays VALUES ('TLS','Timor oriental');
INSERT INTO Pays VALUES ('TOG','Togo');
INSERT INTO Pays VALUES ('TPE','Taipei chinois');
INSERT INTO Pays VALUES ('TTO2','Trinité-et-Tobago');
INSERT INTO Pays VALUES ('TUN','Tunisie');
INSERT INTO Pays VALUES ('TUR','Turquie');
INSERT INTO Pays VALUES ('TUV','Tuvalu');
INSERT INTO Pays VALUES ('UAE','Émirats arabes unis');
INSERT INTO Pays VALUES ('UGA','Ouganda');
INSERT INTO Pays VALUES ('UKR','Ukraine');
INSERT INTO Pays VALUES ('URU','Uruguay');
INSERT INTO Pays VALUES ('USA','États-Unis');
INSERT INTO Pays VALUES ('UZB','Ouzbékistan');
INSERT INTO Pays VALUES ('VAN','Vanuatu');
INSERT INTO Pays VALUES ('VEN','Venezuela');
INSERT INTO Pays VALUES ('VIE','Viêt Nam');
INSERT INTO Pays VALUES ('VIN','Saint-Vincent-et-les-Grenadines');
INSERT INTO Pays VALUES ('YEM','Yémen');
INSERT INTO Pays VALUES ('ZAM','Zambie');
INSERT INTO Pays VALUES ('ZIM','Zimbabwe');


INSERT INTO Sport VALUES (1,'Biathlon');
INSERT INTO Sport VALUES (2,'Bobsleigh');
INSERT INTO Sport VALUES (3,'Combiné nordique');
INSERT INTO Sport VALUES (4,'Curling');
INSERT INTO Sport VALUES (5,'Hockey sur glace');
INSERT INTO Sport VALUES (6,'Luge');
INSERT INTO Sport VALUES (7,'Patinage artistique');
INSERT INTO Sport VALUES (8,'Patinage de vitesse');
INSERT INTO Sport VALUES (9,'Patinage de vitesse sur piste courte');
INSERT INTO Sport VALUES (10,'Saut à ski');
INSERT INTO Sport VALUES (11,'Skeleton');
INSERT INTO Sport VALUES (12,'Ski acrobatique');
INSERT INTO Sport VALUES (13,'Ski alpin');
INSERT INTO Sport VALUES (14,'Ski de fond');
INSERT INTO Sport VALUES (15,'Surf des neiges');


INSERT INTO Athlete VALUES (1,'BJOERNDALEN','Ole Einar',to_date('27-01-1974', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (2,'BJOERGEN','Marit',to_date('21-03-1980', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (3,'AN','Victor',to_date('23-11-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (4,'PECHSTEIN','Claudia',to_date('22-02-1972', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (5,'WÜST','Ireen',to_date('01-04-1986', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (6,'SVENDSEN','Emil Hegle',to_date('12-07-1985', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (7,'AMMANN','Simon',to_date('25-06-1981', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (8,'KRAMER','Sven',to_date('23-04-1986', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (9,'SABLIKOVA','Martina',to_date('27-05-1987', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (10,'HAMELIN','Charles',to_date('14-04-1984', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (11,'MORGENSTERN','Thomas',to_date('30-10-1986', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (12,'HELLNER','Marcus',to_date('25-11-1985', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (13,'HOEFL-RIESCH','Maria',to_date('24-11-1984', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (14,'DOMRACHEVA','Darya',to_date('03-08-1986', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (15,'COLOGNA','Dario',to_date('11-03-1986', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (16,'LOCH','Felix',to_date('24-07-1989', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (17,'ZHOU','Yang',to_date('09-06-1991', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (18,'NYSTAD','Claudia',to_date('01-02-1978', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (19,'SACHENBACHER-STEHLE','Evi',to_date('27-11-1980', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (20,'KALLA','Charlotte',to_date('22-07-1987', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (21,'ZAITSEVA','Olga',to_date('16-05-1978', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (22,'PLYUSHCHENKO','Evgeny',to_date('03-11-1982', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (23,'MAZE','Tina',to_date('02-05-1983', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (24,'DAVIS','Shani',to_date('13-08-1982', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (25,'FOURCADE','Martin',to_date('14-09-1988', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (26,'OLSSON','Johan',to_date('19-03-1980', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (27,'ZOEGGELER','Armin',to_date('04-01-1974', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (28,'KOWALCZYK','Justyna',to_date('23-01-1983', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (29,'HENKEL','Andrea',to_date('10-12-1977', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (30,'BERGER','Tora',to_date('18-03-1981', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (31,'NORTHUG','Petter Jr.',to_date('06-01-1986', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (32,'DI CENTA','Giorgio',to_date('10-07-1972', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (33,'KUZMINA','Anastazia',to_date('28-08-1984', 'DD-MM-YYYY'),'SVK');
INSERT INTO Athlete VALUES (34,'PARK','Seung-Hi',to_date('28-03-1992', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (35,'STECHER','Mario',to_date('17-07-1977', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (36,'RAICH','Benjamin',to_date('28-02-1978', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (37,'USTYUGOV','Evgeny',to_date('04-06-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (38,'RICHARDSSON','Daniel',to_date('15-03-1982', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (39,'GEISENBERGER','Natalie',to_date('05-02-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (40,'SCHOCH','Philipp',to_date('12-10-1979', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (41,'BILODEAU','Alexandre',to_date('08-09-1987', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (42,'WHITE','Shaun',to_date('03-09-1986', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (43,'LIGETY','Ted',to_date('31-08-1984', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (44,'SANG-HWA','Lee',to_date('25-02-1989', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (45,'STOCH','Kamil',to_date('25-05-1987', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (46,'TER MORS','Jorien',to_date('21-12-1989', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (47,'GRAABAK','Joergen',to_date('26-04-1991', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (48,'WILD','Vic',to_date('23-08-1986', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (49,'MILLER','Bode',to_date('12-10-1977', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (50,'MANCUSO','Julia',to_date('09-03-1984', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (51,'MORRISON','Denny',to_date('08-09-1985', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (52,'MOAN','Magnus Hovdal',to_date('26-08-1983', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (53,'HAAG','Anna',to_date('01-06-1986', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (54,'BECKERT','Stephanie',to_date('30-05-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (55,'DE JONG','Bob',to_date('13-11-1976', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (56,'SCHLIERENZAUER','Gregor',to_date('07-01-1990', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (57,'HUEFNER','Tatjana',to_date('30-04-1983', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (58,'JANSRUD','Kjetil',to_date('28-08-1985', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (59,'SVINDAL','Aksel Lund',to_date('26-12-1982', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (60,'JOHAUG','Therese',to_date('25-06-1988', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (61,'FRENZEL','Eric',to_date('21-11-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (62,'BLOKHUIJSEN','Jan',to_date('01-04-1989', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (63,'SHIM','Suk-Hee',to_date('30-01-1997', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (64,'DEMONG','Bill',to_date('29-03-1980', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (65,'NESBITT','Christine',to_date('17-05-1985', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (66,'LEGKOV','Alexander',to_date('07-05-1983', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (67,'TETER','Hannah',to_date('27-01-1987', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (68,'BEGG-SMITH','Dale',to_date('18-01-1985', 'DD-MM-YYYY'),'AUS');
INSERT INTO Athlete VALUES (69,'BRIGHT','Torah',to_date('27-12-1986', 'DD-MM-YYYY'),'AUS');
INSERT INTO Athlete VALUES (70,'FENNINGER','Anna',to_date('18-06-1989', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (71,'KRIUKOV','Nikita',to_date('30-05-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (72,'OESTBERG','Ingvild Flugstad',to_date('09-11-1990', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (73,'KIM','Yuna',to_date('05-09-1990', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (74,'VERWEIJ','Koen',to_date('26-08-1990', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (75,'WANK','Andreas',to_date('18-02-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (76,'GRIGOREV','Vladimir',to_date('08-08-1982', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (77,'MO','Tae Bum',to_date('15-02-1989', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (78,'BIELER','Christoph',to_date('28-10-1977', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (79,'GRUBER','Bernhard',to_date('12-08-1982', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (80,'TUITERT','Mark',to_date('04-04-1980', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (81,'CLARK','Kelly',to_date('26-07-1983', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (82,'ECKHOFF','Tiril',to_date('21-05-1990', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (83,'LASSILA','Lydia',to_date('17-01-1982', 'DD-MM-YYYY'),'AUS');
INSERT INTO Athlete VALUES (84,'GRISHIN','Alexei',to_date('18-06-1979', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (85,'SOEDERGREN','Anders',to_date('17-05-1977', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (86,'KEARNEY','Hannah',to_date('26-02-1986', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (87,'TRETYAKOV','Aleksandr',to_date('19-04-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (88,'INGEMARSDOTTER','Ida',to_date('26-04-1985', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (89,'STEIRA','Kristin Stormer',to_date('30-04-1981', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (90,'REBENSBURG','Viktoria',to_date('04-10-1989', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (91,'SHIPULIN','Anton',to_date('21-08-1987', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (92,'SEMERENKO','Vita',to_date('18-01-1986', 'DD-MM-YYYY'),'UKR');
INSERT INTO Athlete VALUES (93,'BRODKA','Zbigniew',to_date('08-10-1984', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (94,'BEEK','Lotte van',to_date('09-12-1991', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (95,'MULDER','Michel',to_date('27-02-1986', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (96,'KROG','Magnus',to_date('19-03-1987', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (97,'BERGSMA','Jorrit',to_date('01-02-1986', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (98,'TSUPER','Alla',to_date('16-04-1979', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (99,'ANDERSON','Jasey Jay',to_date('13-04-1975', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (100,'RICKER','Maelle',to_date('02-12-1978', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (101,'MATT','Mario',to_date('09-04-1979', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (102,'JAUHOJARVI','Sami',to_date('05-05-1981', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (103,'SAUERBREIJ','Nicolien',to_date('31-07-1979', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (104,'DEFAGO','Didier',to_date('02-10-1977', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (105,'CRAWFORD','Chandra',to_date('19-11-1983', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (106,'FERRY','Bjoern',to_date('01-08-1978', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (107,'SEMERENKO','Valj',to_date('18-01-1986', 'DD-MM-YYYY'),'UKR');
INSERT INTO Athlete VALUES (108,'LAMY CHAPPUIS','Jason',to_date('09-09-1986', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (109,'VAULTIER','Pierre',to_date('24-06-1987', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (110,'ANESI','Matteo',to_date('16-08-1984', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (111,'GROOTHUIS','Stefan',to_date('23-11-1981', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (112,'HATTESTAD','Ola Vigen',to_date('19-04-1982', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (113,'KUSHNIR','Anton',to_date('13-10-1984', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (114,'PODLADTCHIKOV','Iouri',to_date('13-09-1988', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (115,'RAZZOLI','Giuliano',to_date('18-12-1984', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (116,'GISIN','Dominique',to_date('04-06-1985', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (117,'JANKA','Carlo',to_date('15-10-1986', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (118,'VILETTA','Sandro',to_date('23-01-1986', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (119,'VOLKOV','Alexey',to_date('05-04-1988', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (120,'DZHYMA','Juliya',to_date('19-09-1990', 'DD-MM-YYYY'),'UKR');
INSERT INTO Athlete VALUES (121,'PIDHRUSHNA','Olena',to_date('09-01-1987', 'DD-MM-YYYY'),'UKR');
INSERT INTO Athlete VALUES (122,'BOE','Tarjei',to_date('29-07-1988', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (123,'FALLA','Maiken Caspersen',to_date('13-08-1990', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (124,'SCHMID','Michael',to_date('18-03-1984', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (125,'KLEMETSEN','Haavard',to_date('05-01-1979', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (126,'FARRINGTON','Kaitlyn',to_date('18-12-1989', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (127,'ANDERSON','Jamie',to_date('13-09-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (128,'KUMMER','Patrizia',to_date('16-10-1987', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (129,'DUJMOVITS','Julia',to_date('12-06-1987', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (130,'FREUND','Severin',to_date('11-05-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (131,'LEENSTRA','Marrit',to_date('10-05-1989', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (132,'GIROUX','Mathieu',to_date('03-02-1986', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (133,'MAKOWSKY','Lucas',to_date('30-05-1987', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (134,'ELISTRATOV','Semion',to_date('03-05-1990', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (135,'CHO','Ha-Ri',to_date('29-07-1986', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (136,'JEAN','Olivier',to_date('15-03-1984', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (137,'HAMELIN','Francois',to_date('18-12-1986', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (138,'SOTNIKOVA','Adelina',to_date('01-07-1996', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (139,'WELLINGER','Andreas',to_date('28-08-1995', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (140,'YARNOLD','Elizabeth',to_date('31-10-1988', 'DD-MM-YYYY'),'GBR');
INSERT INTO Athlete VALUES (141,'WIKEN','Emma',to_date('01-05-1989', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (142,'NELSON','Lars',to_date('19-08-1985', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (143,'NISKANEN','Iivo',to_date('12-01-1992', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (144,'HANYU','Yuzuru',to_date('07-12-1994', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (145,'LIPNITSKAYA','Yulia',to_date('05-06-1998', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (146,'KOTSENBURG','Sage',to_date('27-07-1993', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (147,'SAMKOVA','Eva',to_date('28-04-1993', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (148,'JIANROU','Li',to_date('15-08-1986', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (149,'KIM','Alang',to_date('22-08-1995', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (150,'VOGT','Carina',to_date('05-02-1992', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (151,'KRAUS','Marinus',to_date('13-02-1991', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (152,'HONG','Zhang',to_date('12-04-1988', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (153,'MAYER','Matthias',to_date('09-06-1990', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (154,'SHIFFRIN','Mikaela',to_date('13-03-1995', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (155,'MALYSHKO','Dmitry',to_date('19-03-1987', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (156,'CHAPUIS','Jean Frederic',to_date('02-03-1989', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (157,'THOMPSON','Marielle',to_date('15-06-1992', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (158,'DUFOUR-LAPOINTE','Justine',to_date('25-03-1994', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (159,'HOWELL','Dara',to_date('23-08-1994', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (160,'WISE','David',to_date('30-06-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (161,'BOWMAN','Maddie',to_date('10-01-1994', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (162,'CHRISTENSEN','Joss',to_date('20-12-1991', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (163,'KOSTELIC','Ivica',to_date('23-11-1979', 'DD-MM-YYYY'),'CRO');
INSERT INTO Athlete VALUES (164,'SCHILD','Marlies',to_date('31-05-1981', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (165,'KIRCHEISEN','Bjoern',to_date('06-08-1983', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (166,'DEMTSCHENKO','Albert',to_date('27-11-1971', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (167,'VYLEGZHANIN','Maxim',to_date('18-10-1982', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (168,'ST-GELAIS','Marianne',to_date('17-02-1990', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (169,'SAARINEN','Aino Kaisa',to_date('01-02-1979', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (170,'ANGERER','Tobias',to_date('12-04-1977', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (171,'KASAI','Noriaki',to_date('06-06-1972', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (172,'HOSP','Nicole',to_date('06-11-1983', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (173,'SUMANN','Christoph',to_date('19-01-1976', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (174,'MORAVEC','Ondrej',to_date('09-06-1984', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (175,'AHONEN','Janne',to_date('11-05-1977', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (176,'LI','Nina',to_date('10-01-1983', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (177,'TEICHMANN','Axel',to_date('14-07-1979', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (178,'DUKURS','Martins',to_date('31-03-1984', 'DD-MM-YYYY'),'LAT');
INSERT INTO Athlete VALUES (179,'VILUKHINA','Olga',to_date('22-03-1988', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (180,'SOUKALOVA','Gabriela',to_date('01-11-1989', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (181,'NISKANEN','Kerttu',to_date('13-06-1988', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (182,'CHAN','Patrick',to_date('31-12-1990', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (183,'LESSER','Erik',to_date('17-05-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (184,'FONTANA','Arianna',to_date('14-04-1990', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (185,'BAUER','Lukas',to_date('18-08-1977', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (186,'CELSKI','J.R.',to_date('17-07-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (187,'DASHINSKI','Dmitri',to_date('09-11-1977', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (188,'MESOTITSCH','Daniel',to_date('22-05-1976', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (189,'DROLET','Marie-Eve',to_date('03-02-1982', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (190,'FILBRICH','Jens',to_date('13-03-1979', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (191,'BOEHLER','Stefanie',to_date('27-02-1981', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (192,'KOBER','Amelie',to_date('16-11-1987', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (193,'MALTAIS','Dominique',to_date('09-11-1980', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (194,'SKOBREV','Ivan',to_date('08-02-1983', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (195,'INNERHOFER','Christof',to_date('17-12-1984', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (196,'WEIBRECHT','Andrew',to_date('10-02-1986', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (197,'SOUKUP','Jaroslav',to_date('12-07-1982', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (198,'EDER','Simon',to_date('23-02-1983', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (199,'BRUNET','Marie Laure',to_date('20-11-1988', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (200,'PETERSON','Teodor',to_date('01-05-1988', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (201,'RYDZEK','Johannes',to_date('09-12-1991', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (202,'KOSIR','Zan',to_date('11-04-1984', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (203,'KARL','Benjamin',to_date('16-10-1985', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (204,'PREVC','Peter',to_date('20-09-1992', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (205,'WOZNIAK','Katarzyna',to_date('05-10-1989', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (206,'BACHLEDA-CURUS','Katarzyna',to_date('01-01-1980', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (207,'ZLOTKOWSKA','Luiza',to_date('25-05-1986', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (208,'MALONE','Jordan',to_date('20-04-1984', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (209,'RIESSLE','Fabian',to_date('18-12-1990', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (210,'SUNDBY','Martin Johnsrud',to_date('26-09-1984', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (211,'TIANYU','Han',to_date('03-06-1996', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (212,'DAJING','Wu',to_date('24-07-1994', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (213,'DORIN HABERT','Marie',to_date('19-06-1986', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (214,'LANDERTINGER','Dominik',to_date('13-03-1988', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (215,'TABATA','Maki',to_date('09-11-1974', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (216,'LODWICK','Todd',to_date('21-11-1976', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (217,'POUTIAINEN','Tanja',to_date('06-04-1980', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (218,'NOVIKOV','Sergei',to_date('27-04-1979', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (219,'WOLF','Jenny',to_date('31-01-1979', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (220,'MOELLER','David',to_date('13-01-1982', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (221,'TAKEUCHI','Tomoka',to_date('21-12-1983', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (222,'SCHOCH','Simon',to_date('07-10-1978', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (223,'JACOBELLIS','Lindsey',to_date('19-08-1985', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (224,'WATABE','Akito',to_date('26-05-1988', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (225,'RUDMAN','Shelley',to_date('23-03-1981', 'DD-MM-YYYY'),'GBR');
INSERT INTO Athlete VALUES (226,'NAGASHIMA','Keiichiro',to_date('20-04-1982', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (227,'ANTHONIOZ','Deborah',to_date('29-08-1978', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (228,'HERBST','Reinfried',to_date('11-10-1978', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (229,'REITHMAYER','Nina',to_date('08-06-1984', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (230,'HIRSCHER','Marcel',to_date('02-03-1989', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (231,'MISSILLIER','Steve',to_date('12-12-1984', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (232,'KHRUSTALEVA','Elena',to_date('28-09-1980', 'DD-MM-YYYY'),'KAZ');
INSERT INTO Athlete VALUES (233,'SCHEMPP','Simon',to_date('14-11-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (234,'PEIFFER','Arnd',to_date('18-03-1987', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (235,'VITKOVA','Veronika',to_date('09-12-1988', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (236,'GASPARIN','Selina',to_date('03-04-1984', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (237,'BESSMERTNYKH','Alexander',to_date('15-09-1986', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (238,'ZELLER','Katrin',to_date('01-03-1979', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (239,'KYLLOENEN','Anne',to_date('30-11-1987', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (240,'LAHTEENMAKI','Krista',to_date('12-12-1990', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (241,'MORRIS','David',to_date('31-08-1984', 'DD-MM-YYYY'),'AUS');
INSERT INTO Athlete VALUES (242,'XU','Mengtao',to_date('12-07-1990', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (243,'DUFOUR-LAPOINTE','Chloe',to_date('02-12-1991', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (244,'SERWA','Kelsey',to_date('01-09-1989', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (245,'MATT','Andreas',to_date('19-10-1982', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (246,'BOVOLENTA','Arnaud',to_date('06-09-1988', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (247,'ASADA','Mao',to_date('25-09-1990', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (248,'REYNOLDS','Kevin',to_date('23-07-1990', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (249,'IVANOVA','Tatiana',to_date('16-02-1991', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (250,'ILYUKHINA','Ekaterina',to_date('19-06-1987', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (251,'OLYUNIN','Nikolay',to_date('23-10-1991', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (252,'SANDBECH','Staale',to_date('03-06-1993', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (253,'KARSTENS','Anke',to_date('13-10-1985', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (254,'PIIROINEN','Peetu',to_date('15-02-1988', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (255,'GALMARINI','Nevin',to_date('04-12-1986', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (256,'PIKUS-PACE','Noelle',to_date('08-12-1982', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (257,'CZERWONKA','Natalia',to_date('20-10-1988', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (258,'FATKULINA','Olga',to_date('23-01-1990', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (259,'KODAIRA','Nao',to_date('26-05-1986', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (260,'HOZUMI','Masako',to_date('11-09-1986', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (261,'SMEEKENS','Jan',to_date('11-02-1987', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (262,'KUCK','Jonathan',to_date('14-03-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (263,'HANSEN','Brian',to_date('03-09-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (264,'MALTAIS','Valerie',to_date('04-07-1990', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (265,'ALVAREZ','Eduardo',to_date('30-01-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (266,'TSCHARNKE','Tim',to_date('13-12-1989', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (267,'JAPAROV','Dmitriy',to_date('01-01-1986', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (268,'OSMOND','Kaetlyn',to_date('05-12-1995', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (269,'HIRANO','Ayumu',to_date('29-11-1998', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (270,'RUKAJARVI','Enni',to_date('13-05-1990', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (271,'HEWITT','Jessica',to_date('09-10-1986', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (272,'KEXIN','Fan',to_date('19-09-1993', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (273,'CREVELING','Chris',to_date('29-12-1986', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (274,'DIETHART','Thomas',to_date('25-02-1992', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (275,'HAYBOECK','Michael',to_date('05-03-1991', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (276,'IRASCHKO-STOLZ','Daniela',to_date('21-11-1983', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (277,'JOO','Hyong Jun',to_date('22-04-1991', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (278,'KIM','Cheol Min',to_date('29-11-1992', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (279,'LEE','Seung Hoon',to_date('06-03-1988', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (280,'SHUMILOVA','Ekaterina',to_date('25-10-1986', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (281,'ROMANOVA','Yana',to_date('11-05-1983', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (282,'BOEHM','Daniel',to_date('16-06-1986', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (283,'MARTINOD','Marie',to_date('20-07-1984', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (284,'RIDDLE','Mike',to_date('17-06-1986', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (285,'KINGSBURY','Mikael',to_date('24-07-1992', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (286,'KENWORTHY','Gus',to_date('01-10-1991', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (287,'LOGAN','Devin',to_date('17-02-1993', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (288,'RUBENIS','Martins',to_date('26-09-1978', 'DD-MM-YYYY'),'LAT');
INSERT INTO Athlete VALUES (289,'BARDAL','Anders',to_date('24-08-1982', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (290,'GOERGL','Elisabeth',to_date('20-02-1981', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (291,'JOENSSON','Emil',to_date('15-08-1985', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (292,'BOER','Margot',to_date('07-08-1985', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (293,'GRAF','Olga',to_date('15-07-1983', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (294,'LOBYSHEVA','Yekaterina',to_date('13-03-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (295,'MAGAL','Jiri',to_date('11-04-1977', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (296,'HOLLINGSWORTH','Mellisa',to_date('04-10-1980', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (297,'ROPONEN','Riitta-Liisa',to_date('06-05-1978', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (298,'TAKAHASHI','Daisuke',to_date('16-03-1986', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (299,'BUAAS','Kjersti',to_date('05-01-1982', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (300,'GREGORIN','Teja',to_date('29-06-1980', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (301,'KRANJEC','Robert',to_date('16-07-1981', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (302,'HURAJT','Pavol',to_date('04-02-1978', 'DD-MM-YYYY'),'SVK');
INSERT INTO Athlete VALUES (303,'FESSEL','Nicole',to_date('19-03-1983', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (304,'BØKKO','Håvard',to_date('02-02-1987', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (305,'HAMLIN','Erin',to_date('19-11-1986', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (306,'HUDEC','Jan',to_date('19-08-1981', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (307,'KOIVURANTA','Anssi',to_date('03-07-1988', 'DD-MM-YYYY'),'FIN');
INSERT INTO Athlete VALUES (308,'MYHRER','Andre',to_date('11-01-1983', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (309,'SMYSHLYAEV','Alexandr',to_date('16-03-1987', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (310,'ITO','Daiki',to_date('27-12-1985', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (311,'KATO','Joji',to_date('06-02-1985', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (312,'GAILLARD','Jean Marc',to_date('07-10-1980', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (313,'LIU','Zhongqing',to_date('10-11-1985', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (314,'KOSTNER','Carolina',to_date('08-02-1987', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (315,'PITTIN','Alessandro',to_date('11-02-1990', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (316,'DE LE RUE','Paul-Henri',to_date('17-04-1984', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (317,'WANG','Beixing',to_date('10-03-1985', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (318,'KLEIBEUKER','Carien',to_date('12-03-1978', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (319,'FLATLAND','Ann Kristin',to_date('06-11-1982', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (320,'ZETTEL','Kathrin',to_date('05-08-1986', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (321,'KREINER','Marion',to_date('04-05-1981', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (322,'FABJAN','Vesna',to_date('13-03-1985', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (323,'NIEDZWIEDZKI','Konrad',to_date('02-01-1985', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (324,'GUT','Lara',to_date('27-04-1991', 'DD-MM-YYYY'),'SUI');
INSERT INTO Athlete VALUES (325,'PINTURAULT','Alexis',to_date('20-03-1991', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (326,'HOFER','Lukas',to_date('30-09-1989', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (327,'OBERHOFER','Karin',to_date('03-11-1985', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (328,'WIERER','Dorothea',to_date('03-04-1990', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (329,'SKARDINO','Nadezhda',to_date('27-03-1985', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (330,'BEATRIX','Jean Guillaume',to_date('24-03-1988', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (331,'PETUKHOV','Alexey',to_date('28-06-1983', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (332,'CHERNOUSOV','Ilia',to_date('07-08-1986', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (333,'KHAZOVA','Irina',to_date('20-03-1984', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (334,'JAKS','Martin',to_date('06-09-1986', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (335,'DUVILLARD','Robin',to_date('22-12-1983', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (336,'MANIFICAT','Maurice',to_date('04-04-1986', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (337,'PERRILLAT BOITEUX','Ivan',to_date('28-12-1985', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (338,'JIA','Zongyang',to_date('01-03-1991', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (339,'HOLMLUND','Anna',to_date('03-10-1987', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (340,'JOSSERAND','Marion',to_date('06-10-1986', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (341,'TEN','Denis',to_date('13-06-1993', 'DD-MM-YYYY'),'KAZ');
INSERT INTO Athlete VALUES (342,'ABBOTT','Jeremy',to_date('05-06-1985', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (343,'WAGNER','Ashley',to_date('16-05-1991', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (344,'TIRUMA','Eliza',to_date('21-08-1990', 'DD-MM-YYYY'),'LAT');
INSERT INTO Athlete VALUES (345,'EDELMANN','Tino',to_date('13-04-1985', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (346,'KLAPFER','Lukas',to_date('25-12-1985', 'DD-MM-YYYY'),'AUT');
INSERT INTO Athlete VALUES (347,'ZAVARZINA','Alena',to_date('27-05-1989', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (348,'RAMOIN','Tony',to_date('23-12-1988', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (349,'JACOBSEN','Anders',to_date('17-02-1985', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (350,'TAKEUCHI','Taku',to_date('20-05-1987', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (351,'HUBER','Anja',to_date('20-05-1983', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (352,'ANTOINE','Matthew',to_date('02-04-1985', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (353,'SZYMANSKI','Jan',to_date('02-03-1989', 'DD-MM-YYYY'),'POL');
INSERT INTO Athlete VALUES (354,'SKOKOVA','Yuliya',to_date('01-12-1982', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (355,'LEE','Kang Seok',to_date('28-02-1985', 'DD-MM-YYYY'),'KOR');
INSERT INTO Athlete VALUES (356,'SHIKHOVA','Yekaterina',to_date('25-06-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (357,'VAN RIESSEN','Laurine',to_date('10-08-1987', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (358,'MULDER','Ronald',to_date('27-02-1986', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (359,'KNEGT','Sjinkie',to_date('05-07-1989', 'DD-MM-YYYY'),'NED');
INSERT INTO Athlete VALUES (360,'VIVIANI','Elena',to_date('10-10-1992', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (361,'PERETTI','Lucia',to_date('14-11-1990', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (362,'VALCEPINA','Martina',to_date('04-06-1992', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (363,'DUDEK','Alyson',to_date('30-07-1990', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (364,'HIRAOKA','Taku',to_date('29-10-1995', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (365,'NIKITINA','Elena',to_date('02-11-1992', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (366,'WENG','Heidi',to_date('20-07-1991', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (367,'NILSSON','Stina',to_date('24-06-1993', 'DD-MM-YYYY'),'SWE');
INSERT INTO Athlete VALUES (368,'HERRMANN','Denise',to_date('20-12-1988', 'DD-MM-YYYY'),'GER');
INSERT INTO Athlete VALUES (369,'GOLD','Gracie',to_date('17-08-1995', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (370,'BROWN','Jason',to_date('15-12-1994', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (371,'TRESPEUCH','Chloe',to_date('13-04-1994', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (372,'MCMORRIS','Mark',to_date('09-12-1993', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (373,'DEIBOLD','Alex',to_date('08-05-1986', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (374,'JONES','Jenny',to_date('03-07-1980', 'DD-MM-YYYY'),'GBR');
INSERT INTO Athlete VALUES (375,'COURNOYER','Charle',to_date('11-06-1991', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (376,'CHEN','Dequan',to_date('30-08-1995', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (377,'SHI','Jingnan',to_date('07-04-1994', 'DD-MM-YYYY'),'CHN');
INSERT INTO Athlete VALUES (378,'SHIMIZU','Reruhi',to_date('04-12-1993', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (379,'MATTEL','Coline',to_date('03-11-1995', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (380,'KRISTOFFERSEN','Henrik',to_date('02-07-1994', 'DD-MM-YYYY'),'NOR');
INSERT INTO Athlete VALUES (381,'STRACHOVA','Sarka',to_date('11-02-1985', 'DD-MM-YYYY'),'CZE');
INSERT INTO Athlete VALUES (382,'GARANICHEV','Evgeniy',to_date('13-02-1988', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (383,'WINDISCH','Dominik',to_date('06-11-1989', 'DD-MM-YYYY'),'ITA');
INSERT INTO Athlete VALUES (384,'FAK','Jakov',to_date('01-08-1987', 'DD-MM-YYYY'),'SLO');
INSERT INTO Athlete VALUES (385,'ONOZUKA','Ayana',to_date('23-03-1988', 'DD-MM-YYYY'),'JPN');
INSERT INTO Athlete VALUES (386,'MIDOL','Jonathan',to_date('13-01-1988', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (387,'ROLLAND','Kevin',to_date('10-08-1989', 'DD-MM-YYYY'),'FRA');
INSERT INTO Athlete VALUES (388,'GOEPPER','Nicholas',to_date('14-03-1994', 'DD-MM-YYYY'),'USA');
INSERT INTO Athlete VALUES (389,'LAMARRE','Kim',to_date('20-05-1988', 'DD-MM-YYYY'),'CAN');
INSERT INTO Athlete VALUES (390,'AHN','Viktor',to_date('20-10-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (391,'SKARDZINA','Nadzeya',to_date('28-03-1985', 'DD-MM-YYYY'),'BLR');
INSERT INTO Athlete VALUES (392,'TOFALVI','Eva',NULL,'ROU');
INSERT INTO Athlete VALUES (393,'CHOI','Heung-Chul',NULL,'KOR');
INSERT INTO Athlete VALUES (394,'KIM','Hyun-Ki',NULL,'KOR');
INSERT INTO Athlete VALUES (395,'BAJCICAK','Martin',NULL,'SVK');
INSERT INTO Athlete VALUES (396,'SHEVCHENKO','Valentina',NULL,'UKR');
INSERT INTO Athlete VALUES (397,'UEMURA','Aiko',NULL,'JPN');
INSERT INTO Athlete VALUES (398,'DERYZEMLYA','Andriy',NULL,'UKR');
INSERT INTO Athlete VALUES (399,'TOBRELUTS','Indrek',NULL,'EST');
INSERT INTO Athlete VALUES (400,'MATURA','Jan',NULL,'CZE');
INSERT INTO Athlete VALUES (401,'SIMARI BIRKNER','Macarena',NULL,'ARG');
INSERT INTO Athlete VALUES (402,'KIRCHGASSER','Michaela',NULL,'AUT');
INSERT INTO Athlete VALUES (403,'WINDISCH','Veronika',NULL,'AUT');
INSERT INTO Athlete VALUES (404,'CLARK RIBEIRO','Isabel',NULL,'BRA');
INSERT INTO Athlete VALUES (405,'RUIZ CASTILLO','Carolina',NULL,'ESP');
INSERT INTO Athlete VALUES (406,'SYKARAS','Kostas',NULL,'GRE');
INSERT INTO Athlete VALUES (407,'CHEBOTKO','Nikolay',NULL,'KAZ');
INSERT INTO Athlete VALUES (408,'GWIZDON','Magdalena',NULL,'POL');
INSERT INTO Athlete VALUES (409,'LOBKOV','Dmitry',NULL,'RUS');
INSERT INTO Athlete VALUES (410,'CETINKAYA','Kelime',NULL,'TUR');
INSERT INTO Athlete VALUES (411,'OGLAGO','Sabahattin',NULL,'TUR');
INSERT INTO Athlete VALUES (412,'SIMARI BIRKNER','Cristian Javier',NULL,'ARG');
INSERT INTO Athlete VALUES (413,'OWENS','Jenny',NULL,'AUS');
INSERT INTO Athlete VALUES (414,'KROELL','Klaus',NULL,'AUT');
INSERT INTO Athlete VALUES (415,'DENIFL','Wilhelm',NULL,'AUT');
INSERT INTO Athlete VALUES (416,'PROMMEGGER','Andreas',NULL,'AUT');
INSERT INTO Athlete VALUES (417,'RIEGLER','Claudia',NULL,'AUT');
INSERT INTO Athlete VALUES (418,'KLETCHEROV','Michail',NULL,'BUL');
INSERT INTO Athlete VALUES (419,'JANDA','Jakub',NULL,'CZE');
INSERT INTO Athlete VALUES (420,'VERNER','Tomas',NULL,'CZE');
INSERT INTO Athlete VALUES (421,'NOVOTNA','Katerina',NULL,'CZE');
INSERT INTO Athlete VALUES (422,'BANK','Ondrej',NULL,'CZE');
INSERT INTO Athlete VALUES (423,'KRAUS','Tomas',NULL,'CZE');
INSERT INTO Athlete VALUES (424,'CHURAVY','Pavel',NULL,'CZE');
INSERT INTO Athlete VALUES (425,'SUDOVA','Nikola',NULL,'CZE');
INSERT INTO Athlete VALUES (426,'SLAVIK','Tomas',NULL,'CZE');
INSERT INTO Athlete VALUES (427,'MOELLER','Martin',NULL,'DEN');
INSERT INTO Athlete VALUES (428,'LESSING','Roland',NULL,'EST');
INSERT INTO Athlete VALUES (429,'KOSKELA','Pekka',NULL,'FIN');
INSERT INTO Athlete VALUES (430,'LACROIX','Sebastian',NULL,'FRA');
INSERT INTO Athlete VALUES (431,'LIZEROUX','Julien',NULL,'FRA');
INSERT INTO Athlete VALUES (432,'JOUBERT','Brian',NULL,'FRA');
INSERT INTO Athlete VALUES (433,'ALCOTT','Chimene',NULL,'GBR');
INSERT INTO Athlete VALUES (434,'BROMLEY','Kristan',NULL,'GBR');
INSERT INTO Athlete VALUES (435,'ELEY','Jon',NULL,'GBR');
INSERT INTO Athlete VALUES (436,'BIRNBACHER','Andreas',NULL,'GER');
INSERT INTO Athlete VALUES (437,'WISCHNEWSKI','Anke',NULL,'GER');
INSERT INTO Athlete VALUES (438,'FISCHNALLER','Roland',NULL,'ITA');
INSERT INTO Athlete VALUES (439,'PONZA','Michela',NULL,'ITA');
INSERT INTO Athlete VALUES (440,'SIMONCELLI','Davide',NULL,'ITA');
INSERT INTO Athlete VALUES (441,'KARBON','Denise',NULL,'ITA');
INSERT INTO Athlete VALUES (442,'SASAKI','Akira',NULL,'JPN');
INSERT INTO Athlete VALUES (443,'YUASA','Naoki',NULL,'JPN');
INSERT INTO Athlete VALUES (444,'WATASE','Yuta',NULL,'JPN');
INSERT INTO Athlete VALUES (445,'ISA','Hidenori',NULL,'JPN');
INSERT INTO Athlete VALUES (446,'DUKURS','Tomass',NULL,'LAT');
INSERT INTO Athlete VALUES (447,'RASIMOVICIUTE','Diana',NULL,'LTU');
INSERT INTO Athlete VALUES (448,'VALENCIC','Mitja',NULL,'SLO');
INSERT INTO Athlete VALUES (449,'MARIC','Janez',NULL,'SLO');
INSERT INTO Athlete VALUES (450,'AUFDENBLATTEN','Fraenzi',NULL,'SUI');
INSERT INTO Athlete VALUES (451,'LARSSON','Markus',NULL,'SWE');
INSERT INTO Athlete VALUES (452,'BERGMAN','Carl Johan',NULL,'SWE');
INSERT INTO Athlete VALUES (453,'DIDENKO','Nadiya',NULL,'UKR');
INSERT INTO Athlete VALUES (454,'BAILEY','Lowell',NULL,'USA');
INSERT INTO Athlete VALUES (455,'RANDALL','Kikkan',NULL,'USA');
INSERT INTO Athlete VALUES (456,'FREEMAN','Kris',NULL,'USA');
INSERT INTO Athlete VALUES (457,'KOOS','Torin',NULL,'USA');
INSERT INTO Athlete VALUES (458,'SULLIVAN','Marco',NULL,'USA');
INSERT INTO Athlete VALUES (459,'REITER','Justin',NULL,'USA');
INSERT INTO Athlete VALUES (460,'MOURAO','Jaqueline',NULL,'BRA');
INSERT INTO Athlete VALUES (461,'BARAHONA','Noelle',NULL,'CHI');
INSERT INTO Athlete VALUES (462,'NEUREUTHER','Felix',NULL,'GER');
INSERT INTO Athlete VALUES (463,'ABRAMASHVILI','Iason',NULL,'GEO');
INSERT INTO Athlete VALUES (464,'GEDEVANISHVILI','Elene',NULL,'GEO');
INSERT INTO Athlete VALUES (465,'STRAMATURARU','Raluca',NULL,'ROU');
INSERT INTO Athlete VALUES (466,'BUSSLER','Patrick',NULL,'GER');
INSERT INTO Athlete VALUES (467,'JOERG','Selina',NULL,'GER');
INSERT INTO Athlete VALUES (468,'HESSE','Judith',NULL,'GER');
INSERT INTO Athlete VALUES (469,'LEHMANN','Robert',NULL,'GER');
INSERT INTO Athlete VALUES (470,'CHATAIGNIER','Maxime',NULL,'FRA');
INSERT INTO Athlete VALUES (471,'FAUCONNET','Thibaut',NULL,'FRA');
INSERT INTO Athlete VALUES (472,'PIERRON','Veronique',NULL,'FRA');
INSERT INTO Athlete VALUES (473,'BARNES','Lanny',NULL,'USA');
INSERT INTO Athlete VALUES (474,'BURKE','Tim',NULL,'USA');
INSERT INTO Athlete VALUES (475,'NEWELL','Andrew',NULL,'USA');
INSERT INTO Athlete VALUES (476,'JOHNSON','Anders',NULL,'USA');
INSERT INTO Athlete VALUES (477,'GUAY','Erik',NULL,'CAN');
INSERT INTO Athlete VALUES (478,'JANYK','Michael',NULL,'CAN');
INSERT INTO Athlete VALUES (479,'OSBORNE-PARADIS','Manuel',NULL,'CAN');
INSERT INTO Athlete VALUES (480,'KOCHER','Zina',NULL,'CAN');
INSERT INTO Athlete VALUES (481,'LEGUELLEC','Jean Philippe',NULL,'CAN');
INSERT INTO Athlete VALUES (482,'AMMAR','Amanda',NULL,'CAN');
INSERT INTO Athlete VALUES (483,'KERSHAW','Devon',NULL,'CAN');
INSERT INTO Athlete VALUES (484,'CHEREPANOV','Sergey',NULL,'KAZ');
INSERT INTO Athlete VALUES (485,'ROBICHAUD','Audrey',NULL,'CAN');
INSERT INTO Athlete VALUES (486,'BARMASHOV','Dmitriy',NULL,'KAZ');
INSERT INTO Athlete VALUES (487,'REIHERD','Dmitriy',NULL,'KAZ');
INSERT INTO Athlete VALUES (488,'RYBALOVA','Darya',NULL,'KAZ');
INSERT INTO Athlete VALUES (489,'GOUGH','Alex',NULL,'CAN');
INSERT INTO Athlete VALUES (490,'LIPSCOMB','Crispin',NULL,'CAN');
INSERT INTO Athlete VALUES (491,'MARTIN','Brad',NULL,'CAN');
INSERT INTO Athlete VALUES (492,'NICOLL','Mercedes',NULL,'CAN');
INSERT INTO Athlete VALUES (493,'SCHUSSLER','Brittany',NULL,'CAN');
INSERT INTO Athlete VALUES (494,'BABENKO','Dmitry',NULL,'KAZ');
INSERT INTO Athlete VALUES (495,'ZHIGIN','Aleksandr',NULL,'KAZ');
INSERT INTO Athlete VALUES (496,'KRYZL','Krystof',NULL,'CZE');
INSERT INTO Athlete VALUES (497,'SLESINGR','Michal',NULL,'CZE');
INSERT INTO Athlete VALUES (498,'KUMMEL','Peeter',NULL,'EST');
INSERT INTO Athlete VALUES (499,'REHEMAA','Aivar',NULL,'EST');
INSERT INTO Athlete VALUES (500,'NOUSIAINEN','Ville',NULL,'FIN');
INSERT INTO Athlete VALUES (501,'GLEBOVA','Elena',NULL,'EST');
INSERT INTO Athlete VALUES (502,'RYYNAENEN','Janne',NULL,'FIN');
INSERT INTO Athlete VALUES (503,'KORPI','Janne',NULL,'FIN');
INSERT INTO Athlete VALUES (504,'HAJEK','Antonin',NULL,'CZE');
INSERT INTO Athlete VALUES (505,'MATVEEVA','Natalia',NULL,'RUS');
INSERT INTO Athlete VALUES (506,'COOK','Emily',NULL,'USA');
INSERT INTO Athlete VALUES (507,'KORNILOV','Denis',NULL,'RUS');
INSERT INTO Athlete VALUES (508,'VASSILIEV','Dmitry',NULL,'RUS');
INSERT INTO Athlete VALUES (509,'TUDEGESHEVA','Ekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (510,'HOLLAND','Nate',NULL,'USA');
INSERT INTO Athlete VALUES (511,'ROMMEL','Frank',NULL,'GER');
INSERT INTO Athlete VALUES (512,'UHLAENDER','Katie',NULL,'USA');
INSERT INTO Athlete VALUES (513,'FREDRICKS','Tucker',NULL,'USA');
INSERT INTO Athlete VALUES (514,'LAMB','Maria',NULL,'USA');
INSERT INTO Athlete VALUES (515,'BORODULINA','Tatiana',NULL,'RUS');
INSERT INTO Athlete VALUES (516,'TREJBAL','Filip',NULL,'CZE');
INSERT INTO Athlete VALUES (517,'VRABLIK','Martin',NULL,'CZE');
INSERT INTO Athlete VALUES (518,'GANTNEROVA','Jana',NULL,'SVK');
INSERT INTO Athlete VALUES (519,'LINDELL-VIKARBY','Jessica',NULL,'SWE');
INSERT INTO Athlete VALUES (520,'PIETILAE-HOLMNER','Maria',NULL,'SWE');
INSERT INTO Athlete VALUES (521,'COOK','Stacey',NULL,'USA');
INSERT INTO Athlete VALUES (522,'NYMAN','Steven',NULL,'USA');
INSERT INTO Athlete VALUES (523,'STIEGLER','Resi',NULL,'USA');
INSERT INTO Athlete VALUES (524,'MAKARAINEN','Kaisa',NULL,'FIN');
INSERT INTO Athlete VALUES (525,'GEREKOVA','Jana',NULL,'SVK');
INSERT INTO Athlete VALUES (526,'KAZAR','Matej',NULL,'SVK');
INSERT INTO Athlete VALUES (527,'MATIASKO','Miroslav',NULL,'SVK');
INSERT INTO Athlete VALUES (528,'KOZISEK','Dusan',NULL,'CZE');
INSERT INTO Athlete VALUES (529,'ISHIDA','Masako',NULL,'JPN');
INSERT INTO Athlete VALUES (530,'ONDA','Yuichi',NULL,'JPN');
INSERT INTO Athlete VALUES (531,'OTCENAS','Martin',NULL,'SVK');
INSERT INTO Athlete VALUES (532,'PROCHAZKOVA','Alena',NULL,'SVK');
INSERT INTO Athlete VALUES (533,'NORGREN','Britta',NULL,'SWE');
INSERT INTO Athlete VALUES (534,'ITO','Miki',NULL,'JPN');
INSERT INTO Athlete VALUES (535,'SPETT','Per',NULL,'SWE');
INSERT INTO Athlete VALUES (536,'NINIS','Jozef',NULL,'SVK');
INSERT INTO Athlete VALUES (537,'GILLINGS','Zoe',NULL,'GBR');
INSERT INTO Athlete VALUES (538,'FUJIMORI','Yuka',NULL,'JPN');
INSERT INTO Athlete VALUES (539,'POUTALA','Mika',NULL,'FIN');
INSERT INTO Athlete VALUES (540,'OIKAWA','Yuya',NULL,'JPN');
INSERT INTO Athlete VALUES (541,'NIGG','Marina',NULL,'LIE');
INSERT INTO Athlete VALUES (542,'WEIRATHER','Tina',NULL,'LIE');
INSERT INTO Athlete VALUES (543,'HALLENBARTER','Simon',NULL,'SUI');
INSERT INTO Athlete VALUES (544,'GRYGORENKO','Kateryna',NULL,'UKR');
INSERT INTO Athlete VALUES (545,'LAMBERT','Thomas',NULL,'SUI');
INSERT INTO Athlete VALUES (546,'ULRICH','Renato',NULL,'SUI');
INSERT INTO Athlete VALUES (547,'ABRAMENKO','Oleksandr',NULL,'UKR');
INSERT INTO Athlete VALUES (548,'KOCHER','Martina',NULL,'SUI');
INSERT INTO Athlete VALUES (549,'KIS','Andriy',NULL,'UKR');
INSERT INTO Athlete VALUES (550,'KIRKOVA','Maria',NULL,'BUL');
INSERT INTO Athlete VALUES (551,'BARTHET','Anne-Sophie',NULL,'FRA');
INSERT INTO Athlete VALUES (552,'FANARA','Thomas',NULL,'FRA');
INSERT INTO Athlete VALUES (553,'GRANGE','Jean-Baptiste',NULL,'FRA');
INSERT INTO Athlete VALUES (554,'MARCHAND-ARVIER','Marie',NULL,'FRA');
INSERT INTO Athlete VALUES (555,'THEAUX','Adrien',NULL,'FRA');
INSERT INTO Athlete VALUES (556,'COSTAZZA','Chiara',NULL,'ITA');
INSERT INTO Athlete VALUES (557,'FANCHINI','Elena',NULL,'ITA');
INSERT INTO Athlete VALUES (558,'FANCHINI','Nadia',NULL,'ITA');
INSERT INTO Athlete VALUES (559,'FILL','Peter',NULL,'ITA');
INSERT INTO Athlete VALUES (560,'HEEL','Werner',NULL,'ITA');
INSERT INTO Athlete VALUES (561,'MERIGHETTI','Daniela',NULL,'ITA');
INSERT INTO Athlete VALUES (562,'MOELGG','Manfred',NULL,'ITA');
INSERT INTO Athlete VALUES (563,'STUFFER','Verena',NULL,'ITA');
INSERT INTO Athlete VALUES (564,'THALER','Patrick',NULL,'ITA');
INSERT INTO Athlete VALUES (565,'FOURCADE','Simon',NULL,'FRA');
INSERT INTO Athlete VALUES (566,'WINDISCH','Markus',NULL,'ITA');
INSERT INTO Athlete VALUES (567,'DE LORENZI','Christian',NULL,'ITA');
INSERT INTO Athlete VALUES (568,'BOTTOMLEY','Esther',NULL,'AUS');
INSERT INTO Athlete VALUES (569,'FISCHER','Remo',NULL,'SUI');
INSERT INTO Athlete VALUES (570,'LIVERS','Toni',NULL,'SUI');
INSERT INTO Athlete VALUES (571,'PERL','Curdin',NULL,'SUI');
INSERT INTO Athlete VALUES (572,'LI','Hongxue',NULL,'CHN');
INSERT INTO Athlete VALUES (573,'MAN','Dandan',NULL,'CHN');
INSERT INTO Athlete VALUES (574,'REN','Long',NULL,'CHN');
INSERT INTO Athlete VALUES (575,'CLARA','Roland',NULL,'ITA');
INSERT INTO Athlete VALUES (576,'PASINI','Fabio',NULL,'ITA');
INSERT INTO Athlete VALUES (577,'LEE','Chae-Won',NULL,'KOR');
INSERT INTO Athlete VALUES (578,'CHENG','Shuang',NULL,'CHN');
INSERT INTO Athlete VALUES (579,'ZHANG','Xin',NULL,'CHN');
INSERT INTO Athlete VALUES (580,'MATIZ','Giacomo',NULL,'ITA');
INSERT INTO Athlete VALUES (581,'SCANZIO','Deborah',NULL,'ITA');
INSERT INTO Athlete VALUES (582,'BRAUD','Francois',NULL,'FRA');
INSERT INTO Athlete VALUES (583,'LAHEURTE','Maxime',NULL,'FRA');
INSERT INTO Athlete VALUES (584,'BRESADOLA','Davide',NULL,'ITA');
INSERT INTO Athlete VALUES (585,'MICHIELLI','Giuseppe',NULL,'ITA');
INSERT INTO Athlete VALUES (586,'CRAWFORD','Holly',NULL,'AUS');
INSERT INTO Athlete VALUES (587,'JEKOVA','Alexandra',NULL,'BUL');
INSERT INTO Athlete VALUES (588,'SUN','Zhifeng',NULL,'CHN');
INSERT INTO Athlete VALUES (589,'RODRIGUEZ','Sophie',NULL,'FRA');
INSERT INTO Athlete VALUES (590,'BOCCACINI','Corinna',NULL,'ITA');
INSERT INTO Athlete VALUES (591,'ERLACHER','Meinhard',NULL,'ITA');
INSERT INTO Athlete VALUES (592,'MAAS','Cheryl',NULL,'NED');
INSERT INTO Athlete VALUES (593,'COLLOREDO','Sebastian',NULL,'ITA');
INSERT INTO Athlete VALUES (594,'STEELE','Michelle',NULL,'AUS');
INSERT INTO Athlete VALUES (595,'OIOLI','Maurizio',NULL,'ITA');
INSERT INTO Athlete VALUES (596,'CONFORTOLA','Yuri',NULL,'ITA');
INSERT INTO Athlete VALUES (597,'KERSTHOLT','Niels',NULL,'NED');
INSERT INTO Athlete VALUES (598,'ZHANG','Shuang',NULL,'CHN');
INSERT INTO Athlete VALUES (599,'LEE','Bo Ra',NULL,'KOR');
INSERT INTO Athlete VALUES (600,'LEE','Kyou-Hyuk',NULL,'KOR');
INSERT INTO Athlete VALUES (601,'SANDFORD','Ben',NULL,'NZL');
INSERT INTO Athlete VALUES (602,'LOESETH','Nina',NULL,'NOR');
INSERT INTO Athlete VALUES (603,'DOLIDOWITSCH','Sergei',NULL,'BLR');
INSERT INTO Athlete VALUES (604,'LASUTKIN','Alexander',NULL,'BLR');
INSERT INTO Athlete VALUES (605,'SANNIKOVA','Alena',NULL,'BLR');
INSERT INTO Athlete VALUES (606,'GJERDALEN','Tord Asle',NULL,'NOR');
INSERT INTO Athlete VALUES (607,'WURM','Harald',NULL,'AUT');
INSERT INTO Athlete VALUES (608,'DAMJANOVSKI','Darko',NULL,'MKD');
INSERT INTO Athlete VALUES (609,'PFEIFER','Viktor',NULL,'AUT');
INSERT INTO Athlete VALUES (610,'PFISTER','Daniel',NULL,'AUT');
INSERT INTO Athlete VALUES (611,'MACOVEI','Bogdan',NULL,'MDA');
INSERT INTO Athlete VALUES (612,'MOLL','Susanne',NULL,'AUT');
INSERT INTO Athlete VALUES (613,'SCHAIRER','Markus',NULL,'AUT');
INSERT INTO Athlete VALUES (614,'SAMSAL','Dalibor',NULL,'CRO');
INSERT INTO Athlete VALUES (615,'ZRNCIC-DIM','Natko',NULL,'CRO');
INSERT INTO Athlete VALUES (616,'BAUER','Klemen',NULL,'SLO');
INSERT INTO Athlete VALUES (617,'SHERPA','Dachhiri',NULL,'NEP');
INSERT INTO Athlete VALUES (618,'DAMJAN','Jernej',NULL,'SLO');
INSERT INTO Athlete VALUES (619,'FLANDER','Rok',NULL,'SLO');
INSERT INTO Athlete VALUES (620,'SUSTERSIC','Izidor',NULL,'SLO');
INSERT INTO Athlete VALUES (621,'GUTIERREZ','Mireia',NULL,'AND');
INSERT INTO Athlete VALUES (622,'PALKA','Krystyna',NULL,'POL');
INSERT INTO Athlete VALUES (623,'PLYWACZYK','Krzysztof',NULL,'POL');
INSERT INTO Athlete VALUES (624,'ORGUE','Laura',NULL,'ESP');
INSERT INTO Athlete VALUES (625,'KRECZMER','Maciej',NULL,'POL');
INSERT INTO Athlete VALUES (626,'LIGOCKI','Mateusz',NULL,'POL');
INSERT INTO Athlete VALUES (627,'LIGOCKI','Michal',NULL,'POL');
INSERT INTO Athlete VALUES (628,'ZYLA','Piotr',NULL,'POL');
INSERT INTO Athlete VALUES (629,'WAS','Artur',NULL,'POL');
INSERT INTO Athlete VALUES (630,'KNOCH','Viktor',NULL,'HUN');
INSERT INTO Athlete VALUES (631,'TOLA','Erjon',NULL,'ALB');
INSERT INTO Athlete VALUES (632,'CASTELLET','Queralt',NULL,'ESP');
INSERT INTO Athlete VALUES (633,'NOVAKOVIC','Zana',NULL,'BIH');
INSERT INTO Athlete VALUES (634,'COLETTI','Alexandra',NULL,'MON');
INSERT INTO Athlete VALUES (635,'JENOT','Olivier',NULL,'MON');
INSERT INTO Athlete VALUES (636,'ZAKURDAEV','Igor',NULL,'KAZ');
INSERT INTO Athlete VALUES (637,'KOSHKIN','Dmitriy',NULL,'KAZ');
INSERT INTO Athlete VALUES (638,'BEDAREVA','Maria',NULL,'RUS');
INSERT INTO Athlete VALUES (639,'ZUEV','Stepan',NULL,'RUS');
INSERT INTO Athlete VALUES (640,'YAKOVISHINA','Elena',NULL,'RUS');
INSERT INTO Athlete VALUES (641,'SEJERSTED','Lotte Smiseth',NULL,'NOR');
INSERT INTO Athlete VALUES (642,'BYDLINSKI','Maciej',NULL,'POL');
INSERT INTO Athlete VALUES (643,'KLUS','Aleksandra',NULL,'POL');
INSERT INTO Athlete VALUES (644,'TRAVERS','Dow',NULL,'CAY');
INSERT INTO Athlete VALUES (645,'BENIANIDZE','Alex',NULL,'GEO');
INSERT INTO Athlete VALUES (646,'PAPAMICHAEL','Constantinos',NULL,'CYP');
INSERT INTO Athlete VALUES (647,'LONGHI','Jhonatan',NULL,'BRA');
INSERT INTO Athlete VALUES (648,'HARRISSON','Maya',NULL,'BRA');
INSERT INTO Athlete VALUES (649,'NOVOSELIC','Sofija',NULL,'CRO');
INSERT INTO Athlete VALUES (650,'TSIKLAURI','Nino',NULL,'GEO');
INSERT INTO Athlete VALUES (651,'BARBU','Alexandru',NULL,'ROU');
INSERT INTO Athlete VALUES (652,'LOESETH','Mona',NULL,'NOR');
INSERT INTO Athlete VALUES (653,'LINDNER','Georg',NULL,'MDA');
INSERT INTO Athlete VALUES (654,'GROSS','Stefano',NULL,'ITA');
INSERT INTO Athlete VALUES (655,'PARIS','Dominik',NULL,'ITA');
INSERT INTO Athlete VALUES (656,'IGNJATOVIC','Nevena',NULL,'SRB');
INSERT INTO Athlete VALUES (657,'BRIGNONE','Federica',NULL,'ITA');
INSERT INTO Athlete VALUES (658,'MARSAGLIA','Francesca',NULL,'ITA');
INSERT INTO Athlete VALUES (659,'MATSOTSKA','Bogdana',NULL,'UKR');
INSERT INTO Athlete VALUES (660,'FEIERABEND','Denise',NULL,'SUI');
INSERT INTO Athlete VALUES (661,'CARRERAS','Pol',NULL,'ESP');
INSERT INTO Athlete VALUES (662,'PREFONTAINE','Marie-Pier',NULL,'CAN');
INSERT INTO Athlete VALUES (663,'GAGNON','Marie-Michele',NULL,'CAN');
INSERT INTO Athlete VALUES (664,'SPENCE','Brad',NULL,'CAN');
INSERT INTO Athlete VALUES (665,'YURKIW','Larisa',NULL,'CAN');
INSERT INTO Athlete VALUES (666,'RALLI','Sophia',NULL,'GRE');
INSERT INTO Athlete VALUES (667,'BASSANI ANTIVARI','Gaia',NULL,'AZE');
INSERT INTO Athlete VALUES (668,'JUNG','Dong-Hyun',NULL,'KOR');
INSERT INTO Athlete VALUES (669,'RISTEVSKI','Antonio',NULL,'MKD');
INSERT INTO Athlete VALUES (670,'BERECZ','Anna',NULL,'HUN');
INSERT INTO Athlete VALUES (671,'FARKAS','Norbert',NULL,'HUN');
INSERT INTO Athlete VALUES (672,'KUDRATOV','Alisher',NULL,'TJK');
INSERT INTO Athlete VALUES (673,'SMITH','Warren Cummings',NULL,'EST');
INSERT INTO Athlete VALUES (674,'ESTEVE RIGAIL','Kevin',NULL,'AND');
INSERT INTO Athlete VALUES (675,'CHAMOUN','Jacky',NULL,'LIB');
INSERT INTO Athlete VALUES (676,'SHKANOVA','Maria',NULL,'BLR');
INSERT INTO Athlete VALUES (677,'SAVEH SHEMSHAKI','Hossein',NULL,'IRI');
INSERT INTO Athlete VALUES (678,'ZVEJNIEKS','Kristaps',NULL,'LAT');
INSERT INTO Athlete VALUES (679,'RODE','Roberts',NULL,'LAT');
INSERT INTO Athlete VALUES (680,'GASUNA','Lelde',NULL,'LAT');
INSERT INTO Athlete VALUES (681,'TERRA','Ferran',NULL,'ESP');
INSERT INTO Athlete VALUES (682,'DE LA CUESTA','Paul',NULL,'ESP');
INSERT INTO Athlete VALUES (683,'PRISADOV','Stefan',NULL,'BUL');
INSERT INTO Athlete VALUES (684,'GEORGIEV','Georgi',NULL,'BUL');
INSERT INTO Athlete VALUES (685,'CHONGAROV','Nikola',NULL,'BUL');
INSERT INTO Athlete VALUES (686,'QUIROGA','Julietta',NULL,'ARG');
INSERT INTO Athlete VALUES (687,'FAARUP','Christoffer',NULL,'DEN');
INSERT INTO Athlete VALUES (688,'GEIGER','Christina',NULL,'GER');
INSERT INTO Athlete VALUES (689,'WIRTH','Barbara',NULL,'GER');
INSERT INTO Athlete VALUES (690,'DOPFER','Fritz',NULL,'GER');
INSERT INTO Athlete VALUES (691,'SANDELL','Marcus',NULL,'FIN');
INSERT INTO Athlete VALUES (692,'RYDING','David',NULL,'GBR');
INSERT INTO Athlete VALUES (693,'HANSDOTTER','Frida',NULL,'SWE');
INSERT INTO Athlete VALUES (694,'KLING','Kajsa',NULL,'SWE');
INSERT INTO Athlete VALUES (695,'HARGIN','Mattias',NULL,'SWE');
INSERT INTO Athlete VALUES (696,'OLSSON','Matts',NULL,'SWE');
INSERT INTO Athlete VALUES (697,'BAECK','Axel',NULL,'SWE');
INSERT INTO Athlete VALUES (698,'GASTALDI','Sebastiano',NULL,'ARG');
INSERT INTO Athlete VALUES (699,'FERK','Marusa',NULL,'SLO');
INSERT INTO Athlete VALUES (700,'STUHEC','Ilka',NULL,'SLO');
INSERT INTO Athlete VALUES (701,'XIA','Lina',NULL,'CHN');
INSERT INTO Athlete VALUES (702,'SMITH','Leanne',NULL,'USA');
INSERT INTO Athlete VALUES (703,'JITLOFF','Tim',NULL,'USA');
INSERT INTO Athlete VALUES (704,'KASPER','Nolan',NULL,'USA');
INSERT INTO Athlete VALUES (705,'FORD','Julia',NULL,'USA');
INSERT INTO Athlete VALUES (706,'CHODOUNSKY','David',NULL,'USA');
INSERT INTO Athlete VALUES (707,'MCJAMES','Megan',NULL,'USA');
INSERT INTO Athlete VALUES (708,'ROSS','Laurenne',NULL,'USA');
INSERT INTO Athlete VALUES (709,'KUCEROVA','Nikol',NULL,'CZE');
INSERT INTO Athlete VALUES (710,'KRIZOVA','Klara',NULL,'CZE');
INSERT INTO Athlete VALUES (711,'PAULATHOVA','Katerina',NULL,'CZE');
INSERT INTO Athlete VALUES (712,'ZEMANOVA','Andrea',NULL,'CZE');
INSERT INTO Athlete VALUES (713,'KUENG','Patrick',NULL,'SUI');
INSERT INTO Athlete VALUES (714,'ABDERHALDEN','Marianne',NULL,'SUI');
INSERT INTO Athlete VALUES (715,'CAVIEZEL','Mauro',NULL,'SUI');
INSERT INTO Athlete VALUES (716,'FEUZ','Beat',NULL,'SUI');
INSERT INTO Athlete VALUES (717,'SUTER','Fabienne',NULL,'SUI');
INSERT INTO Athlete VALUES (718,'KANTOROVA','Barbara',NULL,'SVK');
INSERT INTO Athlete VALUES (719,'LUKACOVA','Barbora',NULL,'SVK');
INSERT INTO Athlete VALUES (720,'SAALOVA','Kristina',NULL,'SVK');
INSERT INTO Athlete VALUES (721,'ZAMPA','Adam',NULL,'SVK');
INSERT INTO Athlete VALUES (722,'BAUMANN','Romed',NULL,'AUT');
INSERT INTO Athlete VALUES (723,'FRANZ','Max',NULL,'AUT');
INSERT INTO Athlete VALUES (724,'SCHILD','Bernadette',NULL,'AUT');
INSERT INTO Athlete VALUES (725,'SCHOERGHOFER','Philipp',NULL,'AUT');
INSERT INTO Athlete VALUES (726,'STREITBERGER','Georg',NULL,'AUT');
INSERT INTO Athlete VALUES (727,'OETTL REYES','Ornella',NULL,'PER');
INSERT INTO Athlete VALUES (728,'OETTL REYES','Manfred',NULL,'PER');
INSERT INTO Athlete VALUES (729,'BAUD','Adeline',NULL,'FRA');
INSERT INTO Athlete VALUES (730,'BERTRAND','Marion',NULL,'FRA');
INSERT INTO Athlete VALUES (731,'MARMOTTAN','Anemone',NULL,'FRA');
INSERT INTO Athlete VALUES (732,'NOENS','Nastasia',NULL,'FRA');
INSERT INTO Athlete VALUES (733,'CLAREY','Johan',NULL,'FRA');
INSERT INTO Athlete VALUES (734,'FAIVRE','Mathieu',NULL,'FRA');
INSERT INTO Athlete VALUES (735,'FAYED','Guillermo',NULL,'FRA');
INSERT INTO Athlete VALUES (736,'MERMILLOD BLONDIN','Thomas',NULL,'FRA');
INSERT INTO Athlete VALUES (737,'POISSON','David',NULL,'FRA');
INSERT INTO Athlete VALUES (738,'VORONOV','Artem',NULL,'UZB');
INSERT INTO Athlete VALUES (739,'GRIGOREVA','Kseniya',NULL,'UZB');
INSERT INTO Athlete VALUES (740,'LAIKERT','Igor',NULL,'BIH');
INSERT INTO Athlete VALUES (741,'RUDIC','Marko',NULL,'BIH');
INSERT INTO Athlete VALUES (742,'PHELAN','Brittany',NULL,'CAN');
INSERT INTO Athlete VALUES (743,'MIELZYNSKI','Erin',NULL,'CAN');
INSERT INTO Athlete VALUES (744,'SIMMERLING','Georgia',NULL,'CAN');
INSERT INTO Athlete VALUES (745,'HOHENLOHE','Hubertus von',NULL,'MEX');
INSERT INTO Athlete VALUES (746,'TORSTI','Samu',NULL,'FIN');
INSERT INTO Athlete VALUES (747,'SEREBRAKIAN','Arman-Ted',NULL,'ARM');
INSERT INTO Athlete VALUES (748,'OLIVERAS','Marc',NULL,'AND');
INSERT INTO Athlete VALUES (749,'HAUGEN','Leif Kristian',NULL,'NOR');
INSERT INTO Athlete VALUES (750,'GILARDONI','Marina',NULL,'SUI');
INSERT INTO Athlete VALUES (751,'SZCZUREK','Lukasz',NULL,'POL');
INSERT INTO Athlete VALUES (752,'NAUMIK','Sergey',NULL,'KAZ');
INSERT INTO Athlete VALUES (753,'SAVITSKIY','Yan',NULL,'KAZ');
INSERT INTO Athlete VALUES (754,'KENESHEV','Dias',NULL,'KAZ');
INSERT INTO Athlete VALUES (755,'TRIFONOV','Alexandr',NULL,'KAZ');
INSERT INTO Athlete VALUES (756,'LEBEDEVA','Marina',NULL,'KAZ');
INSERT INTO Athlete VALUES (757,'SOLEMDAL','Synnoeve',NULL,'NOR');
INSERT INTO Athlete VALUES (758,'SEMENOV','Serhiy',NULL,'UKR');
INSERT INTO Athlete VALUES (759,'SEDNEV','Serguei',NULL,'UKR');
INSERT INTO Athlete VALUES (760,'PRYMA','Artem',NULL,'UKR');
INSERT INTO Athlete VALUES (761,'SUZUKI','Fuyuko',NULL,'JPN');
INSERT INTO Athlete VALUES (762,'KAUKENAS','Tomas',NULL,'LTU');
INSERT INTO Athlete VALUES (763,'LEE','In-Bok',NULL,'KOR');
INSERT INTO Athlete VALUES (764,'MUN','Ji-Hee',NULL,'KOR');
INSERT INTO Athlete VALUES (765,'PINZARU','Victor',NULL,'MDA');
INSERT INTO Athlete VALUES (766,'PETROVIC','Milanko',NULL,'SRB');
INSERT INTO Athlete VALUES (767,'CRAWFORD','Rosanna',NULL,'CAN');
INSERT INTO Athlete VALUES (768,'GREEN','Brendan',NULL,'CAN');
INSERT INTO Athlete VALUES (769,'PERRAS','Scott',NULL,'CAN');
INSERT INTO Athlete VALUES (770,'SMITH','Nathan',NULL,'CAN');
INSERT INTO Athlete VALUES (771,'IMRIE','Megan',NULL,'CAN');
INSERT INTO Athlete VALUES (772,'KOIV','Kauri',NULL,'EST');
INSERT INTO Athlete VALUES (773,'LEHTLA','Kadri',NULL,'EST');
INSERT INTO Athlete VALUES (774,'STEPTSENKO','Danil',NULL,'EST');
INSERT INTO Athlete VALUES (775,'GOMBOS','Karoly',NULL,'HUN');
INSERT INTO Athlete VALUES (776,'JUSKANE','Zanna',NULL,'LAT');
INSERT INTO Athlete VALUES (777,'RASTORGUJEVS','Andrejs',NULL,'LAT');
INSERT INTO Athlete VALUES (778,'ABRAMENKO','Evgeny',NULL,'BLR');
INSERT INTO Athlete VALUES (779,'KALINCHIK','Liudmila',NULL,'BLR');
INSERT INTO Athlete VALUES (780,'PADIAL HERNANDEZ','Victoria',NULL,'ESP');
INSERT INTO Athlete VALUES (781,'ILIEV','Vladimir',NULL,'BUL');
INSERT INTO Athlete VALUES (782,'KENANOV','Miroslav',NULL,'BUL');
INSERT INTO Athlete VALUES (783,'ANEV','Krasimir',NULL,'BUL');
INSERT INTO Athlete VALUES (784,'ALMOUKOV','Alexei',NULL,'AUS');
INSERT INTO Athlete VALUES (785,'STEPHAN','Christoph',NULL,'GER');
INSERT INTO Athlete VALUES (786,'LAUKKANEN','Mari',NULL,'FIN');
INSERT INTO Athlete VALUES (787,'KAUPPINEN','Jarkko',NULL,'FIN');
INSERT INTO Athlete VALUES (788,'SONG','Chaoqing',NULL,'CHN');
INSERT INTO Athlete VALUES (789,'JACKSON','Lee-Steve',NULL,'GBR');
INSERT INTO Athlete VALUES (790,'DOKL','Peter',NULL,'SLO');
INSERT INTO Athlete VALUES (791,'COOK','Annalies',NULL,'USA');
INSERT INTO Athlete VALUES (792,'DUNKLEE','Susan',NULL,'USA');
INSERT INTO Athlete VALUES (793,'STUDEBAKER','Sara',NULL,'USA');
INSERT INTO Athlete VALUES (794,'NORDGREN','Leif',NULL,'USA');
INSERT INTO Athlete VALUES (795,'CURRIER','Russell',NULL,'USA');
INSERT INTO Athlete VALUES (796,'JOLLER','Ivan',NULL,'SUI');
INSERT INTO Athlete VALUES (797,'WEGER','Benjamin',NULL,'SUI');
INSERT INTO Athlete VALUES (798,'CHRAPANOVA','Martina',NULL,'SVK');
INSERT INTO Athlete VALUES (799,'POLIAKOVA','Terezia',NULL,'SVK');
INSERT INTO Athlete VALUES (800,'BESCOND','Anais',NULL,'FRA');
INSERT INTO Athlete VALUES (801,'BOEUF','Alexis',NULL,'FRA');
INSERT INTO Athlete VALUES (802,'BOLLIET','Marine',NULL,'FRA');
INSERT INTO Athlete VALUES (803,'HAELG','Philipp',NULL,'LIE');
INSERT INTO Athlete VALUES (804,'GAFAROV','Anton',NULL,'RUS');
INSERT INTO Athlete VALUES (805,'SHAPOVALOVA','Evgenia',NULL,'RUS');
INSERT INTO Athlete VALUES (806,'SLONOVA','Anastasia',NULL,'KAZ');
INSERT INTO Athlete VALUES (807,'VELICHKO','Yevgeniy',NULL,'KAZ');
INSERT INTO Athlete VALUES (808,'STAROSTIN','Mark',NULL,'KAZ');
INSERT INTO Athlete VALUES (809,'TCHEKALEVA','Yulia',NULL,'RUS');
INSERT INTO Athlete VALUES (810,'VOLZHENTSEV','Stanislav',NULL,'RUS');
INSERT INTO Athlete VALUES (811,'JACOBSEN','Astrid Uhrenholdt',NULL,'NOR');
INSERT INTO Athlete VALUES (812,'ROENNING','Eldar',NULL,'NOR');
INSERT INTO Athlete VALUES (813,'GLOEERSEN','Anders',NULL,'NOR');
INSERT INTO Athlete VALUES (814,'JASKOWIEC','Sylwia',NULL,'POL');
INSERT INTO Athlete VALUES (815,'PEREKHODA','Ruslan',NULL,'UKR');
INSERT INTO Athlete VALUES (816,'ANTSYBOR','Maryna',NULL,'UKR');
INSERT INTO Athlete VALUES (817,'TSESELSKA','Kateryna',NULL,'UKR');
INSERT INTO Athlete VALUES (818,'RIBELA','Leandro',NULL,'BRA');
INSERT INTO Athlete VALUES (819,'MALEC','Vedrana',NULL,'CRO');
INSERT INTO Athlete VALUES (820,'PEPENE','Paul Constantin',NULL,'ROU');
INSERT INTO Athlete VALUES (821,'PUCHIANU','Cornel',NULL,'ROU');
INSERT INTO Athlete VALUES (822,'KARP','Algo',NULL,'EST');
INSERT INTO Athlete VALUES (823,'CAMENSCIC','Alexandra',NULL,'MDA');
INSERT INTO Athlete VALUES (824,'BRANDSDAL','Eirik',NULL,'NOR');
INSERT INTO Athlete VALUES (825,'SMRKOVIC','Rejhan',NULL,'SRB');
INSERT INTO Athlete VALUES (826,'HOFER','David',NULL,'ITA');
INSERT INTO Athlete VALUES (827,'BROCARD','Elisa',NULL,'ITA');
INSERT INTO Athlete VALUES (828,'OJASTE','Triin',NULL,'EST');
INSERT INTO Athlete VALUES (829,'MACIUSZEK','Paulina',NULL,'POL');
INSERT INTO Athlete VALUES (830,'HARVEY','Alex',NULL,'CAN');
INSERT INTO Athlete VALUES (831,'SIMON','Agnes',NULL,'HUN');
INSERT INTO Athlete VALUES (832,'SZABO','Milan',NULL,'HUN');
INSERT INTO Athlete VALUES (833,'ROJO','Imanol',NULL,'ESP');
INSERT INTO Athlete VALUES (834,'CHINBAT','Otgontsetseg',NULL,'MGL');
INSERT INTO Athlete VALUES (835,'TAMMJARV','Karel',NULL,'EST');
INSERT INTO Athlete VALUES (836,'SEYD','Seyed Sattar',NULL,'IRI');
INSERT INTO Athlete VALUES (837,'PAIPALS','Janis',NULL,'LAT');
INSERT INTO Athlete VALUES (838,'LIEPINS','Arvis',NULL,'LAT');
INSERT INTO Athlete VALUES (839,'GUTIERREZ','Javier',NULL,'ESP');
INSERT INTO Athlete VALUES (840,'MALCHEVA','Teodora',NULL,'BUL');
INSERT INTO Athlete VALUES (841,'WATSON','Aimee',NULL,'AUS');
INSERT INTO Athlete VALUES (842,'DUBAREZAVA','Nastassia',NULL,'BLR');
INSERT INTO Athlete VALUES (843,'IVANOU','Aliaksei',NULL,'BLR');
INSERT INTO Athlete VALUES (844,'PETERS','Kari',NULL,'LUX');
INSERT INTO Athlete VALUES (845,'WENZL','Josef',NULL,'GER');
INSERT INTO Athlete VALUES (846,'MALVALEHTO','Mona-Lisa',NULL,'FIN');
INSERT INTO Athlete VALUES (847,'HEIKKINEN','Matti',NULL,'FIN');
INSERT INTO Athlete VALUES (848,'JYLHAE','Martti',NULL,'FIN');
INSERT INTO Athlete VALUES (849,'LEHTONEN','Lari',NULL,'FIN');
INSERT INTO Athlete VALUES (850,'PENTSINEN','Anssi',NULL,'FIN');
INSERT INTO Athlete VALUES (851,'MUSGRAVE','Andrew',NULL,'GBR');
INSERT INTO Athlete VALUES (852,'MUSGRAVE','Rosamund',NULL,'GBR');
INSERT INTO Athlete VALUES (853,'SMITH','Callum',NULL,'GBR');
INSERT INTO Athlete VALUES (854,'YOUNG','Andrew',NULL,'GBR');
INSERT INTO Athlete VALUES (855,'MURPHY','Tucker',NULL,'BER');
INSERT INTO Athlete VALUES (856,'LINDBORG','Sara',NULL,'SWE');
INSERT INTO Athlete VALUES (857,'JEZERSEK','Barbara',NULL,'SLO');
INSERT INTO Athlete VALUES (858,'VISNAR','Katja',NULL,'SLO');
INSERT INTO Athlete VALUES (859,'XU','Wenlong',NULL,'CHN');
INSERT INTO Athlete VALUES (860,'SUN','Qinghai',NULL,'CHN');
INSERT INTO Athlete VALUES (861,'STEPHEN','Elizabeth',NULL,'USA');
INSERT INTO Athlete VALUES (862,'HOFFMAN','Noah',NULL,'USA');
INSERT INTO Athlete VALUES (863,'NOVAK','Petr',NULL,'CZE');
INSERT INTO Athlete VALUES (864,'RAZYM','Ales',NULL,'CZE');
INSERT INTO Athlete VALUES (865,'MORAVCOVA','Klara',NULL,'CZE');
INSERT INTO Athlete VALUES (866,'KINDSCHI','Joeri',NULL,'SUI');
INSERT INTO Athlete VALUES (867,'VAN DER GRAAFF','Laurien',NULL,'SUI');
INSERT INTO Athlete VALUES (868,'BONER','Seraina',NULL,'SUI');
INSERT INTO Athlete VALUES (869,'KOTSCHOVA','Daniela',NULL,'SVK');
INSERT INTO Athlete VALUES (870,'MLYNAR','Peter',NULL,'SVK');
INSERT INTO Athlete VALUES (871,'DUERR','Johannes',NULL,'AUT');
INSERT INTO Athlete VALUES (872,'SMUTNA','Katerina',NULL,'AUT');
INSERT INTO Athlete VALUES (873,'CARCELEN','Roberto',NULL,'PER');
INSERT INTO Athlete VALUES (874,'FAIVRE PICON','Anouk',NULL,'FRA');
INSERT INTO Athlete VALUES (875,'GAILLARD','Cyril',NULL,'FRA');
INSERT INTO Athlete VALUES (876,'HUGUE','Coraline',NULL,'FRA');
INSERT INTO Athlete VALUES (877,'MIRANDA','Cyril',NULL,'FRA');
INSERT INTO Athlete VALUES (878,'KARISIK','Tanja',NULL,'BIH');
INSERT INTO Athlete VALUES (879,'PLAKALOVIC','Mladen',NULL,'BIH');
INSERT INTO Athlete VALUES (880,'CALDWELL','Sophie',NULL,'USA');
INSERT INTO Athlete VALUES (881,'HALFVARSSON','Calle',NULL,'SWE');
INSERT INTO Athlete VALUES (882,'GAIAZOVA','Daria',NULL,'CAN');
INSERT INTO Athlete VALUES (883,'WEBSTER','Brittany',NULL,'CAN');
INSERT INTO Athlete VALUES (884,'JONES','Perianne',NULL,'CAN');
INSERT INTO Athlete VALUES (885,'BROOKS','Holly',NULL,'USA');
INSERT INTO Athlete VALUES (886,'WATSON','Callum',NULL,'AUS');
INSERT INTO Athlete VALUES (887,'HAMILTON','Simeon',NULL,'USA');
INSERT INTO Athlete VALUES (888,'MIKAYELYAN','Sergey',NULL,'ARM');
INSERT INTO Athlete VALUES (889,'VOLKOV','Andrey',NULL,'RUS');
INSERT INTO Athlete VALUES (890,'VOLKOV','Sergey',NULL,'RUS');
INSERT INTO Athlete VALUES (891,'KOROTKOV','Egor',NULL,'RUS');
INSERT INTO Athlete VALUES (892,'LIVINSKAYA','Yulia',NULL,'RUS');
INSERT INTO Athlete VALUES (893,'MOZHAEV','Sergey',NULL,'RUS');
INSERT INTO Athlete VALUES (894,'MURATOVA','Elena',NULL,'RUS');
INSERT INTO Athlete VALUES (895,'RAKHIMOVA','Regina',NULL,'RUS');
INSERT INTO Athlete VALUES (896,'PERTAKHIYA','Marika',NULL,'RUS');
INSERT INTO Athlete VALUES (897,'STOLYAROVA','Ekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (898,'GALYSHEVA','Yulia',NULL,'KAZ');
INSERT INTO Athlete VALUES (899,'ARAPBAYEVA','Zhibek',NULL,'KAZ');
INSERT INTO Athlete VALUES (900,'BERESTOVSKIY','Sergei',NULL,'KAZ');
INSERT INTO Athlete VALUES (901,'HOEIE GJEFSEN','Marte',NULL,'NOR');
INSERT INTO Athlete VALUES (902,'POLYUK','Olga',NULL,'UKR');
INSERT INTO Athlete VALUES (903,'MURATA','Arisa',NULL,'JPN');
INSERT INTO Athlete VALUES (904,'NISHI','Nobuyuki',NULL,'JPN');
INSERT INTO Athlete VALUES (905,'ENDO','Sho',NULL,'JPN');
INSERT INTO Athlete VALUES (906,'BORGE LIE','Thomas',NULL,'NOR');
INSERT INTO Athlete VALUES (907,'DELBOSCO','Christopher',NULL,'CAN');
INSERT INTO Athlete VALUES (908,'LEMAN','Brady',NULL,'CAN');
INSERT INTO Athlete VALUES (909,'SEO','Jung-Hwa',NULL,'KOR');
INSERT INTO Athlete VALUES (910,'CREMA','Katya',NULL,'AUS');
INSERT INTO Athlete VALUES (911,'HALL','Sam',NULL,'AUS');
INSERT INTO Athlete VALUES (912,'KNELLER','Scott',NULL,'AUS');
INSERT INTO Athlete VALUES (913,'HUSKOVA','Hanna',NULL,'BLR');
INSERT INTO Athlete VALUES (914,'OSIPAU','Denis',NULL,'BLR');
INSERT INTO Athlete VALUES (915,'CHOI','Jae-Woo',NULL,'KOR');
INSERT INTO Athlete VALUES (916,'ZACHER','Heidi',NULL,'GER');
INSERT INTO Athlete VALUES (917,'QI','Guangpu',NULL,'CHN');
INSERT INTO Athlete VALUES (918,'WU','Chao',NULL,'CHN');
INSERT INTO Athlete VALUES (919,'NING','Qin',NULL,'CHN');
INSERT INTO Athlete VALUES (920,'KIRAMO','Arttu',NULL,'FIN');
INSERT INTO Athlete VALUES (921,'PELLINEN','Jouni',NULL,'FIN');
INSERT INTO Athlete VALUES (922,'FORSLUND','Michael',NULL,'SWE');
INSERT INTO Athlete VALUES (923,'KLOSER','Heidi',NULL,'USA');
INSERT INTO Athlete VALUES (924,'CALDWELL','Ashley',NULL,'USA');
INSERT INTO Athlete VALUES (925,'MCPHIE','Heather',NULL,'USA');
INSERT INTO Athlete VALUES (926,'WILSON','Bradley',NULL,'USA');
INSERT INTO Athlete VALUES (927,'OUTTRIM','Eliza',NULL,'USA');
INSERT INTO Athlete VALUES (928,'DENEEN','Patrick',NULL,'USA');
INSERT INTO Athlete VALUES (929,'VACULIKOVA','Tereza',NULL,'CZE');
INSERT INTO Athlete VALUES (930,'LUEDI','Sanna',NULL,'SUI');
INSERT INTO Athlete VALUES (931,'MUELLER','Katrin',NULL,'SUI');
INSERT INTO Athlete VALUES (932,'NIEDERER','Armin',NULL,'SUI');
INSERT INTO Athlete VALUES (933,'SCHAERER','Tanja',NULL,'SUI');
INSERT INTO Athlete VALUES (934,'SMITH','Fanny',NULL,'SUI');
INSERT INTO Athlete VALUES (935,'FIVA','Alex',NULL,'SUI');
INSERT INTO Athlete VALUES (936,'KOLLER','Patrick',NULL,'AUT');
INSERT INTO Athlete VALUES (937,'OFNER','Katrin',NULL,'AUT');
INSERT INTO Athlete VALUES (938,'ZANGERL','Thomas',NULL,'AUT');
INSERT INTO Athlete VALUES (939,'BENNA','Anthony',NULL,'FRA');
INSERT INTO Athlete VALUES (940,'DAVID','Ophelie',NULL,'FRA');
INSERT INTO Athlete VALUES (941,'DUNCAN','David',NULL,'CAN');
INSERT INTO Athlete VALUES (942,'LIMBACHER','Andrea',NULL,'AUT');
INSERT INTO Athlete VALUES (943,'DUFOUR-LAPOINTE','Maxime',NULL,'CAN');
INSERT INTO Athlete VALUES (944,'MARQUIS','Philippe',NULL,'CAN');
INSERT INTO Athlete VALUES (945,'SCHAUER','Andreas',NULL,'GER');
INSERT INTO Athlete VALUES (946,'RAKIMGALIEV','Abzal',NULL,'KAZ');
INSERT INTO Athlete VALUES (947,'POPOVA','Nataliia',NULL,'UKR');
INSERT INTO Athlete VALUES (948,'SUZUKI','Akiko',NULL,'JPN');
INSERT INTO Athlete VALUES (949,'KELEMEN','Zoltan',NULL,'ROU');
INSERT INTO Athlete VALUES (950,'FERNANDEZ','Javier',NULL,'ESP');
INSERT INTO Athlete VALUES (951,'MARCHEI','Valentina',NULL,'ITA');
INSERT INTO Athlete VALUES (952,'ROMANENKOV','Viktor',NULL,'EST');
INSERT INTO Athlete VALUES (953,'LIEBERS','Peter',NULL,'GER');
INSERT INTO Athlete VALUES (954,'ZHANG','Kexin',NULL,'CHN');
INSERT INTO Athlete VALUES (955,'MCCORKELL','Jenna',NULL,'GBR');
INSERT INTO Athlete VALUES (956,'HELGESSON','Viktoria',NULL,'SWE');
INSERT INTO Athlete VALUES (957,'MAJOROV','Alexander',NULL,'SWE');
INSERT INTO Athlete VALUES (958,'BREZINA','Michal',NULL,'CZE');
INSERT INTO Athlete VALUES (959,'FRANK','Kerstin',NULL,'AUT');
INSERT INTO Athlete VALUES (960,'AMODIO','Florent',NULL,'FRA');
INSERT INTO Athlete VALUES (961,'MACHIDA','Tatsuki',NULL,'JPN');
INSERT INTO Athlete VALUES (962,'PAVLICHENKO','Semen',NULL,'RUS');
INSERT INTO Athlete VALUES (963,'KHOREVA','Natalia',NULL,'RUS');
INSERT INTO Athlete VALUES (964,'KUROWSKI','Maciej',NULL,'POL');
INSERT INTO Athlete VALUES (965,'KANAYAMA','Hidenari',NULL,'JPN');
INSERT INTO Athlete VALUES (966,'MANDZIY','Andriy',NULL,'UKR');
INSERT INTO Athlete VALUES (967,'CRETU','Valentin',NULL,'ROU');
INSERT INTO Athlete VALUES (968,'GASPARINI','Sandra',NULL,'ITA');
INSERT INTO Athlete VALUES (969,'LANGENHAN','Andi',NULL,'GER');
INSERT INTO Athlete VALUES (970,'KIVLENIEKS','Inars',NULL,'LAT');
INSERT INTO Athlete VALUES (971,'MAURINS','Kristaps',NULL,'LAT');
INSERT INTO Athlete VALUES (972,'CARIGIET','Gregory',NULL,'SUI');
INSERT INTO Athlete VALUES (973,'HANSEN','Kate',NULL,'USA');
INSERT INTO Athlete VALUES (974,'HYMAN','Ondrej',NULL,'CZE');
INSERT INTO Athlete VALUES (975,'EGGER','Reinhard',NULL,'AUT');
INSERT INTO Athlete VALUES (976,'KINDL','Wolfgang',NULL,'AUT');
INSERT INTO Athlete VALUES (977,'BUCSIS','Anastasia',NULL,'CAN');
INSERT INTO Athlete VALUES (978,'PANIN','Ivan',NULL,'RUS');
INSERT INTO Athlete VALUES (979,'KOKSLIEN','Mikko',NULL,'NOR');
INSERT INTO Athlete VALUES (980,'KATO','Taihei',NULL,'JPN');
INSERT INTO Athlete VALUES (981,'WATABE','Yoshito',NULL,'JPN');
INSERT INTO Athlete VALUES (982,'BAUER','Armin',NULL,'ITA');
INSERT INTO Athlete VALUES (983,'RUNGGALDIER','Lukas',NULL,'ITA');
INSERT INTO Athlete VALUES (984,'TIIRMAA','Karl-August',NULL,'EST');
INSERT INTO Athlete VALUES (985,'NURMSALU','Kaarel',NULL,'EST');
INSERT INTO Athlete VALUES (986,'BERLOT','Gasper',NULL,'SLO');
INSERT INTO Athlete VALUES (987,'JELENKO','Marjan',NULL,'SLO');
INSERT INTO Athlete VALUES (988,'ORANIC','Mitja',NULL,'SLO');
INSERT INTO Athlete VALUES (989,'FLETCHER','Taylor',NULL,'USA');
INSERT INTO Athlete VALUES (990,'FLETCHER','Bryan',NULL,'USA');
INSERT INTO Athlete VALUES (991,'DVORAK','Miroslav',NULL,'CZE');
INSERT INTO Athlete VALUES (992,'HUG','Tim',NULL,'SUI');
INSERT INTO Athlete VALUES (993,'JODKO','Maciej',NULL,'POL');
INSERT INTO Athlete VALUES (994,'KROL','Aleksandra',NULL,'POL');
INSERT INTO Athlete VALUES (995,'SZTOKFISZ','Karolina',NULL,'POL');
INSERT INTO Athlete VALUES (996,'ZAJAC','Joanna',NULL,'POL');
INSERT INTO Athlete VALUES (997,'TSOY','Valeriya',NULL,'KAZ');
INSERT INTO Athlete VALUES (998,'BOLDYKOV','Andrey',NULL,'RUS');
INSERT INTO Athlete VALUES (999,'DETKOV','Stanislav',NULL,'RUS');
INSERT INTO Athlete VALUES (1000,'SOBOLEV','Alexey',NULL,'RUS');
INSERT INTO Athlete VALUES (1001,'TARASOV','Sergey',NULL,'RUS');
INSERT INTO Athlete VALUES (1002,'OLAFSEN','Helene',NULL,'NOR');
INSERT INTO Athlete VALUES (1003,'ENGELI','Hilde-Katrine',NULL,'NOR');
INSERT INTO Athlete VALUES (1004,'SIVERTZEN','Stian',NULL,'NOR');
INSERT INTO Athlete VALUES (1005,'DUCKWORTH','Alexandra',NULL,'CAN');
INSERT INTO Athlete VALUES (1006,'AONO','Ryo',NULL,'JPN');
INSERT INTO Athlete VALUES (1007,'OKADA','Rana',NULL,'JPN');
INSERT INTO Athlete VALUES (1008,'CHUNDAK','Annamari',NULL,'UKR');
INSERT INTO Athlete VALUES (1009,'PENYAK','Yosyf',NULL,'UKR');
INSERT INTO Athlete VALUES (1010,'MAKAR','Morena',NULL,'CRO');
INSERT INTO Athlete VALUES (1011,'MICIC','Nina',NULL,'SRB');
INSERT INTO Athlete VALUES (1012,'PERATHONER','Emanuel',NULL,'ITA');
INSERT INTO Athlete VALUES (1013,'MARCH','Aaron',NULL,'ITA');
INSERT INTO Athlete VALUES (1014,'BRUTTO','Raffaella',NULL,'ITA');
INSERT INTO Athlete VALUES (1015,'CAI','Xuetong',NULL,'CHN');
INSERT INTO Athlete VALUES (1016,'BERGHUIS','Bell',NULL,'NED');
INSERT INTO Athlete VALUES (1017,'VAN DER WAL','Dolf',NULL,'NED');
INSERT INTO Athlete VALUES (1018,'CALVE','Caroline',NULL,'CAN');
INSERT INTO Athlete VALUES (1019,'FAGAN','Robert',NULL,'CAN');
INSERT INTO Athlete VALUES (1020,'LAMBERT','Michael',NULL,'CAN');
INSERT INTO Athlete VALUES (1021,'LAVIGNE','Ariane',NULL,'CAN');
INSERT INTO Athlete VALUES (1022,'MORISON','Matthew',NULL,'CAN');
INSERT INTO Athlete VALUES (1023,'KIM','Ho-jun',NULL,'KOR');
INSERT INTO Athlete VALUES (1024,'SHIN','Bong-shik',NULL,'KOR');
INSERT INTO Athlete VALUES (1025,'SOBOLEV','Andrey',NULL,'RUS');
INSERT INTO Athlete VALUES (1026,'MARIN TARROCH','Lluis',NULL,'AND');
INSERT INTO Athlete VALUES (1027,'SCHAD','Konstantin',NULL,'GER');
INSERT INTO Athlete VALUES (1028,'LABOECK','Isabella',NULL,'GER');
INSERT INTO Athlete VALUES (1029,'BERGMANN','Alexander',NULL,'GER');
INSERT INTO Athlete VALUES (1030,'LIU','Jiayu',NULL,'CHN');
INSERT INTO Athlete VALUES (1031,'SHI','Wancheng',NULL,'CHN');
INSERT INTO Athlete VALUES (1032,'ZHANG','Yiwei',NULL,'CHN');
INSERT INTO Athlete VALUES (1033,'HERNANDEZ','Regino',NULL,'ESP');
INSERT INTO Athlete VALUES (1034,'YANKOV','Radoslav',NULL,'BUL');
INSERT INTO Athlete VALUES (1035,'PULLIN','Alex',NULL,'AUS');
INSERT INTO Athlete VALUES (1036,'JOHNSTONE','Nathan',NULL,'AUS');
INSERT INTO Athlete VALUES (1037,'SINCLAIR','Rebecca',NULL,'NZL');
INSERT INTO Athlete VALUES (1038,'LAARI','Ilkka-Eemeli',NULL,'FIN');
INSERT INTO Athlete VALUES (1039,'LINDFORS','Anton',NULL,'FIN');
INSERT INTO Athlete VALUES (1040,'MALIN','Markus',NULL,'FIN');
INSERT INTO Athlete VALUES (1041,'HARINGTON','Dominic',NULL,'GBR');
INSERT INTO Athlete VALUES (1042,'KILNER','Ben',NULL,'GBR');
INSERT INTO Athlete VALUES (1043,'MARGUC','Rok',NULL,'SLO');
INSERT INTO Athlete VALUES (1044,'BAUMGARTNER','Nick',NULL,'USA');
INSERT INTO Athlete VALUES (1045,'DAVIS','Danny',NULL,'USA');
INSERT INTO Athlete VALUES (1046,'BRETZ','Gregory',NULL,'USA');
INSERT INTO Athlete VALUES (1047,'BAKES','David',NULL,'CZE');
INSERT INTO Athlete VALUES (1048,'PANCOCHOVA','Sarka',NULL,'CZE');
INSERT INTO Athlete VALUES (1049,'MATTEOTTI','Luca',NULL,'ITA');
INSERT INTO Athlete VALUES (1050,'MICK','Christoph',NULL,'ITA');
INSERT INTO Athlete VALUES (1051,'MEILER','Simona',NULL,'SUI');
INSERT INTO Athlete VALUES (1052,'PURTSCHERT','Nadja',NULL,'SUI');
INSERT INTO Athlete VALUES (1053,'ZOGG','Julie',NULL,'SUI');
INSERT INTO Athlete VALUES (1054,'CANDRIAN','Sina',NULL,'SUI');
INSERT INTO Athlete VALUES (1055,'FLUETSCH','Kaspar',NULL,'SUI');
INSERT INTO Athlete VALUES (1056,'HALLER','Ursina',NULL,'SUI');
INSERT INTO Athlete VALUES (1057,'HALLER','Christian',NULL,'SUI');
INSERT INTO Athlete VALUES (1058,'DOUSCHAN','Hanno',NULL,'AUT');
INSERT INTO Athlete VALUES (1059,'MATHIES','Lukas',NULL,'AUT');
INSERT INTO Athlete VALUES (1060,'MESCHIK','Ina',NULL,'AUT');
INSERT INTO Athlete VALUES (1061,'RAMBERGER','Maria',NULL,'AUT');
INSERT INTO Athlete VALUES (1062,'UNTERKOFLER','Anton',NULL,'AUT');
INSERT INTO Athlete VALUES (1063,'BAISAMY','Johann',NULL,'FRA');
INSERT INTO Athlete VALUES (1064,'DUFOUR','Sylvain',NULL,'FRA');
INSERT INTO Athlete VALUES (1065,'LONGO','Arthur',NULL,'FRA');
INSERT INTO Athlete VALUES (1066,'MOENNE LOCCOZ','Nelly',NULL,'FRA');
INSERT INTO Athlete VALUES (1067,'THOVEX','Mirabelle',NULL,'FRA');
INSERT INTO Athlete VALUES (1068,'REID','Charles',NULL,'CAN');
INSERT INTO Athlete VALUES (1069,'SMITS','Seppe',NULL,'BEL');
INSERT INTO Athlete VALUES (1070,'KOT','Maciej',NULL,'POL');
INSERT INTO Athlete VALUES (1071,'DELLASEGA','Roberto',NULL,'ITA');
INSERT INTO Athlete VALUES (1072,'MORRICE','Trevor',NULL,'CAN');
INSERT INTO Athlete VALUES (1073,'KANG','Chil-Ku',NULL,'KOR');
INSERT INTO Athlete VALUES (1074,'ZOGRAFSKI','Vladimir',NULL,'BUL');
INSERT INTO Athlete VALUES (1075,'TEPES','Jurij',NULL,'SLO');
INSERT INTO Athlete VALUES (1076,'ALEXANDER','Nicholas',NULL,'USA');
INSERT INTO Athlete VALUES (1077,'FAIRALL','Nicholas',NULL,'USA');
INSERT INTO Athlete VALUES (1078,'HLAVA','Lukas',NULL,'CZE');
INSERT INTO Athlete VALUES (1079,'KOUDELKA','Roman',NULL,'CZE');
INSERT INTO Athlete VALUES (1080,'DESCHWANDEN','Gregor',NULL,'SUI');
INSERT INTO Athlete VALUES (1081,'KUBACKI','Dawid',NULL,'POL');
INSERT INTO Athlete VALUES (1082,'BOYD-CLOWES','Mackenzie',NULL,'CAN');
INSERT INTO Athlete VALUES (1083,'CHUDINOV','Sergei',NULL,'RUS');
INSERT INTO Athlete VALUES (1084,'KOMURO','Nozomi',NULL,'JPN');
INSERT INTO Athlete VALUES (1085,'MAZILU','Maria Marinela',NULL,'ROU');
INSERT INTO Athlete VALUES (1086,'VELICU','Dorin Dumitru',NULL,'ROU');
INSERT INTO Athlete VALUES (1087,'FAIRBAIRN','John',NULL,'CAN');
INSERT INTO Athlete VALUES (1088,'MIRAMBELL','Ander',NULL,'ESP');
INSERT INTO Athlete VALUES (1089,'FARROW','John',NULL,'AUS');
INSERT INTO Athlete VALUES (1090,'EUSTACE','Katharine',NULL,'NZL');
INSERT INTO Athlete VALUES (1091,'DALY','John',NULL,'USA');
INSERT INTO Athlete VALUES (1092,'TRESS','Kyle',NULL,'USA');
INSERT INTO Athlete VALUES (1093,'GUGGENBERGER','Matthias',NULL,'AUT');
INSERT INTO Athlete VALUES (1094,'REID','Sarah',NULL,'CAN');
INSERT INTO Athlete VALUES (1095,'DRUSZKIEWICZ','Sebastian',NULL,'POL');
INSERT INTO Athlete VALUES (1096,'KUZIN','Denis',NULL,'KAZ');
INSERT INTO Athlete VALUES (1097,'KRECH','Roman',NULL,'KAZ');
INSERT INTO Athlete VALUES (1098,'GOLIKOVA','Angelina',NULL,'RUS');
INSERT INTO Athlete VALUES (1099,'YESIN','Aleksey',NULL,'RUS');
INSERT INTO Athlete VALUES (1100,'RUMYANTSEV','Aleksandr',NULL,'RUS');
INSERT INTO Athlete VALUES (1101,'CHERNOVA','Anna',NULL,'RUS');
INSERT INTO Athlete VALUES (1102,'PEDERSEN','Sverre Lunde',NULL,'NOR');
INSERT INTO Athlete VALUES (1103,'KAMIJO','Yuji',NULL,'JPN');
INSERT INTO Athlete VALUES (1104,'ISHIZAWA','Shiho',NULL,'JPN');
INSERT INTO Athlete VALUES (1105,'TSUJI','Maki',NULL,'JPN');
INSERT INTO Athlete VALUES (1106,'NOH','Seon Yeong',NULL,'KOR');
INSERT INTO Athlete VALUES (1107,'HEMMER','Mari',NULL,'NOR');
INSERT INTO Athlete VALUES (1108,'NAUTA','Yvonne',NULL,'NED');
INSERT INTO Athlete VALUES (1109,'VAN DER WEIJDEN','Annouk',NULL,'NED');
INSERT INTO Athlete VALUES (1110,'GREGG','Jamie',NULL,'CAN');
INSERT INTO Athlete VALUES (1111,'DUTTON','William',NULL,'CAN');
INSERT INTO Athlete VALUES (1112,'NINZI','Mirko',NULL,'ITA');
INSERT INTO Athlete VALUES (1113,'SILOVS','Haralds',NULL,'LAT');
INSERT INTO Athlete VALUES (1114,'GREIG','Daniel',NULL,'AUS');
INSERT INTO Athlete VALUES (1115,'DOBBIN','Shane',NULL,'NZL');
INSERT INTO Athlete VALUES (1116,'HIRSCHBICHLER','Gabriele',NULL,'GER');
INSERT INTO Athlete VALUES (1117,'BECKERT','Patrick',NULL,'GER');
INSERT INTO Athlete VALUES (1118,'SCHWARZ','Samuel',NULL,'GER');
INSERT INTO Athlete VALUES (1119,'IHLE','Nico',NULL,'GER');
INSERT INTO Athlete VALUES (1120,'QI','Shuai',NULL,'CHN');
INSERT INTO Athlete VALUES (1121,'TODD','Sugar',NULL,'USA');
INSERT INTO Athlete VALUES (1122,'MEEK','Patrick',NULL,'USA');
INSERT INTO Athlete VALUES (1123,'ROOKARD','Jilleanne',NULL,'USA');
INSERT INTO Athlete VALUES (1124,'RICHARDSON','Heather',NULL,'USA');
INSERT INTO Athlete VALUES (1125,'WHITMORE','Mitchell',NULL,'USA');
INSERT INTO Athlete VALUES (1126,'RINGSRED','Anna',NULL,'USA');
INSERT INTO Athlete VALUES (1127,'CHOLEWINSKI','Lauren',NULL,'USA');
INSERT INTO Athlete VALUES (1128,'GUNTHER','Kelly',NULL,'USA');
INSERT INTO Athlete VALUES (1129,'ERBANOVA','Karolina',NULL,'CZE');
INSERT INTO Athlete VALUES (1130,'ROKITA','Anna',NULL,'AUT');
INSERT INTO Athlete VALUES (1131,'BELYAKOVA','Olga',NULL,'RUS');
INSERT INTO Athlete VALUES (1132,'MALISZEWSKA','Patrycja',NULL,'POL');
INSERT INTO Athlete VALUES (1133,'BEKZHANOV','Aydar',NULL,'KAZ');
INSERT INTO Athlete VALUES (1134,'SIMONOVA','Inna',NULL,'KAZ');
INSERT INTO Athlete VALUES (1135,'BYKANOV','Vladislav',NULL,'ISR');
INSERT INTO Athlete VALUES (1136,'TAKAMIDO','Yuzo',NULL,'JPN');
INSERT INTO Athlete VALUES (1137,'SAKASHITA','Satoshi',NULL,'JPN');
INSERT INTO Athlete VALUES (1138,'ITO','Ayuko',NULL,'JPN');
INSERT INTO Athlete VALUES (1139,'SAKAI','Yui',NULL,'JPN');
INSERT INTO Athlete VALUES (1140,'SAKURAI','Biba',NULL,'JPN');
INSERT INTO Athlete VALUES (1141,'SHIMIZU','Sayuri',NULL,'JPN');
INSERT INTO Athlete VALUES (1142,'BLACKBURN','Mackenzie',NULL,'TPE');
INSERT INTO Athlete VALUES (1143,'HEIDUM','Bernadett',NULL,'HUN');
INSERT INTO Athlete VALUES (1144,'KESZLER','Andrea',NULL,'HUN');
INSERT INTO Athlete VALUES (1145,'BERES','Bence',NULL,'HUN');
INSERT INTO Athlete VALUES (1146,'VAN KERKHOF','Yara',NULL,'NED');
INSERT INTO Athlete VALUES (1147,'VAN DER WART','Freek',NULL,'NED');
INSERT INTO Athlete VALUES (1148,'LUI','Pan To Barton',NULL,'HKG');
INSERT INTO Athlete VALUES (1149,'LIU','Qiuhong',NULL,'CHN');
INSERT INTO Athlete VALUES (1150,'LIANG','Wenhao',NULL,'CHN');
INSERT INTO Athlete VALUES (1151,'BODA','Pierre',NULL,'AUS');
INSERT INTO Athlete VALUES (1152,'SEIFERT','Robert',NULL,'GER');
INSERT INTO Athlete VALUES (1153,'CHRISTIE','Elise',NULL,'GBR');
INSERT INTO Athlete VALUES (1154,'GILMARTIN','Charlotte',NULL,'GBR');
INSERT INTO Athlete VALUES (1155,'WHELBOURNE','Jack',NULL,'GBR');
INSERT INTO Athlete VALUES (1156,'SMITH','Jessica',NULL,'USA');
INSERT INTO Athlete VALUES (1157,'LEPAPE','Sebastien',NULL,'FRA');
INSERT INTO Athlete VALUES (1158,'MACE','Benjamin',NULL,'FRA');
INSERT INTO Athlete VALUES (1159,'KOLB','Hanna',NULL,'GER');
INSERT INTO Athlete VALUES (1160,'WOERNER','Anna',NULL,'GER');
INSERT INTO Athlete VALUES (1161,'FISCHER','Thomas',NULL,'GER');
INSERT INTO Athlete VALUES (1162,'COX','Britteny',NULL,'AUS');
INSERT INTO Athlete VALUES (1163,'GRAHAM','Matt',NULL,'AUS');
INSERT INTO Athlete VALUES (1164,'FLISAR','Filip',NULL,'SLO');
INSERT INTO Athlete VALUES (1165,'HILL','Kevin',NULL,'CAN');
INSERT INTO Athlete VALUES (1166,'GULINI','Faye',NULL,'USA');
INSERT INTO Athlete VALUES (1167,'JAMES','Scott',NULL,'AUS');
INSERT INTO Athlete VALUES (1168,'FRENETTE','Peter',NULL,'USA');
INSERT INTO Athlete VALUES (1169,'FREITAG','Richard',NULL,'GER');
INSERT INTO Athlete VALUES (1170,'FANNEMEL','Anders',NULL,'NOR');
INSERT INTO Athlete VALUES (1171,'GILDAY','Michael',NULL,'CAN');
INSERT INTO Athlete VALUES (1172,'ZAVECKAS','Rokas',NULL,'LTU');
INSERT INTO Athlete VALUES (1173,'MYTSAK','Dmytro',NULL,'UKR');
INSERT INTO Athlete VALUES (1174,'SMALL','Greta',NULL,'AUS');
INSERT INTO Athlete VALUES (1175,'VERDU SANCHEZ','Joan',NULL,'AND');
INSERT INTO Athlete VALUES (1176,'ABOLTINA','Agnese',NULL,'LAT');
INSERT INTO Athlete VALUES (1177,'BELL','Florence',NULL,'IRL');
INSERT INTO Athlete VALUES (1178,'TOBI','Triin',NULL,'EST');
INSERT INTO Athlete VALUES (1179,'VALCAREGGI','Massimiliano',NULL,'GRE');
INSERT INTO Athlete VALUES (1180,'MOHBAT','Alexandre',NULL,'LIB');
INSERT INTO Athlete VALUES (1181,'VILHJALMSDOTTIR','Helga Maria',NULL,'ISL');
INSERT INTO Athlete VALUES (1182,'MICHELOTTI','Vincenzo Romano',NULL,'SMR');
INSERT INTO Athlete VALUES (1183,'VLHOVA','Petra',NULL,'SVK');
INSERT INTO Athlete VALUES (1184,'LAMHAMEDI','Adam',NULL,'MAR');
INSERT INTO Athlete VALUES (1185,'SONG','Na',NULL,'CHN');
INSERT INTO Athlete VALUES (1186,'VISHNEVSKAYA','Galina',NULL,'KAZ');
INSERT INTO Athlete VALUES (1187,'GASPARIN','Aita',NULL,'SUI');
INSERT INTO Athlete VALUES (1188,'PREUSS','Franziska',NULL,'GER');
INSERT INTO Athlete VALUES (1189,'PRIPICI','Florin Daniel',NULL,'ROU');
INSERT INTO Athlete VALUES (1190,'KRASOVSKYI','Oleksii',NULL,'UKR');
INSERT INTO Athlete VALUES (1191,'GLANVILLE','Lucy',NULL,'AUS');
INSERT INTO Athlete VALUES (1192,'KIVARI','Lauri',NULL,'FIN');
INSERT INTO Athlete VALUES (1193,'SUMMERHAYES','Katie',NULL,'GBR');
INSERT INTO Athlete VALUES (1194,'MAHLER','Kai',NULL,'SUI');
INSERT INTO Athlete VALUES (1195,'BLUNCK','Aaron',NULL,'USA');
INSERT INTO Athlete VALUES (1196,'KIM','Kwang-Jin',NULL,'KOR');
INSERT INTO Athlete VALUES (1197,'KIM','Haejin',NULL,'KOR');
INSERT INTO Athlete VALUES (1198,'WELLS','Beau-James',NULL,'NZL');
INSERT INTO Athlete VALUES (1199,'YAN','Han',NULL,'CHN');
INSERT INTO Athlete VALUES (1200,'LI','Zijun',NULL,'CHN');
INSERT INTO Athlete VALUES (1201,'PARK','So Youn',NULL,'KOR');
INSERT INTO Athlete VALUES (1202,'MARTINEZ','Michael Christian',NULL,'PHI');
INSERT INTO Athlete VALUES (1203,'FENNELL','John',NULL,'CAN');
INSERT INTO Athlete VALUES (1204,'MALYK','Mitchel',NULL,'CAN');
INSERT INTO Athlete VALUES (1205,'STETSKIV','Olena',NULL,'UKR');
INSERT INTO Athlete VALUES (1206,'FERLAZZO','Alex',NULL,'AUS');
INSERT INTO Athlete VALUES (1207,'ZIRNE','Ulla',NULL,'LAT');
INSERT INTO Athlete VALUES (1208,'VOETTER','Andrea',NULL,'ITA');
INSERT INTO Athlete VALUES (1209,'LIEN','Te-An',NULL,'TPE');
INSERT INTO Athlete VALUES (1210,'BRITCHER','Summer',NULL,'USA');
INSERT INTO Athlete VALUES (1211,'WEST','Tucker',NULL,'USA');
INSERT INTO Athlete VALUES (1212,'KOTENOVA','Vendula',NULL,'CZE');
INSERT INTO Athlete VALUES (1213,'HEROLA','Ilkka',NULL,'FIN');
INSERT INTO Athlete VALUES (1214,'ILVES','Kristjan',NULL,'EST');
INSERT INTO Athlete VALUES (1215,'PORTYK','Tomas',NULL,'CZE');
INSERT INTO Athlete VALUES (1216,'AVTANEEV','Nikita',NULL,'RUS');
INSERT INTO Athlete VALUES (1217,'HOEPFL','Johannes',NULL,'GER');
INSERT INTO Athlete VALUES (1218,'HABLUETZEL','David',NULL,'SUI');
INSERT INTO Athlete VALUES (1219,'GOLD','Arielle',NULL,'USA');
INSERT INTO Athlete VALUES (1220,'KRALJ','Jan',NULL,'SLO');
INSERT INTO Athlete VALUES (1221,'RAVNJAK','Tim-Kevin',NULL,'SLO');
INSERT INTO Athlete VALUES (1222,'TAKANASHI','Sara',NULL,'JPN');
INSERT INTO Athlete VALUES (1223,'HENRICH','Taylor',NULL,'CAN');
INSERT INTO Athlete VALUES (1224,'KOREK','Dusty',NULL,'CAN');
INSERT INTO Athlete VALUES (1225,'LEMARE','Lea',NULL,'FRA');
INSERT INTO Athlete VALUES (1226,'ALTHAUS','Katharina',NULL,'GER');
INSERT INTO Athlete VALUES (1227,'NAGAI','Hideaki',NULL,'JPN');
INSERT INTO Athlete VALUES (1228,'CIESLAR','Adam',NULL,'POL');
INSERT INTO Athlete VALUES (1229,'KLIMOV','Evgeniy',NULL,'RUS');
INSERT INTO Athlete VALUES (1230,'PIHO','Han Hendrik',NULL,'EST');
INSERT INTO Athlete VALUES (1231,'COSTA','Samuel',NULL,'ITA');
INSERT INTO Athlete VALUES (1232,'PASICHNYK','Viktor',NULL,'UKR');
INSERT INTO Athlete VALUES (1233,'LEINONEN','Mikke',NULL,'FIN');
INSERT INTO Athlete VALUES (1234,'VAEHAESOEYRINKI','Eetu',NULL,'FIN');
INSERT INTO Athlete VALUES (1235,'TAKAHASHI','Hiroatsu',NULL,'JPN');
INSERT INTO Athlete VALUES (1236,'SASAHARA','Yuki',NULL,'JPN');
INSERT INTO Athlete VALUES (1237,'ORLOVA','Maria',NULL,'RUS');
INSERT INTO Athlete VALUES (1238,'POTYLITSINA','Olga',NULL,'RUS');
INSERT INTO Athlete VALUES (1239,'NEILSON','Eric',NULL,'CAN');
INSERT INTO Athlete VALUES (1240,'KEFALAS','Alexandros',NULL,'GRE');
INSERT INTO Athlete VALUES (1241,'FLOCK','Janine',NULL,'AUT');
INSERT INTO Athlete VALUES (1242,'MAIER','Raphael',NULL,'AUT');
INSERT INTO Athlete VALUES (1243,'CHAFFER','Lucy',NULL,'AUS');
INSERT INTO Athlete VALUES (1244,'GRIEBEL','Sophia',NULL,'GER');
INSERT INTO Athlete VALUES (1245,'KROECKEL','Alexander',NULL,'GER');
INSERT INTO Athlete VALUES (1246,'THEES','Marion',NULL,'GER');
INSERT INTO Athlete VALUES (1247,'LEE','Hansin',NULL,'KOR');
INSERT INTO Athlete VALUES (1248,'YUN','Sungbin',NULL,'KOR');
INSERT INTO Athlete VALUES (1249,'GREENWOOD','Sean',NULL,'IRL');
INSERT INTO Athlete VALUES (1250,'PRIEDULENA','Lelde',NULL,'LAT');
INSERT INTO Athlete VALUES (1251,'PARSONS','Dominic Edward',NULL,'GBR');
INSERT INTO Athlete VALUES (1252,'TREGYBOV','Nikita',NULL,'RUS');
INSERT INTO Athlete VALUES (1253,'BELOV','Evgeniy',NULL,'RUS');
INSERT INTO Athlete VALUES (1254,'ARDISAUSKAITE','Ingrida',NULL,'LTU');
INSERT INTO Athlete VALUES (1255,'STROLIA','Vytautas',NULL,'LTU');
INSERT INTO Athlete VALUES (1256,'GLAVATSKIKH','Konstantin',NULL,'RUS');
INSERT INTO Athlete VALUES (1257,'TSINZOV','Veselin',NULL,'BUL');
INSERT INTO Athlete VALUES (1258,'GRIDIN','Andrey',NULL,'BUL');
INSERT INTO Athlete VALUES (1259,'GRIGOROVA-BURGOVA','Antoniya',NULL,'BUL');
INSERT INTO Athlete VALUES (1260,'USTIUGOV','Sergey',NULL,'RUS');
INSERT INTO Athlete VALUES (1261,'KUBINSKA','Kornelia',NULL,'POL');
INSERT INTO Athlete VALUES (1262,'SZYMANCZAK','Agnieszka',NULL,'POL');
INSERT INTO Athlete VALUES (1263,'ANTOLEC','Jan',NULL,'POL');
INSERT INTO Athlete VALUES (1264,'GAZUREK','Sebastian',NULL,'POL');
INSERT INTO Athlete VALUES (1265,'KLISZ','Pawel',NULL,'POL');
INSERT INTO Athlete VALUES (1266,'STAREGA','Maciej',NULL,'POL');
INSERT INTO Athlete VALUES (1267,'FERNANDEZ','Yonathan Jesus',NULL,'CHI');
INSERT INTO Athlete VALUES (1268,'DOTSENKO','Anastasia',NULL,'RUS');
INSERT INTO Athlete VALUES (1269,'ZHUKOVA','Natalia',NULL,'RUS');
INSERT INTO Athlete VALUES (1270,'IVANOVA','Julia',NULL,'RUS');
INSERT INTO Athlete VALUES (1271,'KUZIUKOVA','Olga',NULL,'RUS');
INSERT INTO Athlete VALUES (1272,'REZASOLTANI','Farzaneh',NULL,'IRI');
INSERT INTO Athlete VALUES (1273,'KAMINSKAYA','Valiantsina',NULL,'BLR');
INSERT INTO Athlete VALUES (1274,'SARA','Timea',NULL,'ROU');
INSERT INTO Athlete VALUES (1275,'AKHMADIYEV','Yerdos',NULL,'KAZ');
INSERT INTO Athlete VALUES (1276,'VOLOTKA','Denis',NULL,'KAZ');
INSERT INTO Athlete VALUES (1277,'KOLOMINA','Yelena',NULL,'KAZ');
INSERT INTO Athlete VALUES (1278,'OSSIPOVA','Tatyana',NULL,'KAZ');
INSERT INTO Athlete VALUES (1279,'POLTORANIN','Alexey',NULL,'KAZ');
INSERT INTO Athlete VALUES (1280,'RAGOZIN','Roman',NULL,'KAZ');
INSERT INTO Athlete VALUES (1281,'CICHERO','Federico Pablo',NULL,'ARG');
INSERT INTO Athlete VALUES (1282,'AYMONIER','Celia',NULL,'FRA');
INSERT INTO Athlete VALUES (1283,'BACKSCHEIDER','Adrien',NULL,'FRA');
INSERT INTO Athlete VALUES (1284,'GROS','Baptiste',NULL,'FRA');
INSERT INTO Athlete VALUES (1285,'JAY','Renaud',NULL,'FRA');
INSERT INTO Athlete VALUES (1286,'JEAN','Aurore',NULL,'FRA');
INSERT INTO Athlete VALUES (1287,'RANKEL','Raido',NULL,'EST');
INSERT INTO Athlete VALUES (1288,'SELLIS','Siim',NULL,'EST');
INSERT INTO Athlete VALUES (1289,'BABIKOV','Ivan',NULL,'CAN');
INSERT INTO Athlete VALUES (1290,'COCKNEY','Jesse',NULL,'CAN');
INSERT INTO Athlete VALUES (1291,'KILLICK','Graeme',NULL,'CAN');
INSERT INTO Athlete VALUES (1292,'NISHIKAWA','Emily',NULL,'CAN');
INSERT INTO Athlete VALUES (1293,'WIDMER','Heidi',NULL,'CAN');
INSERT INTO Athlete VALUES (1294,'VALJAS','Len',NULL,'CAN');
INSERT INTO Athlete VALUES (1295,'ERIKSON','Hanna',NULL,'SWE');
INSERT INTO Athlete VALUES (1296,'NOECKLER','Dietmar',NULL,'ITA');
INSERT INTO Athlete VALUES (1297,'PELLEGRINO','Federico',NULL,'ITA');
INSERT INTO Athlete VALUES (1298,'PELLEGRIN','Mattia',NULL,'ITA');
INSERT INTO Athlete VALUES (1299,'NIZZI','Enrico',NULL,'ITA');
INSERT INTO Athlete VALUES (1300,'DE FABIANI','Francesco',NULL,'ITA');
INSERT INTO Athlete VALUES (1301,'AGREITER','Debora',NULL,'ITA');
INSERT INTO Athlete VALUES (1302,'DE MARTIN TOPRANIN','Virginia',NULL,'ITA');
INSERT INTO Athlete VALUES (1303,'PILLER','Marina',NULL,'ITA');
INSERT INTO Athlete VALUES (1304,'DEBERTOLIS','Ilaria',NULL,'ITA');
INSERT INTO Athlete VALUES (1305,'VUERICH','Gaia',NULL,'ITA');
INSERT INTO Athlete VALUES (1306,'LAURENT','Greta',NULL,'ITA');
INSERT INTO Athlete VALUES (1307,'KOVACEVIC','Ivana',NULL,'SRB');
INSERT INTO Athlete VALUES (1308,'DADIC','Edi',NULL,'CRO');
INSERT INTO Athlete VALUES (1309,'GOLBERG','Paal',NULL,'NOR');
INSERT INTO Athlete VALUES (1310,'ROETHE','Sjur',NULL,'NOR');
INSERT INTO Athlete VALUES (1311,'SARGENT','Ida',NULL,'USA');
INSERT INTO Athlete VALUES (1312,'DIGGINS','Jessica',NULL,'USA');
INSERT INTO Athlete VALUES (1313,'ROSSITER','Jan',NULL,'IRL');
INSERT INTO Athlete VALUES (1314,'BOLD','Byambadorj',NULL,'MGL');
INSERT INTO Athlete VALUES (1315,'ANGELIS','Apostolos',NULL,'GRE');
INSERT INTO Athlete VALUES (1316,'TSAKIRI','Panagiota',NULL,'GRE');
INSERT INTO Athlete VALUES (1317,'MAYERHOFER','Veronika',NULL,'AUT');
INSERT INTO Athlete VALUES (1318,'SCHWARZ','Nathalie',NULL,'AUT');
INSERT INTO Athlete VALUES (1319,'STADLOBER','Teresa',NULL,'AUT');
INSERT INTO Athlete VALUES (1320,'HAUKE','Max',NULL,'AUT');
INSERT INTO Athlete VALUES (1321,'TRITSCHER','Bernhard',NULL,'AUT');
INSERT INTO Athlete VALUES (1322,'BELLINGHAM','Phillip',NULL,'AUS');
INSERT INTO Athlete VALUES (1323,'SEMENOV','Michail',NULL,'BLR');
INSERT INTO Athlete VALUES (1324,'BING','Thomas',NULL,'GER');
INSERT INTO Athlete VALUES (1325,'DOTZLER','Hannes',NULL,'GER');
INSERT INTO Athlete VALUES (1326,'EISENLAUER','Sebastian',NULL,'GER');
INSERT INTO Athlete VALUES (1327,'BJORNSEN','Sadie',NULL,'USA');
INSERT INTO Athlete VALUES (1328,'GREGG','Brian',NULL,'USA');
INSERT INTO Athlete VALUES (1329,'MIKKONEN','Juho',NULL,'FIN');
INSERT INTO Athlete VALUES (1330,'SARASOJA-LILJA','Riikka',NULL,'FIN');
INSERT INTO Athlete VALUES (1331,'HWANG','Jun-Ho',NULL,'KOR');
INSERT INTO Athlete VALUES (1332,'GROHOVA','Karolina',NULL,'CZE');
INSERT INTO Athlete VALUES (1333,'NOVAKOVA','Petra',NULL,'CZE');
INSERT INTO Athlete VALUES (1334,'VRABCOVA-NYVLTOVA','Eva',NULL,'CZE');
INSERT INTO Athlete VALUES (1335,'ANTYPENKO','Tetyana',NULL,'UKR');
INSERT INTO Athlete VALUES (1336,'DAUSHKANE','Inga',NULL,'LAT');
INSERT INTO Athlete VALUES (1337,'BIRGISSON','Saevar',NULL,'ISL');
INSERT INTO Athlete VALUES (1338,'BJORNSEN','Erik',NULL,'USA');
INSERT INTO Athlete VALUES (1339,'BAUMANN','Jonas',NULL,'SUI');
INSERT INTO Athlete VALUES (1340,'HEDIGER','Jovian',NULL,'SUI');
INSERT INTO Athlete VALUES (1341,'CEBASEK','Alenka',NULL,'SLO');
INSERT INTO Athlete VALUES (1342,'RAZINGER','Nika',NULL,'SLO');
INSERT INTO Athlete VALUES (1343,'KOLAROSKA','Marija',NULL,'MKD');
INSERT INTO Athlete VALUES (1344,'SCHAAD','Roman',NULL,'SUI');
INSERT INTO Athlete VALUES (1345,'YEGHOYAN','Artur',NULL,'ARM');
INSERT INTO Athlete VALUES (1346,'JESPERSEN','Chris Andre',NULL,'NOR');
INSERT INTO Athlete VALUES (1347,'PETITJEAN','Mathilde Amivi',NULL,'TOG');
INSERT INTO Athlete VALUES (1348,'LISOGOR','Marina',NULL,'UKR');
INSERT INTO Athlete VALUES (1349,'ANGER','Lucia',NULL,'GER');
INSERT INTO Athlete VALUES (1350,'BUILLET','Marion',NULL,'FRA');
INSERT INTO Athlete VALUES (1351,'MORRONE DI SILVESTRI','Angelica',NULL,'DMA');
INSERT INTO Athlete VALUES (1352,'DI SILVESTRI','Gary',NULL,'DMA');
INSERT INTO Athlete VALUES (1353,'IQBAL','Nadeem',NULL,'IND');
INSERT INTO Athlete VALUES (1354,'GALSTYAN','Katya',NULL,'ARM');
INSERT INTO Athlete VALUES (1355,'MURAKAMI','Kanako',NULL,'JPN');
INSERT INTO Athlete VALUES (1356,'GE','Misha',NULL,'UZB');
INSERT INTO Athlete VALUES (1357,'BYCHENKO','Alexei',NULL,'ISR');
INSERT INTO Athlete VALUES (1358,'RAYA','Javier',NULL,'ESP');
INSERT INTO Athlete VALUES (1359,'GODOROZHA','Yakov',NULL,'UKR');
INSERT INTO Athlete VALUES (1360,'MEITE','Mae Berenice',NULL,'FRA');
INSERT INTO Athlete VALUES (1361,'RAJICOVA','Nicole',NULL,'SVK');
INSERT INTO Athlete VALUES (1362,'PARKINSON','Paul Bonifacio',NULL,'ITA');
INSERT INTO Athlete VALUES (1363,'DALEMAN','Gabrielle',NULL,'CAN');
INSERT INTO Athlete VALUES (1364,'FIRUS','Liam',NULL,'CAN');
INSERT INTO Athlete VALUES (1365,'HAN','Brooklee',NULL,'AUS');
INSERT INTO Athlete VALUES (1366,'KERRY','Brendan',NULL,'AUS');
INSERT INTO Athlete VALUES (1367,'EDMUNDS','Polina',NULL,'USA');
INSERT INTO Athlete VALUES (1368,'WILLIAMS','Isadora',NULL,'BRA');
INSERT INTO Athlete VALUES (1369,'KIM','Hae Jin',NULL,'KOR');
INSERT INTO Athlete VALUES (1370,'WEINZIERL','Nathalie',NULL,'GER');
INSERT INTO Athlete VALUES (1371,'GJERSEM','Anne Line',NULL,'NOR');
INSERT INTO Athlete VALUES (1372,'UKOLOVA','Elizaveta',NULL,'CZE');
INSERT INTO Athlete VALUES (1373,'HENDRICKX','Jorik',NULL,'BEL');
INSERT INTO Athlete VALUES (1374,'BATURINA','Ekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (1375,'PERETYAGIN','Aleksander',NULL,'RUS');
INSERT INTO Athlete VALUES (1376,'BENYOV','Stanislav',NULL,'BUL');
INSERT INTO Athlete VALUES (1377,'KULS','Ewa',NULL,'POL');
INSERT INTO Athlete VALUES (1378,'WOJTUSCISZYN','Natalia',NULL,'POL');
INSERT INTO Athlete VALUES (1379,'EDNEY','Samuel',NULL,'CAN');
INSERT INTO Athlete VALUES (1380,'JONES','Arianne',NULL,'CAN');
INSERT INTO Athlete VALUES (1381,'MCRAE','Kimberley',NULL,'CAN');
INSERT INTO Athlete VALUES (1382,'BONNEFOY','Morgane',NULL,'FRA');
INSERT INTO Athlete VALUES (1383,'GBUROVA','Viera',NULL,'SVK');
INSERT INTO Athlete VALUES (1384,'ROBATSCHER','Sandra',NULL,'ITA');
INSERT INTO Athlete VALUES (1385,'FISCHNALLER','Dominik',NULL,'ITA');
INSERT INTO Athlete VALUES (1386,'RIEDER','Emanuel',NULL,'ITA');
INSERT INTO Athlete VALUES (1387,'SUNG','Eunryung',NULL,'KOR');
INSERT INTO Athlete VALUES (1388,'KELLY','Aidan',NULL,'USA');
INSERT INTO Athlete VALUES (1389,'MAZDZER','Christopher',NULL,'USA');
INSERT INTO Athlete VALUES (1390,'SHKHUMOVA','Olena',NULL,'UKR');
INSERT INTO Athlete VALUES (1391,'KIM','Donghyeon',NULL,'KOR');
INSERT INTO Athlete VALUES (1392,'KASTLUNGER','Miriam',NULL,'AUT');
INSERT INTO Athlete VALUES (1393,'KOPPANG','Jo Alexander',NULL,'NOR');
INSERT INTO Athlete VALUES (1394,'NOERBECH','Thor Haug',NULL,'NOR');
INSERT INTO Athlete VALUES (1395,'ROLFSEN','Toennes Stang',NULL,'NOR');
INSERT INTO Athlete VALUES (1396,'PLATZER','Birgit',NULL,'AUT');
INSERT INTO Athlete VALUES (1397,'AXENOVA','Yelizaveta',NULL,'KAZ');
INSERT INTO Athlete VALUES (1398,'BANANI','Bruno',NULL,'TGA');
INSERT INTO Athlete VALUES (1399,'KESHAVAN','Shiva',NULL,'IND');
INSERT INTO Athlete VALUES (1400,'SOBOLEVA','Natalia',NULL,'RUS');
INSERT INTO Athlete VALUES (1401,'NEDEFUJI','Ayumu',NULL,'JPN');
INSERT INTO Athlete VALUES (1402,'KADONO','Yuki',NULL,'JPN');
INSERT INTO Athlete VALUES (1403,'KOLEGOV','Valery',NULL,'RUS');
INSERT INTO Athlete VALUES (1404,'KOPRIVITSA','Anton',NULL,'RUS');
INSERT INTO Athlete VALUES (1405,'KHARITONOV','Pavel',NULL,'RUS');
INSERT INTO Athlete VALUES (1406,'LI','Shuang',NULL,'CHN');
INSERT INTO Athlete VALUES (1407,'BANKES','Charlotte',NULL,'FRA');
INSERT INTO Athlete VALUES (1408,'GRIMAL','Clemence',NULL,'FRA');
INSERT INTO Athlete VALUES (1409,'BLASMAN','Jenna',NULL,'CAN');
INSERT INTO Athlete VALUES (1410,'HOLDEN','Jake',NULL,'CAN');
INSERT INTO Athlete VALUES (1411,'LEESON','Marianne',NULL,'CAN');
INSERT INTO Athlete VALUES (1412,'LIVINGSTON','Derek',NULL,'CAN');
INSERT INTO Athlete VALUES (1413,'PARROT','Maxence',NULL,'CAN');
INSERT INTO Athlete VALUES (1414,'ROBANSKE','Christopher',NULL,'CAN');
INSERT INTO Athlete VALUES (1415,'TOUTANT','Sebastien',NULL,'CAN');
INSERT INTO Athlete VALUES (1416,'TSUYUKI','Katie',NULL,'CAN');
INSERT INTO Athlete VALUES (1417,'OBRIEN','Spencer',NULL,'CAN');
INSERT INTO Athlete VALUES (1418,'HERRERO','Laro',NULL,'ESP');
INSERT INTO Athlete VALUES (1419,'OCHNER','Nadya',NULL,'ITA');
INSERT INTO Athlete VALUES (1420,'VISINTIN','Omar',NULL,'ITA');
INSERT INTO Athlete VALUES (1421,'LEONI','Tommaso',NULL,'ITA');
INSERT INTO Athlete VALUES (1422,'MOIOLI','Michela',NULL,'ITA');
INSERT INTO Athlete VALUES (1423,'EGUIBAR','Lucas',NULL,'ESP');
INSERT INTO Athlete VALUES (1424,'MATTSSON','Niklas',NULL,'SWE');
INSERT INTO Athlete VALUES (1425,'THORGREN','Sven',NULL,'SWE');
INSERT INTO Athlete VALUES (1426,'BERGREM','Torgeir',NULL,'NOR');
INSERT INTO Athlete VALUES (1427,'BRAATEN','Gjermund',NULL,'NOR');
INSERT INTO Athlete VALUES (1428,'NORENDAL','Silje',NULL,'NOR');
INSERT INTO Athlete VALUES (1429,'ULSLETTEN','Emil Andre',NULL,'NOR');
INSERT INTO Athlete VALUES (1430,'GASSER','Anna',NULL,'AUT');
INSERT INTO Athlete VALUES (1431,'KRAINER','Adrian',NULL,'AUT');
INSERT INTO Athlete VALUES (1432,'SCHATTSCHNEIDER','Clemens',NULL,'AUT');
INSERT INTO Athlete VALUES (1433,'WEISSENBACHER','Mathias',NULL,'AUT');
INSERT INTO Athlete VALUES (1434,'HAEMMERLE','Alessandro',NULL,'AUT');
INSERT INTO Athlete VALUES (1435,'SHORR','Karly',NULL,'USA');
INSERT INTO Athlete VALUES (1436,'WALKER','Ty',NULL,'USA');
INSERT INTO Athlete VALUES (1437,'GULDEMOND','Charles',NULL,'USA');
INSERT INTO Athlete VALUES (1438,'STASSEL','Ryan',NULL,'USA');
INSERT INTO Athlete VALUES (1439,'JENSON','Jessika',NULL,'USA');
INSERT INTO Athlete VALUES (1440,'GOLD','Taylor',NULL,'USA');
INSERT INTO Athlete VALUES (1441,'JACOB','Trevor',NULL,'USA');
INSERT INTO Athlete VALUES (1442,'HERNANDEZ','Jacqueline',NULL,'USA');
INSERT INTO Athlete VALUES (1443,'BAUMEISTER','Stefan',NULL,'GER');
INSERT INTO Athlete VALUES (1444,'BERG','Paul',NULL,'GER');
INSERT INTO Athlete VALUES (1445,'ENNE','Merika',NULL,'FIN');
INSERT INTO Athlete VALUES (1446,'PAUMOLA','Ville',NULL,'FIN');
INSERT INTO Athlete VALUES (1447,'SUITIALA','Ella',NULL,'FIN');
INSERT INTO Athlete VALUES (1448,'TAKA','Jussi',NULL,'FIN');
INSERT INTO Athlete VALUES (1449,'TONTERI','Roope',NULL,'FIN');
INSERT INTO Athlete VALUES (1450,'KIM','Sang-kyum',NULL,'KOR');
INSERT INTO Athlete VALUES (1451,'BOLTON','Cameron',NULL,'AUS');
INSERT INTO Athlete VALUES (1452,'BROCKHOFF','Belle',NULL,'AUS');
INSERT INTO Athlete VALUES (1453,'CALLISTER','Kent',NULL,'AUS');
INSERT INTO Athlete VALUES (1454,'HUGHES','Jarryd',NULL,'AUS');
INSERT INTO Athlete VALUES (1455,'MAGIROS','Stephanie',NULL,'AUS');
INSERT INTO Athlete VALUES (1456,'TRIGGER','Hannah',NULL,'AUS');
INSERT INTO Athlete VALUES (1457,'LEE','Kwang-ki',NULL,'KOR');
INSERT INTO Athlete VALUES (1458,'OCONNOR','Seamus',NULL,'IRL');
INSERT INTO Athlete VALUES (1459,'NOVAK','Emil',NULL,'CZE');
INSERT INTO Athlete VALUES (1460,'LEDECKA','Ester',NULL,'CZE');
INSERT INTO Athlete VALUES (1461,'FULLER','Aimee',NULL,'GBR');
INSERT INTO Athlete VALUES (1462,'MORGAN','Billy',NULL,'GBR');
INSERT INTO Athlete VALUES (1463,'NICHOLLS','Jamie',NULL,'GBR');
INSERT INTO Athlete VALUES (1464,'GOTLIEB','Shelly',NULL,'NZL');
INSERT INTO Athlete VALUES (1465,'LUXTON','Stefi',NULL,'NZL');
INSERT INTO Athlete VALUES (1466,'PRIOR','Christy',NULL,'NZL');
INSERT INTO Athlete VALUES (1467,'TORR','Rebecca',NULL,'NZL');
INSERT INTO Athlete VALUES (1468,'DEKKER','Michelle',NULL,'NED');
INSERT INTO Athlete VALUES (1469,'DE JONG','Dimi',NULL,'NED');
INSERT INTO Athlete VALUES (1470,'WATTER','Tim',NULL,'SUI');
INSERT INTO Athlete VALUES (1471,'MUELLER','Stefanie',NULL,'SUI');
INSERT INTO Athlete VALUES (1472,'ROHRER','Verena',NULL,'SUI');
INSERT INTO Athlete VALUES (1473,'SCHERRER','Jan',NULL,'SUI');
INSERT INTO Athlete VALUES (1474,'DERUNGS','Isabel',NULL,'SUI');
INSERT INTO Athlete VALUES (1475,'GERBER','Sandra Daniela',NULL,'SUI');
INSERT INTO Athlete VALUES (1476,'JAMES','Marvin',NULL,'SUI');
INSERT INTO Athlete VALUES (1477,'JENNY','Ladina',NULL,'SUI');
INSERT INTO Athlete VALUES (1478,'KOCH','Lucien',NULL,'SUI');
INSERT INTO Athlete VALUES (1479,'KOENZ','Elena',NULL,'SUI');
INSERT INTO Athlete VALUES (1480,'KOTNIK','Gloria',NULL,'SLO');
INSERT INTO Athlete VALUES (1481,'SAKAZUME','Ryosuke',NULL,'JPN');
INSERT INTO Athlete VALUES (1482,'SEREIKAITE','Agne',NULL,'LTU');
INSERT INTO Athlete VALUES (1483,'PROSVIRNOVA','Sofia',NULL,'RUS');
INSERT INTO Athlete VALUES (1484,'REZNIK','Valeriya',NULL,'RUS');
INSERT INTO Athlete VALUES (1485,'SIARHEYU','Maksim',NULL,'BLR');
INSERT INTO Athlete VALUES (1486,'TALAYEVA','Volha',NULL,'BLR');
INSERT INTO Athlete VALUES (1487,'BODOVA','Tatiana',NULL,'SVK');
INSERT INTO Athlete VALUES (1488,'DOTTI','Tommaso',NULL,'ITA');
INSERT INTO Athlete VALUES (1489,'LOBELLO','Anthony',NULL,'ITA');
INSERT INTO Athlete VALUES (1490,'SCOTT','Emily',NULL,'USA');
INSERT INTO Athlete VALUES (1491,'KONYA','Zsofia',NULL,'HUN');
INSERT INTO Athlete VALUES (1492,'LIU SHAOLIN','Sandor',NULL,'HUN');
INSERT INTO Athlete VALUES (1493,'LOCKETT','Deanna',NULL,'AUS');
INSERT INTO Athlete VALUES (1494,'ZHUMAGAZIYEV','Nurbergen',NULL,'KAZ');
INSERT INTO Athlete VALUES (1495,'NIKISHA','Denis',NULL,'KAZ');
INSERT INTO Athlete VALUES (1496,'VLASOVA','Safiya',NULL,'UKR');
INSERT INTO Athlete VALUES (1497,'SIN','Da Woon',NULL,'KOR');
INSERT INTO Athlete VALUES (1498,'PARK','Se Yeong',NULL,'KOR');
INSERT INTO Athlete VALUES (1499,'LEE','Han-Bin',NULL,'KOR');
INSERT INTO Athlete VALUES (1500,'SEIDEL','Anna',NULL,'GER');
INSERT INTO Athlete VALUES (1501,'LOUDIN','Vojtech',NULL,'CZE');
INSERT INTO Athlete VALUES (1502,'PUKITIS','Roberto',NULL,'LAT');
INSERT INTO Athlete VALUES (1503,'SHOEBRIDGE','Richard',NULL,'GBR');
INSERT INTO Athlete VALUES (1504,'VAN RUIJVEN','Lara',NULL,'NED');
INSERT INTO Athlete VALUES (1505,'ITO','Yuki',NULL,'JPN');
INSERT INTO Athlete VALUES (1506,'YAMADA','Yurina',NULL,'JPN');
INSERT INTO Athlete VALUES (1507,'ZIOBRO','Jan',NULL,'POL');
INSERT INTO Athlete VALUES (1508,'PCHELINTSEV','Alexey',NULL,'KAZ');
INSERT INTO Athlete VALUES (1509,'ZHAPAROV','Marat',NULL,'KAZ');
INSERT INTO Athlete VALUES (1510,'CLAIR','Julia',NULL,'FRA');
INSERT INTO Athlete VALUES (1511,'ROMASHOV','Alexey',NULL,'RUS');
INSERT INTO Athlete VALUES (1512,'AVVAKUMOVA','Irina',NULL,'RUS');
INSERT INTO Athlete VALUES (1513,'LAMY CHAPPUIS','Ronan',NULL,'FRA');
INSERT INTO Athlete VALUES (1514,'SAMMELSELG','Siim-Tanel',NULL,'EST');
INSERT INTO Athlete VALUES (1515,'INSAM','Evelyn',NULL,'ITA');
INSERT INTO Athlete VALUES (1516,'RUNGGALDIER','Elena',NULL,'ITA');
INSERT INTO Athlete VALUES (1517,'JAHR','Line',NULL,'NOR');
INSERT INTO Athlete VALUES (1518,'LUNDBY','Maren',NULL,'NOR');
INSERT INTO Athlete VALUES (1519,'SMEBY','Helena Olsson',NULL,'NOR');
INSERT INTO Athlete VALUES (1520,'VELTA','Rune',NULL,'NOR');
INSERT INTO Athlete VALUES (1521,'HAZETDINOV','Ilmir',NULL,'RUS');
INSERT INTO Athlete VALUES (1522,'MAKSIMOCHKIN','Mikhail',NULL,'RUS');
INSERT INTO Athlete VALUES (1523,'ROWLEY','Matthew',NULL,'CAN');
INSERT INTO Athlete VALUES (1524,'TANAKA','Atsuko',NULL,'CAN');
INSERT INTO Athlete VALUES (1525,'VAN','Lindsey',NULL,'USA');
INSERT INTO Athlete VALUES (1526,'HENDRICKSON','Sarah',NULL,'USA');
INSERT INTO Athlete VALUES (1527,'JEROME','Jessica',NULL,'USA');
INSERT INTO Athlete VALUES (1528,'POLYCHRONIDIS','Nico',NULL,'GRE');
INSERT INTO Athlete VALUES (1529,'HOELZL','Chiara',NULL,'AUT');
INSERT INTO Athlete VALUES (1530,'GRAESSLER','Ulrike',NULL,'GER');
INSERT INTO Athlete VALUES (1531,'KYKKAENEN','Julia',NULL,'FIN');
INSERT INTO Athlete VALUES (1532,'MAEAETTAE','Jarkko',NULL,'FIN');
INSERT INTO Athlete VALUES (1533,'MUOTKA','Olli',NULL,'FIN');
INSERT INTO Athlete VALUES (1534,'CHOI','Seou',NULL,'KOR');
INSERT INTO Athlete VALUES (1535,'ERNST','Gianina',NULL,'GER');
INSERT INTO Athlete VALUES (1536,'WINDMUELLER','Bigna',NULL,'SUI');
INSERT INTO Athlete VALUES (1537,'LOGAR','Eva',NULL,'SLO');
INSERT INTO Athlete VALUES (1538,'POZUN','Katja',NULL,'SLO');
INSERT INTO Athlete VALUES (1539,'ROGELJ','Spela',NULL,'SLO');
INSERT INTO Athlete VALUES (1540,'VTIC','Maja',NULL,'SLO');
INSERT INTO Athlete VALUES (1541,'PITEA','Sorin Iulian',NULL,'ROU');
INSERT INTO Athlete VALUES (1542,'KONDO','Taro',NULL,'JPN');
INSERT INTO Athlete VALUES (1543,'SUMIYOSHI','Miyako',NULL,'JPN');
INSERT INTO Athlete VALUES (1544,'KIKUCHI','Ayaka',NULL,'JPN');
INSERT INTO Athlete VALUES (1545,'FUJIMURA','Shoko',NULL,'JPN');
INSERT INTO Athlete VALUES (1546,'YAMANAKA','Daichi',NULL,'JPN');
INSERT INTO Athlete VALUES (1547,'OSHIGIRI','Misaki',NULL,'JPN');
INSERT INTO Athlete VALUES (1548,'TAKAGI','Nana',NULL,'JPN');
INSERT INTO Athlete VALUES (1549,'NOGAL','Artur',NULL,'POL');
INSERT INTO Athlete VALUES (1550,'KOVAL','Denis',NULL,'RUS');
INSERT INTO Athlete VALUES (1551,'KUZNETCOV','Artyom',NULL,'RUS');
INSERT INTO Athlete VALUES (1552,'YUSKOV','Denis',NULL,'RUS');
INSERT INTO Athlete VALUES (1553,'MALYSHEVA','Yekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (1554,'ANDERSSON','David',NULL,'SWE');
INSERT INTO Athlete VALUES (1555,'AYDOVA','Yekaterina',NULL,'KAZ');
INSERT INTO Athlete VALUES (1556,'MEZENTSEV','Fyodor',NULL,'KAZ');
INSERT INTO Athlete VALUES (1557,'SUNG','Ching-Yang',NULL,'TPE');
INSERT INTO Athlete VALUES (1558,'FERNANDEZ','Ewen',NULL,'FRA');
INSERT INTO Athlete VALUES (1559,'BLONDIN','Ivanie',NULL,'CAN');
INSERT INTO Athlete VALUES (1560,'CHRIST','Kali',NULL,'CAN');
INSERT INTO Athlete VALUES (1561,'IRVINE','Kaylin',NULL,'CAN');
INSERT INTO Athlete VALUES (1562,'JUNIO','Gilmore',NULL,'CAN');
INSERT INTO Athlete VALUES (1563,'OUARDI','Muncef',NULL,'CAN');
INSERT INTO Athlete VALUES (1564,'TUTT','Brianne',NULL,'CAN');
INSERT INTO Athlete VALUES (1565,'WOTHERSPOON','Danielle',NULL,'CAN');
INSERT INTO Athlete VALUES (1566,'DE HAITRE','Vincent',NULL,'CAN');
INSERT INTO Athlete VALUES (1567,'DALDOSSI','Yvonne',NULL,'ITA');
INSERT INTO Athlete VALUES (1568,'LOLLOBRIGIDA','Francesca',NULL,'ITA');
INSERT INTO Athlete VALUES (1569,'BOSA','David',NULL,'ITA');
INSERT INTO Athlete VALUES (1570,'GIOVANNINI','Andrea',NULL,'ITA');
INSERT INTO Athlete VALUES (1571,'BOKKO','Hege',NULL,'NOR');
INSERT INTO Athlete VALUES (1572,'HVAMMEN','Espen',NULL,'NOR');
INSERT INTO Athlete VALUES (1573,'LORENTZEN','Havard',NULL,'NOR');
INSERT INTO Athlete VALUES (1574,'SPIELER NILSEN','Simen',NULL,'NOR');
INSERT INTO Athlete VALUES (1575,'NJAATUN','Ida',NULL,'NOR');
INSERT INTO Athlete VALUES (1576,'MANTIA','Joey',NULL,'USA');
INSERT INTO Athlete VALUES (1577,'GARCIA','Jonathan',NULL,'USA');
INSERT INTO Athlete VALUES (1578,'LEHMAN','Emery',NULL,'USA');
INSERT INTO Athlete VALUES (1579,'NAGY','Konrad',NULL,'HUN');
INSERT INTO Athlete VALUES (1580,'BITTNER','Vanessa',NULL,'AUT');
INSERT INTO Athlete VALUES (1581,'HUDEY','Marsha',NULL,'CAN');
INSERT INTO Athlete VALUES (1582,'BOWE','Brittany',NULL,'USA');
INSERT INTO Athlete VALUES (1583,'PULLI','Tommi',NULL,'FIN');
INSERT INTO Athlete VALUES (1584,'KIM','Taeyun',NULL,'KOR');
INSERT INTO Athlete VALUES (1585,'PARK','Seung Ju',NULL,'KOR');
INSERT INTO Athlete VALUES (1586,'KIM','Bo Reum',NULL,'KOR');
INSERT INTO Athlete VALUES (1587,'KIM','Hyun Yung',NULL,'KOR');
INSERT INTO Athlete VALUES (1588,'YANG','Shin Young',NULL,'KOR');
INSERT INTO Athlete VALUES (1589,'GEISREITER','Moritz',NULL,'GER');
INSERT INTO Athlete VALUES (1590,'ANGERMUELLER','Monique',NULL,'GER');
INSERT INTO Athlete VALUES (1591,'BAUMGAERTNER','Alexej',NULL,'GER');
INSERT INTO Athlete VALUES (1592,'KRAUS','Bente',NULL,'GER');
INSERT INTO Athlete VALUES (1593,'ROTH','Denise',NULL,'GER');
INSERT INTO Athlete VALUES (1594,'LI','Dan',NULL,'CHN');
INSERT INTO Athlete VALUES (1595,'ZHAO','Xin',NULL,'CHN');
INSERT INTO Athlete VALUES (1596,'MU','Zhongsheng',NULL,'CHN');
INSERT INTO Athlete VALUES (1597,'BAI','Qiuming',NULL,'CHN');
INSERT INTO Athlete VALUES (1598,'TIAN','Guojun',NULL,'CHN');
INSERT INTO Athlete VALUES (1599,'LI','Qishi',NULL,'CHN');
INSERT INTO Athlete VALUES (1600,'PEETERS','Jelena',NULL,'BEL');
INSERT INTO Athlete VALUES (1601,'SWINGS','Bart',NULL,'BEL');
INSERT INTO Athlete VALUES (1602,'DE JONG','Antoinette',NULL,'NED');
INSERT INTO Athlete VALUES (1603,'WILLIAMSON','Shane',NULL,'JPN');
INSERT INTO Athlete VALUES (1604,'KIM','Junho',NULL,'KOR');
INSERT INTO Athlete VALUES (1605,'SERYAYEV','Yevgeny',NULL,'RUS');
INSERT INTO Athlete VALUES (1606,'SUVOROV','Aleksey',NULL,'RUS');
INSERT INTO Athlete VALUES (1607,'BOGOLYUBSKY','Igor',NULL,'RUS');
INSERT INTO Athlete VALUES (1608,'JANUSKEVICIUTE','Ieva',NULL,'LTU');
INSERT INTO Athlete VALUES (1609,'CLARO','Eugenio',NULL,'CHI');
INSERT INTO Athlete VALUES (1610,'VON APPEN','Henrik',NULL,'CHI');
INSERT INTO Athlete VALUES (1611,'BRACHNER','Patrick',NULL,'AZE');
INSERT INTO Athlete VALUES (1612,'CHRAPEK','Karolina',NULL,'POL');
INSERT INTO Athlete VALUES (1613,'GASIENICA-DANIEL','Maryna',NULL,'POL');
INSERT INTO Athlete VALUES (1614,'GARNIEWICZ','Mateusz',NULL,'POL');
INSERT INTO Athlete VALUES (1615,'JASICZEK','Michal',NULL,'POL');
INSERT INTO Athlete VALUES (1616,'VANDEPUT','Virgile',NULL,'ISR');
INSERT INTO Athlete VALUES (1617,'TAZI','Kenza',NULL,'MAR');
INSERT INTO Athlete VALUES (1618,'KIYADARBANDSARI','Mohammad',NULL,'IRI');
INSERT INTO Athlete VALUES (1619,'ABBASI','Forough',NULL,'IRI');
INSERT INTO Athlete VALUES (1620,'DANILOCHKIN','Yuri',NULL,'BLR');
INSERT INTO Athlete VALUES (1621,'PFIFFNER','Marco',NULL,'LIE');
INSERT INTO Athlete VALUES (1622,'TAYLOR','Alexandra',NULL,'CYP');
INSERT INTO Athlete VALUES (1623,'CAILL','Ania Monica',NULL,'ROU');
INSERT INTO Athlete VALUES (1624,'HADZIC','Tarik',NULL,'MNE');
INSERT INTO Athlete VALUES (1625,'BULATOVIC','Ivana',NULL,'MNE');
INSERT INTO Athlete VALUES (1626,'TRIKHICHEV','Pavel',NULL,'RUS');
INSERT INTO Athlete VALUES (1627,'BANCORA','Salome',NULL,'ARG');
INSERT INTO Athlete VALUES (1628,'BIRKNER KETELHOHN','Jorge F.',NULL,'ARG');
INSERT INTO Athlete VALUES (1629,'ALOPINA','Ksenia',NULL,'RUS');
INSERT INTO Athlete VALUES (1630,'MAYTAKOV','Sergei',NULL,'RUS');
INSERT INTO Athlete VALUES (1631,'NOVIKOV','Vladislav',NULL,'RUS');
INSERT INTO Athlete VALUES (1632,'KHOROSHILOV','Alexander',NULL,'RUS');
INSERT INTO Athlete VALUES (1633,'GLEBOV','Alexander',NULL,'RUS');
INSERT INTO Athlete VALUES (1634,'KHUBER','Martin',NULL,'KAZ');
INSERT INTO Athlete VALUES (1635,'ZHANG','Yuxin',NULL,'CHN');
INSERT INTO Athlete VALUES (1636,'WIKSTROEM','Emelie',NULL,'SWE');
INSERT INTO Athlete VALUES (1637,'HECTOR','Sara',NULL,'SWE');
INSERT INTO Athlete VALUES (1638,'SWENN-LARSSON','Anna',NULL,'SWE');
INSERT INTO Athlete VALUES (1639,'ACHIRILOAIE','Ioan Valeriu',NULL,'ROU');
INSERT INTO Athlete VALUES (1640,'PELLEGRIN','Elise',NULL,'MLT');
INSERT INTO Athlete VALUES (1641,'DE ALIPRANDINI','Luca',NULL,'ITA');
INSERT INTO Athlete VALUES (1642,'BROWN','Philip',NULL,'CAN');
INSERT INTO Athlete VALUES (1643,'PHILP','Trevor',NULL,'CAN');
INSERT INTO Athlete VALUES (1644,'PRIDY','Morgan',NULL,'CAN');
INSERT INTO Athlete VALUES (1645,'TERWIEL','Elli',NULL,'CAN');
INSERT INTO Athlete VALUES (1646,'THOMSEN','Benjamin',NULL,'CAN');
INSERT INTO Athlete VALUES (1647,'NANI','Roberto',NULL,'ITA');
INSERT INTO Athlete VALUES (1648,'BENDIK','Martin',NULL,'SVK');
INSERT INTO Athlete VALUES (1649,'FALAT','Matej',NULL,'SVK');
INSERT INTO Athlete VALUES (1650,'ZAMPA','Andreas',NULL,'SVK');
INSERT INTO Athlete VALUES (1651,'PUENTE TASIAS','Alex',NULL,'ESP');
INSERT INTO Athlete VALUES (1652,'BAMFORD','Emily',NULL,'AUS');
INSERT INTO Athlete VALUES (1653,'CHRYSTAL','Lavinia',NULL,'AUS');
INSERT INTO Athlete VALUES (1654,'DEMSCHAR','Dominic',NULL,'AUS');
INSERT INTO Athlete VALUES (1655,'PERAUDO','Ross',NULL,'AUS');
INSERT INTO Athlete VALUES (1656,'VUKICEVIC','Marko',NULL,'SRB');
INSERT INTO Athlete VALUES (1657,'KOMSIC','Andrea',NULL,'CRO');
INSERT INTO Athlete VALUES (1658,'ZUBCIC','Filip',NULL,'CRO');
INSERT INTO Athlete VALUES (1659,'VIDOVIC','Matej',NULL,'CRO');
INSERT INTO Athlete VALUES (1660,'BRIGOVIC','Sebastian',NULL,'CRO');
INSERT INTO Athlete VALUES (1661,'MIKLOS','Edit',NULL,'HUN');
INSERT INTO Athlete VALUES (1662,'LYNE','Conor',NULL,'IRL');
INSERT INTO Athlete VALUES (1663,'KILDE','Aleksander Aamodt',NULL,'NOR');
INSERT INTO Athlete VALUES (1664,'MOWINCKEL','Ragnhild',NULL,'NOR');
INSERT INTO Athlete VALUES (1665,'SOLEVAAG','Sebastian-Foss',NULL,'NOR');
INSERT INTO Athlete VALUES (1666,'HUETTER','Cornelia',NULL,'AUT');
INSERT INTO Athlete VALUES (1667,'STERZ','Regina',NULL,'AUT');
INSERT INTO Athlete VALUES (1668,'STRIEDINGER','Otmar',NULL,'AUT');
INSERT INTO Athlete VALUES (1669,'GOLDBERG','Jared',NULL,'USA');
INSERT INTO Athlete VALUES (1670,'WILES','Jacqueline',NULL,'USA');
INSERT INTO Athlete VALUES (1671,'LUITZ','Stefan',NULL,'GER');
INSERT INTO Athlete VALUES (1672,'PALONIEMI','Santeri',NULL,'FIN');
INSERT INTO Athlete VALUES (1673,'GANONG','Travis',NULL,'USA');
INSERT INTO Athlete VALUES (1674,'PARK','Je-Yun',NULL,'KOR');
INSERT INTO Athlete VALUES (1675,'GIM','So-Hui',NULL,'KOR');
INSERT INTO Athlete VALUES (1676,'SUCHARITAKUL','Kanes',NULL,'THA');
INSERT INTO Athlete VALUES (1677,'ALESSANDRIA','Arnaud',NULL,'MON');
INSERT INTO Athlete VALUES (1678,'DUBOVSKA','Martina',NULL,'CZE');
INSERT INTO Athlete VALUES (1679,'ONSKULIS','Martins',NULL,'LAT');
INSERT INTO Athlete VALUES (1680,'GUDMUNDSSON','Brynjar Jokull',NULL,'ISL');
INSERT INTO Athlete VALUES (1681,'KRISTGEIRSSON','Einar Kristinn',NULL,'ISL');
INSERT INTO Athlete VALUES (1682,'BARWOOD','Adam',NULL,'NZL');
INSERT INTO Athlete VALUES (1683,'VANAKORN','Vanessa',NULL,'THA');
INSERT INTO Athlete VALUES (1684,'MEHILLI','Suela',NULL,'ALB');
INSERT INTO Athlete VALUES (1685,'CAMPBELL','Jasmine',NULL,'ISV');
INSERT INTO Athlete VALUES (1686,'DIAS','Camille',NULL,'POR');
INSERT INTO Athlete VALUES (1687,'HANSE','Arthur',NULL,'POR');
INSERT INTO Athlete VALUES (1688,'YULE','Daniel',NULL,'SUI');
INSERT INTO Athlete VALUES (1689,'ZENHAEUSERN','Ramon',NULL,'SUI');
INSERT INTO Athlete VALUES (1690,'MURISIER','Justin',NULL,'SUI');
INSERT INTO Athlete VALUES (1691,'AERNI','Luca',NULL,'SUI');
INSERT INTO Athlete VALUES (1692,'CAVIEZEL','Gino',NULL,'SUI');
INSERT INTO Athlete VALUES (1693,'GISIN','Michelle',NULL,'SUI');
INSERT INTO Athlete VALUES (1694,'HOLDENER','Wendy',NULL,'SUI');
INSERT INTO Athlete VALUES (1695,'SELVA','Federica',NULL,'SMR');
INSERT INTO Athlete VALUES (1696,'KOSI','Klemen',NULL,'SLO');
INSERT INTO Athlete VALUES (1697,'KRANJEC','Zan',NULL,'SLO');
INSERT INTO Athlete VALUES (1698,'LAVTAR','Katarina',NULL,'SLO');
INSERT INTO Athlete VALUES (1699,'GOUTT','Yohan Goncalves',NULL,'TLS');
INSERT INTO Athlete VALUES (1700,'STEYN','Luke',NULL,'ZIM');
INSERT INTO Athlete VALUES (1701,'SIMSEK','Emre',NULL,'TUR');
INSERT INTO Athlete VALUES (1702,'KANG','Young-Seo',NULL,'KOR');
INSERT INTO Athlete VALUES (1703,'KOCAAGA','Tugba',NULL,'TUR');
INSERT INTO Athlete VALUES (1704,'KARIM','Muhammad',NULL,'PAK');
INSERT INTO Athlete VALUES (1705,'DIPOL','Alessia Afi',NULL,'TOG');
INSERT INTO Athlete VALUES (1706,'THAKUR','Himanshu',NULL,'IND');
INSERT INTO Athlete VALUES (1707,'KYUNG','Sung Hyun',NULL,'KOR');
INSERT INTO Athlete VALUES (1708,'HOJNISZ','Monika',NULL,'POL');
INSERT INTO Athlete VALUES (1709,'NOWAKOWSKA-ZIEMNIAK','Weronika',NULL,'POL');
INSERT INTO Athlete VALUES (1710,'GUZIK','Grzegorz',NULL,'POL');
INSERT INTO Athlete VALUES (1711,'LEPEL','Rafal',NULL,'POL');
INSERT INTO Athlete VALUES (1712,'SLONINA','Lukasz',NULL,'POL');
INSERT INTO Athlete VALUES (1713,'ZLATEV','Ivan',NULL,'BUL');
INSERT INTO Athlete VALUES (1714,'STOYANOVA','Desislava',NULL,'BUL');
INSERT INTO Athlete VALUES (1715,'NAKAJIMA','Yuki',NULL,'JPN');
INSERT INTO Athlete VALUES (1716,'SUZUKI','Rina',NULL,'JPN');
INSERT INTO Athlete VALUES (1717,'KOBAYASHI','Miki',NULL,'JPN');
INSERT INTO Athlete VALUES (1718,'CHEPELIN','Vladimir',NULL,'BLR');
INSERT INTO Athlete VALUES (1719,'LIADOV','Yuryi',NULL,'BLR');
INSERT INTO Athlete VALUES (1720,'PISAREVA','Nadzeya',NULL,'BLR');
INSERT INTO Athlete VALUES (1721,'LOGINOV','Alexander',NULL,'RUS');
INSERT INTO Athlete VALUES (1722,'GLAZYRINA','Ekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (1723,'PIDRUCHNYI','Dmytro',NULL,'UKR');
INSERT INTO Athlete VALUES (1724,'ZHANG','Yan',NULL,'CHN');
INSERT INTO Athlete VALUES (1725,'TANG','Jialin',NULL,'CHN');
INSERT INTO Athlete VALUES (1726,'DREISSIGACKER','Hannah',NULL,'USA');
INSERT INTO Athlete VALUES (1727,'CHEVALIER','Anais',NULL,'FRA');
INSERT INTO Athlete VALUES (1728,'DESTHIEUX','Simon',NULL,'FRA');
INSERT INTO Athlete VALUES (1729,'LINDSTROEM','Fredrik',NULL,'SWE');
INSERT INTO Athlete VALUES (1730,'ERMITS','Kalev',NULL,'EST');
INSERT INTO Athlete VALUES (1731,'GAIM','Grete',NULL,'EST');
INSERT INTO Athlete VALUES (1732,'TALIHAERM','Johanna',NULL,'EST');
INSERT INTO Athlete VALUES (1733,'YURLOVA','Daria',NULL,'EST');
INSERT INTO Athlete VALUES (1734,'GONTIER','Nicole',NULL,'ITA');
INSERT INTO Athlete VALUES (1735,'RUNGGALDIER','Alexia',NULL,'ITA');
INSERT INTO Athlete VALUES (1736,'FIALKOVA','Paulina',NULL,'SVK');
INSERT INTO Athlete VALUES (1737,'HASILLA','Tomas',NULL,'SVK');
INSERT INTO Athlete VALUES (1738,'LOBO ESCOLAR','Victor',NULL,'ESP');
INSERT INTO Athlete VALUES (1739,'PANTOV','Anton',NULL,'KAZ');
INSERT INTO Athlete VALUES (1740,'RAIKOVA','Alina',NULL,'KAZ');
INSERT INTO Athlete VALUES (1741,'USANOVA','Darya',NULL,'KAZ');
INSERT INTO Athlete VALUES (1742,'BOE','Johannes Thingnes',NULL,'NOR');
INSERT INTO Athlete VALUES (1743,'RINGEN','Elise',NULL,'NOR');
INSERT INTO Athlete VALUES (1744,'ARWIDSON','Tobias',NULL,'SWE');
INSERT INTO Athlete VALUES (1745,'SZOCS','Emoke',NULL,'HUN');
INSERT INTO Athlete VALUES (1746,'SOULIE','Laure',NULL,'AND');
INSERT INTO Athlete VALUES (1747,'HAUSER','Lisa Theresa',NULL,'AUT');
INSERT INTO Athlete VALUES (1748,'INNERHOFER','Katharina',NULL,'AUT');
INSERT INTO Athlete VALUES (1749,'HILDEBRAND','Franziska',NULL,'GER');
INSERT INTO Athlete VALUES (1750,'DAHLMEIER','Laura',NULL,'GER');
INSERT INTO Athlete VALUES (1751,'HEINICKE','Megan',NULL,'CAN');
INSERT INTO Athlete VALUES (1752,'TOIVANEN','Ahti',NULL,'FIN');
INSERT INTO Athlete VALUES (1753,'DAROZHKA','Aliaksandr',NULL,'BLR');
INSERT INTO Athlete VALUES (1754,'KRUPCIK','Tomas',NULL,'CZE');
INSERT INTO Athlete VALUES (1755,'KRCMAR','Michal',NULL,'CZE');
INSERT INTO Athlete VALUES (1756,'LANDOVA','Jitka',NULL,'CZE');
INSERT INTO Athlete VALUES (1757,'PUSKARCIKOVA','Eva',NULL,'CZE');
INSERT INTO Athlete VALUES (1758,'LIGHTFOOT','Amanda',NULL,'GBR');
INSERT INTO Athlete VALUES (1759,'WIESTNER','Serafin',NULL,'SUI');
INSERT INTO Athlete VALUES (1760,'BOECKLI','Claudio',NULL,'SUI');
INSERT INTO Athlete VALUES (1761,'CADURISCH','Irene',NULL,'SUI');
INSERT INTO Athlete VALUES (1762,'GASPARIN','Elisa',NULL,'SUI');
INSERT INTO Athlete VALUES (1763,'OHACO','Dominique',NULL,'CHI');
INSERT INTO Athlete VALUES (1764,'HOSHINO','Junko',NULL,'JPN');
INSERT INTO Athlete VALUES (1765,'TSUDA','Kentaro',NULL,'JPN');
INSERT INTO Athlete VALUES (1766,'MITSUBOSHI','Manami',NULL,'JPN');
INSERT INTO Athlete VALUES (1767,'TAKAO','Chiho',NULL,'JPN');
INSERT INTO Athlete VALUES (1768,'CROOK','Peter',NULL,'IVB');
INSERT INTO Athlete VALUES (1769,'RIEMEN-ZEREBECKA','Karolina',NULL,'POL');
INSERT INTO Athlete VALUES (1770,'CHIRTCOVA','Anastasiia',NULL,'RUS');
INSERT INTO Athlete VALUES (1771,'PAVLENKO','Aleksey',NULL,'RUS');
INSERT INTO Athlete VALUES (1772,'BUROV','Ilya',NULL,'RUS');
INSERT INTO Athlete VALUES (1773,'KROTOV','Pavel',NULL,'RUS');
INSERT INTO Athlete VALUES (1774,'KORSUNOVA','Veronika',NULL,'RUS');
INSERT INTO Athlete VALUES (1775,'ORLOVA','Alexandra',NULL,'RUS');
INSERT INTO Athlete VALUES (1776,'SLIVETS','Assoli',NULL,'RUS');
INSERT INTO Athlete VALUES (1777,'SLIVETS','Timofei',NULL,'RUS');
INSERT INTO Athlete VALUES (1778,'MIRTOVA','Anna',NULL,'RUS');
INSERT INTO Athlete VALUES (1779,'KORPACHEV','Pavel',NULL,'RUS');
INSERT INTO Athlete VALUES (1780,'MAKAGONOVA','Natalya',NULL,'RUS');
INSERT INTO Athlete VALUES (1781,'NABOKIKH','Pavel',NULL,'RUS');
INSERT INTO Athlete VALUES (1782,'CHESNOKOVA','Elizavetta',NULL,'RUS');
INSERT INTO Athlete VALUES (1783,'ALDABERGENOVA','Zhanbota',NULL,'KAZ');
INSERT INTO Athlete VALUES (1784,'INKARBEK','Baglan',NULL,'KAZ');
INSERT INTO Athlete VALUES (1785,'ADELISSE','Antoine',NULL,'FRA');
INSERT INTO Athlete VALUES (1786,'BARON','Alizee',NULL,'FRA');
INSERT INTO Athlete VALUES (1787,'BERGER SABBATEL','Marielle',NULL,'FRA');
INSERT INTO Athlete VALUES (1788,'BERTONI','Xavier',NULL,'FRA');
INSERT INTO Athlete VALUES (1789,'BONNAIRE','Jules',NULL,'FRA');
INSERT INTO Athlete VALUES (1790,'CARADEUX','Anais',NULL,'FRA');
INSERT INTO Athlete VALUES (1791,'CAVET','Benjamin',NULL,'FRA');
INSERT INTO Athlete VALUES (1792,'DEVOUASSOUX','Jonas',NULL,'FRA');
INSERT INTO Athlete VALUES (1793,'KRIEF','Thomas',NULL,'FRA');
INSERT INTO Athlete VALUES (1794,'LAFFONT','Perrine',NULL,'FRA');
INSERT INTO Athlete VALUES (1795,'JOFFROY','Stephanie',NULL,'CHI');
INSERT INTO Athlete VALUES (1796,'PANCRAS','Jeremy',NULL,'FRA');
INSERT INTO Athlete VALUES (1797,'VALENTIN','Benoit',NULL,'FRA');
INSERT INTO Athlete VALUES (1798,'GRIFFITHS','Katia',NULL,'ESP');
INSERT INTO Athlete VALUES (1799,'SLEPECKA','Natalia',NULL,'SVK');
INSERT INTO Athlete VALUES (1800,'STROMKOVA','Zuzana',NULL,'SVK');
INSERT INTO Athlete VALUES (1801,'EDER','Markus',NULL,'ITA');
INSERT INTO Athlete VALUES (1802,'BEAULIEU-MARCHAND','Alex',NULL,'CAN');
INSERT INTO Athlete VALUES (1803,'TSUBOTA','Yuki',NULL,'CAN');
INSERT INTO Athlete VALUES (1804,'DOREY','Justin',NULL,'CAN');
INSERT INTO Athlete VALUES (1805,'GAGNON','Marc-Antoine',NULL,'CAN');
INSERT INTO Athlete VALUES (1806,'GERRITS','Travis',NULL,'CAN');
INSERT INTO Athlete VALUES (1807,'GROENEWOUD','Rosalind',NULL,'CAN');
INSERT INTO Athlete VALUES (1808,'HANSEN','Keltie',NULL,'CAN');
INSERT INTO Athlete VALUES (1809,'MARGETTS','Matt',NULL,'CAN');
INSERT INTO Athlete VALUES (1810,'TURSKI','Kaya',NULL,'CAN');
INSERT INTO Athlete VALUES (1811,'EKLUND','John',NULL,'SWE');
INSERT INTO Athlete VALUES (1812,'BERTAGNA','Silvia',NULL,'ITA');
INSERT INTO Athlete VALUES (1813,'TJADER','Jesper',NULL,'SWE');
INSERT INTO Athlete VALUES (1814,'DAHLSTROM','Emma',NULL,'SWE');
INSERT INTO Athlete VALUES (1815,'FJALLSTROM','Ludvig',NULL,'SWE');
INSERT INTO Athlete VALUES (1816,'BOWMAN','Noah',NULL,'CAN');
INSERT INTO Athlete VALUES (1817,'AURDAL','Aleksander',NULL,'NOR');
INSERT INTO Athlete VALUES (1818,'BRAATEN','Oystein',NULL,'NOR');
INSERT INTO Athlete VALUES (1819,'HAATVEIT','Andreas',NULL,'NOR');
INSERT INTO Athlete VALUES (1820,'JUELL','Didrik Bastian',NULL,'NOR');
INSERT INTO Athlete VALUES (1821,'LINDSTAD','Jon Anders',NULL,'NOR');
INSERT INTO Athlete VALUES (1822,'MITHASSEL','Christian',NULL,'NOR');
INSERT INTO Athlete VALUES (1823,'WESSEL','Hedvig',NULL,'NOR');
INSERT INTO Athlete VALUES (1824,'NAESLUND','Sandra',NULL,'SWE');
INSERT INTO Athlete VALUES (1825,'OEHLING NORBERG','Victor',NULL,'SWE');
INSERT INTO Athlete VALUES (1826,'WESTER','Oscar',NULL,'SWE');
INSERT INTO Athlete VALUES (1827,'HARLAUT','Henrik',NULL,'SWE');
INSERT INTO Athlete VALUES (1828,'PUZDERKO','Mykola',NULL,'UKR');
INSERT INTO Athlete VALUES (1829,'NOVOSAD','Anastasiya',NULL,'UKR');
INSERT INTO Athlete VALUES (1830,'MOKHNATSKA','Nadiya',NULL,'UKR');
INSERT INTO Athlete VALUES (1831,'BAIR','Philomena',NULL,'AUT');
INSERT INTO Athlete VALUES (1832,'GOHL','Andreas',NULL,'AUT');
INSERT INTO Athlete VALUES (1833,'LADNER','Marco',NULL,'AUT');
INSERT INTO Athlete VALUES (1834,'TRIBONDEAU','Luca',NULL,'AUT');
INSERT INTO Athlete VALUES (1835,'WAHRSTOETTER','Christoph',NULL,'AUT');
INSERT INTO Athlete VALUES (1836,'GRIMUS','Anton',NULL,'AUS');
INSERT INTO Athlete VALUES (1837,'HENSHAW','Russell',NULL,'AUS');
INSERT INTO Athlete VALUES (1838,'KENNEDY-SIM','Sami',NULL,'AUS');
INSERT INTO Athlete VALUES (1839,'PARKS','Nicole',NULL,'AUS');
INSERT INTO Athlete VALUES (1840,'PEEL','Laura',NULL,'AUS');
INSERT INTO Athlete VALUES (1841,'SCOTT','Danielle',NULL,'AUS');
INSERT INTO Athlete VALUES (1842,'SEGAL','Anna',NULL,'AUS');
INSERT INTO Athlete VALUES (1843,'SHEEHAN','Amy',NULL,'AUS');
INSERT INTO Athlete VALUES (1844,'SUMMERS','Brodie',NULL,'AUS');
INSERT INTO Athlete VALUES (1845,'WELLS','Samantha',NULL,'AUS');
INSERT INTO Athlete VALUES (1846,'WILLIAMS','Davina',NULL,'AUS');
INSERT INTO Athlete VALUES (1847,'HUNDER','Per Kristian',NULL,'NOR');
INSERT INTO Athlete VALUES (1848,'CURRIER','Lyman',NULL,'USA');
INSERT INTO Athlete VALUES (1849,'VANLAANEN','Angeli',NULL,'USA');
INSERT INTO Athlete VALUES (1850,'BROWN','Bobby',NULL,'USA');
INSERT INTO Athlete VALUES (1851,'YATER-WALLACE','Torin',NULL,'USA');
INSERT INTO Athlete VALUES (1852,'DREW','Annalisa',NULL,'USA');
INSERT INTO Athlete VALUES (1853,'SIGOURNEY','Brita',NULL,'USA');
INSERT INTO Athlete VALUES (1854,'BOHONNON','Mac',NULL,'USA');
INSERT INTO Athlete VALUES (1855,'TELLER','John',NULL,'USA');
INSERT INTO Athlete VALUES (1856,'HERMAN','Keri',NULL,'USA');
INSERT INTO Athlete VALUES (1857,'EIGLER','Florian',NULL,'GER');
INSERT INTO Athlete VALUES (1858,'ZIMMERMANN','Lisa',NULL,'GER');
INSERT INTO Athlete VALUES (1859,'GRASEMANN','Laura',NULL,'GER');
INSERT INTO Athlete VALUES (1860,'BOHNACKER','Daniel',NULL,'GER');
INSERT INTO Athlete VALUES (1861,'CAKMAKLI','Sabrina',NULL,'GER');
INSERT INTO Athlete VALUES (1862,'STAUDINGER','Christina',NULL,'AUT');
INSERT INTO Athlete VALUES (1863,'KEMPPAINEN','Antti-Jussi',NULL,'FIN');
INSERT INTO Athlete VALUES (1864,'MIETTUNEN','Ville',NULL,'FIN');
INSERT INTO Athlete VALUES (1865,'PENTTALA','Jussi',NULL,'FIN');
INSERT INTO Athlete VALUES (1866,'RAISANEN','Otso',NULL,'FIN');
INSERT INTO Athlete VALUES (1867,'SALONEN','Jimi',NULL,'FIN');
INSERT INTO Athlete VALUES (1868,'SEO','Jee-Won',NULL,'KOR');
INSERT INTO Athlete VALUES (1869,'PARK','Hee-Jin',NULL,'KOR');
INSERT INTO Athlete VALUES (1870,'ONEILL','Taylah',NULL,'AUS');
INSERT INTO Athlete VALUES (1871,'KOLMAKOV','Pavel',NULL,'KAZ');
INSERT INTO Athlete VALUES (1872,'SKALA','Marek',NULL,'CZE');
INSERT INTO Athlete VALUES (1873,'BUCHAN','Murray',NULL,'GBR');
INSERT INTO Athlete VALUES (1874,'LONSDALE','Emma',NULL,'GBR');
INSERT INTO Athlete VALUES (1875,'MACHON','James',NULL,'GBR');
INSERT INTO Athlete VALUES (1876,'WOODS','James',NULL,'GBR');
INSERT INTO Athlete VALUES (1877,'SANTOS','Joselane',NULL,'BRA');
INSERT INTO Athlete VALUES (1878,'OLLILA','Antti',NULL,'FIN');
INSERT INTO Athlete VALUES (1879,'KUZMA','Janina',NULL,'NZL');
INSERT INTO Athlete VALUES (1880,'SHEEHAN','Lyndon',NULL,'NZL');
INSERT INTO Athlete VALUES (1881,'WELLS','Byron',NULL,'NZL');
INSERT INTO Athlete VALUES (1882,'WELLS','Josiah',NULL,'NZL');
INSERT INTO Athlete VALUES (1883,'WILLCOX-SILFVERBERG','Anna',NULL,'NZL');
INSERT INTO Athlete VALUES (1884,'AERTS','Katrien',NULL,'BEL');
INSERT INTO Athlete VALUES (1885,'MUELLER','Jorinde',NULL,'SUI');
INSERT INTO Athlete VALUES (1886,'RAGETTLI','Nina',NULL,'SUI');
INSERT INTO Athlete VALUES (1887,'AMBUEHL','Elias',NULL,'SUI');
INSERT INTO Athlete VALUES (1888,'BERRA','Camillia',NULL,'SUI');
INSERT INTO Athlete VALUES (1889,'BHEND','Eveline',NULL,'SUI');
INSERT INTO Athlete VALUES (1890,'BOESCH','Fabian',NULL,'SUI');
INSERT INTO Athlete VALUES (1891,'FAIVRE','Virginie',NULL,'SUI');
INSERT INTO Athlete VALUES (1892,'GASSER','Mischa',NULL,'SUI');
INSERT INTO Athlete VALUES (1893,'GISLER','Joel',NULL,'SUI');
INSERT INTO Athlete VALUES (1894,'JAEGER','Mirjam',NULL,'SUI');
INSERT INTO Athlete VALUES (1895,'LAUPER','Nils',NULL,'SUI');
INSERT INTO Athlete VALUES (1896,'LERJEN','Yannic',NULL,'SUI');
INSERT INTO Athlete VALUES (1897,'SCHULER','Luca',NULL,'SUI');
INSERT INTO Athlete VALUES (1898,'MARINO','Julia',NULL,'PAR');
INSERT INTO Athlete VALUES (1899,'KRASS','Julia',NULL,'USA');
INSERT INTO Athlete VALUES (1900,'MAYR','Benedikt',NULL,'GER');
INSERT INTO Athlete VALUES (1901,'PATJA','Aleksi',NULL,'FIN');
INSERT INTO Athlete VALUES (1902,'PODCHUFAROVA','Olga',NULL,'RUS');
INSERT INTO Athlete VALUES (1903,'ENGER','Gyda',NULL,'NOR');
INSERT INTO Athlete VALUES (1904,'TIMOFEEV','Evgeniy',NULL,'KGZ');
INSERT INTO Athlete VALUES (1905,'ASGEIRSDOTTIR','Erla',NULL,'ISL');
INSERT INTO Athlete VALUES (1906,'PARDO ANDRETTA','Antonio Jose',NULL,'VEN');
INSERT INTO Athlete VALUES (1907,'PLUSHENKO','Evgeni',NULL,'RUS');
INSERT INTO Athlete VALUES (1908,'TRETIAKOV','Alexander',to_date('19-04-1985', 'DD-MM-YYYY'),'RUS');
INSERT INTO Athlete VALUES (1909,'Welle-Strand HORN','Fanny',NULL,'NOR');
INSERT INTO Athlete VALUES (1910,'DOHERTY','Sean',NULL,'USA');
INSERT INTO Athlete VALUES (1911,'BURDYGA','Natalya',NULL,'UKR');
INSERT INTO Athlete VALUES (1912,'PANFILOVA','Mariya',NULL,'UKR');
INSERT INTO Athlete VALUES (1913,'PINTER','Friedrich',NULL,'AUT');
INSERT INTO Athlete VALUES (1914,'MOYSE','Heather',NULL,'CAN');
INSERT INTO Athlete VALUES (1915,'HUMPHRIES','Kaillie',NULL,'CAN');
INSERT INTO Athlete VALUES (1916,'WILLIAMS','Lauryn',NULL,'USA');
INSERT INTO Athlete VALUES (1917,'MEYERS','Elana',NULL,'USA');
INSERT INTO Athlete VALUES (1918,'GREUBEL','Jamie',NULL,'USA');
INSERT INTO Athlete VALUES (1919,'EVANS','Aja',NULL,'USA');
INSERT INTO Athlete VALUES (1920,'KAMPHUIS','Esme',NULL,'NED');
INSERT INTO Athlete VALUES (1921,'VIS','Judith',NULL,'NED');
INSERT INTO Athlete VALUES (1922,'PROKOFF','Sandra',NULL,'GER');
INSERT INTO Athlete VALUES (1923,'FRITZ','Franziska',NULL,'GER');
INSERT INTO Athlete VALUES (1924,'WILLEMSEN','Elfje',NULL,'BEL');
INSERT INTO Athlete VALUES (1925,'Emilie MARIEN','Hanna',NULL,'BEL');
INSERT INTO Athlete VALUES (1926,'MARTINI','Cathleen',NULL,'GER');
INSERT INTO Athlete VALUES (1927,'SENKEL','Christin',NULL,'GER');
INSERT INTO Athlete VALUES (1928,'MEYER','Fabienne',NULL,'SUI');
INSERT INTO Athlete VALUES (1929,'MAYER','Tanja',NULL,'SUI');
INSERT INTO Athlete VALUES (1930,'UDOBKINA','Liudmila',NULL,'RUS');
INSERT INTO Athlete VALUES (1931,'STULNEVA','Olga',NULL,'RUS');
INSERT INTO Athlete VALUES (1932,'SCHNEIDERHEINZE','Anja',NULL,'GER');
INSERT INTO Athlete VALUES (1933,'SCHNEIDER','Stephanie',NULL,'GER');
INSERT INTO Athlete VALUES (1934,'JONES','Lolo',NULL,'USA');
INSERT INTO Athlete VALUES (1935,'FENLATOR','Jazmine',NULL,'USA');
INSERT INTO Athlete VALUES (1936,'WALKER','Paula',NULL,'GBR');
INSERT INTO Athlete VALUES (1937,'WILSON','Rebekah',NULL,'GBR');
INSERT INTO Athlete VALUES (1938,'CIOCHETTI','Jennifer',NULL,'CAN');
INSERT INTO Athlete VALUES (1939,'VALOIS','Chelsea',NULL,'CAN');
INSERT INTO Athlete VALUES (1940,'RAWLINSON','Jana',NULL,'AUS');
INSERT INTO Athlete VALUES (1941,'RADJENOVIC','Astrid',NULL,'AUS');
INSERT INTO Athlete VALUES (1942,'HENGSTER','Christina',NULL,'AUT');
INSERT INTO Athlete VALUES (1943,'TUECHI','Alexandra',NULL,'AUT');
INSERT INTO Athlete VALUES (1944,'SERGEEVA','Nadezhda',NULL,'RUS');
INSERT INTO Athlete VALUES (1945,'PALEEVA','Nadezhda',NULL,'RUS');
INSERT INTO Athlete VALUES (1946,'GRECU','Andreea',NULL,'ROU');
INSERT INTO Athlete VALUES (1947,'CONSTANTIN','Maria',NULL,'ROU');
INSERT INTO Athlete VALUES (1948,'KIM','Sunok',NULL,'KOR');
INSERT INTO Athlete VALUES (1949,'SHIN','Mihwa',NULL,'KOR');
INSERT INTO Athlete VALUES (1950,'SANTOS','Fabiana',NULL,'BRA');
INSERT INTO Athlete VALUES (1951,'Mayara DA SILVA','Sally',NULL,'BRA');
INSERT INTO Athlete VALUES (1952,'ZUBKOV','Alexander',NULL,'RUS');
INSERT INTO Athlete VALUES (1953,'VOEVODA','Alexey',NULL,'RUS');
INSERT INTO Athlete VALUES (1954,'HEFTI','Beat',NULL,'SUI');
INSERT INTO Athlete VALUES (1955,'BAUMANN','Alex',NULL,'SUI');
INSERT INTO Athlete VALUES (1956,'HOLCOMB','Steven',NULL,'USA');
INSERT INTO Athlete VALUES (1957,'LANGTON','Steven',NULL,'USA');
INSERT INTO Athlete VALUES (1958,'BELUGIN','Maxim',NULL,'RUS');
INSERT INTO Athlete VALUES (1959,'KASJANOV','Alexander',NULL,'RUS');
INSERT INTO Athlete VALUES (1960,'DREISHKENS','Daumants',NULL,'LAT');
INSERT INTO Athlete VALUES (1961,'MELBARDIS','Oskars',NULL,'LAT');
INSERT INTO Athlete VALUES (1962,'BARNETT','Bryan',NULL,'CAN');
INSERT INTO Athlete VALUES (1963,'KRIPPS','Justin',NULL,'CAN');
INSERT INTO Athlete VALUES (1964,'LUMSDEN','Jesse',NULL,'CAN');
INSERT INTO Athlete VALUES (1965,'SPRING','Chris',NULL,'CAN');
INSERT INTO Athlete VALUES (1966,'BAECKER','Jannis',NULL,'GER');
INSERT INTO Athlete VALUES (1967,'FRIEDRICH','Francesco',NULL,'GER');
INSERT INTO Athlete VALUES (1968,'RUSH','Lyndon',NULL,'CAN');
INSERT INTO Athlete VALUES (1969,'BROWN','Lascelles',NULL,'CAN');
INSERT INTO Athlete VALUES (1970,'EGGER','Juerg',NULL,'SUI');
INSERT INTO Athlete VALUES (1971,'PETER','Rico',NULL,'SUI');
INSERT INTO Athlete VALUES (1972,'KUSKE','Kevin',NULL,'GER');
INSERT INTO Athlete VALUES (1973,'FLORSCHUETZ','Thomas',NULL,'GER');
INSERT INTO Athlete VALUES (1974,'FOGT','Christopher',NULL,'USA');
INSERT INTO Athlete VALUES (1975,'BUTNER','Cory',NULL,'USA');
INSERT INTO Athlete VALUES (1976,'CUNNINGHAM','Nick',NULL,'USA');
INSERT INTO Athlete VALUES (1977,'ROBINSON','Dallas',NULL,'USA');
INSERT INTO Athlete VALUES (1978,'BERTAZZO','Simone',NULL,'ITA');
INSERT INTO Athlete VALUES (1979,'FONTANA','Simone',NULL,'ITA');
INSERT INTO Athlete VALUES (1980,'ROEDIGER','Alexander',NULL,'GER');
INSERT INTO Athlete VALUES (1981,'ARNDT','Maximilian',NULL,'GER');
INSERT INTO Athlete VALUES (1982,'KIBERMANIS','Oskars',NULL,'LAT');
INSERT INTO Athlete VALUES (1983,'LEIBOMS','Vairis',NULL,'LAT');
INSERT INTO Athlete VALUES (1984,'ISTRATE','Nicolae',NULL,'ROU');
INSERT INTO Athlete VALUES (1985,'Cezar CRACIUN','Florin',NULL,'ROU');
INSERT INTO Athlete VALUES (1986,'WON','Yunjong',NULL,'KOR');
INSERT INTO Athlete VALUES (1987,'SEO','Youngwoo',NULL,'KOR');
INSERT INTO Athlete VALUES (1988,'VAN CALKER','Edwin',NULL,'NED');
INSERT INTO Athlete VALUES (1989,'VAN DER ZIJDE','Bror',NULL,'NED');
INSERT INTO Athlete VALUES (1990,'HEINRICH','Romain',NULL,'FRA');
INSERT INTO Athlete VALUES (1991,'COSTERG','Loic',NULL,'FRA');
INSERT INTO Athlete VALUES (1992,'GATTUSO','Sebastien',NULL,'MON');
INSERT INTO Athlete VALUES (1993,'SERVELLE','Patrice',NULL,'MON');
INSERT INTO Athlete VALUES (1994,'MAIER','Benjamin',NULL,'AUT');
INSERT INTO Athlete VALUES (1995,'SAMMER','Markus',NULL,'AUT');
INSERT INTO Athlete VALUES (1996,'BAINES','John',NULL,'GBR');
INSERT INTO Athlete VALUES (1997,'DEEN','Lamin',NULL,'GBR');
INSERT INTO Athlete VALUES (1998,'VRBA','Jan',NULL,'CZE');
INSERT INTO Athlete VALUES (1999,'VACEK','Michal',NULL,'CZE');
INSERT INTO Athlete VALUES (2000,'KIM','Donghyun',NULL,'KOR');
INSERT INTO Athlete VALUES (2001,'JUN','Junglin',NULL,'KOR');
INSERT INTO Athlete VALUES (2002,'HARVEY','Duncan',NULL,'AUS');
INSERT INTO Athlete VALUES (2003,'SPENCE','Heath',NULL,'AUS');
INSERT INTO Athlete VALUES (2004,'KUPCZYK','Dawid',NULL,'POL');
INSERT INTO Athlete VALUES (2005,'MROZ','Pawel',NULL,'POL');
INSERT INTO Athlete VALUES (2006,'SUZUKI','Hiroshi',NULL,'JPN');
INSERT INTO Athlete VALUES (2007,'MIYAZAKI','Hisashi',NULL,'JPN');
INSERT INTO Athlete VALUES (2008,'WATT','Winston',NULL,'JAM');
INSERT INTO Athlete VALUES (2009,'DIXON','Marvin',NULL,'JAM');
INSERT INTO Athlete VALUES (2010,'RADENOVIC','Vuk',NULL,'SRB');
INSERT INTO Athlete VALUES (2011,'BUNDALO','Aleksandar',NULL,'SRB');
INSERT INTO Athlete VALUES (2012,'TRUNENKOV','Dmitry',NULL,'RUS');
INSERT INTO Athlete VALUES (2013,'NEGODAYLO','Alexey',NULL,'RUS');
INSERT INTO Athlete VALUES (2014,'STRENGA','Janis',NULL,'LAT');
INSERT INTO Athlete VALUES (2015,'VILKASTE','Arvis',NULL,'LAT');
INSERT INTO Athlete VALUES (2016,'TOMASEVICZ','Curt',NULL,'USA');
INSERT INTO Athlete VALUES (2017,'PUSHKAREV','Aleksei',NULL,'RUS');
INSERT INTO Athlete VALUES (2018,'HUZIN','Ilvir',NULL,'RUS');
INSERT INTO Athlete VALUES (2019,'BENSON','Stuart',NULL,'GBR');
INSERT INTO Athlete VALUES (2020,'FEARON','Joel',NULL,'GBR');
INSERT INTO Athlete VALUES (2021,'James JACKSON','John',NULL,'GBR');
INSERT INTO Athlete VALUES (2022,'TASKER','Bruce',NULL,'GBR');
INSERT INTO Athlete VALUES (2023,'PUTZE','Martin',NULL,'GER');
INSERT INTO Athlete VALUES (2024,'HUEBENBECKER','Marko',NULL,'GER');
INSERT INTO Athlete VALUES (2025,'POSER','Christian',NULL,'GER');
INSERT INTO Athlete VALUES (2026,'BLUHM','Joshua',NULL,'GER');
INSERT INTO Athlete VALUES (2027,'LAMPARTER','Thomas',NULL,'SUI');
INSERT INTO Athlete VALUES (2028,'BISSETT','David',NULL,'CAN');
INSERT INTO Athlete VALUES (2029,'WRIGHT','Neville',NULL,'CAN');
INSERT INTO Athlete VALUES (2030,'BERMBACH','Gregor',NULL,'GER');
INSERT INTO Athlete VALUES (2031,'MARGIS','Thorsten',NULL,'GER');
INSERT INTO Athlete VALUES (2032,'JANSMA','Sybren',NULL,'NED');
INSERT INTO Athlete VALUES (2033,'KLAASSEN','Arno',NULL,'NED');
INSERT INTO Athlete VALUES (2034,'OLSEN','Justin',NULL,'USA');
INSERT INTO Athlete VALUES (2035,'QUINN','Johnny',NULL,'USA');
INSERT INTO Athlete VALUES (2036,'MCNAUGHTON','James',NULL,'CAN');
INSERT INTO Athlete VALUES (2037,'RANDALL','Timothy',NULL,'CAN');
INSERT INTO Athlete VALUES (2038,'BROKS','Raivis',NULL,'LAT');
INSERT INTO Athlete VALUES (2039,'LUSIS','Helvijs',NULL,'LAT');
INSERT INTO Athlete VALUES (2040,'MOISEEV','Petr',NULL,'RUS');
INSERT INTO Athlete VALUES (2041,'ZAKHAROV','Nikita',NULL,'RUS');
INSERT INTO Athlete VALUES (2042,'MOKROUSOV','Maxim',NULL,'RUS');
INSERT INTO Athlete VALUES (2043,'KHRENKOV','Nikolay',NULL,'RUS');
INSERT INTO Athlete VALUES (2044,'SUCHY','Dominik',NULL,'CZE');
INSERT INTO Athlete VALUES (2045,'DVORAK','Dominik',NULL,'CZE');
INSERT INTO Athlete VALUES (2046,'LEFORT','Elly',NULL,'FRA');
INSERT INTO Athlete VALUES (2047,'RIBET','Florent',NULL,'FRA');
INSERT INTO Athlete VALUES (2048,'ROMANINI','Samuele',NULL,'ITA');
INSERT INTO Athlete VALUES (2049,'COSTA','Francesco',NULL,'ITA');
INSERT INTO Athlete VALUES (2050,'SIMONS','Ben',NULL,'GBR');
INSERT INTO Athlete VALUES (2051,'MATTHEWS','Andrew',NULL,'GBR');
INSERT INTO Athlete VALUES (2052,'SUK','Youngjin',NULL,'KOR');
INSERT INTO Athlete VALUES (2053,'SOMOV','Angel',NULL,'AUT');
INSERT INTO Athlete VALUES (2054,'WITHALM','Stefan',NULL,'AUT');
INSERT INTO Athlete VALUES (2055,'MATA','Lucas',NULL,'AUS');
INSERT INTO Athlete VALUES (2056,'NICHOLS','Gareth',NULL,'AUS');
INSERT INTO Athlete VALUES (2057,'BAILLARD','Jeremy',NULL,'FRA');
INSERT INTO Athlete VALUES (2058,'BOUTHERIN','Jeremie',NULL,'FRA');
INSERT INTO Athlete VALUES (2059,'Alexis GODEFROY','Thibault',NULL,'FRA');
INSERT INTO Athlete VALUES (2060,'Daniel Jean-Paul RICARD','Vincent',NULL,'FRA');
INSERT INTO Athlete VALUES (2061,'NEAGU','Andreas',NULL,'ROU');
INSERT INTO Athlete VALUES (2062,'MUNTEAN','Paul',NULL,'ROU');
INSERT INTO Athlete VALUES (2063,'OTAVA','Bogdan',NULL,'ROU');
INSERT INTO Athlete VALUES (2064,'JAGNESAK','Milan',NULL,'SVK');
INSERT INTO Athlete VALUES (2065,'NAROVEC','Petr',NULL,'SVK');
INSERT INTO Athlete VALUES (2066,'KOZIENKA','Lukas',NULL,'SVK');
INSERT INTO Athlete VALUES (2067,'MOKRAS','Juraj',NULL,'SVK');
INSERT INTO Athlete VALUES (2068,'SATO','Shintaro',NULL,'JPN');
INSERT INTO Athlete VALUES (2069,'KUROIWA','Toshiki',NULL,'JPN');
INSERT INTO Athlete VALUES (2070,'KIM','Sik',NULL,'KOR');
INSERT INTO Athlete VALUES (2071,'KIM','Kyunghyun',NULL,'KOR');
INSERT INTO Athlete VALUES (2072,'OH','Jeahan',NULL,'KOR');
INSERT INTO Athlete VALUES (2073,'BINDILATTI','Edson',NULL,'BRA');
INSERT INTO Athlete VALUES (2074,'Carlos PESSONI','Odirlei',NULL,'BRA');
INSERT INTO Athlete VALUES (2075,'Ricardo MARTINS','Edson',NULL,'BRA');
INSERT INTO Athlete VALUES (2076,'GONCALVES SILVA','Fabio',NULL,'BRA');
INSERT INTO Athlete VALUES (2077,'DEMETRE','Luke',NULL,'CAN');
INSERT INTO Athlete VALUES (2078,'RINHOLM','Graeme',NULL,'CAN');
INSERT INTO Athlete VALUES (2079,'KASPEROWICZ','Michal',NULL,'POL');
INSERT INTO Athlete VALUES (2080,'ZALEWSKI','Daniel',NULL,'POL');
INSERT INTO Athlete VALUES (2081,'MINATO','Yusuke',NULL,'JPN');
INSERT INTO Athlete VALUES (2082,'NABEEV','Niyaz',NULL,'RUS');
INSERT INTO Athlete VALUES (2083,'YAHIN','Ernest',NULL,'RUS');
INSERT INTO Athlete VALUES (2084,'LAWES','Kaitlyn',NULL,'CAN');
INSERT INTO Athlete VALUES (2085,'MCEWEN','Dawn',NULL,'CAN');
INSERT INTO Athlete VALUES (2086,'OFFICER','Jill',NULL,'CAN');
INSERT INTO Athlete VALUES (2087,'WALL','Kirsten',NULL,'CAN');
INSERT INTO Athlete VALUES (2088,'BERTRUP','Christina',NULL,'SWE');
INSERT INTO Athlete VALUES (2089,'KNOCHENHAUER','Agnes',NULL,'SWE');
INSERT INTO Athlete VALUES (2090,'PRYTZ','Maria',NULL,'SWE');
INSERT INTO Athlete VALUES (2091,'SIGFRIDSSON','Margaretha',NULL,'SWE');
INSERT INTO Athlete VALUES (2092,'WENNERSTROM','Maria',NULL,'SWE');
INSERT INTO Athlete VALUES (2093,'ADAMS','Vicki',NULL,'GBR');
INSERT INTO Athlete VALUES (2094,'GRAY','Lauren',NULL,'GBR');
INSERT INTO Athlete VALUES (2095,'HAMILTON','Claire',NULL,'GBR');
INSERT INTO Athlete VALUES (2096,'MUIRHEAD','Eve',NULL,'GBR');
INSERT INTO Athlete VALUES (2097,'SLOAN','Anna',NULL,'GBR');
INSERT INTO Athlete VALUES (2098,'OTT','Mirjam',NULL,'SUI');
INSERT INTO Athlete VALUES (2099,'SCHAFER','Carmen',NULL,'SUI');
INSERT INTO Athlete VALUES (2100,'KUNG','Carmen',NULL,'SUI');
INSERT INTO Athlete VALUES (2101,'GREINER','Janine',NULL,'SUI');
INSERT INTO Athlete VALUES (2102,'PATZ','Alina',NULL,'SUI');
INSERT INTO Athlete VALUES (2103,'OGASAWARA','Ayumi',NULL,'JPN');
INSERT INTO Athlete VALUES (2104,'FUNAYAMA','Yumie',NULL,'JPN');
INSERT INTO Athlete VALUES (2105,'ONODERA','Kaho',NULL,'JPN');
INSERT INTO Athlete VALUES (2106,'TOMABECHI','Michiko',NULL,'JPN');
INSERT INTO Athlete VALUES (2107,'YOSHIDA','Chinami',NULL,'JPN');
INSERT INTO Athlete VALUES (2108,'NIELSEN','Lene',NULL,'DEN');
INSERT INTO Athlete VALUES (2109,'SIMONSEN','Helle',NULL,'DEN');
INSERT INTO Athlete VALUES (2110,'ELLEGAARD','Jeanne',NULL,'DEN');
INSERT INTO Athlete VALUES (2111,'POULSEN','Maria',NULL,'DEN');
INSERT INTO Athlete VALUES (2112,'DE NEERGAARD','Mette',NULL,'DEN');
INSERT INTO Athlete VALUES (2113,'BINGYU','Wang',NULL,'CHN');
INSERT INTO Athlete VALUES (2114,'YIN','Liu',NULL,'CHN');
INSERT INTO Athlete VALUES (2115,'QUINGSHUANG','Yue',NULL,'CHN');
INSERT INTO Athlete VALUES (2116,'YAN','Zhou',NULL,'CHN');
INSERT INTO Athlete VALUES (2117,'YILUN','Jiang',NULL,'CHN');
INSERT INTO Athlete VALUES (2118,'JI-SUN','Kim',NULL,'KOR');
INSERT INTO Athlete VALUES (2119,'SEUL-BEE','Lee',NULL,'KOR');
INSERT INTO Athlete VALUES (2120,'MI-SUNG','Shin',NULL,'KOR');
INSERT INTO Athlete VALUES (2121,'UN-CHI','Gim',NULL,'KOR');
INSERT INTO Athlete VALUES (2122,'HYUN-JUNG','Lee',NULL,'KOR');
INSERT INTO Athlete VALUES (2123,'JACOBS','Brad',NULL,'CAN');
INSERT INTO Athlete VALUES (2124,'FRY','Ryan',NULL,'CAN');
INSERT INTO Athlete VALUES (2125,'J. HARNDEN','E.',NULL,'CAN');
INSERT INTO Athlete VALUES (2126,'HARNDEN','Ryan',NULL,'CAN');
INSERT INTO Athlete VALUES (2127,'FLAXEY','Caleb',NULL,'CAN');
INSERT INTO Athlete VALUES (2128,'MURDOCH','David',NULL,'GBR');
INSERT INTO Athlete VALUES (2129,'BREWSTER','Tom',NULL,'GBR');
INSERT INTO Athlete VALUES (2130,'DRUMMOND','Greg',NULL,'GBR');
INSERT INTO Athlete VALUES (2131,'ANDREWS','Scott',NULL,'GBR');
INSERT INTO Athlete VALUES (2132,'GOODFELLOW','Michael',NULL,'GBR');
INSERT INTO Athlete VALUES (2133,'EDIN','Niklas',NULL,'SWE');
INSERT INTO Athlete VALUES (2134,'KRAUPP','Sebastian',NULL,'SWE');
INSERT INTO Athlete VALUES (2135,'LINDBERG','Fredrik',NULL,'SWE');
INSERT INTO Athlete VALUES (2136,'KJALL','Viktor',NULL,'SWE');
INSERT INTO Athlete VALUES (2137,'ERIKSSON','Oskar',NULL,'SWE');
INSERT INTO Athlete VALUES (2138,'RUI','Liu',NULL,'CHN');
INSERT INTO Athlete VALUES (2139,'XIAOMING','Xu',NULL,'CHN');
INSERT INTO Athlete VALUES (2140,'DEXIN','Ba',NULL,'CHN');
INSERT INTO Athlete VALUES (2141,'JIALIANG','Zang',NULL,'CHN');
INSERT INTO Athlete VALUES (2142,'DEJIA','Zou',NULL,'CHN');
INSERT INTO Athlete VALUES (2143,'ULSRUD','Thomas',NULL,'NOR');
INSERT INTO Athlete VALUES (2144,'NERGARD','Torger',NULL,'NOR');
INSERT INTO Athlete VALUES (2145,'SVAE','Christoffer',NULL,'NOR');
INSERT INTO Athlete VALUES (2146,'VAD PETERSSON','Havard',NULL,'NOR');
INSERT INTO Athlete VALUES (2147,'HOIBERG','Markus',NULL,'NOR');
INSERT INTO Athlete VALUES (2148,'STJERNE','Rasmus',NULL,'DEN');
INSERT INTO Athlete VALUES (2149,'FREDERIKSEN','Johnny',NULL,'DEN');
INSERT INTO Athlete VALUES (2150,'POULSEN','Mikkel',NULL,'DEN');
INSERT INTO Athlete VALUES (2151,'HARRY','Troels',NULL,'DEN');
INSERT INTO Athlete VALUES (2152,'VILANDT','Lars',NULL,'DEN');
INSERT INTO Athlete VALUES (2153,'DROZDOV','Andrey',NULL,'RUS');
INSERT INTO Athlete VALUES (2154,'ARKHIPOV','Evgeniy',NULL,'RUS');
INSERT INTO Athlete VALUES (2155,'STUKALSKIY','Aleksey',NULL,'RUS');
INSERT INTO Athlete VALUES (2156,'DRON','Petr',NULL,'RUS');
INSERT INTO Athlete VALUES (2157,'KOZYREV','Aleksandr',NULL,'RUS');
INSERT INTO Athlete VALUES (2158,'MICHEL','Sven',NULL,'SUI');
INSERT INTO Athlete VALUES (2159,'PATZ','Claudio',NULL,'SUI');
INSERT INTO Athlete VALUES (2160,'TROLLIET','Sandro',NULL,'SUI');
INSERT INTO Athlete VALUES (2161,'GEMPELER','Simon',NULL,'SUI');
INSERT INTO Athlete VALUES (2162,'Agosta','Meghan',NULL,'CAN');
INSERT INTO Athlete VALUES (2163,'Apps','Gillian',NULL,'CAN');
INSERT INTO Athlete VALUES (2164,'Daoust','Mélodie',NULL,'CAN');
INSERT INTO Athlete VALUES (2165,'Fortino','Laura',NULL,'CAN');
INSERT INTO Athlete VALUES (2166,'Hefford','Jayna',NULL,'CAN');
INSERT INTO Athlete VALUES (2167,'Irwin','Haley',NULL,'CAN');
INSERT INTO Athlete VALUES (2168,'Jenner','Brianne',NULL,'CAN');
INSERT INTO Athlete VALUES (2169,'Johnston','Rebecca',NULL,'CAN');
INSERT INTO Athlete VALUES (2170,'Labonté','Charline',NULL,'CAN');
INSERT INTO Athlete VALUES (2171,'Lacasse','Geneviève',NULL,'CAN');
INSERT INTO Athlete VALUES (2172,'Larocque','Jocelyne',NULL,'CAN');
INSERT INTO Athlete VALUES (2173,'Mikkelson','Meaghan',NULL,'CAN');
INSERT INTO Athlete VALUES (2174,'Ouellette','Caroline',NULL,'CAN');
INSERT INTO Athlete VALUES (2175,'Poulin','Marie-Philip',NULL,'CAN');
INSERT INTO Athlete VALUES (2176,'Rougeau','Lauriane',NULL,'CAN');
INSERT INTO Athlete VALUES (2177,'Spooner','Natalie',NULL,'CAN');
INSERT INTO Athlete VALUES (2178,'Szabados','Shannon',NULL,'CAN');
INSERT INTO Athlete VALUES (2179,'Wakefield','Jennifer',NULL,'CAN');
INSERT INTO Athlete VALUES (2180,'Ward','Catherine',NULL,'CAN');
INSERT INTO Athlete VALUES (2181,'Watchorn','Tara',NULL,'CAN');
INSERT INTO Athlete VALUES (2182,'Wickenheiser','Hayley',NULL,'CAN');
INSERT INTO Athlete VALUES (2183,'Bellamy','Kacey',NULL,'USA');
INSERT INTO Athlete VALUES (2184,'Bozek','Megan',NULL,'USA');
INSERT INTO Athlete VALUES (2185,'Carpenter','Alex',NULL,'USA');
INSERT INTO Athlete VALUES (2186,'Chu','Julie',NULL,'USA');
INSERT INTO Athlete VALUES (2187,'Coyne','Kendall',NULL,'USA');
INSERT INTO Athlete VALUES (2188,'Decker','Brianna',NULL,'USA');
INSERT INTO Athlete VALUES (2189,'Duggan','Meghan',NULL,'USA');
INSERT INTO Athlete VALUES (2190,'Fry','Lyndsey',NULL,'USA');
INSERT INTO Athlete VALUES (2191,'Kessel','Amanda',NULL,'USA');
INSERT INTO Athlete VALUES (2192,'Knight','Hilary',NULL,'USA');
INSERT INTO Athlete VALUES (2193,'Lamoureux','Jocelyne',NULL,'USA');
INSERT INTO Athlete VALUES (2194,'Lamoureux-Kolls','Monique',NULL,'USA');
INSERT INTO Athlete VALUES (2195,'Marvin','Gigi',NULL,'USA');
INSERT INTO Athlete VALUES (2196,'McLaughlin','Brianne',NULL,'USA');
INSERT INTO Athlete VALUES (2197,'Picard','Michelle',NULL,'USA');
INSERT INTO Athlete VALUES (2198,'Pucci','Josephine',NULL,'USA');
INSERT INTO Athlete VALUES (2199,'Schaus','Molly',NULL,'USA');
INSERT INTO Athlete VALUES (2200,'Schleper','Anne',NULL,'USA');
INSERT INTO Athlete VALUES (2201,'Stack','Kelli',NULL,'USA');
INSERT INTO Athlete VALUES (2202,'Stecklein','Lee',NULL,'USA');
INSERT INTO Athlete VALUES (2203,'Vetter','Jessie',NULL,'USA');
INSERT INTO Athlete VALUES (2204,'Alder','Janine',NULL,'SUI');
INSERT INTO Athlete VALUES (2205,'Altmann','Livia',NULL,'SUI');
INSERT INTO Athlete VALUES (2206,'Anthamatten','Sophie',NULL,'SUI');
INSERT INTO Athlete VALUES (2207,'Benz','Laura',NULL,'SUI');
INSERT INTO Athlete VALUES (2208,'Benz','Sara',NULL,'SUI');
INSERT INTO Athlete VALUES (2209,'Bullo','Nicole',NULL,'SUI');
INSERT INTO Athlete VALUES (2210,'Eggimann','Romy',NULL,'SUI');
INSERT INTO Athlete VALUES (2211,'Forster','Sarah',NULL,'SUI');
INSERT INTO Athlete VALUES (2212,'Frautschi','Angela',NULL,'SUI');
INSERT INTO Athlete VALUES (2213,'Lutz','Jessica',NULL,'SUI');
INSERT INTO Athlete VALUES (2214,'Marty','Julia',NULL,'SUI');
INSERT INTO Athlete VALUES (2215,'Marty','Stefanie',NULL,'SUI');
INSERT INTO Athlete VALUES (2216,'Muller','Alina',NULL,'SUI');
INSERT INTO Athlete VALUES (2217,'Nabholz','Katrin',NULL,'SUI');
INSERT INTO Athlete VALUES (2218,'Raselli','Evelina',NULL,'SUI');
INSERT INTO Athlete VALUES (2219,'Schelling','Florence',NULL,'SUI');
INSERT INTO Athlete VALUES (2220,'Stalder','Lara',NULL,'SUI');
INSERT INTO Athlete VALUES (2221,'Stanz','Phoebe',NULL,'SUI');
INSERT INTO Athlete VALUES (2222,'Stiefel','Anja',NULL,'SUI');
INSERT INTO Athlete VALUES (2223,'Thalmann','Sandra',NULL,'SUI');
INSERT INTO Athlete VALUES (2224,'Waidacher','Nina',NULL,'SUI');
INSERT INTO Athlete VALUES (2225,'Benn','Jamie',NULL,'CAN');
INSERT INTO Athlete VALUES (2226,'Bergeron','Patrice',NULL,'CAN');
INSERT INTO Athlete VALUES (2227,'Bouwmeester','Jay',NULL,'CAN');
INSERT INTO Athlete VALUES (2228,'Carter','Jeff',NULL,'CAN');
INSERT INTO Athlete VALUES (2229,'Crosby','Sidney',NULL,'CAN');
INSERT INTO Athlete VALUES (2230,'Doughty','Drew',NULL,'CAN');
INSERT INTO Athlete VALUES (2231,'Duchene','Matt',NULL,'CAN');
INSERT INTO Athlete VALUES (2232,'Getzlaf','Ryan',NULL,'CAN');
INSERT INTO Athlete VALUES (2233,'Hamhuis','Dan',NULL,'CAN');
INSERT INTO Athlete VALUES (2234,'Keith','Duncan',NULL,'CAN');
INSERT INTO Athlete VALUES (2235,'Kunitz','Chris',NULL,'CAN');
INSERT INTO Athlete VALUES (2236,'Luongo','Roberto',NULL,'CAN');
INSERT INTO Athlete VALUES (2237,'Marleau','Patrick',NULL,'CAN');
INSERT INTO Athlete VALUES (2238,'Nash','Rick',NULL,'CAN');
INSERT INTO Athlete VALUES (2239,'Perry','Corey',NULL,'CAN');
INSERT INTO Athlete VALUES (2240,'Pietrangelo','Alex',NULL,'CAN');
INSERT INTO Athlete VALUES (2241,'Price','Carey',NULL,'CAN');
INSERT INTO Athlete VALUES (2242,'St-Louis','Martin',NULL,'CAN');
INSERT INTO Athlete VALUES (2243,'Sharp','Patrick',NULL,'CAN');
INSERT INTO Athlete VALUES (2244,'Smith','Mike',NULL,'CAN');
INSERT INTO Athlete VALUES (2245,'Subban','P.K.',NULL,'CAN');
INSERT INTO Athlete VALUES (2246,'Tavares','John',NULL,'CAN');
INSERT INTO Athlete VALUES (2247,'Toews','Jonathan',NULL,'CAN');
INSERT INTO Athlete VALUES (2248,'Vlasic','Marc-Édouard',NULL,'CAN');
INSERT INTO Athlete VALUES (2249,'Weber','Shea',NULL,'CAN');
INSERT INTO Athlete VALUES (2250,'Alfredsson','Daniel',NULL,'SWE');
INSERT INTO Athlete VALUES (2251,'Backstrom','Nicklas',NULL,'SWE');
INSERT INTO Athlete VALUES (2252,'Berglund','Patrik',NULL,'SWE');
INSERT INTO Athlete VALUES (2253,'Edler','Alexander',NULL,'SWE');
INSERT INTO Athlete VALUES (2254,'Ekman-Larsson','Oliver',NULL,'SWE');
INSERT INTO Athlete VALUES (2255,'Enroth','Jhonas',NULL,'SWE');
INSERT INTO Athlete VALUES (2256,'Ericsson','Jimmie',NULL,'SWE');
INSERT INTO Athlete VALUES (2257,'Ericsson','Jonathan',NULL,'SWE');
INSERT INTO Athlete VALUES (2258,'Eriksson','Loui',NULL,'SWE');
INSERT INTO Athlete VALUES (2259,'Gustavsson','Jonas',NULL,'SWE');
INSERT INTO Athlete VALUES (2260,'Hagelin','Carl',NULL,'SWE');
INSERT INTO Athlete VALUES (2261,'Hjalmarsson','Niklas',NULL,'SWE');
INSERT INTO Athlete VALUES (2262,'Johansson','Marcus',NULL,'SWE');
INSERT INTO Athlete VALUES (2263,'Karlsson','Erik',NULL,'SWE');
INSERT INTO Athlete VALUES (2264,'Kronwall','Niklas',NULL,'SWE');
INSERT INTO Athlete VALUES (2265,'Krüger','Marcus',NULL,'SWE');
INSERT INTO Athlete VALUES (2266,'Landeskog','Gabriel',NULL,'SWE');
INSERT INTO Athlete VALUES (2267,'Lundqvist','Henrik',NULL,'SWE');
INSERT INTO Athlete VALUES (2268,'Nyquist','Gustav',NULL,'SWE');
INSERT INTO Athlete VALUES (2269,'Oduya','Johnny',NULL,'SWE');
INSERT INTO Athlete VALUES (2270,'Sedin','Daniel',NULL,'SWE');
INSERT INTO Athlete VALUES (2271,'Silfverberg','Jakob',NULL,'SWE');
INSERT INTO Athlete VALUES (2272,'Steen','Alexander',NULL,'SWE');
INSERT INTO Athlete VALUES (2273,'Tallinder','Henrik',NULL,'SWE');
INSERT INTO Athlete VALUES (2274,'Zetterberg','Henrik',NULL,'SWE');
INSERT INTO Athlete VALUES (2275,'Aaltonen','Juhamatti',NULL,'FIN');
INSERT INTO Athlete VALUES (2276,'Barkov','Aleksander',NULL,'FIN');
INSERT INTO Athlete VALUES (2277,'Granlund','Mikael',NULL,'FIN');
INSERT INTO Athlete VALUES (2278,'Hietanen','Juuso',NULL,'FIN');
INSERT INTO Athlete VALUES (2279,'Immonen','Jarkko',NULL,'FIN');
INSERT INTO Athlete VALUES (2280,'Jokinen','Jussi',NULL,'FIN');
INSERT INTO Athlete VALUES (2281,'Jokinen','Olli',NULL,'FIN');
INSERT INTO Athlete VALUES (2282,'Komarov','Leo',NULL,'FIN');
INSERT INTO Athlete VALUES (2283,'Lepistö','Sami',NULL,'FIN');
INSERT INTO Athlete VALUES (2284,'Kontiola','Petri',NULL,'FIN');
INSERT INTO Athlete VALUES (2285,'Korpikoski','Lauri',NULL,'FIN');
INSERT INTO Athlete VALUES (2286,'Kukkonen','Lasse',NULL,'FIN');
INSERT INTO Athlete VALUES (2287,'Lehterä','Jori',NULL,'FIN');
INSERT INTO Athlete VALUES (2288,'Lehtonen','Kari',NULL,'FIN');
INSERT INTO Athlete VALUES (2289,'Määttä','Olli',NULL,'FIN');
INSERT INTO Athlete VALUES (2290,'Niemi','Antti',NULL,'FIN');
INSERT INTO Athlete VALUES (2291,'Pihlström','Antti',NULL,'FIN');
INSERT INTO Athlete VALUES (2292,'Rask','Tuukka',NULL,'FIN');
INSERT INTO Athlete VALUES (2293,'Ruutu','Tuomo',NULL,'FIN');
INSERT INTO Athlete VALUES (2294,'Salminen','Sakari',NULL,'FIN');
INSERT INTO Athlete VALUES (2295,'Salo','Sami',NULL,'FIN');
INSERT INTO Athlete VALUES (2296,'Selänne','Teemu',NULL,'FIN');
INSERT INTO Athlete VALUES (2297,'Timonen','Kimmo',NULL,'FIN');
INSERT INTO Athlete VALUES (2298,'Väänänen','Ossi',NULL,'FIN');
INSERT INTO Athlete VALUES (2299,'Vatanen','Sami',NULL,'FIN');
INSERT INTO Athlete VALUES (2300,'ARLT','Tobias',NULL,'GER');
INSERT INTO Athlete VALUES (2301,'WENDL','Tobias',NULL,'GER');
INSERT INTO Athlete VALUES (2302,'LINGER','Andreas',NULL,'AUT');
INSERT INTO Athlete VALUES (2303,'LINGER','Wolfgang',NULL,'AUT');
INSERT INTO Athlete VALUES (2304,'SICS','Andris',NULL,'LAT');
INSERT INTO Athlete VALUES (2305,'SICS','Juris',NULL,'LAT');
INSERT INTO Athlete VALUES (2306,'SNITH','Justin',NULL,'CAN');
INSERT INTO Athlete VALUES (2307,'WALKER','Tristan',NULL,'CAN');
INSERT INTO Athlete VALUES (2308,'ANTONOV','Vladislav',NULL,'RUS');
INSERT INTO Athlete VALUES (2309,'DENISYEV','Alexander',NULL,'RUS');
INSERT INTO Athlete VALUES (2310,'GRUBER','Patrick',NULL,'ITA');
INSERT INTO Athlete VALUES (2311,'OBERSTOLZ','Christian',NULL,'ITA');
INSERT INTO Athlete VALUES (2312,'RASTNER','Patrick',NULL,'ITA');
INSERT INTO Athlete VALUES (2313,'RIEDER','Ludwig',NULL,'ITA');
INSERT INTO Athlete VALUES (2314,'EGGERT','Toni',NULL,'GER');
INSERT INTO Athlete VALUES (2315,'BENECKEN','Sascha',NULL,'GER');
INSERT INTO Athlete VALUES (2316,'MAKHNUTIN','Vladimir',NULL,'RUS');
INSERT INTO Athlete VALUES (2317,'YUZHAKOV','Vladislav',NULL,'RUS');
INSERT INTO Athlete VALUES (2318,'GUDRAMOVICS','Oskars',NULL,'LAT');
INSERT INTO Athlete VALUES (2319,'KALNINS','Peteris',NULL,'LAT');
INSERT INTO Athlete VALUES (2320,'NICCUM','Christian',NULL,'USA');
INSERT INTO Athlete VALUES (2321,'TERDIMAN','Jayson',NULL,'USA');
INSERT INTO Athlete VALUES (2322,'PETRULAK','Jozef',NULL,'SVK');
INSERT INTO Athlete VALUES (2323,'ZEMANIK','Marian',NULL,'SVK');
INSERT INTO Athlete VALUES (2324,'BROZ','Antonin',NULL,'CZE');
INSERT INTO Athlete VALUES (2325,'BROZ','Lukas',NULL,'CZE');
INSERT INTO Athlete VALUES (2326,'GRIFFALL','Preston',NULL,'USA');
INSERT INTO Athlete VALUES (2327,'MORTENSEN','Matthew',NULL,'USA');
INSERT INTO Athlete VALUES (2328,'MIKRUT','Karol',NULL,'POL');
INSERT INTO Athlete VALUES (2329,'POREBA','Patryk',NULL,'POL');
INSERT INTO Athlete VALUES (2330,'SOLCANSKY','Marek',NULL,'SVK');
INSERT INTO Athlete VALUES (2331,'STUCHLAK','Karol',NULL,'SVK');
INSERT INTO Athlete VALUES (2332,'ZAKHARKIV','Roman',NULL,'UKR');
INSERT INTO Athlete VALUES (2333,'OBOLONCHYK','Oleksandr',NULL,'UKR');
INSERT INTO Athlete VALUES (2334,'PARK','Jinyong',NULL,'KOR');
INSERT INTO Athlete VALUES (2335,'Myung CHO','Jung',NULL,'KOR');
INSERT INTO Athlete VALUES (2336,'FISCHLER','Georg',NULL,'AUT');
INSERT INTO Athlete VALUES (2337,'PENZ','Peter',NULL,'AUT');
INSERT INTO Athlete VALUES (2338,'ZÖGGELER','Armin',NULL,'ITA');
INSERT INTO Athlete VALUES (2339,'TATIANA','VOLOSOZHAR',NULL,'RUS');
INSERT INTO Athlete VALUES (2340,'MAXIM','TRANKOV',NULL,'RUS');
INSERT INTO Athlete VALUES (2341,'KSENIA','STOLBOVA',NULL,'RUS');
INSERT INTO Athlete VALUES (2342,'FEDOR 02','KLIMOV',NULL,'RUS');
INSERT INTO Athlete VALUES (2343,'ALIONA','SAVCHENKO',NULL,'GER');
INSERT INTO Athlete VALUES (2344,'ROBIN 02','SZOLKOWY',NULL,'GER');
INSERT INTO Athlete VALUES (2345,'WHITE','Charlie',NULL,'USA');
INSERT INTO Athlete VALUES (2346,'DAVIS','Meryl',NULL,'USA');
INSERT INTO Athlete VALUES (2347,'MOIR','Scott',NULL,'CAN');
INSERT INTO Athlete VALUES (2348,'VIRTUE','Tessa',NULL,'CAN');
INSERT INTO Athlete VALUES (2349,'ILINYKH','Elena',NULL,'RUS');
INSERT INTO Athlete VALUES (2350,'KATSALAPOV','Nikita',NULL,'RUS');
INSERT INTO Athlete VALUES (2351,'BOURZAT','Fabian',NULL,'FRA');
INSERT INTO Athlete VALUES (2352,'PECHALAT','Nathalie',NULL,'FRA');
INSERT INTO Athlete VALUES (2353,'SOLOVIEV','Dmitri',NULL,'RUS');
INSERT INTO Athlete VALUES (2354,'BOBROVA','Ekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (2355,'CAPPELLINI','Anna',NULL,'ITA');
INSERT INTO Athlete VALUES (2356,'LANOTTE','Luca',NULL,'ITA');
INSERT INTO Athlete VALUES (2357,'POJE','Andrew',NULL,'CAN');
INSERT INTO Athlete VALUES (2358,'WEAVER','Kaitlyn',NULL,'CAN');
INSERT INTO Athlete VALUES (2359,'CHOCK','Madison',NULL,'USA');
INSERT INTO Athlete VALUES (2360,'BATES','Evan',NULL,'USA');
INSERT INTO Athlete VALUES (2361,'SHIBUTANI','Maia',NULL,'USA');
INSERT INTO Athlete VALUES (2362,'SHIBUTANI','Alex',NULL,'USA');
INSERT INTO Athlete VALUES (2363,'BUCKLAND','Nicholas',NULL,'GBR');
INSERT INTO Athlete VALUES (2364,'COOMES','Penny',NULL,'GBR');
INSERT INTO Athlete VALUES (2365,'GAZSI','Alexander',NULL,'GER');
INSERT INTO Athlete VALUES (2366,'ZHIGANSHINA','Nelli',NULL,'GER');
INSERT INTO Athlete VALUES (2367,'SITNIKOV','Alexei',NULL,'AZE');
INSERT INTO Athlete VALUES (2368,'ZLOBINA','Julia',NULL,'AZE');
INSERT INTO Athlete VALUES (2369,'DIAZ','Adria',NULL,'ESP');
INSERT INTO Athlete VALUES (2370,'HURTADO','Sara',NULL,'ESP');
INSERT INTO Athlete VALUES (2371,'GUIGNARD','Charlene',NULL,'ITA');
INSERT INTO Athlete VALUES (2372,'FABBRI','Marco',NULL,'ITA');
INSERT INTO Athlete VALUES (2373,'CARRON','Pernelle',NULL,'FRA');
INSERT INTO Athlete VALUES (2374,'JONES','Lloyd',NULL,'FRA');
INSERT INTO Athlete VALUES (2375,'SINITSINA','Victoria',NULL,'RUS');
INSERT INTO Athlete VALUES (2376,'ZHIGANSHIN','Ruslan',NULL,'RUS');
INSERT INTO Athlete VALUES (2377,'STAGNIUNAS','Deividas',NULL,'LTU');
INSERT INTO Athlete VALUES (2378,'TOBIAS','Isabella',NULL,'LTU');
INSERT INTO Athlete VALUES (2379,'ISLAM','Mitchell',NULL,'CAN');
INSERT INTO Athlete VALUES (2380,'PAUL','Alexandra',NULL,'CAN');
INSERT INTO Athlete VALUES (2381,'KOLBE','Tanja',NULL,'GER');
INSERT INTO Athlete VALUES (2382,'CARUSO','Stefano',NULL,'GER');
INSERT INTO Athlete VALUES (2383,'OBRIEN','Danielle',NULL,'AUS');
INSERT INTO Athlete VALUES (2384,'MERRIMAN','Gregory',NULL,'AUS');
INSERT INTO Athlete VALUES (2385,'REED','Cathy',NULL,'JPN');
INSERT INTO Athlete VALUES (2386,'REED','Chris',NULL,'JPN');
INSERT INTO Athlete VALUES (2387,'UCAR','Alper',NULL,'TUR');
INSERT INTO Athlete VALUES (2388,'AGAFONOVA','Alisa',NULL,'TUR');
INSERT INTO Athlete VALUES (2389,'HUANG','Xintong',NULL,'CHN');
INSERT INTO Athlete VALUES (2390,'ZHENG','Xun',NULL,'CHN');
INSERT INTO Athlete VALUES (2391,'DUN','Dmitri',NULL,'UKR');
INSERT INTO Athlete VALUES (2392,'HEEKIN-CANEDY','Siobhan',NULL,'UKR');
INSERT INTO Athlete VALUES (2393,'Bobrova','Ekaterina',NULL,'RUS');
INSERT INTO Athlete VALUES (2394,'Ilinykh','Elena',NULL,'RUS');
INSERT INTO Athlete VALUES (2395,'Katsalapov','Nikita',NULL,'RUS');
INSERT INTO Athlete VALUES (2396,'Klimov','Fedor',NULL,'RUS');
INSERT INTO Athlete VALUES (2397,'Lipnitskaya','Yulia',NULL,'RUS');
INSERT INTO Athlete VALUES (2398,'Pliouchtchenko','Ievgueni',NULL,'RUS');
INSERT INTO Athlete VALUES (2399,'Soloviev','Dmitri',NULL,'RUS');
INSERT INTO Athlete VALUES (2400,'Stolbova','Ksenia',NULL,'RUS');
INSERT INTO Athlete VALUES (2401,'Trankov','Maxim',NULL,'RUS');
INSERT INTO Athlete VALUES (2402,'Volosozhar','Tatiana',NULL,'RUS');
INSERT INTO Athlete VALUES (2403,'Chan','Patrick',NULL,'CAN');
INSERT INTO Athlete VALUES (2404,'Duhamel','Meagan',NULL,'CAN');
INSERT INTO Athlete VALUES (2405,'Moir','Scott',NULL,'CAN');
INSERT INTO Athlete VALUES (2406,'Moore-Towers','Kirsten',NULL,'CAN');
INSERT INTO Athlete VALUES (2407,'Moscovitch','Dylan',NULL,'CAN');
INSERT INTO Athlete VALUES (2408,'Osmond','Kaetlyn',NULL,'CAN');
INSERT INTO Athlete VALUES (2409,'Radford','Eric',NULL,'CAN');
INSERT INTO Athlete VALUES (2410,'Reynolds','Kevin',NULL,'CAN');
INSERT INTO Athlete VALUES (2411,'Virtue','Tessa',NULL,'CAN');
INSERT INTO Athlete VALUES (2412,'Abbott','Jeremy',NULL,'USA');
INSERT INTO Athlete VALUES (2413,'Brown','Jason',NULL,'USA');
INSERT INTO Athlete VALUES (2414,'Castelli','Marissa',NULL,'USA');
INSERT INTO Athlete VALUES (2415,'Davis','Meryl',NULL,'USA');
INSERT INTO Athlete VALUES (2416,'Gold','Gracie',NULL,'USA');
INSERT INTO Athlete VALUES (2417,'Shnapir','Simon',NULL,'USA');
INSERT INTO Athlete VALUES (2418,'Wagner','Ashley',NULL,'USA');
INSERT INTO Athlete VALUES (2419,'White','Charlie',NULL,'USA');
INSERT INTO Athlete VALUES (2420,'Hee SHIM','Suk',NULL,'KOR');
INSERT INTO Athlete VALUES (2421,'FAN','Kexin',NULL,'CHN');
INSERT INTO Athlete VALUES (2422,'ZAKHAROV','Ruslan',NULL,'RUS');
INSERT INTO Athlete VALUES (2423,'WU','Dajing',NULL,'CHN');
INSERT INTO Athlete VALUES (2424,'BREEUWSMA','Daan',NULL,'NED');
INSERT INTO Athlete VALUES (2425,'AZHGALIYEV','Abzal',NULL,'KAZ');
INSERT INTO Athlete VALUES (2426,'GRUBER','Bettina',NULL,'SUI');
INSERT INTO Athlete VALUES (2427,'NARUSE','Nobu',NULL,'JPN');
INSERT INTO Athlete VALUES (2428,'YOSHIDA','Keishin',NULL,'JPN');
INSERT INTO Athlete VALUES (2429,'MIYAZAWA','Hiroyuki',NULL,'JPN');
INSERT INTO Athlete VALUES (2430,'LENTING','Akira',NULL,'JPN');
INSERT INTO Athlete VALUES (2431,'COLOGNA','Gianluca',NULL,'SUI');


INSERT INTO Epreuve VALUES (1,1,'10km poursuite','Femmes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (2,1,'12,5km départ groupé','Femmes',to_date('17-02-2014', 'DD-MM-YYYY'),to_date('17-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (3,1,'15km','Femmes',to_date('14-02-2014', 'DD-MM-YYYY'),to_date('14-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (4,1,'7,5km','Femmes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('08-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (5,1,'relais 4x6km','Femmes',to_date('21-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (6,1,'10km','Hommes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('08-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (7,1,'12,5km poursuite','Hommes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('10-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (8,1,'15km départ groupé','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (9,1,'20km','Hommes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('13-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (10,1,'relais 4x7,5km','Hommes',to_date('22-02-2014', 'DD-MM-YYYY'),to_date('22-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (11,1,'Relais mix','Mixte',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (12,2,'bob à deux','Femmes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (13,2,'bob à deux','Hommes',to_date('16-02-2014', 'DD-MM-YYYY'),to_date('17-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (14,2,'bob à quatres','Hommes',to_date('22-02-2014', 'DD-MM-YYYY'),to_date('23-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (15,3,'Individuel','Hommes',to_date('12-02-2014', 'DD-MM-YYYY'),to_date('12-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (16,3,'Individuel LH','Hommes',to_date('17-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (17,3,'Par équipes','Hommes',to_date('20-02-2014', 'DD-MM-YYYY'),to_date('20-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (18,4,'curling','Femmes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('20-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (19,4,'curling','Hommes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (20,5,'hockey sur glace','Femmes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('20-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (21,5,'hockey sur glace','Hommes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('23-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (22,6,'Simple','Femmes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (23,6,'Simple','Hommes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (24,6,'Double','Mixte',to_date('12-02-2014', 'DD-MM-YYYY'),to_date('12-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (25,6,'Relais par équipes mixte','Mixte',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('13-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (26,7,'Individuel','Femmes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('20-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (27,7,'Individuel','Hommes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('14-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (28,7,'Couples','Mixte',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('12-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (29,7,'Danse sur glace','Mixte',to_date('16-02-2014', 'DD-MM-YYYY'),to_date('17-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (30,7,'Par équipes','Mixte',to_date('06-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (31,8,'1000m','Femmes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('13-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (32,8,'1500m','Femmes',to_date('16-02-2014', 'DD-MM-YYYY'),to_date('16-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (33,8,'2x500m','Femmes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (34,8,'3000m','Femmes',to_date('09-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (35,8,'5000m','Femmes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (36,8,'Poursuite par équipes','Femmes',to_date('21-02-2014', 'DD-MM-YYYY'),to_date('22-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (37,8,'10000m','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (38,8,'1000m','Hommes',to_date('12-02-2014', 'DD-MM-YYYY'),to_date('12-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (39,8,'1500m','Hommes',to_date('15-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (40,8,'2x500m','Hommes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('10-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (41,8,'5000m','Hommes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('08-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (42,8,'Poursuite par équipes','Hommes',to_date('21-02-2014', 'DD-MM-YYYY'),to_date('22-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (43,9,'500m','Femmes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('13-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (44,9,'1000m','Femmes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (45,9,'1500m','Femmes',to_date('15-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (46,9,'Relais 3000m','Femmes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (47,9,'500m','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (48,9,'1000m','Hommes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (49,9,'1500m','Hommes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('10-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (50,9,'Relais 5000m','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (51,10,'Tremplin normal individuel','Femmes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (52,10,'Grand tremplin individuel','Hommes',to_date('14-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (53,10,'Par équipes','Hommes',to_date('17-02-2014', 'DD-MM-YYYY'),to_date('17-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (54,10,'Tremplin normal individuel','Hommes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (55,11,'Individuel','Femmes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('14-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (56,11,'Individuel','Hommes',to_date('14-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (57,12,'Bosses','Femmes',to_date('06-02-2014', 'DD-MM-YYYY'),to_date('08-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (58,12,'Saut','Femmes',to_date('14-02-2014', 'DD-MM-YYYY'),to_date('14-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (59,12,'Ski Cross','Femmes',to_date('21-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (60,12,'Ski halfpipe','Femmes',to_date('20-02-2014', 'DD-MM-YYYY'),to_date('20-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (61,12,'Ski slopestyle','Femmes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (62,12,'Bosses','Hommes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('10-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (63,12,'Saut','Hommes',to_date('17-02-2014', 'DD-MM-YYYY'),to_date('17-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (64,12,'Ski Cross','Hommes',to_date('20-02-2014', 'DD-MM-YYYY'),to_date('20-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (65,12,'Ski halfpipe','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (66,12,'Ski slopestyle','Hommes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('13-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (67,13,'Descente','Femmes',to_date('09-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (68,13,'Slalom','Femmes',to_date('22-02-2014', 'DD-MM-YYYY'),to_date('22-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (69,13,'Slalom géant','Femmes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (70,13,'Super combiné','Femmes',to_date('14-02-2014', 'DD-MM-YYYY'),to_date('14-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (71,13,'Super G','Femmes',to_date('16-02-2014', 'DD-MM-YYYY'),to_date('16-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (72,13,'Descente','Hommes',to_date('12-02-2014', 'DD-MM-YYYY'),to_date('12-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (73,13,'Slalom','Hommes',to_date('21-02-2014', 'DD-MM-YYYY'),to_date('21-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (74,13,'Slalom géant','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (75,13,'Super combiné','Hommes',to_date('10-02-2014', 'DD-MM-YYYY'),to_date('10-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (76,13,'Super G','Hommes',to_date('15-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (77,14,'10km','Femmes',to_date('13-02-2014', 'DD-MM-YYYY'),to_date('13-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (78,14,'30km','Femmes',to_date('09-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (79,14,'Relais 4x5km','Femmes',to_date('15-02-2014', 'DD-MM-YYYY'),to_date('15-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (80,14,'Skiathlon (7,5km + 7,5km)','Femmes',to_date('08-02-2014', 'DD-MM-YYYY'),to_date('08-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (81,14,'Sprint 1,5km','Femmes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (82,14,'Sprint par équipes','Femmes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (83,14,'15km','Hommes',to_date('14-02-2014', 'DD-MM-YYYY'),to_date('14-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (84,14,'50km','Hommes',to_date('23-02-2014', 'DD-MM-YYYY'),to_date('23-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (85,14,'Relais 4x10km','Hommes',to_date('16-02-2014', 'DD-MM-YYYY'),to_date('16-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (86,14,'Skiathlon (15km + 15km)','Hommes',to_date('09-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (87,14,'Sprint 1,5km','Hommes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (88,14,'Sprint par équipes','Hommes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (89,15,'Halfpipe','Femmes',to_date('12-02-2014', 'DD-MM-YYYY'),to_date('12-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (90,15,'Slalom géant parallèle','Femmes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (91,15,'Slalom parallèle','Femmes',to_date('22-02-2014', 'DD-MM-YYYY'),to_date('22-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (92,15,'Slopestyle','Femmes',to_date('06-02-2014', 'DD-MM-YYYY'),to_date('09-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (93,15,'Snowboard cross','Femmes',to_date('16-02-2014', 'DD-MM-YYYY'),to_date('16-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (94,15,'Halfpipe','Hommes',to_date('11-02-2014', 'DD-MM-YYYY'),to_date('11-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (95,15,'Slalom géant parallèle','Hommes',to_date('19-02-2014', 'DD-MM-YYYY'),to_date('19-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (96,15,'Slalom parallèle','Hommes',to_date('22-02-2014', 'DD-MM-YYYY'),to_date('22-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (97,15,'Slopestyle','Hommes',to_date('06-02-2014', 'DD-MM-YYYY'),to_date('08-02-2014', 'DD-MM-YYYY'));
INSERT INTO Epreuve VALUES (98,15,'Snowboard cross','Hommes',to_date('18-02-2014', 'DD-MM-YYYY'),to_date('18-02-2014', 'DD-MM-YYYY'));


INSERT INTO RangIndividuel VALUES (1,14,1);
INSERT INTO RangIndividuel VALUES (1,30,2);
INSERT INTO RangIndividuel VALUES (1,300,3);
INSERT INTO RangIndividuel VALUES (1,180,4);
INSERT INTO RangIndividuel VALUES (1,107,5);
INSERT INTO RangIndividuel VALUES (1,33,6);
INSERT INTO RangIndividuel VALUES (1,179,7);
INSERT INTO RangIndividuel VALUES (1,327,8);
INSERT INTO RangIndividuel VALUES (1,319,9);
INSERT INTO RangIndividuel VALUES (1,92,10);
INSERT INTO RangIndividuel VALUES (1,21,11);
INSERT INTO RangIndividuel VALUES (1,800,12);
INSERT INTO RangIndividuel VALUES (1,329,13);
INSERT INTO RangIndividuel VALUES (1,213,14);
INSERT INTO RangIndividuel VALUES (1,236,15);
INSERT INTO RangIndividuel VALUES (1,524,16);
INSERT INTO RangIndividuel VALUES (1,328,17);
INSERT INTO RangIndividuel VALUES (1,792,18);
INSERT INTO RangIndividuel VALUES (1,1708,19);
INSERT INTO RangIndividuel VALUES (1,1709,20);
INSERT INTO RangIndividuel VALUES (1,235,21);
INSERT INTO RangIndividuel VALUES (1,121,22);
INSERT INTO RangIndividuel VALUES (1,281,23);
INSERT INTO RangIndividuel VALUES (1,82,24);
INSERT INTO RangIndividuel VALUES (1,480,25);
INSERT INTO RangIndividuel VALUES (1,392,26);
INSERT INTO RangIndividuel VALUES (1,19,27);
INSERT INTO RangIndividuel VALUES (1,771,28);
INSERT INTO RangIndividuel VALUES (1,29,29);
INSERT INTO RangIndividuel VALUES (1,1750,30);
INSERT INTO RangIndividuel VALUES (1,1762,31);
INSERT INTO RangIndividuel VALUES (1,761,32);
INSERT INTO RangIndividuel VALUES (1,779,33);
INSERT INTO RangIndividuel VALUES (1,622,34);
INSERT INTO RangIndividuel VALUES (1,525,35);
INSERT INTO RangIndividuel VALUES (1,757,36);
INSERT INTO RangIndividuel VALUES (1,232,37);
INSERT INTO RangIndividuel VALUES (1,408,38);
INSERT INTO RangIndividuel VALUES (1,1747,39);
INSERT INTO RangIndividuel VALUES (1,1188,40);
INSERT INTO RangIndividuel VALUES (1,1741,41);
INSERT INTO RangIndividuel VALUES (1,1757,42);
INSERT INTO RangIndividuel VALUES (1,447,43);
INSERT INTO RangIndividuel VALUES (1,1727,44);
INSERT INTO RangIndividuel VALUES (1,767,45);
INSERT INTO RangIndividuel VALUES (1,780,46);
INSERT INTO RangIndividuel VALUES (1,280,47);
INSERT INTO RangIndividuel VALUES (1,439,48);
INSERT INTO RangIndividuel VALUES (1,1734,49);
INSERT INTO RangIndividuel VALUES (1,1725,50);
INSERT INTO RangIndividuel VALUES (1,793,51);
INSERT INTO RangIndividuel VALUES (1,1756,52);
INSERT INTO RangIndividuel VALUES (1,1724,53);
INSERT INTO RangIndividuel VALUES (1,791,54);
INSERT INTO RangIndividuel VALUES (1,1732,55);
INSERT INTO RangIndividuel VALUES (1,842,56);
INSERT INTO RangIndividuel VALUES (1,1751,NULL);
INSERT INTO RangIndividuel VALUES (1,786,NULL);
INSERT INTO RangIndividuel VALUES (1,120,NULL);
INSERT INTO RangIndividuel VALUES (1,199,NULL);
INSERT INTO RangIndividuel VALUES (2,14,1);
INSERT INTO RangIndividuel VALUES (2,180,2);
INSERT INTO RangIndividuel VALUES (2,82,3);
INSERT INTO RangIndividuel VALUES (2,300,4);
INSERT INTO RangIndividuel VALUES (2,1708,5);
INSERT INTO RangIndividuel VALUES (2,524,6);
INSERT INTO RangIndividuel VALUES (2,121,7);
INSERT INTO RangIndividuel VALUES (2,235,8);
INSERT INTO RangIndividuel VALUES (2,236,9);
INSERT INTO RangIndividuel VALUES (2,800,10);
INSERT INTO RangIndividuel VALUES (2,792,11);
INSERT INTO RangIndividuel VALUES (2,107,12);
INSERT INTO RangIndividuel VALUES (2,327,13);
INSERT INTO RangIndividuel VALUES (2,30,14);
INSERT INTO RangIndividuel VALUES (2,329,15);
INSERT INTO RangIndividuel VALUES (2,92,16);
INSERT INTO RangIndividuel VALUES (2,29,17);
INSERT INTO RangIndividuel VALUES (2,622,18);
INSERT INTO RangIndividuel VALUES (2,1709,19);
INSERT INTO RangIndividuel VALUES (2,392,20);
INSERT INTO RangIndividuel VALUES (2,179,21);
INSERT INTO RangIndividuel VALUES (2,120,22);
INSERT INTO RangIndividuel VALUES (2,21,23);
INSERT INTO RangIndividuel VALUES (2,319,24);
INSERT INTO RangIndividuel VALUES (2,328,25);
INSERT INTO RangIndividuel VALUES (2,33,26);
INSERT INTO RangIndividuel VALUES (2,771,27);
INSERT INTO RangIndividuel VALUES (2,1749,28);
INSERT INTO RangIndividuel VALUES (2,1762,NULL);
INSERT INTO RangIndividuel VALUES (2,19,NULL);
INSERT INTO RangIndividuel VALUES (3,14,1);
INSERT INTO RangIndividuel VALUES (3,30,2);
INSERT INTO RangIndividuel VALUES (3,300,3);
INSERT INTO RangIndividuel VALUES (3,180,4);
INSERT INTO RangIndividuel VALUES (3,107,5);
INSERT INTO RangIndividuel VALUES (3,33,6);
INSERT INTO RangIndividuel VALUES (3,179,7);
INSERT INTO RangIndividuel VALUES (3,327,8);
INSERT INTO RangIndividuel VALUES (3,319,9);
INSERT INTO RangIndividuel VALUES (3,92,10);
INSERT INTO RangIndividuel VALUES (3,21,11);
INSERT INTO RangIndividuel VALUES (3,800,12);
INSERT INTO RangIndividuel VALUES (3,329,13);
INSERT INTO RangIndividuel VALUES (3,213,14);
INSERT INTO RangIndividuel VALUES (3,236,15);
INSERT INTO RangIndividuel VALUES (3,524,16);
INSERT INTO RangIndividuel VALUES (3,328,17);
INSERT INTO RangIndividuel VALUES (3,792,18);
INSERT INTO RangIndividuel VALUES (3,1708,19);
INSERT INTO RangIndividuel VALUES (3,1709,20);
INSERT INTO RangIndividuel VALUES (3,235,21);
INSERT INTO RangIndividuel VALUES (3,121,22);
INSERT INTO RangIndividuel VALUES (3,281,23);
INSERT INTO RangIndividuel VALUES (3,82,24);
INSERT INTO RangIndividuel VALUES (3,480,25);
INSERT INTO RangIndividuel VALUES (3,392,26);
INSERT INTO RangIndividuel VALUES (3,19,27);
INSERT INTO RangIndividuel VALUES (3,771,28);
INSERT INTO RangIndividuel VALUES (3,29,29);
INSERT INTO RangIndividuel VALUES (3,1750,30);
INSERT INTO RangIndividuel VALUES (3,1762,31);
INSERT INTO RangIndividuel VALUES (3,761,32);
INSERT INTO RangIndividuel VALUES (3,779,33);
INSERT INTO RangIndividuel VALUES (3,622,34);
INSERT INTO RangIndividuel VALUES (3,525,35);
INSERT INTO RangIndividuel VALUES (3,757,36);
INSERT INTO RangIndividuel VALUES (3,232,37);
INSERT INTO RangIndividuel VALUES (3,408,38);
INSERT INTO RangIndividuel VALUES (3,1747,39);
INSERT INTO RangIndividuel VALUES (3,1188,40);
INSERT INTO RangIndividuel VALUES (3,1741,41);
INSERT INTO RangIndividuel VALUES (3,1757,42);
INSERT INTO RangIndividuel VALUES (3,447,43);
INSERT INTO RangIndividuel VALUES (3,1727,44);
INSERT INTO RangIndividuel VALUES (3,767,45);
INSERT INTO RangIndividuel VALUES (3,780,46);
INSERT INTO RangIndividuel VALUES (3,280,47);
INSERT INTO RangIndividuel VALUES (3,439,48);
INSERT INTO RangIndividuel VALUES (3,1734,49);
INSERT INTO RangIndividuel VALUES (3,1725,50);
INSERT INTO RangIndividuel VALUES (3,793,51);
INSERT INTO RangIndividuel VALUES (3,1756,52);
INSERT INTO RangIndividuel VALUES (3,1724,53);
INSERT INTO RangIndividuel VALUES (3,791,54);
INSERT INTO RangIndividuel VALUES (3,1732,55);
INSERT INTO RangIndividuel VALUES (3,842,56);
INSERT INTO RangIndividuel VALUES (3,1751,NULL);
INSERT INTO RangIndividuel VALUES (3,786,NULL);
INSERT INTO RangIndividuel VALUES (3,120,NULL);
INSERT INTO RangIndividuel VALUES (3,199,NULL);
INSERT INTO RangIndividuel VALUES (4,14,1);
INSERT INTO RangIndividuel VALUES (4,30,2);
INSERT INTO RangIndividuel VALUES (4,300,3);
INSERT INTO RangIndividuel VALUES (4,180,4);
INSERT INTO RangIndividuel VALUES (4,107,5);
INSERT INTO RangIndividuel VALUES (4,33,6);
INSERT INTO RangIndividuel VALUES (4,179,7);
INSERT INTO RangIndividuel VALUES (4,327,8);
INSERT INTO RangIndividuel VALUES (4,319,9);
INSERT INTO RangIndividuel VALUES (4,92,10);
INSERT INTO RangIndividuel VALUES (4,21,11);
INSERT INTO RangIndividuel VALUES (4,800,12);
INSERT INTO RangIndividuel VALUES (4,329,13);
INSERT INTO RangIndividuel VALUES (4,213,14);
INSERT INTO RangIndividuel VALUES (4,236,15);
INSERT INTO RangIndividuel VALUES (4,524,16);
INSERT INTO RangIndividuel VALUES (4,328,17);
INSERT INTO RangIndividuel VALUES (4,792,18);
INSERT INTO RangIndividuel VALUES (4,1708,19);
INSERT INTO RangIndividuel VALUES (4,1709,20);
INSERT INTO RangIndividuel VALUES (4,235,21);
INSERT INTO RangIndividuel VALUES (4,121,22);
INSERT INTO RangIndividuel VALUES (4,281,23);
INSERT INTO RangIndividuel VALUES (4,82,24);
INSERT INTO RangIndividuel VALUES (4,480,25);
INSERT INTO RangIndividuel VALUES (4,392,26);
INSERT INTO RangIndividuel VALUES (4,19,27);
INSERT INTO RangIndividuel VALUES (4,771,28);
INSERT INTO RangIndividuel VALUES (4,29,29);
INSERT INTO RangIndividuel VALUES (4,1750,30);
INSERT INTO RangIndividuel VALUES (4,1762,31);
INSERT INTO RangIndividuel VALUES (4,761,32);
INSERT INTO RangIndividuel VALUES (4,779,33);
INSERT INTO RangIndividuel VALUES (4,622,34);
INSERT INTO RangIndividuel VALUES (4,525,35);
INSERT INTO RangIndividuel VALUES (4,757,36);
INSERT INTO RangIndividuel VALUES (4,232,37);
INSERT INTO RangIndividuel VALUES (4,408,38);
INSERT INTO RangIndividuel VALUES (4,1747,39);
INSERT INTO RangIndividuel VALUES (4,1188,40);
INSERT INTO RangIndividuel VALUES (4,1741,41);
INSERT INTO RangIndividuel VALUES (4,1757,42);
INSERT INTO RangIndividuel VALUES (4,447,43);
INSERT INTO RangIndividuel VALUES (4,1727,44);
INSERT INTO RangIndividuel VALUES (4,767,45);
INSERT INTO RangIndividuel VALUES (4,780,46);
INSERT INTO RangIndividuel VALUES (4,280,47);
INSERT INTO RangIndividuel VALUES (4,439,48);
INSERT INTO RangIndividuel VALUES (4,1734,49);
INSERT INTO RangIndividuel VALUES (4,1725,50);
INSERT INTO RangIndividuel VALUES (4,793,51);
INSERT INTO RangIndividuel VALUES (4,1756,52);
INSERT INTO RangIndividuel VALUES (4,1724,53);
INSERT INTO RangIndividuel VALUES (4,791,54);
INSERT INTO RangIndividuel VALUES (4,1732,55);
INSERT INTO RangIndividuel VALUES (4,842,56);
INSERT INTO RangIndividuel VALUES (4,1751,NULL);
INSERT INTO RangIndividuel VALUES (4,786,NULL);
INSERT INTO RangIndividuel VALUES (4,120,NULL);
INSERT INTO RangIndividuel VALUES (4,199,NULL);
INSERT INTO RangIndividuel VALUES (6,1,1);
INSERT INTO RangIndividuel VALUES (6,214,2);
INSERT INTO RangIndividuel VALUES (6,197,3);
INSERT INTO RangIndividuel VALUES (6,91,4);
INSERT INTO RangIndividuel VALUES (6,481,5);
INSERT INTO RangIndividuel VALUES (6,25,6);
INSERT INTO RangIndividuel VALUES (6,198,7);
INSERT INTO RangIndividuel VALUES (6,174,8);
INSERT INTO RangIndividuel VALUES (6,6,9);
INSERT INTO RangIndividuel VALUES (6,384,10);
INSERT INTO RangIndividuel VALUES (6,383,11);
INSERT INTO RangIndividuel VALUES (6,326,12);
INSERT INTO RangIndividuel VALUES (6,770,13);
INSERT INTO RangIndividuel VALUES (6,330,14);
INSERT INTO RangIndividuel VALUES (6,233,15);
INSERT INTO RangIndividuel VALUES (6,37,16);
INSERT INTO RangIndividuel VALUES (6,777,17);
INSERT INTO RangIndividuel VALUES (6,1729,18);
INSERT INTO RangIndividuel VALUES (6,474,19);
INSERT INTO RangIndividuel VALUES (6,173,20);
INSERT INTO RangIndividuel VALUES (6,183,21);
INSERT INTO RangIndividuel VALUES (6,398,22);
INSERT INTO RangIndividuel VALUES (6,768,23);
INSERT INTO RangIndividuel VALUES (6,452,24);
INSERT INTO RangIndividuel VALUES (6,106,25);
INSERT INTO RangIndividuel VALUES (6,616,26);
INSERT INTO RangIndividuel VALUES (6,382,27);
INSERT INTO RangIndividuel VALUES (6,155,28);
INSERT INTO RangIndividuel VALUES (6,1718,29);
INSERT INTO RangIndividuel VALUES (6,821,30);
INSERT INTO RangIndividuel VALUES (6,497,31);
INSERT INTO RangIndividuel VALUES (6,760,32);
INSERT INTO RangIndividuel VALUES (6,218,33);
INSERT INTO RangIndividuel VALUES (6,234,34);
INSERT INTO RangIndividuel VALUES (6,454,35);
INSERT INTO RangIndividuel VALUES (6,565,36);
INSERT INTO RangIndividuel VALUES (6,526,37);
INSERT INTO RangIndividuel VALUES (6,188,38);
INSERT INTO RangIndividuel VALUES (6,122,39);
INSERT INTO RangIndividuel VALUES (6,1759,40);
INSERT INTO RangIndividuel VALUES (6,758,41);
INSERT INTO RangIndividuel VALUES (6,1744,42);
INSERT INTO RangIndividuel VALUES (6,753,43);
INSERT INTO RangIndividuel VALUES (6,759,44);
INSERT INTO RangIndividuel VALUES (6,794,45);
INSERT INTO RangIndividuel VALUES (6,1728,46);
INSERT INTO RangIndividuel VALUES (6,567,47);
INSERT INTO RangIndividuel VALUES (6,762,48);
INSERT INTO RangIndividuel VALUES (6,783,49);
INSERT INTO RangIndividuel VALUES (6,774,50);
INSERT INTO RangIndividuel VALUES (6,449,51);
INSERT INTO RangIndividuel VALUES (6,302,52);
INSERT INTO RangIndividuel VALUES (6,399,53);
INSERT INTO RangIndividuel VALUES (6,772,54);
INSERT INTO RangIndividuel VALUES (6,1742,55);
INSERT INTO RangIndividuel VALUES (6,778,56);
INSERT INTO RangIndividuel VALUES (6,1719,57);
INSERT INTO RangIndividuel VALUES (6,785,58);
INSERT INTO RangIndividuel VALUES (6,752,59);
INSERT INTO RangIndividuel VALUES (6,781,60);
INSERT INTO RangIndividuel VALUES (6,795,61);
INSERT INTO RangIndividuel VALUES (6,1752,62);
INSERT INTO RangIndividuel VALUES (6,797,63);
INSERT INTO RangIndividuel VALUES (6,623,64);
INSERT INTO RangIndividuel VALUES (6,1737,65);
INSERT INTO RangIndividuel VALUES (6,428,66);
INSERT INTO RangIndividuel VALUES (6,789,67);
INSERT INTO RangIndividuel VALUES (6,531,68);
INSERT INTO RangIndividuel VALUES (6,766,69);
INSERT INTO RangIndividuel VALUES (6,418,70);
INSERT INTO RangIndividuel VALUES (6,445,71);
INSERT INTO RangIndividuel VALUES (6,790,72);
INSERT INTO RangIndividuel VALUES (6,784,73);
INSERT INTO RangIndividuel VALUES (6,769,74);
INSERT INTO RangIndividuel VALUES (6,1754,75);
INSERT INTO RangIndividuel VALUES (6,1713,76);
INSERT INTO RangIndividuel VALUES (6,751,77);
INSERT INTO RangIndividuel VALUES (6,787,78);
INSERT INTO RangIndividuel VALUES (6,775,79);
INSERT INTO RangIndividuel VALUES (6,1739,80);
INSERT INTO RangIndividuel VALUES (6,566,81);
INSERT INTO RangIndividuel VALUES (6,763,82);
INSERT INTO RangIndividuel VALUES (6,574,83);
INSERT INTO RangIndividuel VALUES (6,1738,84);
INSERT INTO RangIndividuel VALUES (6,1710,85);
INSERT INTO RangIndividuel VALUES (6,1711,86);
INSERT INTO RangIndividuel VALUES (6,754,87);
INSERT INTO RangIndividuel VALUES (7,25,1);
INSERT INTO RangIndividuel VALUES (7,174,2);
INSERT INTO RangIndividuel VALUES (7,330,3);
INSERT INTO RangIndividuel VALUES (7,1,4);
INSERT INTO RangIndividuel VALUES (7,37,5);
INSERT INTO RangIndividuel VALUES (7,233,6);
INSERT INTO RangIndividuel VALUES (7,6,7);
INSERT INTO RangIndividuel VALUES (7,198,8);
INSERT INTO RangIndividuel VALUES (7,777,9);
INSERT INTO RangIndividuel VALUES (7,214,10);
INSERT INTO RangIndividuel VALUES (7,770,11);
INSERT INTO RangIndividuel VALUES (7,173,12);
INSERT INTO RangIndividuel VALUES (7,1729,13);
INSERT INTO RangIndividuel VALUES (7,91,14);
INSERT INTO RangIndividuel VALUES (7,382,15);
INSERT INTO RangIndividuel VALUES (7,183,16);
INSERT INTO RangIndividuel VALUES (7,326,17);
INSERT INTO RangIndividuel VALUES (7,565,18);
INSERT INTO RangIndividuel VALUES (7,234,19);
INSERT INTO RangIndividuel VALUES (7,197,20);
INSERT INTO RangIndividuel VALUES (7,1728,21);
INSERT INTO RangIndividuel VALUES (7,474,22);
INSERT INTO RangIndividuel VALUES (7,526,23);
INSERT INTO RangIndividuel VALUES (7,616,24);
INSERT INTO RangIndividuel VALUES (7,383,25);
INSERT INTO RangIndividuel VALUES (7,481,26);
INSERT INTO RangIndividuel VALUES (7,122,27);
INSERT INTO RangIndividuel VALUES (7,1744,28);
INSERT INTO RangIndividuel VALUES (7,753,29);
INSERT INTO RangIndividuel VALUES (7,106,30);
INSERT INTO RangIndividuel VALUES (7,384,31);
INSERT INTO RangIndividuel VALUES (7,1742,32);
INSERT INTO RangIndividuel VALUES (7,155,33);
INSERT INTO RangIndividuel VALUES (7,452,34);
INSERT INTO RangIndividuel VALUES (7,768,35);
INSERT INTO RangIndividuel VALUES (7,398,36);
INSERT INTO RangIndividuel VALUES (7,188,37);
INSERT INTO RangIndividuel VALUES (7,454,38);
INSERT INTO RangIndividuel VALUES (7,758,39);
INSERT INTO RangIndividuel VALUES (7,762,40);
INSERT INTO RangIndividuel VALUES (7,1718,41);
INSERT INTO RangIndividuel VALUES (7,567,42);
INSERT INTO RangIndividuel VALUES (7,785,43);
INSERT INTO RangIndividuel VALUES (7,760,44);
INSERT INTO RangIndividuel VALUES (7,399,45);
INSERT INTO RangIndividuel VALUES (7,772,46);
INSERT INTO RangIndividuel VALUES (7,821,47);
INSERT INTO RangIndividuel VALUES (7,783,48);
INSERT INTO RangIndividuel VALUES (7,449,49);
INSERT INTO RangIndividuel VALUES (7,218,50);
INSERT INTO RangIndividuel VALUES (7,778,51);
INSERT INTO RangIndividuel VALUES (7,302,52);
INSERT INTO RangIndividuel VALUES (7,794,53);
INSERT INTO RangIndividuel VALUES (7,759,54);
INSERT INTO RangIndividuel VALUES (7,781,55);
INSERT INTO RangIndividuel VALUES (7,1719,56);
INSERT INTO RangIndividuel VALUES (7,1759,57);
INSERT INTO RangIndividuel VALUES (7,752,58);
INSERT INTO RangIndividuel VALUES (7,774,59);
INSERT INTO RangIndividuel VALUES (7,497,NULL);
INSERT INTO RangIndividuel VALUES (8,6,1);
INSERT INTO RangIndividuel VALUES (8,25,2);
INSERT INTO RangIndividuel VALUES (8,174,3);
INSERT INTO RangIndividuel VALUES (8,384,4);
INSERT INTO RangIndividuel VALUES (8,382,5);
INSERT INTO RangIndividuel VALUES (8,1729,6);
INSERT INTO RangIndividuel VALUES (8,214,7);
INSERT INTO RangIndividuel VALUES (8,1742,8);
INSERT INTO RangIndividuel VALUES (8,768,9);
INSERT INTO RangIndividuel VALUES (8,481,10);
INSERT INTO RangIndividuel VALUES (8,91,11);
INSERT INTO RangIndividuel VALUES (8,106,12);
INSERT INTO RangIndividuel VALUES (8,233,13);
INSERT INTO RangIndividuel VALUES (8,777,14);
INSERT INTO RangIndividuel VALUES (8,526,15);
INSERT INTO RangIndividuel VALUES (8,198,16);
INSERT INTO RangIndividuel VALUES (8,330,17);
INSERT INTO RangIndividuel VALUES (8,234,18);
INSERT INTO RangIndividuel VALUES (8,37,19);
INSERT INTO RangIndividuel VALUES (8,155,20);
INSERT INTO RangIndividuel VALUES (8,474,21);
INSERT INTO RangIndividuel VALUES (8,1,22);
INSERT INTO RangIndividuel VALUES (8,454,23);
INSERT INTO RangIndividuel VALUES (8,197,24);
INSERT INTO RangIndividuel VALUES (8,383,25);
INSERT INTO RangIndividuel VALUES (8,183,26);
INSERT INTO RangIndividuel VALUES (8,173,27);
INSERT INTO RangIndividuel VALUES (8,326,NULL);
INSERT INTO RangIndividuel VALUES (8,770,NULL);
INSERT INTO RangIndividuel VALUES (8,565,NULL);
INSERT INTO RangIndividuel VALUES (9,25,1);
INSERT INTO RangIndividuel VALUES (9,183,2);
INSERT INTO RangIndividuel VALUES (9,382,3);
INSERT INTO RangIndividuel VALUES (9,198,4);
INSERT INTO RangIndividuel VALUES (9,214,5);
INSERT INTO RangIndividuel VALUES (9,330,6);
INSERT INTO RangIndividuel VALUES (9,6,7);
INSERT INTO RangIndividuel VALUES (9,454,8);
INSERT INTO RangIndividuel VALUES (9,758,9);
INSERT INTO RangIndividuel VALUES (9,282,10);
INSERT INTO RangIndividuel VALUES (9,1742,11);
INSERT INTO RangIndividuel VALUES (9,106,12);
INSERT INTO RangIndividuel VALUES (9,565,13);
INSERT INTO RangIndividuel VALUES (9,326,14);
INSERT INTO RangIndividuel VALUES (9,1729,15);
INSERT INTO RangIndividuel VALUES (9,233,16);
INSERT INTO RangIndividuel VALUES (9,197,17);
INSERT INTO RangIndividuel VALUES (9,174,18);
INSERT INTO RangIndividuel VALUES (9,526,19);
INSERT INTO RangIndividuel VALUES (9,753,20);
INSERT INTO RangIndividuel VALUES (9,768,21);
INSERT INTO RangIndividuel VALUES (9,436,22);
INSERT INTO RangIndividuel VALUES (9,762,23);
INSERT INTO RangIndividuel VALUES (9,173,24);
INSERT INTO RangIndividuel VALUES (9,770,25);
INSERT INTO RangIndividuel VALUES (9,122,26);
INSERT INTO RangIndividuel VALUES (9,1739,27);
INSERT INTO RangIndividuel VALUES (9,302,28);
INSERT INTO RangIndividuel VALUES (9,399,29);
INSERT INTO RangIndividuel VALUES (9,1721,30);
INSERT INTO RangIndividuel VALUES (9,567,31);
INSERT INTO RangIndividuel VALUES (9,384,32);
INSERT INTO RangIndividuel VALUES (9,777,33);
INSERT INTO RangIndividuel VALUES (9,1,34);
INSERT INTO RangIndividuel VALUES (9,481,35);
INSERT INTO RangIndividuel VALUES (9,783,36);
INSERT INTO RangIndividuel VALUES (9,452,37);
INSERT INTO RangIndividuel VALUES (9,37,38);
INSERT INTO RangIndividuel VALUES (9,781,39);
INSERT INTO RangIndividuel VALUES (9,188,40);
INSERT INTO RangIndividuel VALUES (9,1744,41);
INSERT INTO RangIndividuel VALUES (9,789,42);
INSERT INTO RangIndividuel VALUES (9,1737,43);
INSERT INTO RangIndividuel VALUES (9,474,44);
INSERT INTO RangIndividuel VALUES (9,784,45);
INSERT INTO RangIndividuel VALUES (9,398,46);
INSERT INTO RangIndividuel VALUES (9,543,47);
INSERT INTO RangIndividuel VALUES (9,797,48);
INSERT INTO RangIndividuel VALUES (9,1718,49);
INSERT INTO RangIndividuel VALUES (9,795,50);
INSERT INTO RangIndividuel VALUES (9,751,51);
INSERT INTO RangIndividuel VALUES (9,616,52);
INSERT INTO RangIndividuel VALUES (9,778,53);
INSERT INTO RangIndividuel VALUES (9,218,54);
INSERT INTO RangIndividuel VALUES (9,1723,55);
INSERT INTO RangIndividuel VALUES (9,1752,56);
INSERT INTO RangIndividuel VALUES (9,497,57);
INSERT INTO RangIndividuel VALUES (9,527,58);
INSERT INTO RangIndividuel VALUES (9,769,59);
INSERT INTO RangIndividuel VALUES (9,821,60);
INSERT INTO RangIndividuel VALUES (9,1755,61);
INSERT INTO RangIndividuel VALUES (9,774,62);
INSERT INTO RangIndividuel VALUES (9,449,63);
INSERT INTO RangIndividuel VALUES (9,119,64);
INSERT INTO RangIndividuel VALUES (9,383,65);
INSERT INTO RangIndividuel VALUES (9,574,66);
INSERT INTO RangIndividuel VALUES (9,796,67);
INSERT INTO RangIndividuel VALUES (9,418,68);
INSERT INTO RangIndividuel VALUES (9,766,69);
INSERT INTO RangIndividuel VALUES (9,1730,70);
INSERT INTO RangIndividuel VALUES (9,566,71);
INSERT INTO RangIndividuel VALUES (9,1738,72);
INSERT INTO RangIndividuel VALUES (9,763,73);
INSERT INTO RangIndividuel VALUES (9,790,74);
INSERT INTO RangIndividuel VALUES (9,782,75);
INSERT INTO RangIndividuel VALUES (9,752,76);
INSERT INTO RangIndividuel VALUES (9,623,77);
INSERT INTO RangIndividuel VALUES (9,772,78);
INSERT INTO RangIndividuel VALUES (9,1760,79);
INSERT INTO RangIndividuel VALUES (9,1753,80);
INSERT INTO RangIndividuel VALUES (9,760,81);
INSERT INTO RangIndividuel VALUES (9,801,82);
INSERT INTO RangIndividuel VALUES (9,794,83);
INSERT INTO RangIndividuel VALUES (9,445,84);
INSERT INTO RangIndividuel VALUES (9,755,85);
INSERT INTO RangIndividuel VALUES (9,1710,86);
INSERT INTO RangIndividuel VALUES (9,1712,87);
INSERT INTO RangIndividuel VALUES (9,775,88);
INSERT INTO RangIndividuel VALUES (9,787,NULL);
INSERT INTO RangIndividuel VALUES (15,61,1);
INSERT INTO RangIndividuel VALUES (15,224,2);
INSERT INTO RangIndividuel VALUES (15,96,3);
INSERT INTO RangIndividuel VALUES (15,315,4);
INSERT INTO RangIndividuel VALUES (15,52,5);
INSERT INTO RangIndividuel VALUES (15,201,6);
INSERT INTO RangIndividuel VALUES (15,983,7);
INSERT INTO RangIndividuel VALUES (15,209,8);
INSERT INTO RangIndividuel VALUES (15,345,9);
INSERT INTO RangIndividuel VALUES (15,125,10);
INSERT INTO RangIndividuel VALUES (15,78,11);
INSERT INTO RangIndividuel VALUES (15,346,12);
INSERT INTO RangIndividuel VALUES (15,979,13);
INSERT INTO RangIndividuel VALUES (15,982,14);
INSERT INTO RangIndividuel VALUES (15,981,15);
INSERT INTO RangIndividuel VALUES (15,1213,16);
INSERT INTO RangIndividuel VALUES (15,583,17);
INSERT INTO RangIndividuel VALUES (15,35,18);
INSERT INTO RangIndividuel VALUES (15,415,19);
INSERT INTO RangIndividuel VALUES (15,582,20);
INSERT INTO RangIndividuel VALUES (15,987,21);
INSERT INTO RangIndividuel VALUES (15,1227,22);
INSERT INTO RangIndividuel VALUES (15,424,23);
INSERT INTO RangIndividuel VALUES (15,64,24);
INSERT INTO RangIndividuel VALUES (15,426,25);
INSERT INTO RangIndividuel VALUES (15,990,26);
INSERT INTO RangIndividuel VALUES (15,992,27);
INSERT INTO RangIndividuel VALUES (15,430,28);
INSERT INTO RangIndividuel VALUES (15,991,29);
INSERT INTO RangIndividuel VALUES (15,1231,30);
INSERT INTO RangIndividuel VALUES (15,980,31);
INSERT INTO RangIndividuel VALUES (15,1215,32);
INSERT INTO RangIndividuel VALUES (15,989,33);
INSERT INTO RangIndividuel VALUES (15,986,34);
INSERT INTO RangIndividuel VALUES (15,108,35);
INSERT INTO RangIndividuel VALUES (15,502,36);
INSERT INTO RangIndividuel VALUES (15,988,37);
INSERT INTO RangIndividuel VALUES (15,1234,38);
INSERT INTO RangIndividuel VALUES (15,1228,39);
INSERT INTO RangIndividuel VALUES (15,1233,40);
INSERT INTO RangIndividuel VALUES (15,1214,41);
INSERT INTO RangIndividuel VALUES (15,1232,42);
INSERT INTO RangIndividuel VALUES (15,1230,43);
INSERT INTO RangIndividuel VALUES (15,984,44);
INSERT INTO RangIndividuel VALUES (15,1229,45);
INSERT INTO RangIndividuel VALUES (16,47,1);
INSERT INTO RangIndividuel VALUES (16,52,2);
INSERT INTO RangIndividuel VALUES (16,209,3);
INSERT INTO RangIndividuel VALUES (16,165,4);
INSERT INTO RangIndividuel VALUES (16,79,5);
INSERT INTO RangIndividuel VALUES (16,224,6);
INSERT INTO RangIndividuel VALUES (16,108,7);
INSERT INTO RangIndividuel VALUES (16,201,8);
INSERT INTO RangIndividuel VALUES (16,125,9);
INSERT INTO RangIndividuel VALUES (16,61,10);
INSERT INTO RangIndividuel VALUES (16,991,11);
INSERT INTO RangIndividuel VALUES (16,96,12);
INSERT INTO RangIndividuel VALUES (16,582,13);
INSERT INTO RangIndividuel VALUES (16,1213,14);
INSERT INTO RangIndividuel VALUES (16,346,15);
INSERT INTO RangIndividuel VALUES (16,987,16);
INSERT INTO RangIndividuel VALUES (16,78,17);
INSERT INTO RangIndividuel VALUES (16,315,18);
INSERT INTO RangIndividuel VALUES (16,35,19);
INSERT INTO RangIndividuel VALUES (16,989,20);
INSERT INTO RangIndividuel VALUES (16,430,21);
INSERT INTO RangIndividuel VALUES (16,990,22);
INSERT INTO RangIndividuel VALUES (16,982,23);
INSERT INTO RangIndividuel VALUES (16,992,24);
INSERT INTO RangIndividuel VALUES (16,1215,25);
INSERT INTO RangIndividuel VALUES (16,1227,26);
INSERT INTO RangIndividuel VALUES (16,583,27);
INSERT INTO RangIndividuel VALUES (16,983,28);
INSERT INTO RangIndividuel VALUES (16,426,29);
INSERT INTO RangIndividuel VALUES (16,1232,30);
INSERT INTO RangIndividuel VALUES (16,64,31);
INSERT INTO RangIndividuel VALUES (16,424,32);
INSERT INTO RangIndividuel VALUES (16,986,33);
INSERT INTO RangIndividuel VALUES (16,1214,34);
INSERT INTO RangIndividuel VALUES (16,981,35);
INSERT INTO RangIndividuel VALUES (16,1230,36);
INSERT INTO RangIndividuel VALUES (16,1228,37);
INSERT INTO RangIndividuel VALUES (16,1234,38);
INSERT INTO RangIndividuel VALUES (16,988,39);
INSERT INTO RangIndividuel VALUES (16,502,40);
INSERT INTO RangIndividuel VALUES (16,585,41);
INSERT INTO RangIndividuel VALUES (16,1233,42);
INSERT INTO RangIndividuel VALUES (16,978,43);
INSERT INTO RangIndividuel VALUES (16,984,44);
INSERT INTO RangIndividuel VALUES (16,216,NULL);
INSERT INTO RangIndividuel VALUES (16,980,NULL);
INSERT INTO RangIndividuel VALUES (22,39,1);
INSERT INTO RangIndividuel VALUES (22,57,2);
INSERT INTO RangIndividuel VALUES (22,305,3);
INSERT INTO RangIndividuel VALUES (22,489,4);
INSERT INTO RangIndividuel VALUES (22,1381,5);
INSERT INTO RangIndividuel VALUES (22,437,6);
INSERT INTO RangIndividuel VALUES (22,249,7);
INSERT INTO RangIndividuel VALUES (22,963,8);
INSERT INTO RangIndividuel VALUES (22,548,9);
INSERT INTO RangIndividuel VALUES (22,973,10);
INSERT INTO RangIndividuel VALUES (22,1374,11);
INSERT INTO RangIndividuel VALUES (22,344,12);
INSERT INTO RangIndividuel VALUES (22,1380,13);
INSERT INTO RangIndividuel VALUES (22,968,14);
INSERT INTO RangIndividuel VALUES (22,1210,15);
INSERT INTO RangIndividuel VALUES (22,1378,16);
INSERT INTO RangIndividuel VALUES (22,1392,17);
INSERT INTO RangIndividuel VALUES (22,1207,18);
INSERT INTO RangIndividuel VALUES (22,1208,19);
INSERT INTO RangIndividuel VALUES (22,229,20);
INSERT INTO RangIndividuel VALUES (22,1377,21);
INSERT INTO RangIndividuel VALUES (22,1384,22);
INSERT INTO RangIndividuel VALUES (22,1396,23);
INSERT INTO RangIndividuel VALUES (22,1212,24);
INSERT INTO RangIndividuel VALUES (22,1383,25);
INSERT INTO RangIndividuel VALUES (22,1205,26);
INSERT INTO RangIndividuel VALUES (22,1382,27);
INSERT INTO RangIndividuel VALUES (22,1397,28);
INSERT INTO RangIndividuel VALUES (22,1387,29);
INSERT INTO RangIndividuel VALUES (22,465,30);
INSERT INTO RangIndividuel VALUES (22,1390,31);
INSERT INTO RangIndividuel VALUES (23,16,1);
INSERT INTO RangIndividuel VALUES (23,166,2);
INSERT INTO RangIndividuel VALUES (23,27,3);
INSERT INTO RangIndividuel VALUES (23,969,4);
INSERT INTO RangIndividuel VALUES (23,962,5);
INSERT INTO RangIndividuel VALUES (23,1385,6);
INSERT INTO RangIndividuel VALUES (23,1375,7);
INSERT INTO RangIndividuel VALUES (23,975,8);
INSERT INTO RangIndividuel VALUES (23,976,9);
INSERT INTO RangIndividuel VALUES (23,288,10);
INSERT INTO RangIndividuel VALUES (23,1379,11);
INSERT INTO RangIndividuel VALUES (23,972,12);
INSERT INTO RangIndividuel VALUES (23,1389,13);
INSERT INTO RangIndividuel VALUES (23,220,14);
INSERT INTO RangIndividuel VALUES (23,610,15);
INSERT INTO RangIndividuel VALUES (23,970,16);
INSERT INTO RangIndividuel VALUES (23,1394,17);
INSERT INTO RangIndividuel VALUES (23,1395,18);
INSERT INTO RangIndividuel VALUES (23,1386,19);
INSERT INTO RangIndividuel VALUES (23,536,20);
INSERT INTO RangIndividuel VALUES (23,971,21);
INSERT INTO RangIndividuel VALUES (23,1211,22);
INSERT INTO RangIndividuel VALUES (23,964,23);
INSERT INTO RangIndividuel VALUES (23,1388,24);
INSERT INTO RangIndividuel VALUES (23,974,25);
INSERT INTO RangIndividuel VALUES (23,1204,26);
INSERT INTO RangIndividuel VALUES (23,1203,27);
INSERT INTO RangIndividuel VALUES (23,549,28);
INSERT INTO RangIndividuel VALUES (23,967,29);
INSERT INTO RangIndividuel VALUES (23,965,30);
INSERT INTO RangIndividuel VALUES (23,966,31);
INSERT INTO RangIndividuel VALUES (23,1398,32);
INSERT INTO RangIndividuel VALUES (23,1206,33);
INSERT INTO RangIndividuel VALUES (23,1393,34);
INSERT INTO RangIndividuel VALUES (23,1391,35);
INSERT INTO RangIndividuel VALUES (23,611,36);
INSERT INTO RangIndividuel VALUES (23,1399,37);
INSERT INTO RangIndividuel VALUES (23,1376,38);
INSERT INTO RangIndividuel VALUES (23,1209,39);
INSERT INTO RangIndividuel VALUES (26,138,1);
INSERT INTO RangIndividuel VALUES (26,73,2);
INSERT INTO RangIndividuel VALUES (26,314,3);
INSERT INTO RangIndividuel VALUES (26,369,4);
INSERT INTO RangIndividuel VALUES (26,145,5);
INSERT INTO RangIndividuel VALUES (26,247,6);
INSERT INTO RangIndividuel VALUES (26,343,7);
INSERT INTO RangIndividuel VALUES (26,948,8);
INSERT INTO RangIndividuel VALUES (26,1367,9);
INSERT INTO RangIndividuel VALUES (26,1360,10);
INSERT INTO RangIndividuel VALUES (26,951,11);
INSERT INTO RangIndividuel VALUES (26,1355,12);
INSERT INTO RangIndividuel VALUES (26,268,13);
INSERT INTO RangIndividuel VALUES (26,1200,14);
INSERT INTO RangIndividuel VALUES (26,954,15);
INSERT INTO RangIndividuel VALUES (26,1197,16);
INSERT INTO RangIndividuel VALUES (26,1363,17);
INSERT INTO RangIndividuel VALUES (26,1370,18);
INSERT INTO RangIndividuel VALUES (26,464,19);
INSERT INTO RangIndividuel VALUES (26,1365,20);
INSERT INTO RangIndividuel VALUES (26,1201,21);
INSERT INTO RangIndividuel VALUES (26,1372,22);
INSERT INTO RangIndividuel VALUES (26,1371,23);
INSERT INTO RangIndividuel VALUES (26,1361,24);
INSERT INTO RangIndividuel VALUES (26,955,25);
INSERT INTO RangIndividuel VALUES (26,959,26);
INSERT INTO RangIndividuel VALUES (26,956,27);
INSERT INTO RangIndividuel VALUES (26,947,28);
INSERT INTO RangIndividuel VALUES (26,501,29);
INSERT INTO RangIndividuel VALUES (26,1368,30);
INSERT INTO RangIndividuel VALUES (27,144,1);
INSERT INTO RangIndividuel VALUES (27,182,2);
INSERT INTO RangIndividuel VALUES (27,341,3);
INSERT INTO RangIndividuel VALUES (27,950,4);
INSERT INTO RangIndividuel VALUES (27,961,5);
INSERT INTO RangIndividuel VALUES (27,298,6);
INSERT INTO RangIndividuel VALUES (27,1199,7);
INSERT INTO RangIndividuel VALUES (27,953,8);
INSERT INTO RangIndividuel VALUES (27,370,9);
INSERT INTO RangIndividuel VALUES (27,958,10);
INSERT INTO RangIndividuel VALUES (27,420,11);
INSERT INTO RangIndividuel VALUES (27,342,12);
INSERT INTO RangIndividuel VALUES (27,432,13);
INSERT INTO RangIndividuel VALUES (27,957,14);
INSERT INTO RangIndividuel VALUES (27,248,15);
INSERT INTO RangIndividuel VALUES (27,1373,16);
INSERT INTO RangIndividuel VALUES (27,1356,17);
INSERT INTO RangIndividuel VALUES (27,960,18);
INSERT INTO RangIndividuel VALUES (27,1202,19);
INSERT INTO RangIndividuel VALUES (27,1359,20);
INSERT INTO RangIndividuel VALUES (27,1357,21);
INSERT INTO RangIndividuel VALUES (27,946,22);
INSERT INTO RangIndividuel VALUES (27,949,23);
INSERT INTO RangIndividuel VALUES (27,952,24);
INSERT INTO RangIndividuel VALUES (27,1358,NULL);
INSERT INTO RangIndividuel VALUES (27,609,NULL);
INSERT INTO RangIndividuel VALUES (27,1362,NULL);
INSERT INTO RangIndividuel VALUES (27,1364,NULL);
INSERT INTO RangIndividuel VALUES (27,1366,NULL);
INSERT INTO RangIndividuel VALUES (27,1907,NULL);
INSERT INTO RangIndividuel VALUES (31,152,1);
INSERT INTO RangIndividuel VALUES (31,5,2);
INSERT INTO RangIndividuel VALUES (31,292,3);
INSERT INTO RangIndividuel VALUES (31,258,4);
INSERT INTO RangIndividuel VALUES (31,94,5);
INSERT INTO RangIndividuel VALUES (31,131,6);
INSERT INTO RangIndividuel VALUES (31,1124,7);
INSERT INTO RangIndividuel VALUES (31,1582,8);
INSERT INTO RangIndividuel VALUES (31,65,9);
INSERT INTO RangIndividuel VALUES (31,1129,10);
INSERT INTO RangIndividuel VALUES (31,468,11);
INSERT INTO RangIndividuel VALUES (31,44,12);
INSERT INTO RangIndividuel VALUES (31,259,13);
INSERT INTO RangIndividuel VALUES (31,317,14);
INSERT INTO RangIndividuel VALUES (31,356,15);
INSERT INTO RangIndividuel VALUES (31,354,16);
INSERT INTO RangIndividuel VALUES (31,1575,17);
INSERT INTO RangIndividuel VALUES (31,1561,18);
INSERT INTO RangIndividuel VALUES (31,1555,19);
INSERT INTO RangIndividuel VALUES (31,294,20);
INSERT INTO RangIndividuel VALUES (31,1560,21);
INSERT INTO RangIndividuel VALUES (31,1543,22);
INSERT INTO RangIndividuel VALUES (31,257,23);
INSERT INTO RangIndividuel VALUES (31,1580,24);
INSERT INTO RangIndividuel VALUES (31,219,25);
INSERT INTO RangIndividuel VALUES (31,1116,26);
INSERT INTO RangIndividuel VALUES (31,1105,27);
INSERT INTO RangIndividuel VALUES (31,1587,28);
INSERT INTO RangIndividuel VALUES (31,207,29);
INSERT INTO RangIndividuel VALUES (31,493,30);
INSERT INTO RangIndividuel VALUES (31,1585,31);
INSERT INTO RangIndividuel VALUES (31,1121,32);
INSERT INTO RangIndividuel VALUES (31,1128,33);
INSERT INTO RangIndividuel VALUES (31,1594,34);
INSERT INTO RangIndividuel VALUES (31,599,35);
INSERT INTO RangIndividuel VALUES (31,1590,NULL);
INSERT INTO RangIndividuel VALUES (32,46,1);
INSERT INTO RangIndividuel VALUES (32,5,2);
INSERT INTO RangIndividuel VALUES (32,94,3);
INSERT INTO RangIndividuel VALUES (32,131,4);
INSERT INTO RangIndividuel VALUES (32,354,5);
INSERT INTO RangIndividuel VALUES (32,206,6);
INSERT INTO RangIndividuel VALUES (32,1124,7);
INSERT INTO RangIndividuel VALUES (32,294,8);
INSERT INTO RangIndividuel VALUES (32,258,9);
INSERT INTO RangIndividuel VALUES (32,356,10);
INSERT INTO RangIndividuel VALUES (32,207,11);
INSERT INTO RangIndividuel VALUES (32,1575,12);
INSERT INTO RangIndividuel VALUES (32,1129,13);
INSERT INTO RangIndividuel VALUES (32,1582,14);
INSERT INTO RangIndividuel VALUES (32,257,15);
INSERT INTO RangIndividuel VALUES (32,1560,16);
INSERT INTO RangIndividuel VALUES (32,65,17);
INSERT INTO RangIndividuel VALUES (32,1123,18);
INSERT INTO RangIndividuel VALUES (32,4,19);
INSERT INTO RangIndividuel VALUES (32,1600,20);
INSERT INTO RangIndividuel VALUES (32,1586,21);
INSERT INTO RangIndividuel VALUES (32,1547,22);
INSERT INTO RangIndividuel VALUES (32,1595,23);
INSERT INTO RangIndividuel VALUES (32,1590,24);
INSERT INTO RangIndividuel VALUES (32,215,25);
INSERT INTO RangIndividuel VALUES (32,493,26);
INSERT INTO RangIndividuel VALUES (32,1599,27);
INSERT INTO RangIndividuel VALUES (32,1555,28);
INSERT INTO RangIndividuel VALUES (32,1106,29);
INSERT INTO RangIndividuel VALUES (32,1116,30);
INSERT INTO RangIndividuel VALUES (32,1544,31);
INSERT INTO RangIndividuel VALUES (32,1548,32);
INSERT INTO RangIndividuel VALUES (32,1571,33);
INSERT INTO RangIndividuel VALUES (32,1580,34);
INSERT INTO RangIndividuel VALUES (32,1564,35);
INSERT INTO RangIndividuel VALUES (32,1588,36);
INSERT INTO RangIndividuel VALUES (33,44,1);
INSERT INTO RangIndividuel VALUES (33,258,2);
INSERT INTO RangIndividuel VALUES (33,292,3);
INSERT INTO RangIndividuel VALUES (33,152,4);
INSERT INTO RangIndividuel VALUES (33,259,5);
INSERT INTO RangIndividuel VALUES (33,219,6);
INSERT INTO RangIndividuel VALUES (33,317,7);
INSERT INTO RangIndividuel VALUES (33,1124,8);
INSERT INTO RangIndividuel VALUES (33,1105,9);
INSERT INTO RangIndividuel VALUES (33,1129,10);
INSERT INTO RangIndividuel VALUES (33,357,11);
INSERT INTO RangIndividuel VALUES (33,65,12);
INSERT INTO RangIndividuel VALUES (33,1582,13);
INSERT INTO RangIndividuel VALUES (33,1543,14);
INSERT INTO RangIndividuel VALUES (33,1127,15);
INSERT INTO RangIndividuel VALUES (33,94,16);
INSERT INTO RangIndividuel VALUES (33,1553,17);
INSERT INTO RangIndividuel VALUES (33,1098,18);
INSERT INTO RangIndividuel VALUES (33,131,19);
INSERT INTO RangIndividuel VALUES (33,599,20);
INSERT INTO RangIndividuel VALUES (33,1593,21);
INSERT INTO RangIndividuel VALUES (33,1555,22);
INSERT INTO RangIndividuel VALUES (33,1120,23);
INSERT INTO RangIndividuel VALUES (33,1587,24);
INSERT INTO RangIndividuel VALUES (33,294,25);
INSERT INTO RangIndividuel VALUES (33,1585,26);
INSERT INTO RangIndividuel VALUES (33,1580,27);
INSERT INTO RangIndividuel VALUES (33,977,28);
INSERT INTO RangIndividuel VALUES (33,1121,29);
INSERT INTO RangIndividuel VALUES (33,1567,30);
INSERT INTO RangIndividuel VALUES (33,598,31);
INSERT INTO RangIndividuel VALUES (33,1581,32);
INSERT INTO RangIndividuel VALUES (33,1565,33);
INSERT INTO RangIndividuel VALUES (33,1116,34);
INSERT INTO RangIndividuel VALUES (33,468,NULL);
INSERT INTO RangIndividuel VALUES (34,5,1);
INSERT INTO RangIndividuel VALUES (34,9,2);
INSERT INTO RangIndividuel VALUES (34,293,3);
INSERT INTO RangIndividuel VALUES (34,4,4);
INSERT INTO RangIndividuel VALUES (34,1109,5);
INSERT INTO RangIndividuel VALUES (34,1575,6);
INSERT INTO RangIndividuel VALUES (34,1602,7);
INSERT INTO RangIndividuel VALUES (34,354,8);
INSERT INTO RangIndividuel VALUES (34,1104,9);
INSERT INTO RangIndividuel VALUES (34,1123,10);
INSERT INTO RangIndividuel VALUES (34,1592,11);
INSERT INTO RangIndividuel VALUES (34,1600,12);
INSERT INTO RangIndividuel VALUES (34,1586,13);
INSERT INTO RangIndividuel VALUES (34,1107,14);
INSERT INTO RangIndividuel VALUES (34,1545,15);
INSERT INTO RangIndividuel VALUES (34,257,16);
INSERT INTO RangIndividuel VALUES (34,54,17);
INSERT INTO RangIndividuel VALUES (34,207,18);
INSERT INTO RangIndividuel VALUES (34,493,19);
INSERT INTO RangIndividuel VALUES (34,356,20);
INSERT INTO RangIndividuel VALUES (34,260,21);
INSERT INTO RangIndividuel VALUES (34,1130,22);
INSERT INTO RangIndividuel VALUES (34,1568,23);
INSERT INTO RangIndividuel VALUES (34,1559,24);
INSERT INTO RangIndividuel VALUES (34,1106,25);
INSERT INTO RangIndividuel VALUES (34,1126,26);
INSERT INTO RangIndividuel VALUES (34,1588,27);
INSERT INTO RangIndividuel VALUES (35,9,1);
INSERT INTO RangIndividuel VALUES (35,5,2);
INSERT INTO RangIndividuel VALUES (35,318,3);
INSERT INTO RangIndividuel VALUES (35,293,4);
INSERT INTO RangIndividuel VALUES (35,4,5);
INSERT INTO RangIndividuel VALUES (35,1108,6);
INSERT INTO RangIndividuel VALUES (35,1107,7);
INSERT INTO RangIndividuel VALUES (35,54,8);
INSERT INTO RangIndividuel VALUES (35,1101,9);
INSERT INTO RangIndividuel VALUES (35,1545,10);
INSERT INTO RangIndividuel VALUES (35,1592,11);
INSERT INTO RangIndividuel VALUES (35,1104,12);
INSERT INTO RangIndividuel VALUES (35,260,13);
INSERT INTO RangIndividuel VALUES (35,1559,14);
INSERT INTO RangIndividuel VALUES (35,205,15);
INSERT INTO RangIndividuel VALUES (35,514,16);
INSERT INTO RangIndividuel VALUES (37,97,1);
INSERT INTO RangIndividuel VALUES (37,8,2);
INSERT INTO RangIndividuel VALUES (37,55,3);
INSERT INTO RangIndividuel VALUES (37,279,4);
INSERT INTO RangIndividuel VALUES (37,1601,5);
INSERT INTO RangIndividuel VALUES (37,1117,6);
INSERT INTO RangIndividuel VALUES (37,1115,7);
INSERT INTO RangIndividuel VALUES (37,1589,8);
INSERT INTO RangIndividuel VALUES (37,1605,9);
INSERT INTO RangIndividuel VALUES (37,1578,10);
INSERT INTO RangIndividuel VALUES (37,1122,11);
INSERT INTO RangIndividuel VALUES (37,494,12);
INSERT INTO RangIndividuel VALUES (37,1591,13);
INSERT INTO RangIndividuel VALUES (37,1095,14);
INSERT INTO RangIndividuel VALUES (38,111,1);
INSERT INTO RangIndividuel VALUES (38,51,2);
INSERT INTO RangIndividuel VALUES (38,95,3);
INSERT INTO RangIndividuel VALUES (38,1119,4);
INSERT INTO RangIndividuel VALUES (38,1118,5);
INSERT INTO RangIndividuel VALUES (38,74,6);
INSERT INTO RangIndividuel VALUES (38,1096,7);
INSERT INTO RangIndividuel VALUES (38,24,8);
INSERT INTO RangIndividuel VALUES (38,263,9);
INSERT INTO RangIndividuel VALUES (38,80,10);
INSERT INTO RangIndividuel VALUES (38,1573,11);
INSERT INTO RangIndividuel VALUES (38,77,12);
INSERT INTO RangIndividuel VALUES (38,1097,13);
INSERT INTO RangIndividuel VALUES (38,93,14);
INSERT INTO RangIndividuel VALUES (38,1576,15);
INSERT INTO RangIndividuel VALUES (38,323,16);
INSERT INTO RangIndividuel VALUES (38,1552,17);
INSERT INTO RangIndividuel VALUES (38,1099,18);
INSERT INTO RangIndividuel VALUES (38,304,19);
INSERT INTO RangIndividuel VALUES (38,1566,20);
INSERT INTO RangIndividuel VALUES (38,600,21);
INSERT INTO RangIndividuel VALUES (38,1114,22);
INSERT INTO RangIndividuel VALUES (38,1601,23);
INSERT INTO RangIndividuel VALUES (38,1113,24);
INSERT INTO RangIndividuel VALUES (38,1112,25);
INSERT INTO RangIndividuel VALUES (38,1111,26);
INSERT INTO RangIndividuel VALUES (38,409,27);
INSERT INTO RangIndividuel VALUES (38,1577,28);
INSERT INTO RangIndividuel VALUES (38,1158,29);
INSERT INTO RangIndividuel VALUES (38,1584,30);
INSERT INTO RangIndividuel VALUES (38,1572,31);
INSERT INTO RangIndividuel VALUES (38,1563,32);
INSERT INTO RangIndividuel VALUES (38,1556,33);
INSERT INTO RangIndividuel VALUES (38,1598,34);
INSERT INTO RangIndividuel VALUES (38,1542,35);
INSERT INTO RangIndividuel VALUES (38,1546,36);
INSERT INTO RangIndividuel VALUES (38,1583,37);
INSERT INTO RangIndividuel VALUES (38,1554,38);
INSERT INTO RangIndividuel VALUES (38,1607,39);
INSERT INTO RangIndividuel VALUES (38,1557,40);
INSERT INTO RangIndividuel VALUES (39,93,1);
INSERT INTO RangIndividuel VALUES (39,74,2);
INSERT INTO RangIndividuel VALUES (39,51,3);
INSERT INTO RangIndividuel VALUES (39,1552,4);
INSERT INTO RangIndividuel VALUES (39,80,5);
INSERT INTO RangIndividuel VALUES (39,304,6);
INSERT INTO RangIndividuel VALUES (39,263,7);
INSERT INTO RangIndividuel VALUES (39,1102,8);
INSERT INTO RangIndividuel VALUES (39,1096,9);
INSERT INTO RangIndividuel VALUES (39,1601,10);
INSERT INTO RangIndividuel VALUES (39,24,11);
INSERT INTO RangIndividuel VALUES (39,111,12);
INSERT INTO RangIndividuel VALUES (39,62,13);
INSERT INTO RangIndividuel VALUES (39,1113,14);
INSERT INTO RangIndividuel VALUES (39,353,15);
INSERT INTO RangIndividuel VALUES (39,1573,16);
INSERT INTO RangIndividuel VALUES (39,1112,17);
INSERT INTO RangIndividuel VALUES (39,194,18);
INSERT INTO RangIndividuel VALUES (39,132,19);
INSERT INTO RangIndividuel VALUES (39,323,20);
INSERT INTO RangIndividuel VALUES (39,1598,21);
INSERT INTO RangIndividuel VALUES (39,1576,22);
INSERT INTO RangIndividuel VALUES (39,1117,23);
INSERT INTO RangIndividuel VALUES (39,1099,24);
INSERT INTO RangIndividuel VALUES (39,1606,25);
INSERT INTO RangIndividuel VALUES (39,1579,26);
INSERT INTO RangIndividuel VALUES (39,469,27);
INSERT INTO RangIndividuel VALUES (39,133,28);
INSERT INTO RangIndividuel VALUES (39,277,29);
INSERT INTO RangIndividuel VALUES (39,494,30);
INSERT INTO RangIndividuel VALUES (39,1542,31);
INSERT INTO RangIndividuel VALUES (39,1158,32);
INSERT INTO RangIndividuel VALUES (39,1566,33);
INSERT INTO RangIndividuel VALUES (39,495,34);
INSERT INTO RangIndividuel VALUES (39,1556,35);
INSERT INTO RangIndividuel VALUES (39,1574,36);
INSERT INTO RangIndividuel VALUES (39,262,37);
INSERT INTO RangIndividuel VALUES (39,1554,38);
INSERT INTO RangIndividuel VALUES (39,110,39);
INSERT INTO RangIndividuel VALUES (39,1558,40);
INSERT INTO RangIndividuel VALUES (40,95,1);
INSERT INTO RangIndividuel VALUES (40,261,2);
INSERT INTO RangIndividuel VALUES (40,358,3);
INSERT INTO RangIndividuel VALUES (40,77,4);
INSERT INTO RangIndividuel VALUES (40,311,5);
INSERT INTO RangIndividuel VALUES (40,226,6);
INSERT INTO RangIndividuel VALUES (40,1097,7);
INSERT INTO RangIndividuel VALUES (40,1119,8);
INSERT INTO RangIndividuel VALUES (40,629,9);
INSERT INTO RangIndividuel VALUES (40,1562,10);
INSERT INTO RangIndividuel VALUES (40,1110,11);
INSERT INTO RangIndividuel VALUES (40,1572,12);
INSERT INTO RangIndividuel VALUES (40,1550,13);
INSERT INTO RangIndividuel VALUES (40,1111,14);
INSERT INTO RangIndividuel VALUES (40,540,15);
INSERT INTO RangIndividuel VALUES (40,1099,16);
INSERT INTO RangIndividuel VALUES (40,429,17);
INSERT INTO RangIndividuel VALUES (40,600,18);
INSERT INTO RangIndividuel VALUES (40,1551,19);
INSERT INTO RangIndividuel VALUES (40,1103,20);
INSERT INTO RangIndividuel VALUES (40,1604,21);
INSERT INTO RangIndividuel VALUES (40,355,22);
INSERT INTO RangIndividuel VALUES (40,409,23);
INSERT INTO RangIndividuel VALUES (40,24,24);
INSERT INTO RangIndividuel VALUES (40,1563,25);
INSERT INTO RangIndividuel VALUES (40,513,26);
INSERT INTO RangIndividuel VALUES (40,1125,27);
INSERT INTO RangIndividuel VALUES (40,1112,28);
INSERT INTO RangIndividuel VALUES (40,539,29);
INSERT INTO RangIndividuel VALUES (40,1596,30);
INSERT INTO RangIndividuel VALUES (40,1569,31);
INSERT INTO RangIndividuel VALUES (40,1573,32);
INSERT INTO RangIndividuel VALUES (40,1557,33);
INSERT INTO RangIndividuel VALUES (40,1118,34);
INSERT INTO RangIndividuel VALUES (40,1597,35);
INSERT INTO RangIndividuel VALUES (40,1549,36);
INSERT INTO RangIndividuel VALUES (40,1113,37);
INSERT INTO RangIndividuel VALUES (40,111,38);
INSERT INTO RangIndividuel VALUES (40,1114,39);
INSERT INTO RangIndividuel VALUES (40,263,NULL);
INSERT INTO RangIndividuel VALUES (41,8,1);
INSERT INTO RangIndividuel VALUES (41,62,2);
INSERT INTO RangIndividuel VALUES (41,97,3);
INSERT INTO RangIndividuel VALUES (41,1601,4);
INSERT INTO RangIndividuel VALUES (41,1102,5);
INSERT INTO RangIndividuel VALUES (41,1552,6);
INSERT INTO RangIndividuel VALUES (41,194,7);
INSERT INTO RangIndividuel VALUES (41,1117,8);
INSERT INTO RangIndividuel VALUES (41,304,9);
INSERT INTO RangIndividuel VALUES (41,1589,10);
INSERT INTO RangIndividuel VALUES (41,1100,11);
INSERT INTO RangIndividuel VALUES (41,279,12);
INSERT INTO RangIndividuel VALUES (41,353,13);
INSERT INTO RangIndividuel VALUES (41,1115,14);
INSERT INTO RangIndividuel VALUES (41,494,15);
INSERT INTO RangIndividuel VALUES (41,1578,16);
INSERT INTO RangIndividuel VALUES (41,1570,17);
INSERT INTO RangIndividuel VALUES (41,1558,18);
INSERT INTO RangIndividuel VALUES (41,262,19);
INSERT INTO RangIndividuel VALUES (41,1122,20);
INSERT INTO RangIndividuel VALUES (41,1591,21);
INSERT INTO RangIndividuel VALUES (41,132,22);
INSERT INTO RangIndividuel VALUES (41,1095,23);
INSERT INTO RangIndividuel VALUES (41,278,24);
INSERT INTO RangIndividuel VALUES (41,1574,25);
INSERT INTO RangIndividuel VALUES (41,1603,26);
INSERT INTO RangIndividuel VALUES (43,148,1);
INSERT INTO RangIndividuel VALUES (43,184,2);
INSERT INTO RangIndividuel VALUES (43,34,3);
INSERT INTO RangIndividuel VALUES (44,34,1);
INSERT INTO RangIndividuel VALUES (44,272,2);
INSERT INTO RangIndividuel VALUES (44,63,3);
INSERT INTO RangIndividuel VALUES (44,1156,4);
INSERT INTO RangIndividuel VALUES (45,17,1);
INSERT INTO RangIndividuel VALUES (45,63,2);
INSERT INTO RangIndividuel VALUES (45,184,3);
INSERT INTO RangIndividuel VALUES (45,46,4);
INSERT INTO RangIndividuel VALUES (45,1490,5);
INSERT INTO RangIndividuel VALUES (45,148,NULL);
INSERT INTO RangIndividuel VALUES (45,149,NULL);
INSERT INTO RangIndividuel VALUES (47,3,1);
INSERT INTO RangIndividuel VALUES (47,212,2);
INSERT INTO RangIndividuel VALUES (47,375,3);
INSERT INTO RangIndividuel VALUES (47,1150,4);
INSERT INTO RangIndividuel VALUES (48,3,1);
INSERT INTO RangIndividuel VALUES (48,76,2);
INSERT INTO RangIndividuel VALUES (48,359,3);
INSERT INTO RangIndividuel VALUES (48,212,4);
INSERT INTO RangIndividuel VALUES (48,1497,NULL);
INSERT INTO RangIndividuel VALUES (49,10,1);
INSERT INTO RangIndividuel VALUES (49,211,2);
INSERT INTO RangIndividuel VALUES (49,3,3);
INSERT INTO RangIndividuel VALUES (49,186,4);
INSERT INTO RangIndividuel VALUES (49,376,5);
INSERT INTO RangIndividuel VALUES (49,1499,6);
INSERT INTO RangIndividuel VALUES (49,1155,7);
INSERT INTO RangIndividuel VALUES (51,150,1);
INSERT INTO RangIndividuel VALUES (51,276,2);
INSERT INTO RangIndividuel VALUES (51,379,3);
INSERT INTO RangIndividuel VALUES (51,1222,4);
INSERT INTO RangIndividuel VALUES (51,1515,5);
INSERT INTO RangIndividuel VALUES (51,1540,6);
INSERT INTO RangIndividuel VALUES (51,1505,7);
INSERT INTO RangIndividuel VALUES (51,1518,8);
INSERT INTO RangIndividuel VALUES (51,1517,9);
INSERT INTO RangIndividuel VALUES (51,1527,10);
INSERT INTO RangIndividuel VALUES (51,1538,11);
INSERT INTO RangIndividuel VALUES (51,1524,12);
INSERT INTO RangIndividuel VALUES (51,1223,13);
INSERT INTO RangIndividuel VALUES (51,1519,14);
INSERT INTO RangIndividuel VALUES (51,1525,15);
INSERT INTO RangIndividuel VALUES (51,1512,16);
INSERT INTO RangIndividuel VALUES (51,1531,17);
INSERT INTO RangIndividuel VALUES (51,1536,18);
INSERT INTO RangIndividuel VALUES (51,1510,19);
INSERT INTO RangIndividuel VALUES (51,1225,20);
INSERT INTO RangIndividuel VALUES (51,1526,21);
INSERT INTO RangIndividuel VALUES (51,1530,22);
INSERT INTO RangIndividuel VALUES (51,1226,23);
INSERT INTO RangIndividuel VALUES (51,1903,24);
INSERT INTO RangIndividuel VALUES (51,1529,25);
INSERT INTO RangIndividuel VALUES (51,1539,26);
INSERT INTO RangIndividuel VALUES (51,1537,27);
INSERT INTO RangIndividuel VALUES (51,1535,28);
INSERT INTO RangIndividuel VALUES (51,1516,29);
INSERT INTO RangIndividuel VALUES (51,1506,30);
INSERT INTO RangIndividuel VALUES (52,45,1);
INSERT INTO RangIndividuel VALUES (52,171,2);
INSERT INTO RangIndividuel VALUES (52,204,3);
INSERT INTO RangIndividuel VALUES (52,130,4);
INSERT INTO RangIndividuel VALUES (52,1170,5);
INSERT INTO RangIndividuel VALUES (52,151,6);
INSERT INTO RangIndividuel VALUES (52,56,7);
INSERT INTO RangIndividuel VALUES (52,275,8);
INSERT INTO RangIndividuel VALUES (52,310,9);
INSERT INTO RangIndividuel VALUES (52,378,10);
INSERT INTO RangIndividuel VALUES (52,307,11);
INSERT INTO RangIndividuel VALUES (52,1070,12);
INSERT INTO RangIndividuel VALUES (52,350,13);
INSERT INTO RangIndividuel VALUES (52,1080,14);
INSERT INTO RangIndividuel VALUES (52,1507,15);
INSERT INTO RangIndividuel VALUES (52,289,16);
INSERT INTO RangIndividuel VALUES (52,618,17);
INSERT INTO RangIndividuel VALUES (52,400,18);
INSERT INTO RangIndividuel VALUES (52,1079,19);
INSERT INTO RangIndividuel VALUES (52,1075,20);
INSERT INTO RangIndividuel VALUES (52,1169,21);
INSERT INTO RangIndividuel VALUES (52,175,22);
INSERT INTO RangIndividuel VALUES (52,7,23);
INSERT INTO RangIndividuel VALUES (52,1520,24);
INSERT INTO RangIndividuel VALUES (52,1082,25);
INSERT INTO RangIndividuel VALUES (52,508,26);
INSERT INTO RangIndividuel VALUES (52,419,27);
INSERT INTO RangIndividuel VALUES (52,504,28);
INSERT INTO RangIndividuel VALUES (52,1521,29);
INSERT INTO RangIndividuel VALUES (52,593,30);
INSERT INTO RangIndividuel VALUES (52,507,31);
INSERT INTO RangIndividuel VALUES (52,274,32);
INSERT INTO RangIndividuel VALUES (52,1533,33);
INSERT INTO RangIndividuel VALUES (52,628,34);
INSERT INTO RangIndividuel VALUES (52,1077,35);
INSERT INTO RangIndividuel VALUES (52,1513,36);
INSERT INTO RangIndividuel VALUES (52,301,37);
INSERT INTO RangIndividuel VALUES (52,349,38);
INSERT INTO RangIndividuel VALUES (52,1534,39);
INSERT INTO RangIndividuel VALUES (52,11,40);
INSERT INTO RangIndividuel VALUES (52,985,41);
INSERT INTO RangIndividuel VALUES (52,1072,42);
INSERT INTO RangIndividuel VALUES (52,1532,43);
INSERT INTO RangIndividuel VALUES (52,393,44);
INSERT INTO RangIndividuel VALUES (52,139,45);
INSERT INTO RangIndividuel VALUES (52,1511,46);
INSERT INTO RangIndividuel VALUES (52,1074,47);
INSERT INTO RangIndividuel VALUES (52,1076,48);
INSERT INTO RangIndividuel VALUES (54,45,1);
INSERT INTO RangIndividuel VALUES (54,204,2);
INSERT INTO RangIndividuel VALUES (54,289,3);
INSERT INTO RangIndividuel VALUES (54,274,4);
INSERT INTO RangIndividuel VALUES (54,275,5);
INSERT INTO RangIndividuel VALUES (54,139,6);
INSERT INTO RangIndividuel VALUES (54,1070,7);
INSERT INTO RangIndividuel VALUES (54,171,8);
INSERT INTO RangIndividuel VALUES (54,618,9);
INSERT INTO RangIndividuel VALUES (54,75,10);
INSERT INTO RangIndividuel VALUES (54,56,11);
INSERT INTO RangIndividuel VALUES (54,307,12);
INSERT INTO RangIndividuel VALUES (54,1507,13);
INSERT INTO RangIndividuel VALUES (54,11,14);
INSERT INTO RangIndividuel VALUES (54,1170,15);
INSERT INTO RangIndividuel VALUES (54,1079,16);
INSERT INTO RangIndividuel VALUES (54,7,17);
INSERT INTO RangIndividuel VALUES (54,378,18);
INSERT INTO RangIndividuel VALUES (54,419,19);
INSERT INTO RangIndividuel VALUES (54,1169,20);
INSERT INTO RangIndividuel VALUES (54,444,21);
INSERT INTO RangIndividuel VALUES (54,1520,22);
INSERT INTO RangIndividuel VALUES (54,400,23);
INSERT INTO RangIndividuel VALUES (54,350,24);
INSERT INTO RangIndividuel VALUES (54,1080,25);
INSERT INTO RangIndividuel VALUES (54,1075,26);
INSERT INTO RangIndividuel VALUES (54,349,27);
INSERT INTO RangIndividuel VALUES (54,593,28);
INSERT INTO RangIndividuel VALUES (54,175,29);
INSERT INTO RangIndividuel VALUES (54,1522,30);
INSERT INTO RangIndividuel VALUES (54,130,31);
INSERT INTO RangIndividuel VALUES (54,1081,32);
INSERT INTO RangIndividuel VALUES (54,1532,33);
INSERT INTO RangIndividuel VALUES (54,1534,34);
INSERT INTO RangIndividuel VALUES (54,1076,35);
INSERT INTO RangIndividuel VALUES (54,1521,36);
INSERT INTO RangIndividuel VALUES (54,1082,37);
INSERT INTO RangIndividuel VALUES (54,985,38);
INSERT INTO RangIndividuel VALUES (54,1533,39);
INSERT INTO RangIndividuel VALUES (54,1513,41);
INSERT INTO RangIndividuel VALUES (54,394,42);
INSERT INTO RangIndividuel VALUES (54,393,43);
INSERT INTO RangIndividuel VALUES (54,1511,44);
INSERT INTO RangIndividuel VALUES (54,1168,45);
INSERT INTO RangIndividuel VALUES (54,1078,46);
INSERT INTO RangIndividuel VALUES (54,476,47);
INSERT INTO RangIndividuel VALUES (54,507,48);
INSERT INTO RangIndividuel VALUES (55,140,1);
INSERT INTO RangIndividuel VALUES (55,256,2);
INSERT INTO RangIndividuel VALUES (55,365,3);
INSERT INTO RangIndividuel VALUES (55,512,4);
INSERT INTO RangIndividuel VALUES (55,1238,5);
INSERT INTO RangIndividuel VALUES (55,1237,6);
INSERT INTO RangIndividuel VALUES (55,1094,7);
INSERT INTO RangIndividuel VALUES (55,351,8);
INSERT INTO RangIndividuel VALUES (55,1241,9);
INSERT INTO RangIndividuel VALUES (55,1244,10);
INSERT INTO RangIndividuel VALUES (55,296,11);
INSERT INTO RangIndividuel VALUES (55,1090,11);
INSERT INTO RangIndividuel VALUES (55,1246,13);
INSERT INTO RangIndividuel VALUES (55,594,14);
INSERT INTO RangIndividuel VALUES (55,1250,14);
INSERT INTO RangIndividuel VALUES (55,225,16);
INSERT INTO RangIndividuel VALUES (55,1243,17);
INSERT INTO RangIndividuel VALUES (55,750,18);
INSERT INTO RangIndividuel VALUES (55,1084,19);
INSERT INTO RangIndividuel VALUES (55,1085,20);
INSERT INTO RangIndividuel VALUES (56,1908,1);
INSERT INTO RangIndividuel VALUES (56,178,2);
INSERT INTO RangIndividuel VALUES (56,352,3);
INSERT INTO RangIndividuel VALUES (56,446,4);
INSERT INTO RangIndividuel VALUES (56,1083,5);
INSERT INTO RangIndividuel VALUES (56,1252,6);
INSERT INTO RangIndividuel VALUES (56,1087,7);
INSERT INTO RangIndividuel VALUES (56,434,8);
INSERT INTO RangIndividuel VALUES (56,1245,9);
INSERT INTO RangIndividuel VALUES (56,1251,10);
INSERT INTO RangIndividuel VALUES (56,511,11);
INSERT INTO RangIndividuel VALUES (56,1235,12);
INSERT INTO RangIndividuel VALUES (56,1239,13);
INSERT INTO RangIndividuel VALUES (56,1093,14);
INSERT INTO RangIndividuel VALUES (56,1091,15);
INSERT INTO RangIndividuel VALUES (56,1248,16);
INSERT INTO RangIndividuel VALUES (56,1089,17);
INSERT INTO RangIndividuel VALUES (56,595,18);
INSERT INTO RangIndividuel VALUES (56,1242,19);
INSERT INTO RangIndividuel VALUES (56,601,20);
INSERT INTO RangIndividuel VALUES (56,1092,21);
INSERT INTO RangIndividuel VALUES (56,1236,22);
INSERT INTO RangIndividuel VALUES (56,1240,23);
INSERT INTO RangIndividuel VALUES (56,1247,24);
INSERT INTO RangIndividuel VALUES (56,1086,25);
INSERT INTO RangIndividuel VALUES (56,1088,26);
INSERT INTO RangIndividuel VALUES (56,1249,27);
INSERT INTO RangIndividuel VALUES (57,158,1);
INSERT INTO RangIndividuel VALUES (57,243,2);
INSERT INTO RangIndividuel VALUES (57,86,3);
INSERT INTO RangIndividuel VALUES (57,397,4);
INSERT INTO RangIndividuel VALUES (57,1162,5);
INSERT INTO RangIndividuel VALUES (57,927,6);
INSERT INTO RangIndividuel VALUES (58,98,1);
INSERT INTO RangIndividuel VALUES (58,242,2);
INSERT INTO RangIndividuel VALUES (58,83,3);
INSERT INTO RangIndividuel VALUES (58,176,4);
INSERT INTO RangIndividuel VALUES (59,157,1);
INSERT INTO RangIndividuel VALUES (59,244,2);
INSERT INTO RangIndividuel VALUES (59,339,3);
INSERT INTO RangIndividuel VALUES (59,940,4);
INSERT INTO RangIndividuel VALUES (59,1824,5);
INSERT INTO RangIndividuel VALUES (59,937,6);
INSERT INTO RangIndividuel VALUES (59,910,7);
INSERT INTO RangIndividuel VALUES (59,934,8);
INSERT INTO RangIndividuel VALUES (60,161,1);
INSERT INTO RangIndividuel VALUES (60,283,2);
INSERT INTO RangIndividuel VALUES (60,385,3);
INSERT INTO RangIndividuel VALUES (60,1891,4);
INSERT INTO RangIndividuel VALUES (60,1879,5);
INSERT INTO RangIndividuel VALUES (60,1853,6);
INSERT INTO RangIndividuel VALUES (60,1807,7);
INSERT INTO RangIndividuel VALUES (60,1894,8);
INSERT INTO RangIndividuel VALUES (60,1852,9);
INSERT INTO RangIndividuel VALUES (60,1843,10);
INSERT INTO RangIndividuel VALUES (60,1849,11);
INSERT INTO RangIndividuel VALUES (60,1790,12);
INSERT INTO RangIndividuel VALUES (60,1808,13);
INSERT INTO RangIndividuel VALUES (60,1861,14);
INSERT INTO RangIndividuel VALUES (60,1846,15);
INSERT INTO RangIndividuel VALUES (60,1798,16);
INSERT INTO RangIndividuel VALUES (60,1884,17);
INSERT INTO RangIndividuel VALUES (60,1874,18);
INSERT INTO RangIndividuel VALUES (60,1782,19);
INSERT INTO RangIndividuel VALUES (60,1780,20);
INSERT INTO RangIndividuel VALUES (60,1869,21);
INSERT INTO RangIndividuel VALUES (60,1886,22);
INSERT INTO RangIndividuel VALUES (60,1766,23);
INSERT INTO RangIndividuel VALUES (61,159,1);
INSERT INTO RangIndividuel VALUES (61,287,2);
INSERT INTO RangIndividuel VALUES (61,389,3);
INSERT INTO RangIndividuel VALUES (61,1842,4);
INSERT INTO RangIndividuel VALUES (61,1814,5);
INSERT INTO RangIndividuel VALUES (61,1803,6);
INSERT INTO RangIndividuel VALUES (61,1193,7);
INSERT INTO RangIndividuel VALUES (61,1812,8);
INSERT INTO RangIndividuel VALUES (61,1889,9);
INSERT INTO RangIndividuel VALUES (61,1856,10);
INSERT INTO RangIndividuel VALUES (61,1899,11);
INSERT INTO RangIndividuel VALUES (61,1888,12);
INSERT INTO RangIndividuel VALUES (61,1763,13);
INSERT INTO RangIndividuel VALUES (61,1858,14);
INSERT INTO RangIndividuel VALUES (61,1883,15);
INSERT INTO RangIndividuel VALUES (61,1831,16);
INSERT INTO RangIndividuel VALUES (61,1898,17);
INSERT INTO RangIndividuel VALUES (61,1799,18);
INSERT INTO RangIndividuel VALUES (61,1810,19);
INSERT INTO RangIndividuel VALUES (61,1800,20);
INSERT INTO RangIndividuel VALUES (61,1778,21);
INSERT INTO RangIndividuel VALUES (61,1767,22);
INSERT INTO RangIndividuel VALUES (62,41,1);
INSERT INTO RangIndividuel VALUES (62,285,2);
INSERT INTO RangIndividuel VALUES (62,309,3);
INSERT INTO RangIndividuel VALUES (62,1805,4);
INSERT INTO RangIndividuel VALUES (62,487,5);
INSERT INTO RangIndividuel VALUES (62,928,6);
INSERT INTO RangIndividuel VALUES (63,113,1);
INSERT INTO RangIndividuel VALUES (63,241,2);
INSERT INTO RangIndividuel VALUES (63,338,3);
INSERT INTO RangIndividuel VALUES (63,917,4);
INSERT INTO RangIndividuel VALUES (64,156,1);
INSERT INTO RangIndividuel VALUES (64,246,2);
INSERT INTO RangIndividuel VALUES (64,386,3);
INSERT INTO RangIndividuel VALUES (64,908,4);
INSERT INTO RangIndividuel VALUES (64,891,5);
INSERT INTO RangIndividuel VALUES (64,1164,6);
INSERT INTO RangIndividuel VALUES (64,932,7);
INSERT INTO RangIndividuel VALUES (64,1857,8);
INSERT INTO RangIndividuel VALUES (65,160,1);
INSERT INTO RangIndividuel VALUES (65,284,2);
INSERT INTO RangIndividuel VALUES (65,387,3);
INSERT INTO RangIndividuel VALUES (65,1882,4);
INSERT INTO RangIndividuel VALUES (65,1816,5);
INSERT INTO RangIndividuel VALUES (65,1198,6);
INSERT INTO RangIndividuel VALUES (65,1195,7);
INSERT INTO RangIndividuel VALUES (65,1863,8);
INSERT INTO RangIndividuel VALUES (65,1880,9);
INSERT INTO RangIndividuel VALUES (65,1797,10);
INSERT INTO RangIndividuel VALUES (65,1793,11);
INSERT INTO RangIndividuel VALUES (65,1804,12);
INSERT INTO RangIndividuel VALUES (65,1821,13);
INSERT INTO RangIndividuel VALUES (65,1896,14);
INSERT INTO RangIndividuel VALUES (65,1809,15);
INSERT INTO RangIndividuel VALUES (65,1895,16);
INSERT INTO RangIndividuel VALUES (65,1873,17);
INSERT INTO RangIndividuel VALUES (65,1893,18);
INSERT INTO RangIndividuel VALUES (65,1833,19);
INSERT INTO RangIndividuel VALUES (65,1832,20);
INSERT INTO RangIndividuel VALUES (65,1788,21);
INSERT INTO RangIndividuel VALUES (65,1765,22);
INSERT INTO RangIndividuel VALUES (65,1875,23);
INSERT INTO RangIndividuel VALUES (65,1781,24);
INSERT INTO RangIndividuel VALUES (65,1196,25);
INSERT INTO RangIndividuel VALUES (65,1851,26);
INSERT INTO RangIndividuel VALUES (65,1768,27);
INSERT INTO RangIndividuel VALUES (65,1848,28);
INSERT INTO RangIndividuel VALUES (65,1881,NULL);
INSERT INTO RangIndividuel VALUES (66,162,1);
INSERT INTO RangIndividuel VALUES (66,286,2);
INSERT INTO RangIndividuel VALUES (66,388,3);
INSERT INTO RangIndividuel VALUES (66,1819,4);
INSERT INTO RangIndividuel VALUES (66,1876,5);
INSERT INTO RangIndividuel VALUES (66,1827,6);
INSERT INTO RangIndividuel VALUES (66,1817,7);
INSERT INTO RangIndividuel VALUES (66,1837,8);
INSERT INTO RangIndividuel VALUES (66,1850,9);
INSERT INTO RangIndividuel VALUES (66,1818,10);
INSERT INTO RangIndividuel VALUES (66,1882,11);
INSERT INTO RangIndividuel VALUES (66,1802,12);
INSERT INTO RangIndividuel VALUES (66,1878,13);
INSERT INTO RangIndividuel VALUES (66,1834,14);
INSERT INTO RangIndividuel VALUES (66,1801,15);
INSERT INTO RangIndividuel VALUES (66,1194,16);
INSERT INTO RangIndividuel VALUES (66,1847,17);
INSERT INTO RangIndividuel VALUES (66,1826,18);
INSERT INTO RangIndividuel VALUES (66,1796,19);
INSERT INTO RangIndividuel VALUES (66,1900,20);
INSERT INTO RangIndividuel VALUES (66,1198,21);
INSERT INTO RangIndividuel VALUES (66,1887,22);
INSERT INTO RangIndividuel VALUES (66,1890,23);
INSERT INTO RangIndividuel VALUES (66,1813,24);
INSERT INTO RangIndividuel VALUES (66,1866,25);
INSERT INTO RangIndividuel VALUES (66,1872,26);
INSERT INTO RangIndividuel VALUES (66,1785,27);
INSERT INTO RangIndividuel VALUES (66,1779,28);
INSERT INTO RangIndividuel VALUES (66,1192,29);
INSERT INTO RangIndividuel VALUES (66,1789,30);
INSERT INTO RangIndividuel VALUES (66,1901,31);
INSERT INTO RangIndividuel VALUES (66,1897,32);
INSERT INTO RangIndividuel VALUES (67,23,1);
INSERT INTO RangIndividuel VALUES (67,116,1);
INSERT INTO RangIndividuel VALUES (67,324,3);
INSERT INTO RangIndividuel VALUES (67,561,4);
INSERT INTO RangIndividuel VALUES (67,717,5);
INSERT INTO RangIndividuel VALUES (67,641,6);
INSERT INTO RangIndividuel VALUES (67,1661,7);
INSERT INTO RangIndividuel VALUES (67,50,8);
INSERT INTO RangIndividuel VALUES (67,172,9);
INSERT INTO RangIndividuel VALUES (67,700,10);
INSERT INTO RangIndividuel VALUES (67,708,11);
INSERT INTO RangIndividuel VALUES (67,557,12);
INSERT INTO RangIndividuel VALUES (67,13,13);
INSERT INTO RangIndividuel VALUES (67,563,14);
INSERT INTO RangIndividuel VALUES (67,90,15);
INSERT INTO RangIndividuel VALUES (67,290,16);
INSERT INTO RangIndividuel VALUES (67,521,17);
INSERT INTO RangIndividuel VALUES (67,699,18);
INSERT INTO RangIndividuel VALUES (67,433,19);
INSERT INTO RangIndividuel VALUES (67,665,20);
INSERT INTO RangIndividuel VALUES (67,710,21);
INSERT INTO RangIndividuel VALUES (67,558,22);
INSERT INTO RangIndividuel VALUES (67,694,23);
INSERT INTO RangIndividuel VALUES (67,1666,24);
INSERT INTO RangIndividuel VALUES (67,1637,25);
INSERT INTO RangIndividuel VALUES (67,1670,26);
INSERT INTO RangIndividuel VALUES (67,1664,27);
INSERT INTO RangIndividuel VALUES (67,640,28);
INSERT INTO RangIndividuel VALUES (67,1174,29);
INSERT INTO RangIndividuel VALUES (67,638,30);
INSERT INTO RangIndividuel VALUES (67,720,31);
INSERT INTO RangIndividuel VALUES (67,401,32);
INSERT INTO RangIndividuel VALUES (67,1612,33);
INSERT INTO RangIndividuel VALUES (67,461,34);
INSERT INTO RangIndividuel VALUES (67,670,35);
INSERT INTO RangIndividuel VALUES (67,542,NULL);
INSERT INTO RangIndividuel VALUES (67,554,NULL);
INSERT INTO RangIndividuel VALUES (67,405,NULL);
INSERT INTO RangIndividuel VALUES (67,714,NULL);
INSERT INTO RangIndividuel VALUES (67,70,NULL);
INSERT INTO RangIndividuel VALUES (67,634,NULL);
INSERT INTO RangIndividuel VALUES (67,1623,NULL);
INSERT INTO RangIndividuel VALUES (68,154,1);
INSERT INTO RangIndividuel VALUES (68,164,2);
INSERT INTO RangIndividuel VALUES (68,320,3);
INSERT INTO RangIndividuel VALUES (68,13,4);
INSERT INTO RangIndividuel VALUES (68,693,5);
INSERT INTO RangIndividuel VALUES (68,1636,6);
INSERT INTO RangIndividuel VALUES (68,732,7);
INSERT INTO RangIndividuel VALUES (68,23,8);
INSERT INTO RangIndividuel VALUES (68,663,9);
INSERT INTO RangIndividuel VALUES (68,381,10);
INSERT INTO RangIndividuel VALUES (68,1638,11);
INSERT INTO RangIndividuel VALUES (68,217,12);
INSERT INTO RangIndividuel VALUES (68,731,13);
INSERT INTO RangIndividuel VALUES (68,689,14);
INSERT INTO RangIndividuel VALUES (68,742,15);
INSERT INTO RangIndividuel VALUES (68,652,16);
INSERT INTO RangIndividuel VALUES (68,660,17);
INSERT INTO RangIndividuel VALUES (68,551,18);
INSERT INTO RangIndividuel VALUES (68,699,19);
INSERT INTO RangIndividuel VALUES (68,1183,19);
INSERT INTO RangIndividuel VALUES (68,541,21);
INSERT INTO RangIndividuel VALUES (68,1678,22);
INSERT INTO RangIndividuel VALUES (68,1629,23);
INSERT INTO RangIndividuel VALUES (68,705,24);
INSERT INTO RangIndividuel VALUES (68,1627,25);
INSERT INTO RangIndividuel VALUES (68,633,26);
INSERT INTO RangIndividuel VALUES (68,401,27);
INSERT INTO RangIndividuel VALUES (68,1693,28);
INSERT INTO RangIndividuel VALUES (68,676,29);
INSERT INTO RangIndividuel VALUES (68,680,30);
INSERT INTO RangIndividuel VALUES (68,1174,31);
INSERT INTO RangIndividuel VALUES (68,1653,32);
INSERT INTO RangIndividuel VALUES (68,1657,33);
INSERT INTO RangIndividuel VALUES (68,1181,34);
INSERT INTO RangIndividuel VALUES (68,670,35);
INSERT INTO RangIndividuel VALUES (68,1905,36);
INSERT INTO RangIndividuel VALUES (68,1176,37);
INSERT INTO RangIndividuel VALUES (68,666,38);
INSERT INTO RangIndividuel VALUES (68,648,39);
INSERT INTO RangIndividuel VALUES (68,1686,40);
INSERT INTO RangIndividuel VALUES (68,1703,41);
INSERT INTO RangIndividuel VALUES (68,1640,42);
INSERT INTO RangIndividuel VALUES (68,1685,43);
INSERT INTO RangIndividuel VALUES (68,1625,44);
INSERT INTO RangIndividuel VALUES (68,1617,45);
INSERT INTO RangIndividuel VALUES (68,1178,46);
INSERT INTO RangIndividuel VALUES (68,675,47);
INSERT INTO RangIndividuel VALUES (68,1619,48);
INSERT INTO RangIndividuel VALUES (68,1702,49);
INSERT INTO RangIndividuel VALUES (68,1698,NULL);
INSERT INTO RangIndividuel VALUES (68,667,NULL);
INSERT INTO RangIndividuel VALUES (68,1622,NULL);
INSERT INTO RangIndividuel VALUES (68,520,NULL);
INSERT INTO RangIndividuel VALUES (68,1694,NULL);
INSERT INTO RangIndividuel VALUES (68,602,NULL);
INSERT INTO RangIndividuel VALUES (68,743,NULL);
INSERT INTO RangIndividuel VALUES (68,1645,NULL);
INSERT INTO RangIndividuel VALUES (68,656,NULL);
INSERT INTO RangIndividuel VALUES (68,643,NULL);
INSERT INTO RangIndividuel VALUES (68,707,NULL);
INSERT INTO RangIndividuel VALUES (68,711,NULL);
INSERT INTO RangIndividuel VALUES (68,649,NULL);
INSERT INTO RangIndividuel VALUES (68,718,NULL);
INSERT INTO RangIndividuel VALUES (68,719,NULL);
INSERT INTO RangIndividuel VALUES (68,621,NULL);
INSERT INTO RangIndividuel VALUES (68,1675,NULL);
INSERT INTO RangIndividuel VALUES (68,686,NULL);
INSERT INTO RangIndividuel VALUES (68,461,NULL);
INSERT INTO RangIndividuel VALUES (68,1613,NULL);
INSERT INTO RangIndividuel VALUES (68,1612,NULL);
INSERT INTO RangIndividuel VALUES (68,650,NULL);
INSERT INTO RangIndividuel VALUES (68,701,NULL);
INSERT INTO RangIndividuel VALUES (68,1608,NULL);
INSERT INTO RangIndividuel VALUES (68,727,NULL);
INSERT INTO RangIndividuel VALUES (68,1705,NULL);
INSERT INTO RangIndividuel VALUES (68,688,NULL);
INSERT INTO RangIndividuel VALUES (68,1684,NULL);
INSERT INTO RangIndividuel VALUES (68,724,NULL);
INSERT INTO RangIndividuel VALUES (68,402,NULL);
INSERT INTO RangIndividuel VALUES (68,556,NULL);
INSERT INTO RangIndividuel VALUES (68,523,NULL);
INSERT INTO RangIndividuel VALUES (68,729,NULL);
INSERT INTO RangIndividuel VALUES (68,657,NULL);
INSERT INTO RangIndividuel VALUES (68,518,NULL);
INSERT INTO RangIndividuel VALUES (68,1652,NULL);
INSERT INTO RangIndividuel VALUES (68,550,NULL);
INSERT INTO RangIndividuel VALUES (68,1177,NULL);
INSERT INTO RangIndividuel VALUES (68,739,NULL);
INSERT INTO RangIndividuel VALUES (69,23,1);
INSERT INTO RangIndividuel VALUES (69,70,2);
INSERT INTO RangIndividuel VALUES (69,90,3);
INSERT INTO RangIndividuel VALUES (69,558,4);
INSERT INTO RangIndividuel VALUES (69,154,5);
INSERT INTO RangIndividuel VALUES (69,520,6);
INSERT INTO RangIndividuel VALUES (69,519,7);
INSERT INTO RangIndividuel VALUES (69,731,8);
INSERT INTO RangIndividuel VALUES (69,324,9);
INSERT INTO RangIndividuel VALUES (69,116,10);
INSERT INTO RangIndividuel VALUES (69,290,11);
INSERT INTO RangIndividuel VALUES (69,402,12);
INSERT INTO RangIndividuel VALUES (69,693,13);
INSERT INTO RangIndividuel VALUES (69,551,14);
INSERT INTO RangIndividuel VALUES (69,217,14);
INSERT INTO RangIndividuel VALUES (69,658,16);
INSERT INTO RangIndividuel VALUES (69,602,17);
INSERT INTO RangIndividuel VALUES (69,694,18);
INSERT INTO RangIndividuel VALUES (69,320,19);
INSERT INTO RangIndividuel VALUES (69,1698,20);
INSERT INTO RangIndividuel VALUES (69,743,21);
INSERT INTO RangIndividuel VALUES (69,729,22);
INSERT INTO RangIndividuel VALUES (69,641,23);
INSERT INTO RangIndividuel VALUES (69,1183,24);
INSERT INTO RangIndividuel VALUES (69,689,25);
INSERT INTO RangIndividuel VALUES (69,717,26);
INSERT INTO RangIndividuel VALUES (69,652,27);
INSERT INTO RangIndividuel VALUES (69,656,28);
INSERT INTO RangIndividuel VALUES (69,523,29);
INSERT INTO RangIndividuel VALUES (69,707,30);
INSERT INTO RangIndividuel VALUES (69,700,31);
INSERT INTO RangIndividuel VALUES (69,1613,32);
INSERT INTO RangIndividuel VALUES (69,1612,33);
INSERT INTO RangIndividuel VALUES (69,1661,34);
INSERT INTO RangIndividuel VALUES (69,1657,35);
INSERT INTO RangIndividuel VALUES (69,550,36);
INSERT INTO RangIndividuel VALUES (69,633,37);
INSERT INTO RangIndividuel VALUES (69,718,38);
INSERT INTO RangIndividuel VALUES (69,401,39);
INSERT INTO RangIndividuel VALUES (69,1653,40);
INSERT INTO RangIndividuel VALUES (69,1174,41);
INSERT INTO RangIndividuel VALUES (69,461,42);
INSERT INTO RangIndividuel VALUES (69,659,43);
INSERT INTO RangIndividuel VALUES (69,676,44);
INSERT INTO RangIndividuel VALUES (69,719,45);
INSERT INTO RangIndividuel VALUES (69,1181,46);
INSERT INTO RangIndividuel VALUES (69,1627,47);
INSERT INTO RangIndividuel VALUES (69,670,48);
INSERT INTO RangIndividuel VALUES (69,650,49);
INSERT INTO RangIndividuel VALUES (69,1652,50);
INSERT INTO RangIndividuel VALUES (69,1623,51);
INSERT INTO RangIndividuel VALUES (69,1905,52);
INSERT INTO RangIndividuel VALUES (69,1675,53);
INSERT INTO RangIndividuel VALUES (69,648,54);
INSERT INTO RangIndividuel VALUES (69,1705,55);
INSERT INTO RangIndividuel VALUES (69,1685,56);
INSERT INTO RangIndividuel VALUES (69,727,57);
INSERT INTO RangIndividuel VALUES (69,666,58);
INSERT INTO RangIndividuel VALUES (69,1686,59);
INSERT INTO RangIndividuel VALUES (69,1684,60);
INSERT INTO RangIndividuel VALUES (69,1178,61);
INSERT INTO RangIndividuel VALUES (69,1617,62);
INSERT INTO RangIndividuel VALUES (69,1703,63);
INSERT INTO RangIndividuel VALUES (69,739,64);
INSERT INTO RangIndividuel VALUES (69,1640,65);
INSERT INTO RangIndividuel VALUES (69,701,66);
INSERT INTO RangIndividuel VALUES (69,1683,67);
INSERT INTO RangIndividuel VALUES (69,13,NULL);
INSERT INTO RangIndividuel VALUES (69,663,NULL);
INSERT INTO RangIndividuel VALUES (69,657,NULL);
INSERT INTO RangIndividuel VALUES (69,50,NULL);
INSERT INTO RangIndividuel VALUES (69,662,NULL);
INSERT INTO RangIndividuel VALUES (69,730,NULL);
INSERT INTO RangIndividuel VALUES (69,1694,NULL);
INSERT INTO RangIndividuel VALUES (69,711,NULL);
INSERT INTO RangIndividuel VALUES (69,381,NULL);
INSERT INTO RangIndividuel VALUES (69,1678,NULL);
INSERT INTO RangIndividuel VALUES (69,686,NULL);
INSERT INTO RangIndividuel VALUES (69,621,NULL);
INSERT INTO RangIndividuel VALUES (69,720,NULL);
INSERT INTO RangIndividuel VALUES (69,680,NULL);
INSERT INTO RangIndividuel VALUES (69,1177,NULL);
INSERT INTO RangIndividuel VALUES (69,1695,NULL);
INSERT INTO RangIndividuel VALUES (69,441,NULL);
INSERT INTO RangIndividuel VALUES (69,1664,NULL);
INSERT INTO RangIndividuel VALUES (69,638,NULL);
INSERT INTO RangIndividuel VALUES (69,699,NULL);
INSERT INTO RangIndividuel VALUES (69,649,NULL);
INSERT INTO RangIndividuel VALUES (69,1176,NULL);
INSERT INTO RangIndividuel VALUES (69,1608,NULL);
INSERT INTO RangIndividuel VALUES (70,13,1);
INSERT INTO RangIndividuel VALUES (70,172,2);
INSERT INTO RangIndividuel VALUES (70,50,3);
INSERT INTO RangIndividuel VALUES (70,23,4);
INSERT INTO RangIndividuel VALUES (70,116,5);
INSERT INTO RangIndividuel VALUES (70,1664,6);
INSERT INTO RangIndividuel VALUES (70,402,7);
INSERT INTO RangIndividuel VALUES (70,70,8);
INSERT INTO RangIndividuel VALUES (70,381,9);
INSERT INTO RangIndividuel VALUES (70,699,10);
INSERT INTO RangIndividuel VALUES (70,657,11);
INSERT INTO RangIndividuel VALUES (70,660,12);
INSERT INTO RangIndividuel VALUES (70,1637,13);
INSERT INTO RangIndividuel VALUES (70,640,14);
INSERT INTO RangIndividuel VALUES (70,1174,15);
INSERT INTO RangIndividuel VALUES (70,1661,16);
INSERT INTO RangIndividuel VALUES (70,1612,17);
INSERT INTO RangIndividuel VALUES (70,621,18);
INSERT INTO RangIndividuel VALUES (70,710,19);
INSERT INTO RangIndividuel VALUES (70,401,20);
INSERT INTO RangIndividuel VALUES (70,670,21);
INSERT INTO RangIndividuel VALUES (70,1623,22);
INSERT INTO RangIndividuel VALUES (70,714,NULL);
INSERT INTO RangIndividuel VALUES (70,461,NULL);
INSERT INTO RangIndividuel VALUES (70,708,NULL);
INSERT INTO RangIndividuel VALUES (70,521,NULL);
INSERT INTO RangIndividuel VALUES (70,634,NULL);
INSERT INTO RangIndividuel VALUES (70,561,NULL);
INSERT INTO RangIndividuel VALUES (70,433,NULL);
INSERT INTO RangIndividuel VALUES (70,557,NULL);
INSERT INTO RangIndividuel VALUES (70,658,NULL);
INSERT INTO RangIndividuel VALUES (70,641,NULL);
INSERT INTO RangIndividuel VALUES (70,324,NULL);
INSERT INTO RangIndividuel VALUES (70,290,NULL);
INSERT INTO RangIndividuel VALUES (70,663,NULL);
INSERT INTO RangIndividuel VALUES (70,518,NULL);
INSERT INTO RangIndividuel VALUES (70,702,NULL);
INSERT INTO RangIndividuel VALUES (70,700,NULL);
INSERT INTO RangIndividuel VALUES (70,720,NULL);
INSERT INTO RangIndividuel VALUES (71,70,1);
INSERT INTO RangIndividuel VALUES (71,13,2);
INSERT INTO RangIndividuel VALUES (71,172,3);
INSERT INTO RangIndividuel VALUES (71,324,4);
INSERT INTO RangIndividuel VALUES (71,23,5);
INSERT INTO RangIndividuel VALUES (71,450,6);
INSERT INTO RangIndividuel VALUES (71,717,7);
INSERT INTO RangIndividuel VALUES (71,50,8);
INSERT INTO RangIndividuel VALUES (71,90,9);
INSERT INTO RangIndividuel VALUES (71,558,10);
INSERT INTO RangIndividuel VALUES (71,1667,11);
INSERT INTO RangIndividuel VALUES (71,563,11);
INSERT INTO RangIndividuel VALUES (71,700,13);
INSERT INTO RangIndividuel VALUES (71,641,14);
INSERT INTO RangIndividuel VALUES (71,1661,15);
INSERT INTO RangIndividuel VALUES (71,699,16);
INSERT INTO RangIndividuel VALUES (71,710,17);
INSERT INTO RangIndividuel VALUES (71,702,18);
INSERT INTO RangIndividuel VALUES (71,1664,19);
INSERT INTO RangIndividuel VALUES (71,662,20);
INSERT INTO RangIndividuel VALUES (71,1637,21);
INSERT INTO RangIndividuel VALUES (71,718,22);
INSERT INTO RangIndividuel VALUES (71,433,23);
INSERT INTO RangIndividuel VALUES (71,640,24);
INSERT INTO RangIndividuel VALUES (71,711,25);
INSERT INTO RangIndividuel VALUES (71,401,26);
INSERT INTO RangIndividuel VALUES (71,659,27);
INSERT INTO RangIndividuel VALUES (71,670,28);
INSERT INTO RangIndividuel VALUES (71,1181,29);
INSERT INTO RangIndividuel VALUES (71,1623,30);
INSERT INTO RangIndividuel VALUES (71,1176,31);
INSERT INTO RangIndividuel VALUES (71,542,NULL);
INSERT INTO RangIndividuel VALUES (71,405,NULL);
INSERT INTO RangIndividuel VALUES (71,561,NULL);
INSERT INTO RangIndividuel VALUES (71,519,NULL);
INSERT INTO RangIndividuel VALUES (71,663,NULL);
INSERT INTO RangIndividuel VALUES (71,554,NULL);
INSERT INTO RangIndividuel VALUES (71,708,NULL);
INSERT INTO RangIndividuel VALUES (71,694,NULL);
INSERT INTO RangIndividuel VALUES (71,116,NULL);
INSERT INTO RangIndividuel VALUES (71,290,NULL);
INSERT INTO RangIndividuel VALUES (71,665,NULL);
INSERT INTO RangIndividuel VALUES (71,658,NULL);
INSERT INTO RangIndividuel VALUES (71,521,NULL);
INSERT INTO RangIndividuel VALUES (71,638,NULL);
INSERT INTO RangIndividuel VALUES (71,1612,NULL);
INSERT INTO RangIndividuel VALUES (71,1174,NULL);
INSERT INTO RangIndividuel VALUES (71,1613,NULL);
INSERT INTO RangIndividuel VALUES (71,676,NULL);
INSERT INTO RangIndividuel VALUES (71,720,NULL);
INSERT INTO RangIndividuel VALUES (72,153,1);
INSERT INTO RangIndividuel VALUES (72,195,2);
INSERT INTO RangIndividuel VALUES (72,58,3);
INSERT INTO RangIndividuel VALUES (72,59,4);
INSERT INTO RangIndividuel VALUES (72,1673,5);
INSERT INTO RangIndividuel VALUES (72,117,6);
INSERT INTO RangIndividuel VALUES (72,559,7);
INSERT INTO RangIndividuel VALUES (72,49,8);
INSERT INTO RangIndividuel VALUES (72,723,9);
INSERT INTO RangIndividuel VALUES (72,477,10);
INSERT INTO RangIndividuel VALUES (72,655,11);
INSERT INTO RangIndividuel VALUES (72,560,12);
INSERT INTO RangIndividuel VALUES (72,716,13);
INSERT INTO RangIndividuel VALUES (72,104,14);
INSERT INTO RangIndividuel VALUES (72,713,15);
INSERT INTO RangIndividuel VALUES (72,737,16);
INSERT INTO RangIndividuel VALUES (72,726,17);
INSERT INTO RangIndividuel VALUES (72,555,18);
INSERT INTO RangIndividuel VALUES (72,1646,19);
INSERT INTO RangIndividuel VALUES (72,422,20);
INSERT INTO RangIndividuel VALUES (72,306,21);
INSERT INTO RangIndividuel VALUES (72,414,22);
INSERT INTO RangIndividuel VALUES (72,1633,23);
INSERT INTO RangIndividuel VALUES (72,1696,24);
INSERT INTO RangIndividuel VALUES (72,479,25);
INSERT INTO RangIndividuel VALUES (72,735,26);
INSERT INTO RangIndividuel VALUES (72,522,27);
INSERT INTO RangIndividuel VALUES (72,682,28);
INSERT INTO RangIndividuel VALUES (72,615,29);
INSERT INTO RangIndividuel VALUES (72,458,30);
INSERT INTO RangIndividuel VALUES (72,1620,31);
INSERT INTO RangIndividuel VALUES (72,674,32);
INSERT INTO RangIndividuel VALUES (72,636,33);
INSERT INTO RangIndividuel VALUES (72,681,34);
INSERT INTO RangIndividuel VALUES (72,517,35);
INSERT INTO RangIndividuel VALUES (72,684,36);
INSERT INTO RangIndividuel VALUES (72,687,37);
INSERT INTO RangIndividuel VALUES (72,685,38);
INSERT INTO RangIndividuel VALUES (72,1677,39);
INSERT INTO RangIndividuel VALUES (72,748,40);
INSERT INTO RangIndividuel VALUES (72,1610,41);
INSERT INTO RangIndividuel VALUES (72,1634,42);
INSERT INTO RangIndividuel VALUES (72,637,43);
INSERT INTO RangIndividuel VALUES (72,740,44);
INSERT INTO RangIndividuel VALUES (72,1648,45);
INSERT INTO RangIndividuel VALUES (72,1639,46);
INSERT INTO RangIndividuel VALUES (72,679,47);
INSERT INTO RangIndividuel VALUES (72,412,NULL);
INSERT INTO RangIndividuel VALUES (72,733,NULL);
INSERT INTO RangIndividuel VALUES (72,1663,NULL);
INSERT INTO RangIndividuel VALUES (73,101,1);
INSERT INTO RangIndividuel VALUES (73,230,2);
INSERT INTO RangIndividuel VALUES (73,380,3);
INSERT INTO RangIndividuel VALUES (73,654,4);
INSERT INTO RangIndividuel VALUES (73,690,4);
INSERT INTO RangIndividuel VALUES (73,721,6);
INSERT INTO RangIndividuel VALUES (73,451,7);
INSERT INTO RangIndividuel VALUES (73,695,7);
INSERT INTO RangIndividuel VALUES (73,1665,9);
INSERT INTO RangIndividuel VALUES (73,163,9);
INSERT INTO RangIndividuel VALUES (73,448,11);
INSERT INTO RangIndividuel VALUES (73,749,12);
INSERT INTO RangIndividuel VALUES (73,704,13);
INSERT INTO RangIndividuel VALUES (73,1632,14);
INSERT INTO RangIndividuel VALUES (73,431,15);
INSERT INTO RangIndividuel VALUES (73,478,16);
INSERT INTO RangIndividuel VALUES (73,692,17);
INSERT INTO RangIndividuel VALUES (73,614,18);
INSERT INTO RangIndividuel VALUES (73,1689,19);
INSERT INTO RangIndividuel VALUES (73,1642,20);
INSERT INTO RangIndividuel VALUES (73,651,21);
INSERT INTO RangIndividuel VALUES (73,463,22);
INSERT INTO RangIndividuel VALUES (73,1615,23);
INSERT INTO RangIndividuel VALUES (73,1621,24);
INSERT INTO RangIndividuel VALUES (73,1682,25);
INSERT INTO RangIndividuel VALUES (73,673,26);
INSERT INTO RangIndividuel VALUES (73,1679,27);
INSERT INTO RangIndividuel VALUES (73,1659,28);
INSERT INTO RangIndividuel VALUES (73,669,29);
INSERT INTO RangIndividuel VALUES (73,1618,30);
INSERT INTO RangIndividuel VALUES (73,677,31);
INSERT INTO RangIndividuel VALUES (73,1651,32);
INSERT INTO RangIndividuel VALUES (73,1626,33);
INSERT INTO RangIndividuel VALUES (73,747,34);
INSERT INTO RangIndividuel VALUES (73,406,35);
INSERT INTO RangIndividuel VALUES (73,1680,36);
INSERT INTO RangIndividuel VALUES (73,1179,37);
INSERT INTO RangIndividuel VALUES (73,1624,38);
INSERT INTO RangIndividuel VALUES (73,738,39);
INSERT INTO RangIndividuel VALUES (73,1662,40);
INSERT INTO RangIndividuel VALUES (73,1904,41);
INSERT INTO RangIndividuel VALUES (73,1180,42);
INSERT INTO RangIndividuel VALUES (73,1699,43);
INSERT INTO RangIndividuel VALUES (73,422,NULL);
INSERT INTO RangIndividuel VALUES (73,631,NULL);
INSERT INTO RangIndividuel VALUES (73,564,NULL);
INSERT INTO RangIndividuel VALUES (73,228,NULL);
INSERT INTO RangIndividuel VALUES (73,36,NULL);
INSERT INTO RangIndividuel VALUES (73,231,NULL);
INSERT INTO RangIndividuel VALUES (73,706,NULL);
INSERT INTO RangIndividuel VALUES (73,1691,NULL);
INSERT INTO RangIndividuel VALUES (73,668,NULL);
INSERT INTO RangIndividuel VALUES (73,1630,NULL);
INSERT INTO RangIndividuel VALUES (73,678,NULL);
INSERT INTO RangIndividuel VALUES (73,683,NULL);
INSERT INTO RangIndividuel VALUES (73,684,NULL);
INSERT INTO RangIndividuel VALUES (73,1697,NULL);
INSERT INTO RangIndividuel VALUES (73,639,NULL);
INSERT INTO RangIndividuel VALUES (73,412,NULL);
INSERT INTO RangIndividuel VALUES (73,1707,NULL);
INSERT INTO RangIndividuel VALUES (73,1649,NULL);
INSERT INTO RangIndividuel VALUES (73,1655,NULL);
INSERT INTO RangIndividuel VALUES (73,661,NULL);
INSERT INTO RangIndividuel VALUES (73,1611,NULL);
INSERT INTO RangIndividuel VALUES (73,1696,NULL);
INSERT INTO RangIndividuel VALUES (73,642,NULL);
INSERT INTO RangIndividuel VALUES (73,1674,NULL);
INSERT INTO RangIndividuel VALUES (73,1701,NULL);
INSERT INTO RangIndividuel VALUES (73,517,NULL);
INSERT INTO RangIndividuel VALUES (73,1628,NULL);
INSERT INTO RangIndividuel VALUES (73,645,NULL);
INSERT INTO RangIndividuel VALUES (73,1656,NULL);
INSERT INTO RangIndividuel VALUES (73,741,NULL);
INSERT INTO RangIndividuel VALUES (73,1687,NULL);
INSERT INTO RangIndividuel VALUES (73,679,NULL);
INSERT INTO RangIndividuel VALUES (73,1620,NULL);
INSERT INTO RangIndividuel VALUES (73,1635,NULL);
INSERT INTO RangIndividuel VALUES (73,1172,NULL);
INSERT INTO RangIndividuel VALUES (73,646,NULL);
INSERT INTO RangIndividuel VALUES (73,1700,NULL);
INSERT INTO RangIndividuel VALUES (73,745,NULL);
INSERT INTO RangIndividuel VALUES (73,672,NULL);
INSERT INTO RangIndividuel VALUES (73,1676,NULL);
INSERT INTO RangIndividuel VALUES (73,308,NULL);
INSERT INTO RangIndividuel VALUES (73,462,NULL);
INSERT INTO RangIndividuel VALUES (73,325,NULL);
INSERT INTO RangIndividuel VALUES (73,553,NULL);
INSERT INTO RangIndividuel VALUES (73,562,NULL);
INSERT INTO RangIndividuel VALUES (73,43,NULL);
INSERT INTO RangIndividuel VALUES (73,443,NULL);
INSERT INTO RangIndividuel VALUES (73,115,NULL);
INSERT INTO RangIndividuel VALUES (73,442,NULL);
INSERT INTO RangIndividuel VALUES (73,1672,NULL);
INSERT INTO RangIndividuel VALUES (73,496,NULL);
INSERT INTO RangIndividuel VALUES (73,1671,NULL);
INSERT INTO RangIndividuel VALUES (73,1643,NULL);
INSERT INTO RangIndividuel VALUES (73,1690,NULL);
INSERT INTO RangIndividuel VALUES (73,615,NULL);
INSERT INTO RangIndividuel VALUES (73,516,NULL);
INSERT INTO RangIndividuel VALUES (73,1681,NULL);
INSERT INTO RangIndividuel VALUES (73,685,NULL);
INSERT INTO RangIndividuel VALUES (73,698,NULL);
INSERT INTO RangIndividuel VALUES (73,740,NULL);
INSERT INTO RangIndividuel VALUES (73,1614,NULL);
INSERT INTO RangIndividuel VALUES (73,635,NULL);
INSERT INTO RangIndividuel VALUES (73,1650,NULL);
INSERT INTO RangIndividuel VALUES (73,1184,NULL);
INSERT INTO RangIndividuel VALUES (73,1654,NULL);
INSERT INTO RangIndividuel VALUES (73,1609,NULL);
INSERT INTO RangIndividuel VALUES (73,671,NULL);
INSERT INTO RangIndividuel VALUES (73,728,NULL);
INSERT INTO RangIndividuel VALUES (73,644,NULL);
INSERT INTO RangIndividuel VALUES (73,697,NULL);
INSERT INTO RangIndividuel VALUES (73,1688,NULL);
INSERT INTO RangIndividuel VALUES (73,664,NULL);
INSERT INTO RangIndividuel VALUES (73,647,NULL);
INSERT INTO RangIndividuel VALUES (73,1173,NULL);
INSERT INTO RangIndividuel VALUES (74,43,1);
INSERT INTO RangIndividuel VALUES (74,231,2);
INSERT INTO RangIndividuel VALUES (74,325,3);
INSERT INTO RangIndividuel VALUES (74,230,4);
INSERT INTO RangIndividuel VALUES (74,422,5);
INSERT INTO RangIndividuel VALUES (74,153,6);
INSERT INTO RangIndividuel VALUES (74,36,7);
INSERT INTO RangIndividuel VALUES (74,462,8);
INSERT INTO RangIndividuel VALUES (74,552,9);
INSERT INTO RangIndividuel VALUES (74,380,10);
INSERT INTO RangIndividuel VALUES (74,1641,11);
INSERT INTO RangIndividuel VALUES (74,690,12);
INSERT INTO RangIndividuel VALUES (74,117,13);
INSERT INTO RangIndividuel VALUES (74,696,14);
INSERT INTO RangIndividuel VALUES (74,703,15);
INSERT INTO RangIndividuel VALUES (74,749,16);
INSERT INTO RangIndividuel VALUES (74,440,17);
INSERT INTO RangIndividuel VALUES (74,725,18);
INSERT INTO RangIndividuel VALUES (74,1669,19);
INSERT INTO RangIndividuel VALUES (74,49,20);
INSERT INTO RangIndividuel VALUES (74,746,21);
INSERT INTO RangIndividuel VALUES (74,721,22);
INSERT INTO RangIndividuel VALUES (74,1697,23);
INSERT INTO RangIndividuel VALUES (74,734,24);
INSERT INTO RangIndividuel VALUES (74,1643,25);
INSERT INTO RangIndividuel VALUES (74,1630,26);
INSERT INTO RangIndividuel VALUES (74,163,27);
INSERT INTO RangIndividuel VALUES (74,715,28);
INSERT INTO RangIndividuel VALUES (74,1642,29);
INSERT INTO RangIndividuel VALUES (74,1692,30);
INSERT INTO RangIndividuel VALUES (74,517,31);
INSERT INTO RangIndividuel VALUES (74,1650,32);
INSERT INTO RangIndividuel VALUES (74,1644,33);
INSERT INTO RangIndividuel VALUES (74,1660,34);
INSERT INTO RangIndividuel VALUES (74,1631,35);
INSERT INTO RangIndividuel VALUES (74,682,36);
INSERT INTO RangIndividuel VALUES (74,1696,37);
INSERT INTO RangIndividuel VALUES (74,748,38);
INSERT INTO RangIndividuel VALUES (74,1654,39);
INSERT INTO RangIndividuel VALUES (74,412,40);
INSERT INTO RangIndividuel VALUES (74,668,41);
INSERT INTO RangIndividuel VALUES (74,1621,42);
INSERT INTO RangIndividuel VALUES (74,678,43);
INSERT INTO RangIndividuel VALUES (74,1682,44);
INSERT INTO RangIndividuel VALUES (74,673,45);
INSERT INTO RangIndividuel VALUES (74,747,46);
INSERT INTO RangIndividuel VALUES (74,1184,47);
INSERT INTO RangIndividuel VALUES (74,651,48);
INSERT INTO RangIndividuel VALUES (74,741,49);
INSERT INTO RangIndividuel VALUES (74,671,50);
INSERT INTO RangIndividuel VALUES (74,1618,51);
INSERT INTO RangIndividuel VALUES (74,406,52);
INSERT INTO RangIndividuel VALUES (74,1611,53);
INSERT INTO RangIndividuel VALUES (74,1179,54);
INSERT INTO RangIndividuel VALUES (74,677,55);
INSERT INTO RangIndividuel VALUES (74,1681,56);
INSERT INTO RangIndividuel VALUES (74,1700,57);
INSERT INTO RangIndividuel VALUES (74,647,58);
INSERT INTO RangIndividuel VALUES (74,1680,59);
INSERT INTO RangIndividuel VALUES (74,1173,60);
INSERT INTO RangIndividuel VALUES (74,1904,61);
INSERT INTO RangIndividuel VALUES (74,1624,62);
INSERT INTO RangIndividuel VALUES (74,1172,63);
INSERT INTO RangIndividuel VALUES (74,646,64);
INSERT INTO RangIndividuel VALUES (74,1676,65);
INSERT INTO RangIndividuel VALUES (74,1707,66);
INSERT INTO RangIndividuel VALUES (74,738,67);
INSERT INTO RangIndividuel VALUES (74,1701,68);
INSERT INTO RangIndividuel VALUES (74,1180,69);
INSERT INTO RangIndividuel VALUES (74,728,70);
INSERT INTO RangIndividuel VALUES (74,1704,71);
INSERT INTO RangIndividuel VALUES (74,1706,72);
INSERT INTO RangIndividuel VALUES (74,631,NULL);
INSERT INTO RangIndividuel VALUES (74,1616,NULL);
INSERT INTO RangIndividuel VALUES (74,691,NULL);
INSERT INTO RangIndividuel VALUES (74,104,NULL);
INSERT INTO RangIndividuel VALUES (74,496,NULL);
INSERT INTO RangIndividuel VALUES (74,1626,NULL);
INSERT INTO RangIndividuel VALUES (74,1658,NULL);
INSERT INTO RangIndividuel VALUES (74,635,NULL);
INSERT INTO RangIndividuel VALUES (74,681,NULL);
INSERT INTO RangIndividuel VALUES (74,698,NULL);
INSERT INTO RangIndividuel VALUES (74,1609,NULL);
INSERT INTO RangIndividuel VALUES (74,1674,NULL);
INSERT INTO RangIndividuel VALUES (74,1175,NULL);
INSERT INTO RangIndividuel VALUES (74,683,NULL);
INSERT INTO RangIndividuel VALUES (74,1651,NULL);
INSERT INTO RangIndividuel VALUES (74,1628,NULL);
INSERT INTO RangIndividuel VALUES (74,1610,NULL);
INSERT INTO RangIndividuel VALUES (74,661,NULL);
INSERT INTO RangIndividuel VALUES (74,1656,NULL);
INSERT INTO RangIndividuel VALUES (74,645,NULL);
INSERT INTO RangIndividuel VALUES (74,463,NULL);
INSERT INTO RangIndividuel VALUES (74,1679,NULL);
INSERT INTO RangIndividuel VALUES (74,740,NULL);
INSERT INTO RangIndividuel VALUES (74,669,NULL);
INSERT INTO RangIndividuel VALUES (74,1620,NULL);
INSERT INTO RangIndividuel VALUES (74,1662,NULL);
INSERT INTO RangIndividuel VALUES (74,644,NULL);
INSERT INTO RangIndividuel VALUES (74,1906,NULL);
INSERT INTO RangIndividuel VALUES (74,1671,NULL);
INSERT INTO RangIndividuel VALUES (74,1182,NULL);
INSERT INTO RangIndividuel VALUES (74,562,NULL);
INSERT INTO RangIndividuel VALUES (74,1647,NULL);
INSERT INTO RangIndividuel VALUES (74,58,NULL);
INSERT INTO RangIndividuel VALUES (74,639,NULL);
INSERT INTO RangIndividuel VALUES (74,1655,NULL);
INSERT INTO RangIndividuel VALUES (74,1687,NULL);
INSERT INTO RangIndividuel VALUES (74,1635,NULL);
INSERT INTO RangIndividuel VALUES (75,118,1);
INSERT INTO RangIndividuel VALUES (75,163,2);
INSERT INTO RangIndividuel VALUES (75,195,3);
INSERT INTO RangIndividuel VALUES (75,58,4);
INSERT INTO RangIndividuel VALUES (75,721,5);
INSERT INTO RangIndividuel VALUES (75,49,6);
INSERT INTO RangIndividuel VALUES (75,422,7);
INSERT INTO RangIndividuel VALUES (75,117,8);
INSERT INTO RangIndividuel VALUES (75,59,8);
INSERT INTO RangIndividuel VALUES (75,615,10);
INSERT INTO RangIndividuel VALUES (75,1669,11);
INSERT INTO RangIndividuel VALUES (75,43,12);
INSERT INTO RangIndividuel VALUES (75,153,13);
INSERT INTO RangIndividuel VALUES (75,722,14);
INSERT INTO RangIndividuel VALUES (75,716,15);
INSERT INTO RangIndividuel VALUES (75,517,16);
INSERT INTO RangIndividuel VALUES (75,555,17);
INSERT INTO RangIndividuel VALUES (75,655,18);
INSERT INTO RangIndividuel VALUES (75,496,19);
INSERT INTO RangIndividuel VALUES (75,1644,20);
INSERT INTO RangIndividuel VALUES (75,1668,21);
INSERT INTO RangIndividuel VALUES (75,682,22);
INSERT INTO RangIndividuel VALUES (75,685,23);
INSERT INTO RangIndividuel VALUES (75,1626,24);
INSERT INTO RangIndividuel VALUES (75,681,25);
INSERT INTO RangIndividuel VALUES (75,636,26);
INSERT INTO RangIndividuel VALUES (75,740,27);
INSERT INTO RangIndividuel VALUES (75,635,28);
INSERT INTO RangIndividuel VALUES (75,412,29);
INSERT INTO RangIndividuel VALUES (75,1632,30);
INSERT INTO RangIndividuel VALUES (75,748,31);
INSERT INTO RangIndividuel VALUES (75,1610,32);
INSERT INTO RangIndividuel VALUES (75,1634,33);
INSERT INTO RangIndividuel VALUES (75,687,34);
INSERT INTO RangIndividuel VALUES (75,1649,NULL);
INSERT INTO RangIndividuel VALUES (75,1620,NULL);
INSERT INTO RangIndividuel VALUES (75,1648,NULL);
INSERT INTO RangIndividuel VALUES (75,1639,NULL);
INSERT INTO RangIndividuel VALUES (75,1663,NULL);
INSERT INTO RangIndividuel VALUES (75,723,NULL);
INSERT INTO RangIndividuel VALUES (75,642,NULL);
INSERT INTO RangIndividuel VALUES (75,715,NULL);
INSERT INTO RangIndividuel VALUES (75,559,NULL);
INSERT INTO RangIndividuel VALUES (75,325,NULL);
INSERT INTO RangIndividuel VALUES (75,736,NULL);
INSERT INTO RangIndividuel VALUES (75,196,NULL);
INSERT INTO RangIndividuel VALUES (75,1628,NULL);
INSERT INTO RangIndividuel VALUES (75,684,NULL);
INSERT INTO RangIndividuel VALUES (75,1677,NULL);
INSERT INTO RangIndividuel VALUES (75,1696,NULL);
INSERT INTO RangIndividuel VALUES (76,58,1);
INSERT INTO RangIndividuel VALUES (76,196,2);
INSERT INTO RangIndividuel VALUES (76,306,3);
INSERT INTO RangIndividuel VALUES (76,49,3);
INSERT INTO RangIndividuel VALUES (76,1668,5);
INSERT INTO RangIndividuel VALUES (76,723,6);
INSERT INTO RangIndividuel VALUES (76,59,7);
INSERT INTO RangIndividuel VALUES (76,559,8);
INSERT INTO RangIndividuel VALUES (76,422,9);
INSERT INTO RangIndividuel VALUES (76,1644,10);
INSERT INTO RangIndividuel VALUES (76,555,11);
INSERT INTO RangIndividuel VALUES (76,713,12);
INSERT INTO RangIndividuel VALUES (76,1663,13);
INSERT INTO RangIndividuel VALUES (76,43,14);
INSERT INTO RangIndividuel VALUES (76,736,15);
INSERT INTO RangIndividuel VALUES (76,655,16);
INSERT INTO RangIndividuel VALUES (76,737,17);
INSERT INTO RangIndividuel VALUES (76,560,17);
INSERT INTO RangIndividuel VALUES (76,733,19);
INSERT INTO RangIndividuel VALUES (76,615,19);
INSERT INTO RangIndividuel VALUES (76,726,21);
INSERT INTO RangIndividuel VALUES (76,117,22);
INSERT INTO RangIndividuel VALUES (76,1673,23);
INSERT INTO RangIndividuel VALUES (76,479,24);
INSERT INTO RangIndividuel VALUES (76,163,24);
INSERT INTO RangIndividuel VALUES (76,1626,26);
INSERT INTO RangIndividuel VALUES (76,716,27);
INSERT INTO RangIndividuel VALUES (76,721,28);
INSERT INTO RangIndividuel VALUES (76,1696,29);
INSERT INTO RangIndividuel VALUES (76,637,30);
INSERT INTO RangIndividuel VALUES (76,639,31);
INSERT INTO RangIndividuel VALUES (76,1610,32);
INSERT INTO RangIndividuel VALUES (76,517,33);
INSERT INTO RangIndividuel VALUES (76,748,34);
INSERT INTO RangIndividuel VALUES (76,635,35);
INSERT INTO RangIndividuel VALUES (76,1650,36);
INSERT INTO RangIndividuel VALUES (76,1620,37);
INSERT INTO RangIndividuel VALUES (76,642,38);
INSERT INTO RangIndividuel VALUES (76,685,39);
INSERT INTO RangIndividuel VALUES (76,1634,40);
INSERT INTO RangIndividuel VALUES (76,684,41);
INSERT INTO RangIndividuel VALUES (76,1649,42);
INSERT INTO RangIndividuel VALUES (76,1648,43);
INSERT INTO RangIndividuel VALUES (76,636,44);
INSERT INTO RangIndividuel VALUES (76,1609,45);
INSERT INTO RangIndividuel VALUES (76,687,46);
INSERT INTO RangIndividuel VALUES (76,412,47);
INSERT INTO RangIndividuel VALUES (76,1656,48);
INSERT INTO RangIndividuel VALUES (76,1628,49);
INSERT INTO RangIndividuel VALUES (76,740,50);
INSERT INTO RangIndividuel VALUES (76,406,51);
INSERT INTO RangIndividuel VALUES (76,1173,52);
INSERT INTO RangIndividuel VALUES (76,1633,NULL);
INSERT INTO RangIndividuel VALUES (76,104,NULL);
INSERT INTO RangIndividuel VALUES (76,195,NULL);
INSERT INTO RangIndividuel VALUES (76,153,NULL);
INSERT INTO RangIndividuel VALUES (76,682,NULL);
INSERT INTO RangIndividuel VALUES (76,653,NULL);
INSERT INTO RangIndividuel VALUES (76,1677,NULL);
INSERT INTO RangIndividuel VALUES (76,679,NULL);
INSERT INTO RangIndividuel VALUES (76,477,NULL);
INSERT INTO RangIndividuel VALUES (76,681,NULL);
INSERT INTO RangIndividuel VALUES (76,1179,NULL);
INSERT INTO RangIndividuel VALUES (77,28,1);
INSERT INTO RangIndividuel VALUES (77,20,2);
INSERT INTO RangIndividuel VALUES (77,60,3);
INSERT INTO RangIndividuel VALUES (77,169,4);
INSERT INTO RangIndividuel VALUES (77,2,5);
INSERT INTO RangIndividuel VALUES (77,191,6);
INSERT INTO RangIndividuel VALUES (77,1269,7);
INSERT INTO RangIndividuel VALUES (77,181,8);
INSERT INTO RangIndividuel VALUES (77,366,9);
INSERT INTO RangIndividuel VALUES (77,240,10);
INSERT INTO RangIndividuel VALUES (77,809,11);
INSERT INTO RangIndividuel VALUES (77,141,12);
INSERT INTO RangIndividuel VALUES (77,1271,13);
INSERT INTO RangIndividuel VALUES (77,239,14);
INSERT INTO RangIndividuel VALUES (77,529,15);
INSERT INTO RangIndividuel VALUES (77,856,16);
INSERT INTO RangIndividuel VALUES (77,1270,17);
INSERT INTO RangIndividuel VALUES (77,1327,18);
INSERT INTO RangIndividuel VALUES (77,811,19);
INSERT INTO RangIndividuel VALUES (77,53,20);
INSERT INTO RangIndividuel VALUES (77,1334,21);
INSERT INTO RangIndividuel VALUES (77,872,22);
INSERT INTO RangIndividuel VALUES (77,303,23);
INSERT INTO RangIndividuel VALUES (77,396,24);
INSERT INTO RangIndividuel VALUES (77,238,25);
INSERT INTO RangIndividuel VALUES (77,1261,26);
INSERT INTO RangIndividuel VALUES (77,1282,27);
INSERT INTO RangIndividuel VALUES (77,624,28);
INSERT INTO RangIndividuel VALUES (77,1286,29);
INSERT INTO RangIndividuel VALUES (77,1335,30);
INSERT INTO RangIndividuel VALUES (77,1303,31);
INSERT INTO RangIndividuel VALUES (77,880,32);
INSERT INTO RangIndividuel VALUES (77,1341,33);
INSERT INTO RangIndividuel VALUES (77,1311,34);
INSERT INTO RangIndividuel VALUES (77,885,35);
INSERT INTO RangIndividuel VALUES (77,1277,36);
INSERT INTO RangIndividuel VALUES (77,572,37);
INSERT INTO RangIndividuel VALUES (77,1318,38);
INSERT INTO RangIndividuel VALUES (77,829,39);
INSERT INTO RangIndividuel VALUES (77,827,40);
INSERT INTO RangIndividuel VALUES (77,857,41);
INSERT INTO RangIndividuel VALUES (77,883,42);
INSERT INTO RangIndividuel VALUES (77,605,43);
INSERT INTO RangIndividuel VALUES (77,882,44);
INSERT INTO RangIndividuel VALUES (77,828,45);
INSERT INTO RangIndividuel VALUES (77,806,46);
INSERT INTO RangIndividuel VALUES (77,1317,47);
INSERT INTO RangIndividuel VALUES (77,865,48);
INSERT INTO RangIndividuel VALUES (77,544,49);
INSERT INTO RangIndividuel VALUES (77,532,50);
INSERT INTO RangIndividuel VALUES (77,577,51);
INSERT INTO RangIndividuel VALUES (77,1278,52);
INSERT INTO RangIndividuel VALUES (77,573,53);
INSERT INTO RangIndividuel VALUES (77,858,54);
INSERT INTO RangIndividuel VALUES (77,482,55);
INSERT INTO RangIndividuel VALUES (77,410,56);
INSERT INTO RangIndividuel VALUES (77,1293,57);
INSERT INTO RangIndividuel VALUES (77,1348,58);
INSERT INTO RangIndividuel VALUES (77,819,59);
INSERT INTO RangIndividuel VALUES (77,1342,60);
INSERT INTO RangIndividuel VALUES (77,568,61);
INSERT INTO RangIndividuel VALUES (77,1274,62);
INSERT INTO RangIndividuel VALUES (77,841,63);
INSERT INTO RangIndividuel VALUES (77,1354,64);
INSERT INTO RangIndividuel VALUES (77,1336,65);
INSERT INTO RangIndividuel VALUES (77,852,66);
INSERT INTO RangIndividuel VALUES (77,1254,67);
INSERT INTO RangIndividuel VALUES (77,1347,68);
INSERT INTO RangIndividuel VALUES (77,831,69);
INSERT INTO RangIndividuel VALUES (77,834,70);
INSERT INTO RangIndividuel VALUES (77,823,71);
INSERT INTO RangIndividuel VALUES (77,878,72);
INSERT INTO RangIndividuel VALUES (77,1272,73);
INSERT INTO RangIndividuel VALUES (77,1343,74);
INSERT INTO RangIndividuel VALUES (77,1307,75);
INSERT INTO RangIndividuel VALUES (78,2,1);
INSERT INTO RangIndividuel VALUES (78,60,2);
INSERT INTO RangIndividuel VALUES (78,89,3);
INSERT INTO RangIndividuel VALUES (78,181,4);
INSERT INTO RangIndividuel VALUES (78,1334,5);
INSERT INTO RangIndividuel VALUES (78,1286,6);
INSERT INTO RangIndividuel VALUES (78,876,7);
INSERT INTO RangIndividuel VALUES (78,141,8);
INSERT INTO RangIndividuel VALUES (78,868,9);
INSERT INTO RangIndividuel VALUES (78,624,10);
INSERT INTO RangIndividuel VALUES (78,53,11);
INSERT INTO RangIndividuel VALUES (78,238,12);
INSERT INTO RangIndividuel VALUES (78,827,13);
INSERT INTO RangIndividuel VALUES (78,396,14);
INSERT INTO RangIndividuel VALUES (78,1269,15);
INSERT INTO RangIndividuel VALUES (78,1301,16);
INSERT INTO RangIndividuel VALUES (78,874,17);
INSERT INTO RangIndividuel VALUES (78,240,18);
INSERT INTO RangIndividuel VALUES (78,366,19);
INSERT INTO RangIndividuel VALUES (78,1319,20);
INSERT INTO RangIndividuel VALUES (78,169,21);
INSERT INTO RangIndividuel VALUES (78,572,22);
INSERT INTO RangIndividuel VALUES (78,529,23);
INSERT INTO RangIndividuel VALUES (78,861,24);
INSERT INTO RangIndividuel VALUES (78,1303,25);
INSERT INTO RangIndividuel VALUES (78,297,26);
INSERT INTO RangIndividuel VALUES (78,885,27);
INSERT INTO RangIndividuel VALUES (78,455,28);
INSERT INTO RangIndividuel VALUES (78,333,29);
INSERT INTO RangIndividuel VALUES (78,1270,30);
INSERT INTO RangIndividuel VALUES (78,857,31);
INSERT INTO RangIndividuel VALUES (78,809,32);
INSERT INTO RangIndividuel VALUES (78,814,33);
INSERT INTO RangIndividuel VALUES (78,20,34);
INSERT INTO RangIndividuel VALUES (78,816,35);
INSERT INTO RangIndividuel VALUES (78,577,36);
INSERT INTO RangIndividuel VALUES (78,1333,37);
INSERT INTO RangIndividuel VALUES (78,544,38);
INSERT INTO RangIndividuel VALUES (78,856,39);
INSERT INTO RangIndividuel VALUES (78,1312,40);
INSERT INTO RangIndividuel VALUES (78,829,41);
INSERT INTO RangIndividuel VALUES (78,605,42);
INSERT INTO RangIndividuel VALUES (78,1261,43);
INSERT INTO RangIndividuel VALUES (78,1304,44);
INSERT INTO RangIndividuel VALUES (78,865,45);
INSERT INTO RangIndividuel VALUES (78,883,46);
INSERT INTO RangIndividuel VALUES (78,1292,47);
INSERT INTO RangIndividuel VALUES (78,1277,48);
INSERT INTO RangIndividuel VALUES (78,482,49);
INSERT INTO RangIndividuel VALUES (78,1259,50);
INSERT INTO RangIndividuel VALUES (78,1278,51);
INSERT INTO RangIndividuel VALUES (78,1293,52);
INSERT INTO RangIndividuel VALUES (78,819,53);
INSERT INTO RangIndividuel VALUES (78,841,54);
INSERT INTO RangIndividuel VALUES (78,28,NULL);
INSERT INTO RangIndividuel VALUES (78,303,NULL);
INSERT INTO RangIndividuel VALUES (78,840,NULL);
INSERT INTO RangIndividuel VALUES (80,2,1);
INSERT INTO RangIndividuel VALUES (80,20,2);
INSERT INTO RangIndividuel VALUES (80,366,3);
INSERT INTO RangIndividuel VALUES (80,60,4);
INSERT INTO RangIndividuel VALUES (80,169,5);
INSERT INTO RangIndividuel VALUES (80,28,6);
INSERT INTO RangIndividuel VALUES (80,181,7);
INSERT INTO RangIndividuel VALUES (80,1312,8);
INSERT INTO RangIndividuel VALUES (80,141,9);
INSERT INTO RangIndividuel VALUES (80,529,10);
INSERT INTO RangIndividuel VALUES (80,1334,11);
INSERT INTO RangIndividuel VALUES (80,861,12);
INSERT INTO RangIndividuel VALUES (80,240,13);
INSERT INTO RangIndividuel VALUES (80,303,14);
INSERT INTO RangIndividuel VALUES (80,809,15);
INSERT INTO RangIndividuel VALUES (80,1303,16);
INSERT INTO RangIndividuel VALUES (80,1269,17);
INSERT INTO RangIndividuel VALUES (80,1286,18);
INSERT INTO RangIndividuel VALUES (80,857,19);
INSERT INTO RangIndividuel VALUES (80,856,20);
INSERT INTO RangIndividuel VALUES (80,1282,21);
INSERT INTO RangIndividuel VALUES (80,876,22);
INSERT INTO RangIndividuel VALUES (80,89,23);
INSERT INTO RangIndividuel VALUES (80,1271,24);
INSERT INTO RangIndividuel VALUES (80,624,25);
INSERT INTO RangIndividuel VALUES (80,238,26);
INSERT INTO RangIndividuel VALUES (80,396,27);
INSERT INTO RangIndividuel VALUES (80,333,28);
INSERT INTO RangIndividuel VALUES (80,829,29);
INSERT INTO RangIndividuel VALUES (80,1301,30);
INSERT INTO RangIndividuel VALUES (80,1327,31);
INSERT INTO RangIndividuel VALUES (80,827,32);
INSERT INTO RangIndividuel VALUES (80,239,33);
INSERT INTO RangIndividuel VALUES (80,1261,34);
INSERT INTO RangIndividuel VALUES (80,191,35);
INSERT INTO RangIndividuel VALUES (80,1333,36);
INSERT INTO RangIndividuel VALUES (80,1319,37);
INSERT INTO RangIndividuel VALUES (80,874,38);
INSERT INTO RangIndividuel VALUES (80,533,39);
INSERT INTO RangIndividuel VALUES (80,1277,40);
INSERT INTO RangIndividuel VALUES (80,806,41);
INSERT INTO RangIndividuel VALUES (80,1292,42);
INSERT INTO RangIndividuel VALUES (80,18,43);
INSERT INTO RangIndividuel VALUES (80,1302,44);
INSERT INTO RangIndividuel VALUES (80,1262,45);
INSERT INTO RangIndividuel VALUES (80,872,46);
INSERT INTO RangIndividuel VALUES (80,885,47);
INSERT INTO RangIndividuel VALUES (80,816,48);
INSERT INTO RangIndividuel VALUES (80,544,49);
INSERT INTO RangIndividuel VALUES (80,572,50);
INSERT INTO RangIndividuel VALUES (80,883,51);
INSERT INTO RangIndividuel VALUES (80,1335,52);
INSERT INTO RangIndividuel VALUES (80,605,53);
INSERT INTO RangIndividuel VALUES (80,577,54);
INSERT INTO RangIndividuel VALUES (80,482,55);
INSERT INTO RangIndividuel VALUES (80,1259,56);
INSERT INTO RangIndividuel VALUES (80,1278,57);
INSERT INTO RangIndividuel VALUES (80,865,58);
INSERT INTO RangIndividuel VALUES (80,819,59);
INSERT INTO RangIndividuel VALUES (80,1274,60);
INSERT INTO RangIndividuel VALUES (80,410,61);
INSERT INTO RangIndividuel VALUES (81,123,1);
INSERT INTO RangIndividuel VALUES (81,72,2);
INSERT INTO RangIndividuel VALUES (81,322,3);
INSERT INTO RangIndividuel VALUES (81,811,4);
INSERT INTO RangIndividuel VALUES (81,88,5);
INSERT INTO RangIndividuel VALUES (81,880,6);
INSERT INTO RangIndividuel VALUES (83,15,1);
INSERT INTO RangIndividuel VALUES (83,26,2);
INSERT INTO RangIndividuel VALUES (83,38,3);
INSERT INTO RangIndividuel VALUES (83,143,4);
INSERT INTO RangIndividuel VALUES (83,185,5);
INSERT INTO RangIndividuel VALUES (83,1346,6);
INSERT INTO RangIndividuel VALUES (83,237,7);
INSERT INTO RangIndividuel VALUES (83,177,8);
INSERT INTO RangIndividuel VALUES (83,1279,9);
INSERT INTO RangIndividuel VALUES (83,12,10);
INSERT INTO RangIndividuel VALUES (83,1325,11);
INSERT INTO RangIndividuel VALUES (83,812,12);
INSERT INTO RangIndividuel VALUES (83,210,13);
INSERT INTO RangIndividuel VALUES (83,190,14);
INSERT INTO RangIndividuel VALUES (83,142,15);
INSERT INTO RangIndividuel VALUES (83,267,16);
INSERT INTO RangIndividuel VALUES (83,102,17);
INSERT INTO RangIndividuel VALUES (83,1309,18);
INSERT INTO RangIndividuel VALUES (83,810,19);
INSERT INTO RangIndividuel VALUES (83,847,20);
INSERT INTO RangIndividuel VALUES (83,312,21);
INSERT INTO RangIndividuel VALUES (83,571,22);
INSERT INTO RangIndividuel VALUES (83,395,23);
INSERT INTO RangIndividuel VALUES (83,1339,24);
INSERT INTO RangIndividuel VALUES (83,1253,25);
INSERT INTO RangIndividuel VALUES (83,266,26);
INSERT INTO RangIndividuel VALUES (83,803,27);
INSERT INTO RangIndividuel VALUES (83,500,28);
INSERT INTO RangIndividuel VALUES (83,625,29);
INSERT INTO RangIndividuel VALUES (83,1300,30);
INSERT INTO RangIndividuel VALUES (83,862,31);
INSERT INTO RangIndividuel VALUES (83,1296,32);
INSERT INTO RangIndividuel VALUES (83,407,33);
INSERT INTO RangIndividuel VALUES (83,807,34);
INSERT INTO RangIndividuel VALUES (83,483,35);
INSERT INTO RangIndividuel VALUES (83,1298,36);
INSERT INTO RangIndividuel VALUES (83,854,37);
INSERT INTO RangIndividuel VALUES (83,1338,38);
INSERT INTO RangIndividuel VALUES (83,1289,39);
INSERT INTO RangIndividuel VALUES (83,499,40);
INSERT INTO RangIndividuel VALUES (83,1257,41);
INSERT INTO RangIndividuel VALUES (83,822,42);
INSERT INTO RangIndividuel VALUES (83,1283,43);
INSERT INTO RangIndividuel VALUES (83,851,44);
INSERT INTO RangIndividuel VALUES (83,835,45);
INSERT INTO RangIndividuel VALUES (83,888,46);
INSERT INTO RangIndividuel VALUES (83,1328,47);
INSERT INTO RangIndividuel VALUES (83,576,48);
INSERT INTO RangIndividuel VALUES (83,604,49);
INSERT INTO RangIndividuel VALUES (83,833,50);
INSERT INTO RangIndividuel VALUES (83,870,51);
INSERT INTO RangIndividuel VALUES (83,456,52);
INSERT INTO RangIndividuel VALUES (83,603,53);
INSERT INTO RangIndividuel VALUES (83,1275,54);
INSERT INTO RangIndividuel VALUES (83,1264,55);
INSERT INTO RangIndividuel VALUES (83,877,56);
INSERT INTO RangIndividuel VALUES (83,1320,57);
INSERT INTO RangIndividuel VALUES (83,427,58);
INSERT INTO RangIndividuel VALUES (83,1323,59);
INSERT INTO RangIndividuel VALUES (83,1308,60);
INSERT INTO RangIndividuel VALUES (83,1287,61);
INSERT INTO RangIndividuel VALUES (83,820,62);
INSERT INTO RangIndividuel VALUES (83,839,63);
INSERT INTO RangIndividuel VALUES (83,1265,64);
INSERT INTO RangIndividuel VALUES (83,1291,65);
INSERT INTO RangIndividuel VALUES (83,1266,66);
INSERT INTO RangIndividuel VALUES (83,853,67);
INSERT INTO RangIndividuel VALUES (83,1331,68);
INSERT INTO RangIndividuel VALUES (83,1190,69);
INSERT INTO RangIndividuel VALUES (83,1255,70);
INSERT INTO RangIndividuel VALUES (83,411,71);
INSERT INTO RangIndividuel VALUES (83,860,72);
INSERT INTO RangIndividuel VALUES (83,838,73);
INSERT INTO RangIndividuel VALUES (83,1337,74);
INSERT INTO RangIndividuel VALUES (83,886,75);
INSERT INTO RangIndividuel VALUES (83,1322,76);
INSERT INTO RangIndividuel VALUES (83,766,77);
INSERT INTO RangIndividuel VALUES (83,832,78);
INSERT INTO RangIndividuel VALUES (83,836,79);
INSERT INTO RangIndividuel VALUES (83,1314,80);
INSERT INTO RangIndividuel VALUES (83,608,81);
INSERT INTO RangIndividuel VALUES (83,1313,82);
INSERT INTO RangIndividuel VALUES (83,1281,83);
INSERT INTO RangIndividuel VALUES (83,855,84);
INSERT INTO RangIndividuel VALUES (83,1353,85);
INSERT INTO RangIndividuel VALUES (83,617,86);
INSERT INTO RangIndividuel VALUES (83,873,87);
INSERT INTO RangIndividuel VALUES (83,830,NULL);
INSERT INTO RangIndividuel VALUES (83,825,NULL);
INSERT INTO RangIndividuel VALUES (83,837,NULL);
INSERT INTO RangIndividuel VALUES (83,1352,NULL);
INSERT INTO RangIndividuel VALUES (83,1345,NULL);
INSERT INTO RangIndividuel VALUES (84,66,1);
INSERT INTO RangIndividuel VALUES (84,167,2);
INSERT INTO RangIndividuel VALUES (84,332,3);
INSERT INTO RangIndividuel VALUES (84,210,4);
INSERT INTO RangIndividuel VALUES (84,603,5);
INSERT INTO RangIndividuel VALUES (84,335,6);
INSERT INTO RangIndividuel VALUES (84,85,7);
INSERT INTO RangIndividuel VALUES (84,38,8);
INSERT INTO RangIndividuel VALUES (84,26,9);
INSERT INTO RangIndividuel VALUES (84,143,10);
INSERT INTO RangIndividuel VALUES (84,575,11);
INSERT INTO RangIndividuel VALUES (84,571,12);
INSERT INTO RangIndividuel VALUES (84,337,13);
INSERT INTO RangIndividuel VALUES (84,395,14);
INSERT INTO RangIndividuel VALUES (84,847,15);
INSERT INTO RangIndividuel VALUES (84,826,16);
INSERT INTO RangIndividuel VALUES (84,1323,17);
INSERT INTO RangIndividuel VALUES (84,31,18);
INSERT INTO RangIndividuel VALUES (84,830,19);
INSERT INTO RangIndividuel VALUES (84,1289,20);
INSERT INTO RangIndividuel VALUES (84,606,21);
INSERT INTO RangIndividuel VALUES (84,569,22);
INSERT INTO RangIndividuel VALUES (84,849,23);
INSERT INTO RangIndividuel VALUES (84,1321,24);
INSERT INTO RangIndividuel VALUES (84,1300,25);
INSERT INTO RangIndividuel VALUES (84,862,26);
INSERT INTO RangIndividuel VALUES (84,15,27);
INSERT INTO RangIndividuel VALUES (84,1291,28);
INSERT INTO RangIndividuel VALUES (84,863,29);
INSERT INTO RangIndividuel VALUES (84,570,30);
INSERT INTO RangIndividuel VALUES (84,185,31);
INSERT INTO RangIndividuel VALUES (84,1346,32);
INSERT INTO RangIndividuel VALUES (84,833,33);
INSERT INTO RangIndividuel VALUES (84,808,34);
INSERT INTO RangIndividuel VALUES (84,312,35);
INSERT INTO RangIndividuel VALUES (84,1324,36);
INSERT INTO RangIndividuel VALUES (84,334,37);
INSERT INTO RangIndividuel VALUES (84,1256,38);
INSERT INTO RangIndividuel VALUES (84,177,39);
INSERT INTO RangIndividuel VALUES (84,234,40);
INSERT INTO RangIndividuel VALUES (84,1258,41);
INSERT INTO RangIndividuel VALUES (84,183,42);
INSERT INTO RangIndividuel VALUES (84,336,43);
INSERT INTO RangIndividuel VALUES (84,499,44);
INSERT INTO RangIndividuel VALUES (84,427,45);
INSERT INTO RangIndividuel VALUES (84,843,46);
INSERT INTO RangIndividuel VALUES (84,839,47);
INSERT INTO RangIndividuel VALUES (84,1275,48);
INSERT INTO RangIndividuel VALUES (84,835,49);
INSERT INTO RangIndividuel VALUES (84,766,50);
INSERT INTO RangIndividuel VALUES (84,1328,51);
INSERT INTO RangIndividuel VALUES (84,295,52);
INSERT INTO RangIndividuel VALUES (84,851,53);
INSERT INTO RangIndividuel VALUES (84,484,54);
INSERT INTO RangIndividuel VALUES (84,807,55);
INSERT INTO RangIndividuel VALUES (84,1290,56);
INSERT INTO RangIndividuel VALUES (84,456,57);
INSERT INTO RangIndividuel VALUES (84,1308,58);
INSERT INTO RangIndividuel VALUES (84,838,59);
INSERT INTO RangIndividuel VALUES (84,859,60);
INSERT INTO RangIndividuel VALUES (84,1257,NULL);
INSERT INTO RangIndividuel VALUES (84,848,NULL);
INSERT INTO RangIndividuel VALUES (84,879,NULL);
INSERT INTO RangIndividuel VALUES (84,608,NULL);
INSERT INTO RangIndividuel VALUES (84,457,NULL);
INSERT INTO RangIndividuel VALUES (86,15,1);
INSERT INTO RangIndividuel VALUES (86,12,2);
INSERT INTO RangIndividuel VALUES (86,210,3);
INSERT INTO RangIndividuel VALUES (86,167,4);
INSERT INTO RangIndividuel VALUES (86,332,5);
INSERT INTO RangIndividuel VALUES (86,312,6);
INSERT INTO RangIndividuel VALUES (86,38,7);
INSERT INTO RangIndividuel VALUES (86,336,8);
INSERT INTO RangIndividuel VALUES (86,142,9);
INSERT INTO RangIndividuel VALUES (86,66,10);
INSERT INTO RangIndividuel VALUES (86,32,11);
INSERT INTO RangIndividuel VALUES (86,1325,12);
INSERT INTO RangIndividuel VALUES (86,85,13);
INSERT INTO RangIndividuel VALUES (86,170,14);
INSERT INTO RangIndividuel VALUES (86,1279,15);
INSERT INTO RangIndividuel VALUES (86,31,16);
INSERT INTO RangIndividuel VALUES (86,830,17);
INSERT INTO RangIndividuel VALUES (86,1253,18);
INSERT INTO RangIndividuel VALUES (86,1310,19);
INSERT INTO RangIndividuel VALUES (86,606,20);
INSERT INTO RangIndividuel VALUES (86,1300,21);
INSERT INTO RangIndividuel VALUES (86,177,22);
INSERT INTO RangIndividuel VALUES (86,1323,23);
INSERT INTO RangIndividuel VALUES (86,1289,24);
INSERT INTO RangIndividuel VALUES (86,143,25);
INSERT INTO RangIndividuel VALUES (86,571,26);
INSERT INTO RangIndividuel VALUES (86,334,27);
INSERT INTO RangIndividuel VALUES (86,1339,28);
INSERT INTO RangIndividuel VALUES (86,575,29);
INSERT INTO RangIndividuel VALUES (86,395,30);
INSERT INTO RangIndividuel VALUES (86,807,31);
INSERT INTO RangIndividuel VALUES (86,102,32);
INSERT INTO RangIndividuel VALUES (86,603,33);
INSERT INTO RangIndividuel VALUES (86,862,34);
INSERT INTO RangIndividuel VALUES (86,863,35);
INSERT INTO RangIndividuel VALUES (86,1324,36);
INSERT INTO RangIndividuel VALUES (86,849,37);
INSERT INTO RangIndividuel VALUES (86,625,38);
INSERT INTO RangIndividuel VALUES (86,847,39);
INSERT INTO RangIndividuel VALUES (86,337,40);
INSERT INTO RangIndividuel VALUES (86,1338,41);
INSERT INTO RangIndividuel VALUES (86,803,42);
INSERT INTO RangIndividuel VALUES (86,295,43);
INSERT INTO RangIndividuel VALUES (86,1291,44);
INSERT INTO RangIndividuel VALUES (86,888,45);
INSERT INTO RangIndividuel VALUES (86,1328,46);
INSERT INTO RangIndividuel VALUES (86,820,47);
INSERT INTO RangIndividuel VALUES (86,484,48);
INSERT INTO RangIndividuel VALUES (86,833,49);
INSERT INTO RangIndividuel VALUES (86,499,50);
INSERT INTO RangIndividuel VALUES (86,427,51);
INSERT INTO RangIndividuel VALUES (86,1257,52);
INSERT INTO RangIndividuel VALUES (86,456,53);
INSERT INTO RangIndividuel VALUES (86,604,54);
INSERT INTO RangIndividuel VALUES (86,808,55);
INSERT INTO RangIndividuel VALUES (86,1258,56);
INSERT INTO RangIndividuel VALUES (86,839,57);
INSERT INTO RangIndividuel VALUES (86,859,58);
INSERT INTO RangIndividuel VALUES (86,886,59);
INSERT INTO RangIndividuel VALUES (86,1265,60);
INSERT INTO RangIndividuel VALUES (86,853,61);
INSERT INTO RangIndividuel VALUES (86,1345,62);
INSERT INTO RangIndividuel VALUES (86,1263,63);
INSERT INTO RangIndividuel VALUES (86,1308,64);
INSERT INTO RangIndividuel VALUES (86,838,65);
INSERT INTO RangIndividuel VALUES (86,1255,66);
INSERT INTO RangIndividuel VALUES (86,1331,67);
INSERT INTO RangIndividuel VALUES (86,871,NULL);
INSERT INTO RangIndividuel VALUES (87,112,1);
INSERT INTO RangIndividuel VALUES (87,200,2);
INSERT INTO RangIndividuel VALUES (87,291,3);
INSERT INTO RangIndividuel VALUES (87,813,4);
INSERT INTO RangIndividuel VALUES (87,1260,5);
INSERT INTO RangIndividuel VALUES (87,12,6);
INSERT INTO RangIndividuel VALUES (89,126,1);
INSERT INTO RangIndividuel VALUES (89,69,2);
INSERT INTO RangIndividuel VALUES (89,81,3);
INSERT INTO RangIndividuel VALUES (89,67,4);
INSERT INTO RangIndividuel VALUES (89,1007,5);
INSERT INTO RangIndividuel VALUES (89,1015,6);
INSERT INTO RangIndividuel VALUES (89,589,7);
INSERT INTO RangIndividuel VALUES (89,1406,8);
INSERT INTO RangIndividuel VALUES (89,1030,9);
INSERT INTO RangIndividuel VALUES (89,1067,10);
INSERT INTO RangIndividuel VALUES (89,632,11);
INSERT INTO RangIndividuel VALUES (89,1056,12);
INSERT INTO RangIndividuel VALUES (89,1416,13);
INSERT INTO RangIndividuel VALUES (89,1408,14);
INSERT INTO RangIndividuel VALUES (89,588,15);
INSERT INTO RangIndividuel VALUES (89,1048,16);
INSERT INTO RangIndividuel VALUES (89,1005,17);
INSERT INTO RangIndividuel VALUES (89,1455,18);
INSERT INTO RangIndividuel VALUES (89,1447,19);
INSERT INTO RangIndividuel VALUES (89,1456,20);
INSERT INTO RangIndividuel VALUES (89,1037,21);
INSERT INTO RangIndividuel VALUES (89,996,22);
INSERT INTO RangIndividuel VALUES (89,1052,23);
INSERT INTO RangIndividuel VALUES (89,1010,24);
INSERT INTO RangIndividuel VALUES (89,492,25);
INSERT INTO RangIndividuel VALUES (89,586,26);
INSERT INTO RangIndividuel VALUES (89,1472,27);
INSERT INTO RangIndividuel VALUES (89,1219,NULL);
INSERT INTO RangIndividuel VALUES (90,128,1);
INSERT INTO RangIndividuel VALUES (90,221,2);
INSERT INTO RangIndividuel VALUES (90,347,3);
INSERT INTO RangIndividuel VALUES (91,129,1);
INSERT INTO RangIndividuel VALUES (91,253,2);
INSERT INTO RangIndividuel VALUES (91,192,3);
INSERT INTO RangIndividuel VALUES (91,590,4);
INSERT INTO RangIndividuel VALUES (91,321,5);
INSERT INTO RangIndividuel VALUES (91,1460,6);
INSERT INTO RangIndividuel VALUES (91,1053,7);
INSERT INTO RangIndividuel VALUES (91,1060,8);
INSERT INTO RangIndividuel VALUES (91,128,9);
INSERT INTO RangIndividuel VALUES (91,1028,10);
INSERT INTO RangIndividuel VALUES (91,467,11);
INSERT INTO RangIndividuel VALUES (91,417,12);
INSERT INTO RangIndividuel VALUES (91,347,13);
INSERT INTO RangIndividuel VALUES (91,221,14);
INSERT INTO RangIndividuel VALUES (91,1400,15);
INSERT INTO RangIndividuel VALUES (91,509,16);
INSERT INTO RangIndividuel VALUES (91,1021,17);
INSERT INTO RangIndividuel VALUES (91,1471,18);
INSERT INTO RangIndividuel VALUES (91,1468,19);
INSERT INTO RangIndividuel VALUES (91,103,20);
INSERT INTO RangIndividuel VALUES (91,1008,21);
INSERT INTO RangIndividuel VALUES (91,1419,22);
INSERT INTO RangIndividuel VALUES (91,1480,23);
INSERT INTO RangIndividuel VALUES (91,1477,24);
INSERT INTO RangIndividuel VALUES (91,995,25);
INSERT INTO RangIndividuel VALUES (91,1018,26);
INSERT INTO RangIndividuel VALUES (91,1411,27);
INSERT INTO RangIndividuel VALUES (91,1003,28);
INSERT INTO RangIndividuel VALUES (91,250,29);
INSERT INTO RangIndividuel VALUES (91,994,30);
INSERT INTO RangIndividuel VALUES (91,1011,31);
INSERT INTO RangIndividuel VALUES (91,997,32);
INSERT INTO RangIndividuel VALUES (92,127,1);
INSERT INTO RangIndividuel VALUES (92,270,2);
INSERT INTO RangIndividuel VALUES (92,374,3);
INSERT INTO RangIndividuel VALUES (92,1054,4);
INSERT INTO RangIndividuel VALUES (92,1048,5);
INSERT INTO RangIndividuel VALUES (92,1435,6);
INSERT INTO RangIndividuel VALUES (92,69,7);
INSERT INTO RangIndividuel VALUES (92,1474,8);
INSERT INTO RangIndividuel VALUES (92,1479,9);
INSERT INTO RangIndividuel VALUES (92,1430,10);
INSERT INTO RangIndividuel VALUES (92,1428,11);
INSERT INTO RangIndividuel VALUES (92,1417,12);
INSERT INTO RangIndividuel VALUES (92,1439,13);
INSERT INTO RangIndividuel VALUES (92,1436,14);
INSERT INTO RangIndividuel VALUES (92,1464,15);
INSERT INTO RangIndividuel VALUES (92,1465,16);
INSERT INTO RangIndividuel VALUES (92,1461,17);
INSERT INTO RangIndividuel VALUES (92,1467,18);
INSERT INTO RangIndividuel VALUES (92,1409,19);
INSERT INTO RangIndividuel VALUES (92,592,20);
INSERT INTO RangIndividuel VALUES (92,1466,NULL);
INSERT INTO RangIndividuel VALUES (92,299,NULL);
INSERT INTO RangIndividuel VALUES (92,1445,NULL);
INSERT INTO RangIndividuel VALUES (93,147,1);
INSERT INTO RangIndividuel VALUES (93,193,2);
INSERT INTO RangIndividuel VALUES (93,371,3);
INSERT INTO RangIndividuel VALUES (93,1166,4);
INSERT INTO RangIndividuel VALUES (93,587,5);
INSERT INTO RangIndividuel VALUES (93,1422,6);
INSERT INTO RangIndividuel VALUES (93,223,7);
INSERT INTO RangIndividuel VALUES (93,1452,8);
INSERT INTO RangIndividuel VALUES (94,114,1);
INSERT INTO RangIndividuel VALUES (94,269,2);
INSERT INTO RangIndividuel VALUES (94,364,3);
INSERT INTO RangIndividuel VALUES (94,42,4);
INSERT INTO RangIndividuel VALUES (94,1218,5);
INSERT INTO RangIndividuel VALUES (94,1032,6);
INSERT INTO RangIndividuel VALUES (94,1031,7);
INSERT INTO RangIndividuel VALUES (94,1221,8);
INSERT INTO RangIndividuel VALUES (94,1453,9);
INSERT INTO RangIndividuel VALUES (94,1045,10);
INSERT INTO RangIndividuel VALUES (94,1057,11);
INSERT INTO RangIndividuel VALUES (94,1046,12);
INSERT INTO RangIndividuel VALUES (94,1036,13);
INSERT INTO RangIndividuel VALUES (94,1440,14);
INSERT INTO RangIndividuel VALUES (94,1458,15);
INSERT INTO RangIndividuel VALUES (94,1063,16);
INSERT INTO RangIndividuel VALUES (94,1065,17);
INSERT INTO RangIndividuel VALUES (94,1412,19);
INSERT INTO RangIndividuel VALUES (94,1457,20);
INSERT INTO RangIndividuel VALUES (94,1167,21);
INSERT INTO RangIndividuel VALUES (94,1217,22);
INSERT INTO RangIndividuel VALUES (94,490,23);
INSERT INTO RangIndividuel VALUES (94,1469,24);
INSERT INTO RangIndividuel VALUES (94,1216,25);
INSERT INTO RangIndividuel VALUES (94,1040,26);
INSERT INTO RangIndividuel VALUES (94,1017,26);
INSERT INTO RangIndividuel VALUES (94,1023,28);
INSERT INTO RangIndividuel VALUES (94,1220,29);
INSERT INTO RangIndividuel VALUES (94,1405,30);
INSERT INTO RangIndividuel VALUES (94,627,31);
INSERT INTO RangIndividuel VALUES (94,1401,32);
INSERT INTO RangIndividuel VALUES (94,1038,33);
INSERT INTO RangIndividuel VALUES (94,1042,34);
INSERT INTO RangIndividuel VALUES (94,503,35);
INSERT INTO RangIndividuel VALUES (94,1001,36);
INSERT INTO RangIndividuel VALUES (94,1006,37);
INSERT INTO RangIndividuel VALUES (94,1041,38);
INSERT INTO RangIndividuel VALUES (94,491,39);
INSERT INTO RangIndividuel VALUES (94,1473,NULL);
INSERT INTO RangIndividuel VALUES (94,254,NULL);
INSERT INTO RangIndividuel VALUES (95,48,1);
INSERT INTO RangIndividuel VALUES (95,255,2);
INSERT INTO RangIndividuel VALUES (95,202,3);
INSERT INTO RangIndividuel VALUES (96,48,1);
INSERT INTO RangIndividuel VALUES (96,202,2);
INSERT INTO RangIndividuel VALUES (96,203,3);
INSERT INTO RangIndividuel VALUES (96,1013,4);
INSERT INTO RangIndividuel VALUES (96,1059,5);
INSERT INTO RangIndividuel VALUES (96,466,6);
INSERT INTO RangIndividuel VALUES (96,255,7);
INSERT INTO RangIndividuel VALUES (96,438,8);
INSERT INTO RangIndividuel VALUES (96,222,9);
INSERT INTO RangIndividuel VALUES (96,1055,10);
INSERT INTO RangIndividuel VALUES (96,1064,11);
INSERT INTO RangIndividuel VALUES (96,1043,12);
INSERT INTO RangIndividuel VALUES (96,416,13);
INSERT INTO RangIndividuel VALUES (96,1443,14);
INSERT INTO RangIndividuel VALUES (96,99,15);
INSERT INTO RangIndividuel VALUES (96,1020,16);
INSERT INTO RangIndividuel VALUES (96,1062,17);
INSERT INTO RangIndividuel VALUES (96,1022,18);
INSERT INTO RangIndividuel VALUES (96,1009,19);
INSERT INTO RangIndividuel VALUES (96,1050,20);
INSERT INTO RangIndividuel VALUES (96,1034,21);
INSERT INTO RangIndividuel VALUES (96,619,22);
INSERT INTO RangIndividuel VALUES (96,1024,23);
INSERT INTO RangIndividuel VALUES (96,1029,24);
INSERT INTO RangIndividuel VALUES (96,591,25);
INSERT INTO RangIndividuel VALUES (96,1450,26);
INSERT INTO RangIndividuel VALUES (96,1025,27);
INSERT INTO RangIndividuel VALUES (96,999,28);
INSERT INTO RangIndividuel VALUES (96,620,NULL);
INSERT INTO RangIndividuel VALUES (96,1403,NULL);
INSERT INTO RangIndividuel VALUES (96,40,NULL);
INSERT INTO RangIndividuel VALUES (96,459,NULL);
INSERT INTO RangIndividuel VALUES (97,146,1);
INSERT INTO RangIndividuel VALUES (97,252,2);
INSERT INTO RangIndividuel VALUES (97,372,3);
INSERT INTO RangIndividuel VALUES (97,1425,4);
INSERT INTO RangIndividuel VALUES (97,1413,5);
INSERT INTO RangIndividuel VALUES (97,1463,6);
INSERT INTO RangIndividuel VALUES (97,254,7);
INSERT INTO RangIndividuel VALUES (97,1402,8);
INSERT INTO RangIndividuel VALUES (97,1415,9);
INSERT INTO RangIndividuel VALUES (97,1462,10);
INSERT INTO RangIndividuel VALUES (97,1449,11);
INSERT INTO RangIndividuel VALUES (97,1427,12);
INSERT INTO RangIndividuel VALUES (97,1069,13);
INSERT INTO RangIndividuel VALUES (97,1438,14);
INSERT INTO RangIndividuel VALUES (97,1437,15);
INSERT INTO RangIndividuel VALUES (97,1167,16);
INSERT INTO RangIndividuel VALUES (97,1458,17);
INSERT INTO RangIndividuel VALUES (97,503,18);
INSERT INTO RangIndividuel VALUES (97,1473,19);
INSERT INTO RangIndividuel VALUES (97,1000,20);
INSERT INTO RangIndividuel VALUES (97,1429,21);
INSERT INTO RangIndividuel VALUES (97,1068,22);
INSERT INTO RangIndividuel VALUES (97,1424,23);
INSERT INTO RangIndividuel VALUES (97,1426,24);
INSERT INTO RangIndividuel VALUES (97,1432,25);
INSERT INTO RangIndividuel VALUES (97,1433,26);
INSERT INTO RangIndividuel VALUES (97,1446,27);
INSERT INTO RangIndividuel VALUES (97,1478,28);
INSERT INTO RangIndividuel VALUES (97,1431,NULL);
INSERT INTO RangIndividuel VALUES (98,109,1);
INSERT INTO RangIndividuel VALUES (98,251,2);
INSERT INTO RangIndividuel VALUES (98,373,3);
INSERT INTO RangIndividuel VALUES (98,316,4);
INSERT INTO RangIndividuel VALUES (98,1004,5);
INSERT INTO RangIndividuel VALUES (98,1049,6);
INSERT INTO RangIndividuel VALUES (98,1423,7);
INSERT INTO RangIndividuel VALUES (98,1165,8);


INSERT INTO Equipe VALUES (1,'UKR');
INSERT INTO Equipe VALUES (2,'RUS');
INSERT INTO Equipe VALUES (3,'NOR');
INSERT INTO Equipe VALUES (4,'CZE');
INSERT INTO Equipe VALUES (5,'BLR');
INSERT INTO Equipe VALUES (6,'ITA');
INSERT INTO Equipe VALUES (7,'USA');
INSERT INTO Equipe VALUES (8,'CAN');
INSERT INTO Equipe VALUES (9,'SUI');
INSERT INTO Equipe VALUES (10,'POL');
INSERT INTO Equipe VALUES (11,'GER');
INSERT INTO Equipe VALUES (12,'KAZ');
INSERT INTO Equipe VALUES (13,'JPN');
INSERT INTO Equipe VALUES (14,'SVK');
INSERT INTO Equipe VALUES (15,'CHN');
INSERT INTO Equipe VALUES (16,'EST');
INSERT INTO Equipe VALUES (17,'RUS');
INSERT INTO Equipe VALUES (18,'GER');
INSERT INTO Equipe VALUES (19,'AUT');
INSERT INTO Equipe VALUES (20,'NOR');
INSERT INTO Equipe VALUES (21,'ITA');
INSERT INTO Equipe VALUES (22,'SLO');
INSERT INTO Equipe VALUES (23,'CAN');
INSERT INTO Equipe VALUES (24,'FRA');
INSERT INTO Equipe VALUES (25,'UKR');
INSERT INTO Equipe VALUES (26,'SWE');
INSERT INTO Equipe VALUES (27,'CZE');
INSERT INTO Equipe VALUES (28,'SVK');
INSERT INTO Equipe VALUES (29,'BLR');
INSERT INTO Equipe VALUES (30,'SUI');
INSERT INTO Equipe VALUES (31,'BUL');
INSERT INTO Equipe VALUES (32,'USA');
INSERT INTO Equipe VALUES (33,'EST');
INSERT INTO Equipe VALUES (34,'KAZ');
INSERT INTO Equipe VALUES (35,'POL');
INSERT INTO Equipe VALUES (36,'NOR');
INSERT INTO Equipe VALUES (37,'CZE');
INSERT INTO Equipe VALUES (38,'ITA');
INSERT INTO Equipe VALUES (39,'RUS');
INSERT INTO Equipe VALUES (40,'SVK');
INSERT INTO Equipe VALUES (41,'FRA');
INSERT INTO Equipe VALUES (42,'UKR');
INSERT INTO Equipe VALUES (43,'USA');
INSERT INTO Equipe VALUES (44,'AUT');
INSERT INTO Equipe VALUES (45,'BLR');
INSERT INTO Equipe VALUES (46,'CAN');
INSERT INTO Equipe VALUES (47,'SUI');
INSERT INTO Equipe VALUES (48,'POL');
INSERT INTO Equipe VALUES (49,'KAZ');
INSERT INTO Equipe VALUES (50,'EST');
INSERT INTO Equipe VALUES (51,'GER');
INSERT INTO Equipe VALUES (52,'CAN');
INSERT INTO Equipe VALUES (53,'USA');
INSERT INTO Equipe VALUES (54,'USA');
INSERT INTO Equipe VALUES (55,'NED');
INSERT INTO Equipe VALUES (56,'GER');
INSERT INTO Equipe VALUES (57,'BEL');
INSERT INTO Equipe VALUES (58,'GER');
INSERT INTO Equipe VALUES (59,'SUI');
INSERT INTO Equipe VALUES (60,'RUS');
INSERT INTO Equipe VALUES (61,'GER');
INSERT INTO Equipe VALUES (62,'USA');
INSERT INTO Equipe VALUES (63,'GBR');
INSERT INTO Equipe VALUES (64,'CAN');
INSERT INTO Equipe VALUES (65,'AUS');
INSERT INTO Equipe VALUES (66,'AUT');
INSERT INTO Equipe VALUES (67,'RUS');
INSERT INTO Equipe VALUES (68,'ROU');
INSERT INTO Equipe VALUES (69,'KOR');
INSERT INTO Equipe VALUES (70,'BRA');
INSERT INTO Equipe VALUES (71,'RUS');
INSERT INTO Equipe VALUES (72,'SUI');
INSERT INTO Equipe VALUES (73,'USA');
INSERT INTO Equipe VALUES (74,'RUS');
INSERT INTO Equipe VALUES (75,'LAT');
INSERT INTO Equipe VALUES (76,'CAN');
INSERT INTO Equipe VALUES (77,'CAN');
INSERT INTO Equipe VALUES (78,'GER');
INSERT INTO Equipe VALUES (79,'CAN');
INSERT INTO Equipe VALUES (80,'SUI');
INSERT INTO Equipe VALUES (81,'GER');
INSERT INTO Equipe VALUES (82,'USA');
INSERT INTO Equipe VALUES (83,'USA');
INSERT INTO Equipe VALUES (84,'ITA');
INSERT INTO Equipe VALUES (85,'GER');
INSERT INTO Equipe VALUES (86,'LAT');
INSERT INTO Equipe VALUES (87,'ROU');
INSERT INTO Equipe VALUES (88,'KOR');
INSERT INTO Equipe VALUES (89,'NED');
INSERT INTO Equipe VALUES (90,'FRA');
INSERT INTO Equipe VALUES (91,'MON');
INSERT INTO Equipe VALUES (92,'AUT');
INSERT INTO Equipe VALUES (93,'GBR');
INSERT INTO Equipe VALUES (94,'CZE');
INSERT INTO Equipe VALUES (95,'KOR');
INSERT INTO Equipe VALUES (96,'AUS');
INSERT INTO Equipe VALUES (97,'POL');
INSERT INTO Equipe VALUES (98,'JPN');
INSERT INTO Equipe VALUES (99,'JAM');
INSERT INTO Equipe VALUES (100,'SRB');
INSERT INTO Equipe VALUES (101,'RUS');
INSERT INTO Equipe VALUES (102,'LAT');
INSERT INTO Equipe VALUES (103,'USA');
INSERT INTO Equipe VALUES (104,'RUS');
INSERT INTO Equipe VALUES (105,'GBR');
INSERT INTO Equipe VALUES (106,'GER');
INSERT INTO Equipe VALUES (107,'GER');
INSERT INTO Equipe VALUES (108,'SUI');
INSERT INTO Equipe VALUES (109,'CAN');
INSERT INTO Equipe VALUES (110,'GER');
INSERT INTO Equipe VALUES (111,'NED');
INSERT INTO Equipe VALUES (112,'USA');
INSERT INTO Equipe VALUES (113,'CAN');
INSERT INTO Equipe VALUES (114,'LAT');
INSERT INTO Equipe VALUES (115,'RUS');
INSERT INTO Equipe VALUES (116,'CZE');
INSERT INTO Equipe VALUES (117,'FRA');
INSERT INTO Equipe VALUES (118,'ITA');
INSERT INTO Equipe VALUES (119,'GBR');
INSERT INTO Equipe VALUES (120,'KOR');
INSERT INTO Equipe VALUES (121,'AUT');
INSERT INTO Equipe VALUES (122,'AUS');
INSERT INTO Equipe VALUES (123,'FRA');
INSERT INTO Equipe VALUES (124,'ROU');
INSERT INTO Equipe VALUES (125,'SVK');
INSERT INTO Equipe VALUES (126,'JPN');
INSERT INTO Equipe VALUES (127,'KOR');
INSERT INTO Equipe VALUES (128,'BRA');
INSERT INTO Equipe VALUES (129,'CAN');
INSERT INTO Equipe VALUES (130,'POL');
INSERT INTO Equipe VALUES (131,'NOR');
INSERT INTO Equipe VALUES (132,'GER');
INSERT INTO Equipe VALUES (133,'AUT');
INSERT INTO Equipe VALUES (134,'FRA');
INSERT INTO Equipe VALUES (135,'JPN');
INSERT INTO Equipe VALUES (136,'USA');
INSERT INTO Equipe VALUES (137,'CZE');
INSERT INTO Equipe VALUES (138,'ITA');
INSERT INTO Equipe VALUES (139,'RUS');
INSERT INTO Equipe VALUES (140,'CAN');
INSERT INTO Equipe VALUES (141,'SWE');
INSERT INTO Equipe VALUES (142,'GBR');
INSERT INTO Equipe VALUES (143,'SUI');
INSERT INTO Equipe VALUES (144,'JPN');
INSERT INTO Equipe VALUES (145,'DEN');
INSERT INTO Equipe VALUES (146,'CHN');
INSERT INTO Equipe VALUES (147,'KOR');
INSERT INTO Equipe VALUES (148,'CAN');
INSERT INTO Equipe VALUES (149,'GBR');
INSERT INTO Equipe VALUES (150,'SWE');
INSERT INTO Equipe VALUES (151,'CHN');
INSERT INTO Equipe VALUES (152,'NOR');
INSERT INTO Equipe VALUES (153,'DEN');
INSERT INTO Equipe VALUES (154,'RUS');
INSERT INTO Equipe VALUES (155,'SUI');
INSERT INTO Equipe VALUES (156,'CAN');
INSERT INTO Equipe VALUES (157,'USA');
INSERT INTO Equipe VALUES (158,'SUI');
INSERT INTO Equipe VALUES (159,'SWE');
INSERT INTO Equipe VALUES (160,'FIN');
INSERT INTO Equipe VALUES (161,'RUS');
INSERT INTO Equipe VALUES (162,'GER');
INSERT INTO Equipe VALUES (163,'JPN');
INSERT INTO Equipe VALUES (164,'CAN');
INSERT INTO Equipe VALUES (165,'SWE');
INSERT INTO Equipe VALUES (166,'FIN');
INSERT INTO Equipe VALUES (167,'USA');
INSERT INTO Equipe VALUES (168,'GER');
INSERT INTO Equipe VALUES (169,'AUT');
INSERT INTO Equipe VALUES (170,'LAT');
INSERT INTO Equipe VALUES (171,'CAN');
INSERT INTO Equipe VALUES (172,'RUS');
INSERT INTO Equipe VALUES (173,'ITA');
INSERT INTO Equipe VALUES (174,'ITA');
INSERT INTO Equipe VALUES (175,'GER');
INSERT INTO Equipe VALUES (176,'RUS');
INSERT INTO Equipe VALUES (177,'LAT');
INSERT INTO Equipe VALUES (178,'USA');
INSERT INTO Equipe VALUES (179,'SVK');
INSERT INTO Equipe VALUES (180,'CZE');
INSERT INTO Equipe VALUES (181,'USA');
INSERT INTO Equipe VALUES (182,'POL');
INSERT INTO Equipe VALUES (183,'SVK');
INSERT INTO Equipe VALUES (184,'UKR');
INSERT INTO Equipe VALUES (185,'KOR');
INSERT INTO Equipe VALUES (186,'AUT');
INSERT INTO Equipe VALUES (187,'GER');
INSERT INTO Equipe VALUES (188,'RUS');
INSERT INTO Equipe VALUES (189,'LAT');
INSERT INTO Equipe VALUES (190,'CAN');
INSERT INTO Equipe VALUES (191,'ITA');
INSERT INTO Equipe VALUES (192,'USA');
INSERT INTO Equipe VALUES (193,'AUT');
INSERT INTO Equipe VALUES (194,'POL');
INSERT INTO Equipe VALUES (195,'CZE');
INSERT INTO Equipe VALUES (196,'SVK');
INSERT INTO Equipe VALUES (197,'UKR');
INSERT INTO Equipe VALUES (198,'KOR');
INSERT INTO Equipe VALUES (199,'RUS');
INSERT INTO Equipe VALUES (200,'RUS');
INSERT INTO Equipe VALUES (201,'GER');
INSERT INTO Equipe VALUES (202,'USA');
INSERT INTO Equipe VALUES (203,'CAN');
INSERT INTO Equipe VALUES (204,'RUS');
INSERT INTO Equipe VALUES (205,'FRA');
INSERT INTO Equipe VALUES (206,'RUS');
INSERT INTO Equipe VALUES (207,'ITA');
INSERT INTO Equipe VALUES (208,'CAN');
INSERT INTO Equipe VALUES (209,'USA');
INSERT INTO Equipe VALUES (210,'USA');
INSERT INTO Equipe VALUES (211,'GBR');
INSERT INTO Equipe VALUES (212,'GER');
INSERT INTO Equipe VALUES (213,'AZE');
INSERT INTO Equipe VALUES (214,'ESP');
INSERT INTO Equipe VALUES (215,'ITA');
INSERT INTO Equipe VALUES (216,'FRA');
INSERT INTO Equipe VALUES (217,'RUS');
INSERT INTO Equipe VALUES (218,'LTU');
INSERT INTO Equipe VALUES (219,'CAN');
INSERT INTO Equipe VALUES (220,'GER');
INSERT INTO Equipe VALUES (221,'AUS');
INSERT INTO Equipe VALUES (222,'JPN');
INSERT INTO Equipe VALUES (223,'TUR');
INSERT INTO Equipe VALUES (224,'CHN');
INSERT INTO Equipe VALUES (225,'UKR');
INSERT INTO Equipe VALUES (226,'RUS');
INSERT INTO Equipe VALUES (227,'CAN');
INSERT INTO Equipe VALUES (228,'USA');
INSERT INTO Equipe VALUES (229,'ITA');
INSERT INTO Equipe VALUES (230,'JPN');
INSERT INTO Equipe VALUES (231,'FRA');
INSERT INTO Equipe VALUES (232,'CHN');
INSERT INTO Equipe VALUES (233,'GER');
INSERT INTO Equipe VALUES (234,'UKR');
INSERT INTO Equipe VALUES (235,'GBR');
INSERT INTO Equipe VALUES (236,'NED');
INSERT INTO Equipe VALUES (237,'POL');
INSERT INTO Equipe VALUES (238,'NED');
INSERT INTO Equipe VALUES (239,'KOR');
INSERT INTO Equipe VALUES (240,'KOR');
INSERT INTO Equipe VALUES (241,'CAN');
INSERT INTO Equipe VALUES (242,'ITA');
INSERT INTO Equipe VALUES (243,'CHN');
INSERT INTO Equipe VALUES (244,'RUS');
INSERT INTO Equipe VALUES (245,'USA');
INSERT INTO Equipe VALUES (246,'CHN');
INSERT INTO Equipe VALUES (247,'NED');
INSERT INTO Equipe VALUES (248,'KAZ');
INSERT INTO Equipe VALUES (249,'GER');
INSERT INTO Equipe VALUES (250,'AUT');
INSERT INTO Equipe VALUES (251,'JPN');
INSERT INTO Equipe VALUES (252,'POL');
INSERT INTO Equipe VALUES (253,'SLO');
INSERT INTO Equipe VALUES (254,'NOR');
INSERT INTO Equipe VALUES (255,'CZE');
INSERT INTO Equipe VALUES (256,'FIN');
INSERT INTO Equipe VALUES (257,'RUS');
INSERT INTO Equipe VALUES (258,'USA');
INSERT INTO Equipe VALUES (259,'KOR');
INSERT INTO Equipe VALUES (260,'CAN');
INSERT INTO Equipe VALUES (261,'SWE');
INSERT INTO Equipe VALUES (262,'FIN');
INSERT INTO Equipe VALUES (263,'GER');
INSERT INTO Equipe VALUES (264,'FRA');
INSERT INTO Equipe VALUES (265,'NOR');
INSERT INTO Equipe VALUES (266,'RUS');
INSERT INTO Equipe VALUES (267,'POL');
INSERT INTO Equipe VALUES (268,'ITA');
INSERT INTO Equipe VALUES (269,'USA');
INSERT INTO Equipe VALUES (270,'CZE');
INSERT INTO Equipe VALUES (271,'SLO');
INSERT INTO Equipe VALUES (272,'UKR');
INSERT INTO Equipe VALUES (273,'AUT');
INSERT INTO Equipe VALUES (274,'CAN');
INSERT INTO Equipe VALUES (275,'NOR');
INSERT INTO Equipe VALUES (276,'FIN');
INSERT INTO Equipe VALUES (277,'SWE');
INSERT INTO Equipe VALUES (278,'GER');
INSERT INTO Equipe VALUES (279,'POL');
INSERT INTO Equipe VALUES (280,'RUS');
INSERT INTO Equipe VALUES (281,'SUI');
INSERT INTO Equipe VALUES (282,'USA');
INSERT INTO Equipe VALUES (283,'AUT');
INSERT INTO Equipe VALUES (284,'SLO');
INSERT INTO Equipe VALUES (285,'SWE');
INSERT INTO Equipe VALUES (286,'RUS');
INSERT INTO Equipe VALUES (287,'FRA');
INSERT INTO Equipe VALUES (288,'NOR');
INSERT INTO Equipe VALUES (289,'ITA');
INSERT INTO Equipe VALUES (290,'FIN');
INSERT INTO Equipe VALUES (291,'SUI');
INSERT INTO Equipe VALUES (292,'CZE');
INSERT INTO Equipe VALUES (293,'GER');
INSERT INTO Equipe VALUES (294,'EST');
INSERT INTO Equipe VALUES (295,'USA');
INSERT INTO Equipe VALUES (296,'CAN');
INSERT INTO Equipe VALUES (297,'KAZ');
INSERT INTO Equipe VALUES (298,'BLR');
INSERT INTO Equipe VALUES (299,'POL');
INSERT INTO Equipe VALUES (300,'JPN');
INSERT INTO Equipe VALUES (301,'FIN');
INSERT INTO Equipe VALUES (302,'RUS');
INSERT INTO Equipe VALUES (303,'SWE');
INSERT INTO Equipe VALUES (304,'NOR');
INSERT INTO Equipe VALUES (305,'SUI');
INSERT INTO Equipe VALUES (306,'USA');
INSERT INTO Equipe VALUES (307,'GER');
INSERT INTO Equipe VALUES (308,'KAZ');
INSERT INTO Equipe VALUES (309,'CZE');


INSERT INTO AthletesEquipe VALUES (1,107);
INSERT INTO AthletesEquipe VALUES (1,120);
INSERT INTO AthletesEquipe VALUES (1,92);
INSERT INTO AthletesEquipe VALUES (1,121);
INSERT INTO AthletesEquipe VALUES (2,21);
INSERT INTO AthletesEquipe VALUES (2,179);
INSERT INTO AthletesEquipe VALUES (2,280);
INSERT INTO AthletesEquipe VALUES (2,281);
INSERT INTO AthletesEquipe VALUES (3,30);
INSERT INTO AthletesEquipe VALUES (3,319);
INSERT INTO AthletesEquipe VALUES (3,82);
INSERT INTO AthletesEquipe VALUES (3,1909);
INSERT INTO AthletesEquipe VALUES (4,180);
INSERT INTO AthletesEquipe VALUES (4,235);
INSERT INTO AthletesEquipe VALUES (4,1756);
INSERT INTO AthletesEquipe VALUES (4,1757);
INSERT INTO AthletesEquipe VALUES (5,14);
INSERT INTO AthletesEquipe VALUES (5,779);
INSERT INTO AthletesEquipe VALUES (5,329);
INSERT INTO AthletesEquipe VALUES (5,1720);
INSERT INTO AthletesEquipe VALUES (6,439);
INSERT INTO AthletesEquipe VALUES (6,327);
INSERT INTO AthletesEquipe VALUES (6,328);
INSERT INTO AthletesEquipe VALUES (6,1734);
INSERT INTO AthletesEquipe VALUES (7,791);
INSERT INTO AthletesEquipe VALUES (7,792);
INSERT INTO AthletesEquipe VALUES (7,793);
INSERT INTO AthletesEquipe VALUES (7,1726);
INSERT INTO AthletesEquipe VALUES (8,480);
INSERT INTO AthletesEquipe VALUES (8,767);
INSERT INTO AthletesEquipe VALUES (8,771);
INSERT INTO AthletesEquipe VALUES (8,1751);
INSERT INTO AthletesEquipe VALUES (9,236);
INSERT INTO AthletesEquipe VALUES (9,1187);
INSERT INTO AthletesEquipe VALUES (9,1761);
INSERT INTO AthletesEquipe VALUES (9,1762);
INSERT INTO AthletesEquipe VALUES (10,408);
INSERT INTO AthletesEquipe VALUES (10,622);
INSERT INTO AthletesEquipe VALUES (10,1708);
INSERT INTO AthletesEquipe VALUES (10,1709);
INSERT INTO AthletesEquipe VALUES (11,29);
INSERT INTO AthletesEquipe VALUES (11,1188);
INSERT INTO AthletesEquipe VALUES (11,1749);
INSERT INTO AthletesEquipe VALUES (11,1750);
INSERT INTO AthletesEquipe VALUES (12,232);
INSERT INTO AthletesEquipe VALUES (12,756);
INSERT INTO AthletesEquipe VALUES (12,1186);
INSERT INTO AthletesEquipe VALUES (12,1741);
INSERT INTO AthletesEquipe VALUES (13,761);
INSERT INTO AthletesEquipe VALUES (13,1715);
INSERT INTO AthletesEquipe VALUES (13,1716);
INSERT INTO AthletesEquipe VALUES (13,1717);
INSERT INTO AthletesEquipe VALUES (14,525);
INSERT INTO AthletesEquipe VALUES (14,798);
INSERT INTO AthletesEquipe VALUES (14,799);
INSERT INTO AthletesEquipe VALUES (14,1736);
INSERT INTO AthletesEquipe VALUES (15,788);
INSERT INTO AthletesEquipe VALUES (15,1185);
INSERT INTO AthletesEquipe VALUES (15,1724);
INSERT INTO AthletesEquipe VALUES (15,1725);
INSERT INTO AthletesEquipe VALUES (16,773);
INSERT INTO AthletesEquipe VALUES (16,1731);
INSERT INTO AthletesEquipe VALUES (16,1732);
INSERT INTO AthletesEquipe VALUES (16,1733);
INSERT INTO AthletesEquipe VALUES (17,119);
INSERT INTO AthletesEquipe VALUES (17,37);
INSERT INTO AthletesEquipe VALUES (17,91);
INSERT INTO AthletesEquipe VALUES (17,155);
INSERT INTO AthletesEquipe VALUES (18,233);
INSERT INTO AthletesEquipe VALUES (18,234);
INSERT INTO AthletesEquipe VALUES (18,183);
INSERT INTO AthletesEquipe VALUES (18,282);
INSERT INTO AthletesEquipe VALUES (19,188);
INSERT INTO AthletesEquipe VALUES (19,173);
INSERT INTO AthletesEquipe VALUES (19,198);
INSERT INTO AthletesEquipe VALUES (19,214);
INSERT INTO AthletesEquipe VALUES (20,1);
INSERT INTO AthletesEquipe VALUES (20,6);
INSERT INTO AthletesEquipe VALUES (20,122);
INSERT INTO AthletesEquipe VALUES (20,1742);
INSERT INTO AthletesEquipe VALUES (21,566);
INSERT INTO AthletesEquipe VALUES (21,567);
INSERT INTO AthletesEquipe VALUES (21,326);
INSERT INTO AthletesEquipe VALUES (21,383);
INSERT INTO AthletesEquipe VALUES (22,449);
INSERT INTO AthletesEquipe VALUES (22,616);
INSERT INTO AthletesEquipe VALUES (22,790);
INSERT INTO AthletesEquipe VALUES (22,384);
INSERT INTO AthletesEquipe VALUES (23,481);
INSERT INTO AthletesEquipe VALUES (23,768);
INSERT INTO AthletesEquipe VALUES (23,769);
INSERT INTO AthletesEquipe VALUES (23,770);
INSERT INTO AthletesEquipe VALUES (24,330);
INSERT INTO AthletesEquipe VALUES (24,801);
INSERT INTO AthletesEquipe VALUES (24,25);
INSERT INTO AthletesEquipe VALUES (24,1728);
INSERT INTO AthletesEquipe VALUES (25,398);
INSERT INTO AthletesEquipe VALUES (25,758);
INSERT INTO AthletesEquipe VALUES (25,760);
INSERT INTO AthletesEquipe VALUES (25,1723);
INSERT INTO AthletesEquipe VALUES (26,452);
INSERT INTO AthletesEquipe VALUES (26,106);
INSERT INTO AthletesEquipe VALUES (26,1729);
INSERT INTO AthletesEquipe VALUES (26,1744);
INSERT INTO AthletesEquipe VALUES (27,174);
INSERT INTO AthletesEquipe VALUES (27,197);
INSERT INTO AthletesEquipe VALUES (27,1754);
INSERT INTO AthletesEquipe VALUES (27,1755);
INSERT INTO AthletesEquipe VALUES (28,302);
INSERT INTO AthletesEquipe VALUES (28,526);
INSERT INTO AthletesEquipe VALUES (28,527);
INSERT INTO AthletesEquipe VALUES (28,1737);
INSERT INTO AthletesEquipe VALUES (29,218);
INSERT INTO AthletesEquipe VALUES (29,778);
INSERT INTO AthletesEquipe VALUES (29,1718);
INSERT INTO AthletesEquipe VALUES (29,1719);
INSERT INTO AthletesEquipe VALUES (30,796);
INSERT INTO AthletesEquipe VALUES (30,797);
INSERT INTO AthletesEquipe VALUES (30,1759);
INSERT INTO AthletesEquipe VALUES (30,1760);
INSERT INTO AthletesEquipe VALUES (31,418);
INSERT INTO AthletesEquipe VALUES (31,781);
INSERT INTO AthletesEquipe VALUES (31,783);
INSERT INTO AthletesEquipe VALUES (31,1713);
INSERT INTO AthletesEquipe VALUES (32,454);
INSERT INTO AthletesEquipe VALUES (32,794);
INSERT INTO AthletesEquipe VALUES (32,795);
INSERT INTO AthletesEquipe VALUES (32,1910);
INSERT INTO AthletesEquipe VALUES (33,428);
INSERT INTO AthletesEquipe VALUES (33,772);
INSERT INTO AthletesEquipe VALUES (33,774);
INSERT INTO AthletesEquipe VALUES (33,1730);
INSERT INTO AthletesEquipe VALUES (34,752);
INSERT INTO AthletesEquipe VALUES (34,754);
INSERT INTO AthletesEquipe VALUES (34,755);
INSERT INTO AthletesEquipe VALUES (34,1739);
INSERT INTO AthletesEquipe VALUES (35,623);
INSERT INTO AthletesEquipe VALUES (35,751);
INSERT INTO AthletesEquipe VALUES (35,1711);
INSERT INTO AthletesEquipe VALUES (35,1712);
INSERT INTO AthletesEquipe VALUES (36,1);
INSERT INTO AthletesEquipe VALUES (36,30);
INSERT INTO AthletesEquipe VALUES (36,6);
INSERT INTO AthletesEquipe VALUES (36,82);
INSERT INTO AthletesEquipe VALUES (37,174);
INSERT INTO AthletesEquipe VALUES (37,197);
INSERT INTO AthletesEquipe VALUES (37,180);
INSERT INTO AthletesEquipe VALUES (37,235);
INSERT INTO AthletesEquipe VALUES (38,326);
INSERT INTO AthletesEquipe VALUES (38,327);
INSERT INTO AthletesEquipe VALUES (38,328);
INSERT INTO AthletesEquipe VALUES (38,383);
INSERT INTO AthletesEquipe VALUES (39,21);
INSERT INTO AthletesEquipe VALUES (39,179);
INSERT INTO AthletesEquipe VALUES (39,91);
INSERT INTO AthletesEquipe VALUES (39,382);
INSERT INTO AthletesEquipe VALUES (40,302);
INSERT INTO AthletesEquipe VALUES (40,525);
INSERT INTO AthletesEquipe VALUES (40,526);
INSERT INTO AthletesEquipe VALUES (40,33);
INSERT INTO AthletesEquipe VALUES (41,330);
INSERT INTO AthletesEquipe VALUES (41,800);
INSERT INTO AthletesEquipe VALUES (41,25);
INSERT INTO AthletesEquipe VALUES (41,213);
INSERT INTO AthletesEquipe VALUES (42,398);
INSERT INTO AthletesEquipe VALUES (42,758);
INSERT INTO AthletesEquipe VALUES (42,1911);
INSERT INTO AthletesEquipe VALUES (42,1912);
INSERT INTO AthletesEquipe VALUES (43,454);
INSERT INTO AthletesEquipe VALUES (43,474);
INSERT INTO AthletesEquipe VALUES (43,792);
INSERT INTO AthletesEquipe VALUES (43,1726);
INSERT INTO AthletesEquipe VALUES (44,188);
INSERT INTO AthletesEquipe VALUES (44,1913);
INSERT INTO AthletesEquipe VALUES (44,1747);
INSERT INTO AthletesEquipe VALUES (44,1748);
INSERT INTO AthletesEquipe VALUES (45,778);
INSERT INTO AthletesEquipe VALUES (45,779);
INSERT INTO AthletesEquipe VALUES (45,842);
INSERT INTO AthletesEquipe VALUES (45,1718);
INSERT INTO AthletesEquipe VALUES (46,767);
INSERT INTO AthletesEquipe VALUES (46,768);
INSERT INTO AthletesEquipe VALUES (46,769);
INSERT INTO AthletesEquipe VALUES (46,771);
INSERT INTO AthletesEquipe VALUES (47,543);
INSERT INTO AthletesEquipe VALUES (47,236);
INSERT INTO AthletesEquipe VALUES (47,797);
INSERT INTO AthletesEquipe VALUES (47,1762);
INSERT INTO AthletesEquipe VALUES (48,408);
INSERT INTO AthletesEquipe VALUES (48,622);
INSERT INTO AthletesEquipe VALUES (48,623);
INSERT INTO AthletesEquipe VALUES (48,751);
INSERT INTO AthletesEquipe VALUES (49,752);
INSERT INTO AthletesEquipe VALUES (49,232);
INSERT INTO AthletesEquipe VALUES (49,1739);
INSERT INTO AthletesEquipe VALUES (49,1741);
INSERT INTO AthletesEquipe VALUES (50,772);
INSERT INTO AthletesEquipe VALUES (50,773);
INSERT INTO AthletesEquipe VALUES (50,774);
INSERT INTO AthletesEquipe VALUES (50,1733);
INSERT INTO AthletesEquipe VALUES (51,19);
INSERT INTO AthletesEquipe VALUES (51,233);
INSERT INTO AthletesEquipe VALUES (51,1750);
INSERT INTO AthletesEquipe VALUES (51,282);
INSERT INTO AthletesEquipe VALUES (52,1914);
INSERT INTO AthletesEquipe VALUES (52,1915);
INSERT INTO AthletesEquipe VALUES (53,1916);
INSERT INTO AthletesEquipe VALUES (53,1917);
INSERT INTO AthletesEquipe VALUES (54,1918);
INSERT INTO AthletesEquipe VALUES (54,1919);
INSERT INTO AthletesEquipe VALUES (55,1920);
INSERT INTO AthletesEquipe VALUES (55,1921);
INSERT INTO AthletesEquipe VALUES (56,1922);
INSERT INTO AthletesEquipe VALUES (56,1923);
INSERT INTO AthletesEquipe VALUES (57,1924);
INSERT INTO AthletesEquipe VALUES (57,1925);
INSERT INTO AthletesEquipe VALUES (58,1926);
INSERT INTO AthletesEquipe VALUES (58,1927);
INSERT INTO AthletesEquipe VALUES (59,1928);
INSERT INTO AthletesEquipe VALUES (59,1929);
INSERT INTO AthletesEquipe VALUES (60,1930);
INSERT INTO AthletesEquipe VALUES (60,1931);
INSERT INTO AthletesEquipe VALUES (61,1932);
INSERT INTO AthletesEquipe VALUES (61,1933);
INSERT INTO AthletesEquipe VALUES (62,1934);
INSERT INTO AthletesEquipe VALUES (62,1935);
INSERT INTO AthletesEquipe VALUES (63,1936);
INSERT INTO AthletesEquipe VALUES (63,1937);
INSERT INTO AthletesEquipe VALUES (64,1938);
INSERT INTO AthletesEquipe VALUES (64,1939);
INSERT INTO AthletesEquipe VALUES (65,1940);
INSERT INTO AthletesEquipe VALUES (65,1941);
INSERT INTO AthletesEquipe VALUES (66,1942);
INSERT INTO AthletesEquipe VALUES (66,1943);
INSERT INTO AthletesEquipe VALUES (67,1944);
INSERT INTO AthletesEquipe VALUES (67,1945);
INSERT INTO AthletesEquipe VALUES (68,1946);
INSERT INTO AthletesEquipe VALUES (68,1947);
INSERT INTO AthletesEquipe VALUES (69,1948);
INSERT INTO AthletesEquipe VALUES (69,1949);
INSERT INTO AthletesEquipe VALUES (70,1950);
INSERT INTO AthletesEquipe VALUES (70,1951);
INSERT INTO AthletesEquipe VALUES (71,1952);
INSERT INTO AthletesEquipe VALUES (71,1953);
INSERT INTO AthletesEquipe VALUES (72,1954);
INSERT INTO AthletesEquipe VALUES (72,1955);
INSERT INTO AthletesEquipe VALUES (73,1956);
INSERT INTO AthletesEquipe VALUES (73,1957);
INSERT INTO AthletesEquipe VALUES (74,1958);
INSERT INTO AthletesEquipe VALUES (74,1959);
INSERT INTO AthletesEquipe VALUES (75,1960);
INSERT INTO AthletesEquipe VALUES (75,1961);
INSERT INTO AthletesEquipe VALUES (76,1962);
INSERT INTO AthletesEquipe VALUES (76,1963);
INSERT INTO AthletesEquipe VALUES (77,1964);
INSERT INTO AthletesEquipe VALUES (77,1965);
INSERT INTO AthletesEquipe VALUES (78,1966);
INSERT INTO AthletesEquipe VALUES (78,1967);
INSERT INTO AthletesEquipe VALUES (79,1968);
INSERT INTO AthletesEquipe VALUES (79,1969);
INSERT INTO AthletesEquipe VALUES (80,1970);
INSERT INTO AthletesEquipe VALUES (80,1971);
INSERT INTO AthletesEquipe VALUES (81,1972);
INSERT INTO AthletesEquipe VALUES (81,1973);
INSERT INTO AthletesEquipe VALUES (82,1974);
INSERT INTO AthletesEquipe VALUES (82,1975);
INSERT INTO AthletesEquipe VALUES (83,1976);
INSERT INTO AthletesEquipe VALUES (83,1977);
INSERT INTO AthletesEquipe VALUES (84,1978);
INSERT INTO AthletesEquipe VALUES (84,1979);
INSERT INTO AthletesEquipe VALUES (85,1980);
INSERT INTO AthletesEquipe VALUES (85,1981);
INSERT INTO AthletesEquipe VALUES (86,1982);
INSERT INTO AthletesEquipe VALUES (86,1983);
INSERT INTO AthletesEquipe VALUES (87,1984);
INSERT INTO AthletesEquipe VALUES (87,1985);
INSERT INTO AthletesEquipe VALUES (88,1986);
INSERT INTO AthletesEquipe VALUES (88,1987);
INSERT INTO AthletesEquipe VALUES (89,1988);
INSERT INTO AthletesEquipe VALUES (89,1989);
INSERT INTO AthletesEquipe VALUES (90,1990);
INSERT INTO AthletesEquipe VALUES (90,1991);
INSERT INTO AthletesEquipe VALUES (91,1992);
INSERT INTO AthletesEquipe VALUES (91,1993);
INSERT INTO AthletesEquipe VALUES (92,1994);
INSERT INTO AthletesEquipe VALUES (92,1995);
INSERT INTO AthletesEquipe VALUES (93,1996);
INSERT INTO AthletesEquipe VALUES (93,1997);
INSERT INTO AthletesEquipe VALUES (94,1998);
INSERT INTO AthletesEquipe VALUES (94,1999);
INSERT INTO AthletesEquipe VALUES (95,2000);
INSERT INTO AthletesEquipe VALUES (95,2001);
INSERT INTO AthletesEquipe VALUES (96,2002);
INSERT INTO AthletesEquipe VALUES (96,2003);
INSERT INTO AthletesEquipe VALUES (97,2004);
INSERT INTO AthletesEquipe VALUES (97,2005);
INSERT INTO AthletesEquipe VALUES (98,2006);
INSERT INTO AthletesEquipe VALUES (98,2007);
INSERT INTO AthletesEquipe VALUES (99,2008);
INSERT INTO AthletesEquipe VALUES (99,2009);
INSERT INTO AthletesEquipe VALUES (100,2010);
INSERT INTO AthletesEquipe VALUES (100,2011);
INSERT INTO AthletesEquipe VALUES (101,1952);
INSERT INTO AthletesEquipe VALUES (101,1953);
INSERT INTO AthletesEquipe VALUES (101,2012);
INSERT INTO AthletesEquipe VALUES (101,2013);
INSERT INTO AthletesEquipe VALUES (102,1960);
INSERT INTO AthletesEquipe VALUES (102,1961);
INSERT INTO AthletesEquipe VALUES (102,2014);
INSERT INTO AthletesEquipe VALUES (102,2015);
INSERT INTO AthletesEquipe VALUES (103,1956);
INSERT INTO AthletesEquipe VALUES (103,2016);
INSERT INTO AthletesEquipe VALUES (103,1974);
INSERT INTO AthletesEquipe VALUES (103,1957);
INSERT INTO AthletesEquipe VALUES (104,1958);
INSERT INTO AthletesEquipe VALUES (104,1959);
INSERT INTO AthletesEquipe VALUES (104,2017);
INSERT INTO AthletesEquipe VALUES (104,2018);
INSERT INTO AthletesEquipe VALUES (105,2019);
INSERT INTO AthletesEquipe VALUES (105,2020);
INSERT INTO AthletesEquipe VALUES (105,2021);
INSERT INTO AthletesEquipe VALUES (105,2022);
INSERT INTO AthletesEquipe VALUES (106,2023);
INSERT INTO AthletesEquipe VALUES (106,1980);
INSERT INTO AthletesEquipe VALUES (106,1981);
INSERT INTO AthletesEquipe VALUES (106,2024);
INSERT INTO AthletesEquipe VALUES (107,1972);
INSERT INTO AthletesEquipe VALUES (107,1973);
INSERT INTO AthletesEquipe VALUES (107,2025);
INSERT INTO AthletesEquipe VALUES (107,2026);
INSERT INTO AthletesEquipe VALUES (108,1954);
INSERT INTO AthletesEquipe VALUES (108,2027);
INSERT INTO AthletesEquipe VALUES (108,1955);
INSERT INTO AthletesEquipe VALUES (108,1970);
INSERT INTO AthletesEquipe VALUES (109,2028);
INSERT INTO AthletesEquipe VALUES (109,1968);
INSERT INTO AthletesEquipe VALUES (109,2029);
INSERT INTO AthletesEquipe VALUES (109,1969);
INSERT INTO AthletesEquipe VALUES (110,2030);
INSERT INTO AthletesEquipe VALUES (110,1966);
INSERT INTO AthletesEquipe VALUES (110,1967);
INSERT INTO AthletesEquipe VALUES (110,2031);
INSERT INTO AthletesEquipe VALUES (111,1988);
INSERT INTO AthletesEquipe VALUES (111,2032);
INSERT INTO AthletesEquipe VALUES (111,2033);
INSERT INTO AthletesEquipe VALUES (111,1989);
INSERT INTO AthletesEquipe VALUES (112,1976);
INSERT INTO AthletesEquipe VALUES (112,2034);
INSERT INTO AthletesEquipe VALUES (112,1977);
INSERT INTO AthletesEquipe VALUES (112,2035);
INSERT INTO AthletesEquipe VALUES (113,1962);
INSERT INTO AthletesEquipe VALUES (113,2036);
INSERT INTO AthletesEquipe VALUES (113,2037);
INSERT INTO AthletesEquipe VALUES (113,1965);
INSERT INTO AthletesEquipe VALUES (114,2038);
INSERT INTO AthletesEquipe VALUES (114,1982);
INSERT INTO AthletesEquipe VALUES (114,2039);
INSERT INTO AthletesEquipe VALUES (114,1983);
INSERT INTO AthletesEquipe VALUES (115,2040);
INSERT INTO AthletesEquipe VALUES (115,2041);
INSERT INTO AthletesEquipe VALUES (115,2042);
INSERT INTO AthletesEquipe VALUES (115,2043);
INSERT INTO AthletesEquipe VALUES (116,2044);
INSERT INTO AthletesEquipe VALUES (116,1998);
INSERT INTO AthletesEquipe VALUES (116,2045);
INSERT INTO AthletesEquipe VALUES (116,1999);
INSERT INTO AthletesEquipe VALUES (117,1990);
INSERT INTO AthletesEquipe VALUES (117,1991);
INSERT INTO AthletesEquipe VALUES (117,2046);
INSERT INTO AthletesEquipe VALUES (117,2047);
INSERT INTO AthletesEquipe VALUES (118,2048);
INSERT INTO AthletesEquipe VALUES (118,1978);
INSERT INTO AthletesEquipe VALUES (118,2049);
INSERT INTO AthletesEquipe VALUES (118,1979);
INSERT INTO AthletesEquipe VALUES (119,1996);
INSERT INTO AthletesEquipe VALUES (119,1997);
INSERT INTO AthletesEquipe VALUES (119,2050);
INSERT INTO AthletesEquipe VALUES (119,2051);
INSERT INTO AthletesEquipe VALUES (120,1986);
INSERT INTO AthletesEquipe VALUES (120,2052);
INSERT INTO AthletesEquipe VALUES (120,2001);
INSERT INTO AthletesEquipe VALUES (120,1987);
INSERT INTO AthletesEquipe VALUES (121,1994);
INSERT INTO AthletesEquipe VALUES (121,2053);
INSERT INTO AthletesEquipe VALUES (121,2054);
INSERT INTO AthletesEquipe VALUES (122,2002);
INSERT INTO AthletesEquipe VALUES (122,2003);
INSERT INTO AthletesEquipe VALUES (122,2055);
INSERT INTO AthletesEquipe VALUES (122,2056);
INSERT INTO AthletesEquipe VALUES (123,2057);
INSERT INTO AthletesEquipe VALUES (123,2058);
INSERT INTO AthletesEquipe VALUES (123,2059);
INSERT INTO AthletesEquipe VALUES (123,2060);
INSERT INTO AthletesEquipe VALUES (124,1985);
INSERT INTO AthletesEquipe VALUES (124,2061);
INSERT INTO AthletesEquipe VALUES (124,2062);
INSERT INTO AthletesEquipe VALUES (124,2063);
INSERT INTO AthletesEquipe VALUES (125,2064);
INSERT INTO AthletesEquipe VALUES (125,2065);
INSERT INTO AthletesEquipe VALUES (125,2066);
INSERT INTO AthletesEquipe VALUES (125,2067);
INSERT INTO AthletesEquipe VALUES (126,2006);
INSERT INTO AthletesEquipe VALUES (126,2007);
INSERT INTO AthletesEquipe VALUES (126,2068);
INSERT INTO AthletesEquipe VALUES (126,2069);
INSERT INTO AthletesEquipe VALUES (127,2000);
INSERT INTO AthletesEquipe VALUES (127,2070);
INSERT INTO AthletesEquipe VALUES (127,2071);
INSERT INTO AthletesEquipe VALUES (127,2072);
INSERT INTO AthletesEquipe VALUES (128,2073);
INSERT INTO AthletesEquipe VALUES (128,2074);
INSERT INTO AthletesEquipe VALUES (128,2075);
INSERT INTO AthletesEquipe VALUES (128,2076);
INSERT INTO AthletesEquipe VALUES (129,1963);
INSERT INTO AthletesEquipe VALUES (129,1964);
INSERT INTO AthletesEquipe VALUES (129,2077);
INSERT INTO AthletesEquipe VALUES (129,2078);
INSERT INTO AthletesEquipe VALUES (130,2004);
INSERT INTO AthletesEquipe VALUES (130,2079);
INSERT INTO AthletesEquipe VALUES (130,2005);
INSERT INTO AthletesEquipe VALUES (130,2080);
INSERT INTO AthletesEquipe VALUES (131,125);
INSERT INTO AthletesEquipe VALUES (131,47);
INSERT INTO AthletesEquipe VALUES (131,96);
INSERT INTO AthletesEquipe VALUES (131,52);
INSERT INTO AthletesEquipe VALUES (132,165);
INSERT INTO AthletesEquipe VALUES (132,61);
INSERT INTO AthletesEquipe VALUES (132,201);
INSERT INTO AthletesEquipe VALUES (132,209);
INSERT INTO AthletesEquipe VALUES (133,35);
INSERT INTO AthletesEquipe VALUES (133,78);
INSERT INTO AthletesEquipe VALUES (133,79);
INSERT INTO AthletesEquipe VALUES (133,346);
INSERT INTO AthletesEquipe VALUES (134,430);
INSERT INTO AthletesEquipe VALUES (134,582);
INSERT INTO AthletesEquipe VALUES (134,583);
INSERT INTO AthletesEquipe VALUES (134,108);
INSERT INTO AthletesEquipe VALUES (135,224);
INSERT INTO AthletesEquipe VALUES (135,2081);
INSERT INTO AthletesEquipe VALUES (135,981);
INSERT INTO AthletesEquipe VALUES (135,1227);
INSERT INTO AthletesEquipe VALUES (136,216);
INSERT INTO AthletesEquipe VALUES (136,64);
INSERT INTO AthletesEquipe VALUES (136,989);
INSERT INTO AthletesEquipe VALUES (136,990);
INSERT INTO AthletesEquipe VALUES (137,424);
INSERT INTO AthletesEquipe VALUES (137,426);
INSERT INTO AthletesEquipe VALUES (137,991);
INSERT INTO AthletesEquipe VALUES (137,1215);
INSERT INTO AthletesEquipe VALUES (138,315);
INSERT INTO AthletesEquipe VALUES (138,982);
INSERT INTO AthletesEquipe VALUES (138,983);
INSERT INTO AthletesEquipe VALUES (138,1231);
INSERT INTO AthletesEquipe VALUES (139,2082);
INSERT INTO AthletesEquipe VALUES (139,978);
INSERT INTO AthletesEquipe VALUES (139,1229);
INSERT INTO AthletesEquipe VALUES (139,2083);
INSERT INTO AthletesEquipe VALUES (140,374);
INSERT INTO AthletesEquipe VALUES (140,2084);
INSERT INTO AthletesEquipe VALUES (140,2085);
INSERT INTO AthletesEquipe VALUES (140,2086);
INSERT INTO AthletesEquipe VALUES (140,2087);
INSERT INTO AthletesEquipe VALUES (141,2088);
INSERT INTO AthletesEquipe VALUES (141,2089);
INSERT INTO AthletesEquipe VALUES (141,2090);
INSERT INTO AthletesEquipe VALUES (141,2091);
INSERT INTO AthletesEquipe VALUES (141,2092);
INSERT INTO AthletesEquipe VALUES (142,2093);
INSERT INTO AthletesEquipe VALUES (142,2094);
INSERT INTO AthletesEquipe VALUES (142,2095);
INSERT INTO AthletesEquipe VALUES (142,2096);
INSERT INTO AthletesEquipe VALUES (142,2097);
INSERT INTO AthletesEquipe VALUES (143,2098);
INSERT INTO AthletesEquipe VALUES (143,2099);
INSERT INTO AthletesEquipe VALUES (143,2100);
INSERT INTO AthletesEquipe VALUES (143,2101);
INSERT INTO AthletesEquipe VALUES (143,2102);
INSERT INTO AthletesEquipe VALUES (144,2103);
INSERT INTO AthletesEquipe VALUES (144,2104);
INSERT INTO AthletesEquipe VALUES (144,2105);
INSERT INTO AthletesEquipe VALUES (144,2106);
INSERT INTO AthletesEquipe VALUES (144,2107);
INSERT INTO AthletesEquipe VALUES (145,2108);
INSERT INTO AthletesEquipe VALUES (145,2109);
INSERT INTO AthletesEquipe VALUES (145,2110);
INSERT INTO AthletesEquipe VALUES (145,2111);
INSERT INTO AthletesEquipe VALUES (145,2112);
INSERT INTO AthletesEquipe VALUES (146,2113);
INSERT INTO AthletesEquipe VALUES (146,2114);
INSERT INTO AthletesEquipe VALUES (146,2115);
INSERT INTO AthletesEquipe VALUES (146,2116);
INSERT INTO AthletesEquipe VALUES (146,2117);
INSERT INTO AthletesEquipe VALUES (147,2118);
INSERT INTO AthletesEquipe VALUES (147,2119);
INSERT INTO AthletesEquipe VALUES (147,2120);
INSERT INTO AthletesEquipe VALUES (147,2121);
INSERT INTO AthletesEquipe VALUES (147,2122);
INSERT INTO AthletesEquipe VALUES (148,2123);
INSERT INTO AthletesEquipe VALUES (148,2124);
INSERT INTO AthletesEquipe VALUES (148,2125);
INSERT INTO AthletesEquipe VALUES (148,2126);
INSERT INTO AthletesEquipe VALUES (148,2127);
INSERT INTO AthletesEquipe VALUES (149,2128);
INSERT INTO AthletesEquipe VALUES (149,2129);
INSERT INTO AthletesEquipe VALUES (149,2130);
INSERT INTO AthletesEquipe VALUES (149,2131);
INSERT INTO AthletesEquipe VALUES (149,2132);
INSERT INTO AthletesEquipe VALUES (150,2133);
INSERT INTO AthletesEquipe VALUES (150,2134);
INSERT INTO AthletesEquipe VALUES (150,2135);
INSERT INTO AthletesEquipe VALUES (150,2136);
INSERT INTO AthletesEquipe VALUES (150,2137);
INSERT INTO AthletesEquipe VALUES (151,2138);
INSERT INTO AthletesEquipe VALUES (151,2139);
INSERT INTO AthletesEquipe VALUES (151,2140);
INSERT INTO AthletesEquipe VALUES (151,2141);
INSERT INTO AthletesEquipe VALUES (151,2142);
INSERT INTO AthletesEquipe VALUES (152,2143);
INSERT INTO AthletesEquipe VALUES (152,2144);
INSERT INTO AthletesEquipe VALUES (152,2145);
INSERT INTO AthletesEquipe VALUES (152,2146);
INSERT INTO AthletesEquipe VALUES (152,2147);
INSERT INTO AthletesEquipe VALUES (153,2148);
INSERT INTO AthletesEquipe VALUES (153,2149);
INSERT INTO AthletesEquipe VALUES (153,2150);
INSERT INTO AthletesEquipe VALUES (153,2151);
INSERT INTO AthletesEquipe VALUES (153,2152);
INSERT INTO AthletesEquipe VALUES (154,2153);
INSERT INTO AthletesEquipe VALUES (154,2154);
INSERT INTO AthletesEquipe VALUES (154,2155);
INSERT INTO AthletesEquipe VALUES (154,2156);
INSERT INTO AthletesEquipe VALUES (154,2157);
INSERT INTO AthletesEquipe VALUES (155,2158);
INSERT INTO AthletesEquipe VALUES (155,2159);
INSERT INTO AthletesEquipe VALUES (155,2160);
INSERT INTO AthletesEquipe VALUES (155,2161);
INSERT INTO AthletesEquipe VALUES (156,2162);
INSERT INTO AthletesEquipe VALUES (156,2163);
INSERT INTO AthletesEquipe VALUES (156,2164);
INSERT INTO AthletesEquipe VALUES (156,2165);
INSERT INTO AthletesEquipe VALUES (156,2166);
INSERT INTO AthletesEquipe VALUES (156,2167);
INSERT INTO AthletesEquipe VALUES (156,2168);
INSERT INTO AthletesEquipe VALUES (156,2169);
INSERT INTO AthletesEquipe VALUES (156,2170);
INSERT INTO AthletesEquipe VALUES (156,2171);
INSERT INTO AthletesEquipe VALUES (156,2172);
INSERT INTO AthletesEquipe VALUES (156,2173);
INSERT INTO AthletesEquipe VALUES (156,2174);
INSERT INTO AthletesEquipe VALUES (156,2175);
INSERT INTO AthletesEquipe VALUES (156,2176);
INSERT INTO AthletesEquipe VALUES (156,2177);
INSERT INTO AthletesEquipe VALUES (156,2178);
INSERT INTO AthletesEquipe VALUES (156,2179);
INSERT INTO AthletesEquipe VALUES (156,2180);
INSERT INTO AthletesEquipe VALUES (156,2181);
INSERT INTO AthletesEquipe VALUES (156,2182);
INSERT INTO AthletesEquipe VALUES (157,2183);
INSERT INTO AthletesEquipe VALUES (157,2184);
INSERT INTO AthletesEquipe VALUES (157,2185);
INSERT INTO AthletesEquipe VALUES (157,2186);
INSERT INTO AthletesEquipe VALUES (157,2187);
INSERT INTO AthletesEquipe VALUES (157,2188);
INSERT INTO AthletesEquipe VALUES (157,2189);
INSERT INTO AthletesEquipe VALUES (157,2190);
INSERT INTO AthletesEquipe VALUES (157,2191);
INSERT INTO AthletesEquipe VALUES (157,2192);
INSERT INTO AthletesEquipe VALUES (157,2193);
INSERT INTO AthletesEquipe VALUES (157,2194);
INSERT INTO AthletesEquipe VALUES (157,2195);
INSERT INTO AthletesEquipe VALUES (157,2196);
INSERT INTO AthletesEquipe VALUES (157,2197);
INSERT INTO AthletesEquipe VALUES (157,2198);
INSERT INTO AthletesEquipe VALUES (157,2199);
INSERT INTO AthletesEquipe VALUES (157,2200);
INSERT INTO AthletesEquipe VALUES (157,2201);
INSERT INTO AthletesEquipe VALUES (157,2202);
INSERT INTO AthletesEquipe VALUES (157,2203);
INSERT INTO AthletesEquipe VALUES (158,2204);
INSERT INTO AthletesEquipe VALUES (158,2205);
INSERT INTO AthletesEquipe VALUES (158,2206);
INSERT INTO AthletesEquipe VALUES (158,2207);
INSERT INTO AthletesEquipe VALUES (158,2208);
INSERT INTO AthletesEquipe VALUES (158,2209);
INSERT INTO AthletesEquipe VALUES (158,2210);
INSERT INTO AthletesEquipe VALUES (158,2211);
INSERT INTO AthletesEquipe VALUES (158,2212);
INSERT INTO AthletesEquipe VALUES (158,2213);
INSERT INTO AthletesEquipe VALUES (158,2214);
INSERT INTO AthletesEquipe VALUES (158,2215);
INSERT INTO AthletesEquipe VALUES (158,2216);
INSERT INTO AthletesEquipe VALUES (158,2217);
INSERT INTO AthletesEquipe VALUES (158,2218);
INSERT INTO AthletesEquipe VALUES (158,2219);
INSERT INTO AthletesEquipe VALUES (158,2220);
INSERT INTO AthletesEquipe VALUES (158,2221);
INSERT INTO AthletesEquipe VALUES (158,2222);
INSERT INTO AthletesEquipe VALUES (158,2223);
INSERT INTO AthletesEquipe VALUES (158,2224);
INSERT INTO AthletesEquipe VALUES (164,2225);
INSERT INTO AthletesEquipe VALUES (164,2226);
INSERT INTO AthletesEquipe VALUES (164,2227);
INSERT INTO AthletesEquipe VALUES (164,2228);
INSERT INTO AthletesEquipe VALUES (164,2229);
INSERT INTO AthletesEquipe VALUES (164,2230);
INSERT INTO AthletesEquipe VALUES (164,2231);
INSERT INTO AthletesEquipe VALUES (164,2232);
INSERT INTO AthletesEquipe VALUES (164,2233);
INSERT INTO AthletesEquipe VALUES (164,2234);
INSERT INTO AthletesEquipe VALUES (164,2235);
INSERT INTO AthletesEquipe VALUES (164,2236);
INSERT INTO AthletesEquipe VALUES (164,2237);
INSERT INTO AthletesEquipe VALUES (164,2238);
INSERT INTO AthletesEquipe VALUES (164,2239);
INSERT INTO AthletesEquipe VALUES (164,2240);
INSERT INTO AthletesEquipe VALUES (164,2241);
INSERT INTO AthletesEquipe VALUES (164,2242);
INSERT INTO AthletesEquipe VALUES (164,2243);
INSERT INTO AthletesEquipe VALUES (164,2244);
INSERT INTO AthletesEquipe VALUES (164,2245);
INSERT INTO AthletesEquipe VALUES (164,2246);
INSERT INTO AthletesEquipe VALUES (164,2247);
INSERT INTO AthletesEquipe VALUES (164,2248);
INSERT INTO AthletesEquipe VALUES (164,2249);
INSERT INTO AthletesEquipe VALUES (165,2250);
INSERT INTO AthletesEquipe VALUES (165,2251);
INSERT INTO AthletesEquipe VALUES (165,2252);
INSERT INTO AthletesEquipe VALUES (165,2253);
INSERT INTO AthletesEquipe VALUES (165,2254);
INSERT INTO AthletesEquipe VALUES (165,2255);
INSERT INTO AthletesEquipe VALUES (165,2256);
INSERT INTO AthletesEquipe VALUES (165,2257);
INSERT INTO AthletesEquipe VALUES (165,2258);
INSERT INTO AthletesEquipe VALUES (165,2259);
INSERT INTO AthletesEquipe VALUES (165,2260);
INSERT INTO AthletesEquipe VALUES (165,2261);
INSERT INTO AthletesEquipe VALUES (165,2262);
INSERT INTO AthletesEquipe VALUES (165,2263);
INSERT INTO AthletesEquipe VALUES (165,2264);
INSERT INTO AthletesEquipe VALUES (165,2265);
INSERT INTO AthletesEquipe VALUES (165,2266);
INSERT INTO AthletesEquipe VALUES (165,2267);
INSERT INTO AthletesEquipe VALUES (165,2268);
INSERT INTO AthletesEquipe VALUES (165,2269);
INSERT INTO AthletesEquipe VALUES (165,2270);
INSERT INTO AthletesEquipe VALUES (165,2271);
INSERT INTO AthletesEquipe VALUES (165,2272);
INSERT INTO AthletesEquipe VALUES (165,2273);
INSERT INTO AthletesEquipe VALUES (165,2274);
INSERT INTO AthletesEquipe VALUES (166,2275);
INSERT INTO AthletesEquipe VALUES (166,2276);
INSERT INTO AthletesEquipe VALUES (166,2277);
INSERT INTO AthletesEquipe VALUES (166,2278);
INSERT INTO AthletesEquipe VALUES (166,2279);
INSERT INTO AthletesEquipe VALUES (166,2280);
INSERT INTO AthletesEquipe VALUES (166,2281);
INSERT INTO AthletesEquipe VALUES (166,2282);
INSERT INTO AthletesEquipe VALUES (166,2283);
INSERT INTO AthletesEquipe VALUES (166,2284);
INSERT INTO AthletesEquipe VALUES (166,2285);
INSERT INTO AthletesEquipe VALUES (166,2286);
INSERT INTO AthletesEquipe VALUES (166,2287);
INSERT INTO AthletesEquipe VALUES (166,2288);
INSERT INTO AthletesEquipe VALUES (166,2289);
INSERT INTO AthletesEquipe VALUES (166,2290);
INSERT INTO AthletesEquipe VALUES (166,2291);
INSERT INTO AthletesEquipe VALUES (166,2292);
INSERT INTO AthletesEquipe VALUES (166,2293);
INSERT INTO AthletesEquipe VALUES (166,2294);
INSERT INTO AthletesEquipe VALUES (166,2295);
INSERT INTO AthletesEquipe VALUES (166,2296);
INSERT INTO AthletesEquipe VALUES (166,2297);
INSERT INTO AthletesEquipe VALUES (166,2298);
INSERT INTO AthletesEquipe VALUES (166,2299);
INSERT INTO AthletesEquipe VALUES (168,2300);
INSERT INTO AthletesEquipe VALUES (168,2301);
INSERT INTO AthletesEquipe VALUES (169,2302);
INSERT INTO AthletesEquipe VALUES (169,2303);
INSERT INTO AthletesEquipe VALUES (170,2304);
INSERT INTO AthletesEquipe VALUES (170,2305);
INSERT INTO AthletesEquipe VALUES (171,2306);
INSERT INTO AthletesEquipe VALUES (171,2307);
INSERT INTO AthletesEquipe VALUES (172,2308);
INSERT INTO AthletesEquipe VALUES (172,2309);
INSERT INTO AthletesEquipe VALUES (173,2310);
INSERT INTO AthletesEquipe VALUES (173,2311);
INSERT INTO AthletesEquipe VALUES (174,2312);
INSERT INTO AthletesEquipe VALUES (174,2313);
INSERT INTO AthletesEquipe VALUES (175,2314);
INSERT INTO AthletesEquipe VALUES (175,2315);
INSERT INTO AthletesEquipe VALUES (176,2316);
INSERT INTO AthletesEquipe VALUES (176,2317);
INSERT INTO AthletesEquipe VALUES (177,2318);
INSERT INTO AthletesEquipe VALUES (177,2319);
INSERT INTO AthletesEquipe VALUES (178,2320);
INSERT INTO AthletesEquipe VALUES (178,2321);
INSERT INTO AthletesEquipe VALUES (179,2322);
INSERT INTO AthletesEquipe VALUES (179,2323);
INSERT INTO AthletesEquipe VALUES (180,2324);
INSERT INTO AthletesEquipe VALUES (180,2325);
INSERT INTO AthletesEquipe VALUES (181,2326);
INSERT INTO AthletesEquipe VALUES (181,2327);
INSERT INTO AthletesEquipe VALUES (182,2328);
INSERT INTO AthletesEquipe VALUES (182,2329);
INSERT INTO AthletesEquipe VALUES (183,2330);
INSERT INTO AthletesEquipe VALUES (183,2331);
INSERT INTO AthletesEquipe VALUES (184,2332);
INSERT INTO AthletesEquipe VALUES (184,2333);
INSERT INTO AthletesEquipe VALUES (185,2334);
INSERT INTO AthletesEquipe VALUES (185,2335);
INSERT INTO AthletesEquipe VALUES (186,2336);
INSERT INTO AthletesEquipe VALUES (186,2337);
INSERT INTO AthletesEquipe VALUES (187,16);
INSERT INTO AthletesEquipe VALUES (187,39);
INSERT INTO AthletesEquipe VALUES (187,2300);
INSERT INTO AthletesEquipe VALUES (187,2301);
INSERT INTO AthletesEquipe VALUES (188,166);
INSERT INTO AthletesEquipe VALUES (188,249);
INSERT INTO AthletesEquipe VALUES (188,2308);
INSERT INTO AthletesEquipe VALUES (188,2309);
INSERT INTO AthletesEquipe VALUES (189,288);
INSERT INTO AthletesEquipe VALUES (189,2304);
INSERT INTO AthletesEquipe VALUES (189,2305);
INSERT INTO AthletesEquipe VALUES (189,344);
INSERT INTO AthletesEquipe VALUES (190,489);
INSERT INTO AthletesEquipe VALUES (190,2306);
INSERT INTO AthletesEquipe VALUES (190,2307);
INSERT INTO AthletesEquipe VALUES (190,1379);
INSERT INTO AthletesEquipe VALUES (191,2310);
INSERT INTO AthletesEquipe VALUES (191,2311);
INSERT INTO AthletesEquipe VALUES (191,2338);
INSERT INTO AthletesEquipe VALUES (191,968);
INSERT INTO AthletesEquipe VALUES (192,305);
INSERT INTO AthletesEquipe VALUES (192,2320);
INSERT INTO AthletesEquipe VALUES (192,2321);
INSERT INTO AthletesEquipe VALUES (192,1389);
INSERT INTO AthletesEquipe VALUES (193,2302);
INSERT INTO AthletesEquipe VALUES (193,2303);
INSERT INTO AthletesEquipe VALUES (193,976);
INSERT INTO AthletesEquipe VALUES (193,1392);
INSERT INTO AthletesEquipe VALUES (194,964);
INSERT INTO AthletesEquipe VALUES (194,1378);
INSERT INTO AthletesEquipe VALUES (194,2328);
INSERT INTO AthletesEquipe VALUES (194,2329);
INSERT INTO AthletesEquipe VALUES (195,2324);
INSERT INTO AthletesEquipe VALUES (195,2325);
INSERT INTO AthletesEquipe VALUES (195,974);
INSERT INTO AthletesEquipe VALUES (195,1212);
INSERT INTO AthletesEquipe VALUES (196,536);
INSERT INTO AthletesEquipe VALUES (196,2322);
INSERT INTO AthletesEquipe VALUES (196,1383);
INSERT INTO AthletesEquipe VALUES (196,2323);
INSERT INTO AthletesEquipe VALUES (197,549);
INSERT INTO AthletesEquipe VALUES (197,2332);
INSERT INTO AthletesEquipe VALUES (197,2333);
INSERT INTO AthletesEquipe VALUES (197,1390);
INSERT INTO AthletesEquipe VALUES (198,1387);
INSERT INTO AthletesEquipe VALUES (198,2334);
INSERT INTO AthletesEquipe VALUES (198,1391);
INSERT INTO AthletesEquipe VALUES (198,2335);
INSERT INTO AthletesEquipe VALUES (199,2339);
INSERT INTO AthletesEquipe VALUES (199,2340);
INSERT INTO AthletesEquipe VALUES (200,2341);
INSERT INTO AthletesEquipe VALUES (200,2342);
INSERT INTO AthletesEquipe VALUES (201,2343);
INSERT INTO AthletesEquipe VALUES (201,2344);
INSERT INTO AthletesEquipe VALUES (202,2345);
INSERT INTO AthletesEquipe VALUES (202,2346);
INSERT INTO AthletesEquipe VALUES (203,2347);
INSERT INTO AthletesEquipe VALUES (203,2348);
INSERT INTO AthletesEquipe VALUES (204,2349);
INSERT INTO AthletesEquipe VALUES (204,2350);
INSERT INTO AthletesEquipe VALUES (205,2351);
INSERT INTO AthletesEquipe VALUES (205,2352);
INSERT INTO AthletesEquipe VALUES (206,2353);
INSERT INTO AthletesEquipe VALUES (206,2354);
INSERT INTO AthletesEquipe VALUES (207,2355);
INSERT INTO AthletesEquipe VALUES (207,2356);
INSERT INTO AthletesEquipe VALUES (208,2357);
INSERT INTO AthletesEquipe VALUES (208,2358);
INSERT INTO AthletesEquipe VALUES (209,2359);
INSERT INTO AthletesEquipe VALUES (209,2360);
INSERT INTO AthletesEquipe VALUES (210,2361);
INSERT INTO AthletesEquipe VALUES (210,2362);
INSERT INTO AthletesEquipe VALUES (211,2363);
INSERT INTO AthletesEquipe VALUES (211,2364);
INSERT INTO AthletesEquipe VALUES (212,2365);
INSERT INTO AthletesEquipe VALUES (212,2366);
INSERT INTO AthletesEquipe VALUES (213,2367);
INSERT INTO AthletesEquipe VALUES (213,2368);
INSERT INTO AthletesEquipe VALUES (214,2369);
INSERT INTO AthletesEquipe VALUES (214,2370);
INSERT INTO AthletesEquipe VALUES (215,2371);
INSERT INTO AthletesEquipe VALUES (215,2372);
INSERT INTO AthletesEquipe VALUES (216,2373);
INSERT INTO AthletesEquipe VALUES (216,2374);
INSERT INTO AthletesEquipe VALUES (217,2375);
INSERT INTO AthletesEquipe VALUES (217,2376);
INSERT INTO AthletesEquipe VALUES (218,2377);
INSERT INTO AthletesEquipe VALUES (218,2378);
INSERT INTO AthletesEquipe VALUES (219,2379);
INSERT INTO AthletesEquipe VALUES (219,2380);
INSERT INTO AthletesEquipe VALUES (220,2381);
INSERT INTO AthletesEquipe VALUES (220,2382);
INSERT INTO AthletesEquipe VALUES (221,2383);
INSERT INTO AthletesEquipe VALUES (221,2384);
INSERT INTO AthletesEquipe VALUES (222,2385);
INSERT INTO AthletesEquipe VALUES (222,2386);
INSERT INTO AthletesEquipe VALUES (223,2387);
INSERT INTO AthletesEquipe VALUES (223,2388);
INSERT INTO AthletesEquipe VALUES (224,2389);
INSERT INTO AthletesEquipe VALUES (224,2390);
INSERT INTO AthletesEquipe VALUES (225,2391);
INSERT INTO AthletesEquipe VALUES (225,2392);
INSERT INTO AthletesEquipe VALUES (226,2393);
INSERT INTO AthletesEquipe VALUES (226,2394);
INSERT INTO AthletesEquipe VALUES (226,2395);
INSERT INTO AthletesEquipe VALUES (226,2396);
INSERT INTO AthletesEquipe VALUES (226,2397);
INSERT INTO AthletesEquipe VALUES (226,2398);
INSERT INTO AthletesEquipe VALUES (226,2399);
INSERT INTO AthletesEquipe VALUES (226,2400);
INSERT INTO AthletesEquipe VALUES (226,2401);
INSERT INTO AthletesEquipe VALUES (226,2402);
INSERT INTO AthletesEquipe VALUES (227,2403);
INSERT INTO AthletesEquipe VALUES (227,2404);
INSERT INTO AthletesEquipe VALUES (227,2405);
INSERT INTO AthletesEquipe VALUES (227,2406);
INSERT INTO AthletesEquipe VALUES (227,2407);
INSERT INTO AthletesEquipe VALUES (227,2408);
INSERT INTO AthletesEquipe VALUES (227,2409);
INSERT INTO AthletesEquipe VALUES (227,2410);
INSERT INTO AthletesEquipe VALUES (227,2411);
INSERT INTO AthletesEquipe VALUES (228,2412);
INSERT INTO AthletesEquipe VALUES (228,2413);
INSERT INTO AthletesEquipe VALUES (228,2414);
INSERT INTO AthletesEquipe VALUES (228,2415);
INSERT INTO AthletesEquipe VALUES (228,2416);
INSERT INTO AthletesEquipe VALUES (228,2417);
INSERT INTO AthletesEquipe VALUES (228,2418);
INSERT INTO AthletesEquipe VALUES (228,2419);
INSERT INTO AthletesEquipe VALUES (236,5);
INSERT INTO AthletesEquipe VALUES (236,131);
INSERT INTO AthletesEquipe VALUES (236,46);
INSERT INTO AthletesEquipe VALUES (237,205);
INSERT INTO AthletesEquipe VALUES (237,206);
INSERT INTO AthletesEquipe VALUES (237,207);
INSERT INTO AthletesEquipe VALUES (238,8);
INSERT INTO AthletesEquipe VALUES (238,74);
INSERT INTO AthletesEquipe VALUES (238,62);
INSERT INTO AthletesEquipe VALUES (239,277);
INSERT INTO AthletesEquipe VALUES (239,278);
INSERT INTO AthletesEquipe VALUES (239,279);
INSERT INTO AthletesEquipe VALUES (240,135);
INSERT INTO AthletesEquipe VALUES (240,149);
INSERT INTO AthletesEquipe VALUES (240,34);
INSERT INTO AthletesEquipe VALUES (240,2420);
INSERT INTO AthletesEquipe VALUES (241,189);
INSERT INTO AthletesEquipe VALUES (241,264);
INSERT INTO AthletesEquipe VALUES (241,168);
INSERT INTO AthletesEquipe VALUES (241,271);
INSERT INTO AthletesEquipe VALUES (242,184);
INSERT INTO AthletesEquipe VALUES (242,360);
INSERT INTO AthletesEquipe VALUES (242,361);
INSERT INTO AthletesEquipe VALUES (242,362);
INSERT INTO AthletesEquipe VALUES (243,17);
INSERT INTO AthletesEquipe VALUES (243,1149);
INSERT INTO AthletesEquipe VALUES (243,2421);
INSERT INTO AthletesEquipe VALUES (243,148);
INSERT INTO AthletesEquipe VALUES (244,134);
INSERT INTO AthletesEquipe VALUES (244,2422);
INSERT INTO AthletesEquipe VALUES (244,3);
INSERT INTO AthletesEquipe VALUES (244,76);
INSERT INTO AthletesEquipe VALUES (245,208);
INSERT INTO AthletesEquipe VALUES (245,186);
INSERT INTO AthletesEquipe VALUES (245,265);
INSERT INTO AthletesEquipe VALUES (245,273);
INSERT INTO AthletesEquipe VALUES (246,376);
INSERT INTO AthletesEquipe VALUES (246,211);
INSERT INTO AthletesEquipe VALUES (246,2423);
INSERT INTO AthletesEquipe VALUES (246,377);
INSERT INTO AthletesEquipe VALUES (247,597);
INSERT INTO AthletesEquipe VALUES (247,2424);
INSERT INTO AthletesEquipe VALUES (247,359);
INSERT INTO AthletesEquipe VALUES (247,1147);
INSERT INTO AthletesEquipe VALUES (248,1133);
INSERT INTO AthletesEquipe VALUES (248,2425);
INSERT INTO AthletesEquipe VALUES (248,1494);
INSERT INTO AthletesEquipe VALUES (248,1495);
INSERT INTO AthletesEquipe VALUES (249,130);
INSERT INTO AthletesEquipe VALUES (249,75);
INSERT INTO AthletesEquipe VALUES (249,139);
INSERT INTO AthletesEquipe VALUES (249,151);
INSERT INTO AthletesEquipe VALUES (250,11);
INSERT INTO AthletesEquipe VALUES (250,56);
INSERT INTO AthletesEquipe VALUES (250,274);
INSERT INTO AthletesEquipe VALUES (250,275);
INSERT INTO AthletesEquipe VALUES (251,171);
INSERT INTO AthletesEquipe VALUES (251,310);
INSERT INTO AthletesEquipe VALUES (251,350);
INSERT INTO AthletesEquipe VALUES (251,378);
INSERT INTO AthletesEquipe VALUES (252,45);
INSERT INTO AthletesEquipe VALUES (252,628);
INSERT INTO AthletesEquipe VALUES (252,1070);
INSERT INTO AthletesEquipe VALUES (252,1507);
INSERT INTO AthletesEquipe VALUES (253,301);
INSERT INTO AthletesEquipe VALUES (253,618);
INSERT INTO AthletesEquipe VALUES (253,204);
INSERT INTO AthletesEquipe VALUES (253,1075);
INSERT INTO AthletesEquipe VALUES (254,289);
INSERT INTO AthletesEquipe VALUES (254,349);
INSERT INTO AthletesEquipe VALUES (254,1170);
INSERT INTO AthletesEquipe VALUES (254,1520);
INSERT INTO AthletesEquipe VALUES (255,400);
INSERT INTO AthletesEquipe VALUES (255,419);
INSERT INTO AthletesEquipe VALUES (255,504);
INSERT INTO AthletesEquipe VALUES (255,1079);
INSERT INTO AthletesEquipe VALUES (256,175);
INSERT INTO AthletesEquipe VALUES (256,307);
INSERT INTO AthletesEquipe VALUES (256,1532);
INSERT INTO AthletesEquipe VALUES (256,1533);
INSERT INTO AthletesEquipe VALUES (257,507);
INSERT INTO AthletesEquipe VALUES (257,508);
INSERT INTO AthletesEquipe VALUES (257,1511);
INSERT INTO AthletesEquipe VALUES (257,1521);
INSERT INTO AthletesEquipe VALUES (258,476);
INSERT INTO AthletesEquipe VALUES (258,1076);
INSERT INTO AthletesEquipe VALUES (258,1077);
INSERT INTO AthletesEquipe VALUES (258,1168);
INSERT INTO AthletesEquipe VALUES (259,393);
INSERT INTO AthletesEquipe VALUES (259,394);
INSERT INTO AthletesEquipe VALUES (259,1073);
INSERT INTO AthletesEquipe VALUES (259,1534);
INSERT INTO AthletesEquipe VALUES (260,1072);
INSERT INTO AthletesEquipe VALUES (260,1082);
INSERT INTO AthletesEquipe VALUES (260,1224);
INSERT INTO AthletesEquipe VALUES (260,1523);
INSERT INTO AthletesEquipe VALUES (261,88);
INSERT INTO AthletesEquipe VALUES (261,53);
INSERT INTO AthletesEquipe VALUES (261,20);
INSERT INTO AthletesEquipe VALUES (261,141);
INSERT INTO AthletesEquipe VALUES (262,169);
INSERT INTO AthletesEquipe VALUES (262,239);
INSERT INTO AthletesEquipe VALUES (262,240);
INSERT INTO AthletesEquipe VALUES (262,181);
INSERT INTO AthletesEquipe VALUES (263,191);
INSERT INTO AthletesEquipe VALUES (263,303);
INSERT INTO AthletesEquipe VALUES (263,18);
INSERT INTO AthletesEquipe VALUES (263,368);
INSERT INTO AthletesEquipe VALUES (264,874);
INSERT INTO AthletesEquipe VALUES (264,876);
INSERT INTO AthletesEquipe VALUES (264,1282);
INSERT INTO AthletesEquipe VALUES (264,1286);
INSERT INTO AthletesEquipe VALUES (265,2);
INSERT INTO AthletesEquipe VALUES (265,811);
INSERT INTO AthletesEquipe VALUES (265,60);
INSERT INTO AthletesEquipe VALUES (265,366);
INSERT INTO AthletesEquipe VALUES (266,809);
INSERT INTO AthletesEquipe VALUES (266,1269);
INSERT INTO AthletesEquipe VALUES (266,1270);
INSERT INTO AthletesEquipe VALUES (266,1271);
INSERT INTO AthletesEquipe VALUES (267,28);
INSERT INTO AthletesEquipe VALUES (267,814);
INSERT INTO AthletesEquipe VALUES (267,829);
INSERT INTO AthletesEquipe VALUES (267,1261);
INSERT INTO AthletesEquipe VALUES (268,827);
INSERT INTO AthletesEquipe VALUES (268,1302);
INSERT INTO AthletesEquipe VALUES (268,1303);
INSERT INTO AthletesEquipe VALUES (268,1304);
INSERT INTO AthletesEquipe VALUES (269,455);
INSERT INTO AthletesEquipe VALUES (269,861);
INSERT INTO AthletesEquipe VALUES (269,1312);
INSERT INTO AthletesEquipe VALUES (269,1327);
INSERT INTO AthletesEquipe VALUES (270,865);
INSERT INTO AthletesEquipe VALUES (270,1332);
INSERT INTO AthletesEquipe VALUES (270,1333);
INSERT INTO AthletesEquipe VALUES (270,1334);
INSERT INTO AthletesEquipe VALUES (271,322);
INSERT INTO AthletesEquipe VALUES (271,857);
INSERT INTO AthletesEquipe VALUES (271,858);
INSERT INTO AthletesEquipe VALUES (271,1341);
INSERT INTO AthletesEquipe VALUES (272,396);
INSERT INTO AthletesEquipe VALUES (272,544);
INSERT INTO AthletesEquipe VALUES (272,816);
INSERT INTO AthletesEquipe VALUES (272,1335);
INSERT INTO AthletesEquipe VALUES (273,872);
INSERT INTO AthletesEquipe VALUES (273,1317);
INSERT INTO AthletesEquipe VALUES (273,1318);
INSERT INTO AthletesEquipe VALUES (273,1319);
INSERT INTO AthletesEquipe VALUES (274,882);
INSERT INTO AthletesEquipe VALUES (274,883);
INSERT INTO AthletesEquipe VALUES (274,884);
INSERT INTO AthletesEquipe VALUES (274,1292);
INSERT INTO AthletesEquipe VALUES (275,2);
INSERT INTO AthletesEquipe VALUES (275,72);
INSERT INTO AthletesEquipe VALUES (276,169);
INSERT INTO AthletesEquipe VALUES (276,181);
INSERT INTO AthletesEquipe VALUES (277,88);
INSERT INTO AthletesEquipe VALUES (277,367);
INSERT INTO AthletesEquipe VALUES (278,191);
INSERT INTO AthletesEquipe VALUES (278,368);
INSERT INTO AthletesEquipe VALUES (279,28);
INSERT INTO AthletesEquipe VALUES (279,814);
INSERT INTO AthletesEquipe VALUES (280,1268);
INSERT INTO AthletesEquipe VALUES (280,1270);
INSERT INTO AthletesEquipe VALUES (281,868);
INSERT INTO AthletesEquipe VALUES (281,2426);
INSERT INTO AthletesEquipe VALUES (282,455);
INSERT INTO AthletesEquipe VALUES (282,880);
INSERT INTO AthletesEquipe VALUES (283,872);
INSERT INTO AthletesEquipe VALUES (283,1319);
INSERT INTO AthletesEquipe VALUES (284,858);
INSERT INTO AthletesEquipe VALUES (284,1341);
INSERT INTO AthletesEquipe VALUES (285,26);
INSERT INTO AthletesEquipe VALUES (285,38);
INSERT INTO AthletesEquipe VALUES (285,12);
INSERT INTO AthletesEquipe VALUES (285,142);
INSERT INTO AthletesEquipe VALUES (286,66);
INSERT INTO AthletesEquipe VALUES (286,167);
INSERT INTO AthletesEquipe VALUES (286,237);
INSERT INTO AthletesEquipe VALUES (286,267);
INSERT INTO AthletesEquipe VALUES (287,312);
INSERT INTO AthletesEquipe VALUES (287,335);
INSERT INTO AthletesEquipe VALUES (287,336);
INSERT INTO AthletesEquipe VALUES (287,337);
INSERT INTO AthletesEquipe VALUES (288,812);
INSERT INTO AthletesEquipe VALUES (288,31);
INSERT INTO AthletesEquipe VALUES (288,210);
INSERT INTO AthletesEquipe VALUES (288,1346);
INSERT INTO AthletesEquipe VALUES (289,32);
INSERT INTO AthletesEquipe VALUES (289,575);
INSERT INTO AthletesEquipe VALUES (289,826);
INSERT INTO AthletesEquipe VALUES (289,1296);
INSERT INTO AthletesEquipe VALUES (290,102);
INSERT INTO AthletesEquipe VALUES (290,847);
INSERT INTO AthletesEquipe VALUES (290,849);
INSERT INTO AthletesEquipe VALUES (290,143);
INSERT INTO AthletesEquipe VALUES (291,569);
INSERT INTO AthletesEquipe VALUES (291,570);
INSERT INTO AthletesEquipe VALUES (291,571);
INSERT INTO AthletesEquipe VALUES (291,1339);
INSERT INTO AthletesEquipe VALUES (292,185);
INSERT INTO AthletesEquipe VALUES (292,528);
INSERT INTO AthletesEquipe VALUES (292,334);
INSERT INTO AthletesEquipe VALUES (292,864);
INSERT INTO AthletesEquipe VALUES (293,170);
INSERT INTO AthletesEquipe VALUES (293,190);
INSERT INTO AthletesEquipe VALUES (293,177);
INSERT INTO AthletesEquipe VALUES (293,1325);
INSERT INTO AthletesEquipe VALUES (294,499);
INSERT INTO AthletesEquipe VALUES (294,822);
INSERT INTO AthletesEquipe VALUES (294,835);
INSERT INTO AthletesEquipe VALUES (294,1287);
INSERT INTO AthletesEquipe VALUES (295,475);
INSERT INTO AthletesEquipe VALUES (295,862);
INSERT INTO AthletesEquipe VALUES (295,887);
INSERT INTO AthletesEquipe VALUES (295,1338);
INSERT INTO AthletesEquipe VALUES (296,1289);
INSERT INTO AthletesEquipe VALUES (296,1290);
INSERT INTO AthletesEquipe VALUES (296,1291);
INSERT INTO AthletesEquipe VALUES (296,1294);
INSERT INTO AthletesEquipe VALUES (297,484);
INSERT INTO AthletesEquipe VALUES (297,807);
INSERT INTO AthletesEquipe VALUES (297,808);
INSERT INTO AthletesEquipe VALUES (297,1276);
INSERT INTO AthletesEquipe VALUES (298,603);
INSERT INTO AthletesEquipe VALUES (298,604);
INSERT INTO AthletesEquipe VALUES (298,843);
INSERT INTO AthletesEquipe VALUES (298,1323);
INSERT INTO AthletesEquipe VALUES (299,625);
INSERT INTO AthletesEquipe VALUES (299,1263);
INSERT INTO AthletesEquipe VALUES (299,1264);
INSERT INTO AthletesEquipe VALUES (299,1266);
INSERT INTO AthletesEquipe VALUES (300,2427);
INSERT INTO AthletesEquipe VALUES (300,2428);
INSERT INTO AthletesEquipe VALUES (300,2429);
INSERT INTO AthletesEquipe VALUES (300,2430);
INSERT INTO AthletesEquipe VALUES (301,102);
INSERT INTO AthletesEquipe VALUES (301,143);
INSERT INTO AthletesEquipe VALUES (302,167);
INSERT INTO AthletesEquipe VALUES (302,71);
INSERT INTO AthletesEquipe VALUES (303,291);
INSERT INTO AthletesEquipe VALUES (303,200);
INSERT INTO AthletesEquipe VALUES (304,112);
INSERT INTO AthletesEquipe VALUES (304,31);
INSERT INTO AthletesEquipe VALUES (305,15);
INSERT INTO AthletesEquipe VALUES (305,2431);
INSERT INTO AthletesEquipe VALUES (306,887);
INSERT INTO AthletesEquipe VALUES (306,1338);
INSERT INTO AthletesEquipe VALUES (307,266);
INSERT INTO AthletesEquipe VALUES (307,1325);
INSERT INTO AthletesEquipe VALUES (308,407);
INSERT INTO AthletesEquipe VALUES (308,1279);
INSERT INTO AthletesEquipe VALUES (309,334);
INSERT INTO AthletesEquipe VALUES (309,864);


INSERT INTO RangEquipe VALUES (5,1,1);
INSERT INTO RangEquipe VALUES (5,2,2);
INSERT INTO RangEquipe VALUES (5,3,3);
INSERT INTO RangEquipe VALUES (5,4,4);
INSERT INTO RangEquipe VALUES (5,5,5);
INSERT INTO RangEquipe VALUES (5,6,6);
INSERT INTO RangEquipe VALUES (5,7,7);
INSERT INTO RangEquipe VALUES (5,8,8);
INSERT INTO RangEquipe VALUES (5,9,9);
INSERT INTO RangEquipe VALUES (5,10,10);
INSERT INTO RangEquipe VALUES (5,11,11);
INSERT INTO RangEquipe VALUES (5,12,12);
INSERT INTO RangEquipe VALUES (5,13,13);
INSERT INTO RangEquipe VALUES (5,14,14);
INSERT INTO RangEquipe VALUES (5,15,15);
INSERT INTO RangEquipe VALUES (5,16,16);
INSERT INTO RangEquipe VALUES (10,17,1);
INSERT INTO RangEquipe VALUES (10,18,2);
INSERT INTO RangEquipe VALUES (10,19,3);
INSERT INTO RangEquipe VALUES (10,20,4);
INSERT INTO RangEquipe VALUES (10,21,5);
INSERT INTO RangEquipe VALUES (10,22,6);
INSERT INTO RangEquipe VALUES (10,23,7);
INSERT INTO RangEquipe VALUES (10,24,8);
INSERT INTO RangEquipe VALUES (10,25,9);
INSERT INTO RangEquipe VALUES (10,26,10);
INSERT INTO RangEquipe VALUES (10,27,11);
INSERT INTO RangEquipe VALUES (10,28,12);
INSERT INTO RangEquipe VALUES (10,29,13);
INSERT INTO RangEquipe VALUES (10,30,14);
INSERT INTO RangEquipe VALUES (10,31,15);
INSERT INTO RangEquipe VALUES (10,32,16);
INSERT INTO RangEquipe VALUES (10,33,17);
INSERT INTO RangEquipe VALUES (10,34,18);
INSERT INTO RangEquipe VALUES (10,35,19);
INSERT INTO RangEquipe VALUES (11,36,1);
INSERT INTO RangEquipe VALUES (11,37,2);
INSERT INTO RangEquipe VALUES (11,38,3);
INSERT INTO RangEquipe VALUES (11,39,4);
INSERT INTO RangEquipe VALUES (11,40,5);
INSERT INTO RangEquipe VALUES (11,41,6);
INSERT INTO RangEquipe VALUES (11,42,7);
INSERT INTO RangEquipe VALUES (11,43,8);
INSERT INTO RangEquipe VALUES (11,44,9);
INSERT INTO RangEquipe VALUES (11,45,10);
INSERT INTO RangEquipe VALUES (11,46,11);
INSERT INTO RangEquipe VALUES (11,47,12);
INSERT INTO RangEquipe VALUES (11,48,13);
INSERT INTO RangEquipe VALUES (11,49,14);
INSERT INTO RangEquipe VALUES (11,50,15);
INSERT INTO RangEquipe VALUES (11,51,NULL);
INSERT INTO RangEquipe VALUES (12,52,1);
INSERT INTO RangEquipe VALUES (12,53,2);
INSERT INTO RangEquipe VALUES (12,54,3);
INSERT INTO RangEquipe VALUES (12,55,4);
INSERT INTO RangEquipe VALUES (12,56,5);
INSERT INTO RangEquipe VALUES (12,57,6);
INSERT INTO RangEquipe VALUES (12,58,7);
INSERT INTO RangEquipe VALUES (12,59,8);
INSERT INTO RangEquipe VALUES (12,60,9);
INSERT INTO RangEquipe VALUES (12,61,10);
INSERT INTO RangEquipe VALUES (12,62,11);
INSERT INTO RangEquipe VALUES (12,63,12);
INSERT INTO RangEquipe VALUES (12,64,13);
INSERT INTO RangEquipe VALUES (12,65,14);
INSERT INTO RangEquipe VALUES (12,66,15);
INSERT INTO RangEquipe VALUES (12,67,16);
INSERT INTO RangEquipe VALUES (12,68,17);
INSERT INTO RangEquipe VALUES (12,69,18);
INSERT INTO RangEquipe VALUES (12,70,19);
INSERT INTO RangEquipe VALUES (13,71,1);
INSERT INTO RangEquipe VALUES (13,72,2);
INSERT INTO RangEquipe VALUES (13,73,3);
INSERT INTO RangEquipe VALUES (13,74,4);
INSERT INTO RangEquipe VALUES (13,75,5);
INSERT INTO RangEquipe VALUES (13,76,6);
INSERT INTO RangEquipe VALUES (13,77,7);
INSERT INTO RangEquipe VALUES (13,78,8);
INSERT INTO RangEquipe VALUES (13,79,9);
INSERT INTO RangEquipe VALUES (13,80,10);
INSERT INTO RangEquipe VALUES (13,81,11);
INSERT INTO RangEquipe VALUES (13,82,12);
INSERT INTO RangEquipe VALUES (13,83,13);
INSERT INTO RangEquipe VALUES (13,84,14);
INSERT INTO RangEquipe VALUES (13,85,15);
INSERT INTO RangEquipe VALUES (13,86,16);
INSERT INTO RangEquipe VALUES (13,87,17);
INSERT INTO RangEquipe VALUES (13,88,18);
INSERT INTO RangEquipe VALUES (13,89,19);
INSERT INTO RangEquipe VALUES (13,90,20);
INSERT INTO RangEquipe VALUES (13,91,21);
INSERT INTO RangEquipe VALUES (13,92,22);
INSERT INTO RangEquipe VALUES (13,93,23);
INSERT INTO RangEquipe VALUES (13,94,24);
INSERT INTO RangEquipe VALUES (13,95,25);
INSERT INTO RangEquipe VALUES (13,96,26);
INSERT INTO RangEquipe VALUES (13,97,27);
INSERT INTO RangEquipe VALUES (13,98,28);
INSERT INTO RangEquipe VALUES (13,99,29);
INSERT INTO RangEquipe VALUES (13,100,NULL);
INSERT INTO RangEquipe VALUES (14,101,1);
INSERT INTO RangEquipe VALUES (14,102,2);
INSERT INTO RangEquipe VALUES (14,103,3);
INSERT INTO RangEquipe VALUES (14,104,4);
INSERT INTO RangEquipe VALUES (14,105,5);
INSERT INTO RangEquipe VALUES (14,106,6);
INSERT INTO RangEquipe VALUES (14,107,7);
INSERT INTO RangEquipe VALUES (14,108,8);
INSERT INTO RangEquipe VALUES (14,109,9);
INSERT INTO RangEquipe VALUES (14,110,10);
INSERT INTO RangEquipe VALUES (14,111,11);
INSERT INTO RangEquipe VALUES (14,112,12);
INSERT INTO RangEquipe VALUES (14,113,13);
INSERT INTO RangEquipe VALUES (14,114,14);
INSERT INTO RangEquipe VALUES (14,115,15);
INSERT INTO RangEquipe VALUES (14,116,16);
INSERT INTO RangEquipe VALUES (14,117,17);
INSERT INTO RangEquipe VALUES (14,118,18);
INSERT INTO RangEquipe VALUES (14,119,19);
INSERT INTO RangEquipe VALUES (14,120,20);
INSERT INTO RangEquipe VALUES (14,121,21);
INSERT INTO RangEquipe VALUES (14,122,22);
INSERT INTO RangEquipe VALUES (14,123,23);
INSERT INTO RangEquipe VALUES (14,124,24);
INSERT INTO RangEquipe VALUES (14,125,25);
INSERT INTO RangEquipe VALUES (14,126,26);
INSERT INTO RangEquipe VALUES (14,127,27);
INSERT INTO RangEquipe VALUES (14,128,28);
INSERT INTO RangEquipe VALUES (14,129,29);
INSERT INTO RangEquipe VALUES (14,130,NULL);
INSERT INTO RangEquipe VALUES (17,131,1);
INSERT INTO RangEquipe VALUES (17,132,2);
INSERT INTO RangEquipe VALUES (17,133,3);
INSERT INTO RangEquipe VALUES (17,134,4);
INSERT INTO RangEquipe VALUES (17,135,5);
INSERT INTO RangEquipe VALUES (17,136,6);
INSERT INTO RangEquipe VALUES (17,137,7);
INSERT INTO RangEquipe VALUES (17,138,8);
INSERT INTO RangEquipe VALUES (17,139,9);
INSERT INTO RangEquipe VALUES (18,140,1);
INSERT INTO RangEquipe VALUES (18,141,2);
INSERT INTO RangEquipe VALUES (18,142,3);
INSERT INTO RangEquipe VALUES (18,143,4);
INSERT INTO RangEquipe VALUES (18,144,5);
INSERT INTO RangEquipe VALUES (18,145,6);
INSERT INTO RangEquipe VALUES (18,146,7);
INSERT INTO RangEquipe VALUES (18,147,8);
INSERT INTO RangEquipe VALUES (19,148,1);
INSERT INTO RangEquipe VALUES (19,149,2);
INSERT INTO RangEquipe VALUES (19,150,3);
INSERT INTO RangEquipe VALUES (19,151,4);
INSERT INTO RangEquipe VALUES (19,152,5);
INSERT INTO RangEquipe VALUES (19,153,6);
INSERT INTO RangEquipe VALUES (19,154,7);
INSERT INTO RangEquipe VALUES (19,155,8);
INSERT INTO RangEquipe VALUES (20,156,1);
INSERT INTO RangEquipe VALUES (20,157,2);
INSERT INTO RangEquipe VALUES (20,158,3);
INSERT INTO RangEquipe VALUES (20,159,4);
INSERT INTO RangEquipe VALUES (20,160,5);
INSERT INTO RangEquipe VALUES (20,161,6);
INSERT INTO RangEquipe VALUES (20,162,7);
INSERT INTO RangEquipe VALUES (20,163,8);
INSERT INTO RangEquipe VALUES (21,164,1);
INSERT INTO RangEquipe VALUES (21,165,2);
INSERT INTO RangEquipe VALUES (21,166,3);
INSERT INTO RangEquipe VALUES (21,167,4);
INSERT INTO RangEquipe VALUES (24,168,1);
INSERT INTO RangEquipe VALUES (24,169,2);
INSERT INTO RangEquipe VALUES (24,170,3);
INSERT INTO RangEquipe VALUES (24,171,4);
INSERT INTO RangEquipe VALUES (24,172,5);
INSERT INTO RangEquipe VALUES (24,173,6);
INSERT INTO RangEquipe VALUES (24,174,7);
INSERT INTO RangEquipe VALUES (24,175,8);
INSERT INTO RangEquipe VALUES (24,176,9);
INSERT INTO RangEquipe VALUES (24,177,10);
INSERT INTO RangEquipe VALUES (24,178,11);
INSERT INTO RangEquipe VALUES (24,179,12);
INSERT INTO RangEquipe VALUES (24,180,13);
INSERT INTO RangEquipe VALUES (24,181,14);
INSERT INTO RangEquipe VALUES (24,182,15);
INSERT INTO RangEquipe VALUES (24,183,16);
INSERT INTO RangEquipe VALUES (24,184,17);
INSERT INTO RangEquipe VALUES (24,185,18);
INSERT INTO RangEquipe VALUES (24,186,19);
INSERT INTO RangEquipe VALUES (25,187,1);
INSERT INTO RangEquipe VALUES (25,188,2);
INSERT INTO RangEquipe VALUES (25,189,3);
INSERT INTO RangEquipe VALUES (25,190,4);
INSERT INTO RangEquipe VALUES (25,191,5);
INSERT INTO RangEquipe VALUES (25,192,6);
INSERT INTO RangEquipe VALUES (25,193,7);
INSERT INTO RangEquipe VALUES (25,194,8);
INSERT INTO RangEquipe VALUES (25,195,9);
INSERT INTO RangEquipe VALUES (25,196,10);
INSERT INTO RangEquipe VALUES (25,197,11);
INSERT INTO RangEquipe VALUES (25,198,12);
INSERT INTO RangEquipe VALUES (28,199,1);
INSERT INTO RangEquipe VALUES (28,200,2);
INSERT INTO RangEquipe VALUES (28,201,3);
INSERT INTO RangEquipe VALUES (29,202,1);
INSERT INTO RangEquipe VALUES (29,203,2);
INSERT INTO RangEquipe VALUES (29,204,3);
INSERT INTO RangEquipe VALUES (29,205,4);
INSERT INTO RangEquipe VALUES (29,206,5);
INSERT INTO RangEquipe VALUES (29,207,6);
INSERT INTO RangEquipe VALUES (29,208,7);
INSERT INTO RangEquipe VALUES (29,209,8);
INSERT INTO RangEquipe VALUES (29,210,9);
INSERT INTO RangEquipe VALUES (29,211,10);
INSERT INTO RangEquipe VALUES (29,212,11);
INSERT INTO RangEquipe VALUES (29,213,12);
INSERT INTO RangEquipe VALUES (29,214,13);
INSERT INTO RangEquipe VALUES (29,215,14);
INSERT INTO RangEquipe VALUES (29,216,15);
INSERT INTO RangEquipe VALUES (29,217,16);
INSERT INTO RangEquipe VALUES (29,218,17);
INSERT INTO RangEquipe VALUES (29,219,18);
INSERT INTO RangEquipe VALUES (29,220,19);
INSERT INTO RangEquipe VALUES (29,221,20);
INSERT INTO RangEquipe VALUES (29,222,NULL);
INSERT INTO RangEquipe VALUES (29,223,NULL);
INSERT INTO RangEquipe VALUES (29,224,NULL);
INSERT INTO RangEquipe VALUES (29,225,NULL);
INSERT INTO RangEquipe VALUES (30,226,1);
INSERT INTO RangEquipe VALUES (30,227,2);
INSERT INTO RangEquipe VALUES (30,228,3);
INSERT INTO RangEquipe VALUES (30,229,4);
INSERT INTO RangEquipe VALUES (30,230,5);
INSERT INTO RangEquipe VALUES (30,231,6);
INSERT INTO RangEquipe VALUES (30,232,7);
INSERT INTO RangEquipe VALUES (30,233,8);
INSERT INTO RangEquipe VALUES (30,234,9);
INSERT INTO RangEquipe VALUES (30,235,10);
INSERT INTO RangEquipe VALUES (36,236,1);
INSERT INTO RangEquipe VALUES (36,237,2);
INSERT INTO RangEquipe VALUES (42,238,1);
INSERT INTO RangEquipe VALUES (42,239,2);
INSERT INTO RangEquipe VALUES (46,240,1);
INSERT INTO RangEquipe VALUES (46,241,2);
INSERT INTO RangEquipe VALUES (46,242,3);
INSERT INTO RangEquipe VALUES (46,243,NULL);
INSERT INTO RangEquipe VALUES (50,244,1);
INSERT INTO RangEquipe VALUES (50,245,2);
INSERT INTO RangEquipe VALUES (50,246,3);
INSERT INTO RangEquipe VALUES (50,247,4);
INSERT INTO RangEquipe VALUES (50,248,5);
INSERT INTO RangEquipe VALUES (53,249,1);
INSERT INTO RangEquipe VALUES (53,250,2);
INSERT INTO RangEquipe VALUES (53,251,3);
INSERT INTO RangEquipe VALUES (53,252,4);
INSERT INTO RangEquipe VALUES (53,253,5);
INSERT INTO RangEquipe VALUES (53,254,6);
INSERT INTO RangEquipe VALUES (53,255,7);
INSERT INTO RangEquipe VALUES (53,256,8);
INSERT INTO RangEquipe VALUES (53,257,9);
INSERT INTO RangEquipe VALUES (53,258,10);
INSERT INTO RangEquipe VALUES (53,259,11);
INSERT INTO RangEquipe VALUES (53,260,12);
INSERT INTO RangEquipe VALUES (79,261,1);
INSERT INTO RangEquipe VALUES (79,262,2);
INSERT INTO RangEquipe VALUES (79,263,3);
INSERT INTO RangEquipe VALUES (79,264,4);
INSERT INTO RangEquipe VALUES (79,265,5);
INSERT INTO RangEquipe VALUES (79,266,6);
INSERT INTO RangEquipe VALUES (79,267,7);
INSERT INTO RangEquipe VALUES (79,268,8);
INSERT INTO RangEquipe VALUES (79,269,9);
INSERT INTO RangEquipe VALUES (79,270,10);
INSERT INTO RangEquipe VALUES (79,271,11);
INSERT INTO RangEquipe VALUES (79,272,12);
INSERT INTO RangEquipe VALUES (79,273,13);
INSERT INTO RangEquipe VALUES (79,274,14);
INSERT INTO RangEquipe VALUES (82,275,1);
INSERT INTO RangEquipe VALUES (82,276,2);
INSERT INTO RangEquipe VALUES (82,277,3);
INSERT INTO RangEquipe VALUES (82,278,4);
INSERT INTO RangEquipe VALUES (82,279,5);
INSERT INTO RangEquipe VALUES (82,280,6);
INSERT INTO RangEquipe VALUES (82,281,7);
INSERT INTO RangEquipe VALUES (82,282,8);
INSERT INTO RangEquipe VALUES (82,283,9);
INSERT INTO RangEquipe VALUES (82,284,10);
INSERT INTO RangEquipe VALUES (85,285,1);
INSERT INTO RangEquipe VALUES (85,286,2);
INSERT INTO RangEquipe VALUES (85,287,3);
INSERT INTO RangEquipe VALUES (85,288,4);
INSERT INTO RangEquipe VALUES (85,289,5);
INSERT INTO RangEquipe VALUES (85,290,6);
INSERT INTO RangEquipe VALUES (85,291,7);
INSERT INTO RangEquipe VALUES (85,292,8);
INSERT INTO RangEquipe VALUES (85,293,9);
INSERT INTO RangEquipe VALUES (85,294,10);
INSERT INTO RangEquipe VALUES (85,295,11);
INSERT INTO RangEquipe VALUES (85,296,12);
INSERT INTO RangEquipe VALUES (85,297,13);
INSERT INTO RangEquipe VALUES (85,298,14);
INSERT INTO RangEquipe VALUES (85,299,15);
INSERT INTO RangEquipe VALUES (85,300,16);
INSERT INTO RangEquipe VALUES (88,301,1);
INSERT INTO RangEquipe VALUES (88,302,2);
INSERT INTO RangEquipe VALUES (88,303,3);
INSERT INTO RangEquipe VALUES (88,304,4);
INSERT INTO RangEquipe VALUES (88,305,5);
INSERT INTO RangEquipe VALUES (88,306,6);
INSERT INTO RangEquipe VALUES (88,307,7);
INSERT INTO RangEquipe VALUES (88,308,8);
INSERT INTO RangEquipe VALUES (88,309,9);
